#	sniffUpdateFile.VSS.sh
#
#	SNiFF+ V3.0
#
#	Copyright (C) 1994-1997 TakeFive Software GmbH
#	Salzburg, Austria (e-mail: sniff@TakeFive.co.at)
#
#	Author: Sandor Korosi
#
#	Shell script for PVCS Version Manager Interface.
#	Update private file in the private working environment: 
#		- touch private file if it is writable and project is shared
#		- or remove private file if shared file is up-to-date
#		- or check out file into private working environment if private 
#		  file is not up-to-date
#
#       Usage: 
#       sniffUpdateFile.PVCS.sh  WorkingDir  FileTypeDir  File  RepositoryDir
#                               [-r Revision]  SWS [OWS [Delimiter [Null-device]]]
#
#       WorkingDir    - working directory of the file (with file-type directory)
#       FileTypeDir   - file-type directory
#       File          - file name
#       RepositoryDir - repository directory of the project
#       TemporaryDir  - temporary directory 
#
#       17.2.95 Max Weninger
#               set variable 'ARCHIVE' without 'TYPE_DIR' if 'TYPE_DIR' is empty

WORK_DIR=$1 
TYPE_DIR=$2
FILE=$3
WORKFILE=$1/$FILE
ARCHIVE=$4	# SNiFF+ automatically expands full ReposPath including FileTypeDir's when called from the adaptor.
DEBUG="0"
SYSTEM=Unix
D=:
if [ "$5" = "-V" ]
then
	REVISION=$6
	shift 2
else
	REVISION=
fi
SWS=$5
if [ "$7" != "" ]
then
	SYSTEM=$7
fi
if [ "$8" != "" ]
then
	D=$8
fi
 
if [ "$SYSTEM" = "Windows" ]
then
	IS_WINDOWS=1
	# note: echo "$SNIFF_DIR" won't work since the \ already get expanded
	SNIFF_DIR="`env | grep '^SNIFF_DIR=' | sed -e 's,\\\\,/,g' -e 's,^[^=]*=,,'`" export SNIFF_DIR
	SWS=`sh -c "echo \"$SWS\""` # ensure full expansion (variable $SNIFF_DIR)
	SWS="`echo $SWS | sed -e 's,\\\\,/,g' `"
else
	IS_WINDOWS=0
fi

if [ "$SNIFF_VSS_USER" != "" ]; then
	VSS_GLOBAL_OPTS="-Y$SNIFF_VSS_USER"
fi

# SourceSafe expects \-style pathnames
WORK_DIR="`echo $WORK_DIR | sed -e 's,/,\\\\\\\\,g' `"
# SourceSafe-specific command for check out file without lock
CHECK_OUT="ss get -V$REVISION \"$ARCHIVE/$FILE\" -GL$WORK_DIR -I-Y \"-O&-\" $VSS_GLOBAL_OPTS"
 
# SourceSafe-specific command for check whether the files are out-of-date
DIFF="ss diff -du \"$ARCHIVE/$FILE\" -V$REVISION \"-O&-\" $VSS_GLOBAL_OPTS"	# Note that the target file will be added later on!
 
# SourceSafe expects \-style pathnames
SS_WORKFILE="`echo $WORKFILE | sed -e 's,/,\\\\\\\\,g' `"
 
# exit if private file has no repository file 
	SS_DIR="ss dir \"$ARCHIVE/$FILE\" \"-O&-\" $VSS_GLOBAL_OPTS";
	ret=eval $SS_DIR;
if [ $? != 0 ]
then
	echo "File @B$FILE@B has no repository file ($ARCHIVE)"
	exit 0
fi

# if private file is writable
if [ -w $WORKFILE ] 
then
	# if project is shared
	if [ "$SWS" != "" ]
	then
		# if private file is a symbolic link
		if [ -h $WORKFILE ]
		then
			exit 0
		fi
	fi
	echo "Touching local writable file @B$FILE@B"
	if [ "$DEBUG" = "1" ]
	then
		echo touch $WORKFILE
	fi
	touch $WORKFILE
	exit 0
fi

# if private file is writable for other user and it isn't a symbolic link
if [ "$IS_WINDOWS" = "0" ] 
then
	if [ -f $WORKFILE -a ! -h $WORKFILE ]
	then
	if [ "`ls -l $WORKFILE | awk '{print $1}' | grep w`" != "" ] 
	then
		echo "Warning: Private file @B$FILE@B is writable for other user"
		exit 0
	fi
	fi
fi

# if project is not shared
if [ "$SWS" = "" ]
then
	# if private file is not up-to-date
	if [ "$DEBUG" = "1" ]
	then
		echo $DIFF $SS_WORKFILE
	fi
	eval $DIFF $SS_WORKFILE
	ret=$?
 
	if [ $ret = 1 ]
	then
		echo "-> Checking @B$FILE@B out"
		# check out local
		if [ "$DEBUG" = "1" ]
		then
			echo $CHECK_OUT
		fi
		eval $CHECK_OUT
	else
		if [ $ret = 2 ]
		then
			exit 1
		fi
	fi
	exit 0
fi

# project is shared
SHARED_FILE=
# if private file does not exist
if [ ! -r $WORKFILE ]
then
	# file is shared
	# search shared file in SWS
	for DIR in $SWS
	do
		SHARED_FILE=$DIR/$TYPE_DIR/$FILE
		if [ -r $SHARED_FILE ]
		then
			break
		else
			SHARED_FILE=
		fi
	done
	# if shared file is not found
	if [ "$SHARED_FILE" = "" ] 
	then
		# check out local
		echo "-> Checking @B$FILE@B out"
		if [ "$DEBUG" = "1" ]
		then
			echo $CHECK_OUT
		fi
		eval $CHECK_OUT
	else
		#SourceSafe expects \-style pathnames
		SS_SHARED_FILE="`echo $SHARED_FILE | sed -e 's,/,\\\\\\\\,g' `"
		if [ "$DEBUG" = "1" ]
		then
			echo $DIFF $SS_SHARED_FILE
		fi
		eval $DIFF $SS_SHARED_FILE
		ret=$?
		#  if shared file is not up-to-date
		if [ $ret = 1 ]
		then
			# check out local
			echo "-> Checking @B$FILE@B out"
			if [ "$DEBUG" = "1" ]
			then
				echo $CHECK_OUT
			fi
			eval $CHECK_OUT
		else
			if [ $ret = 2 ]
			then
				exit 1
			fi
		fi
	fi
	exit 0
fi

# file is in local WS
# search shared file in SWS
if [ "$IS_WINDOWS" != "1" ]
then
	WORKFILE_INODE=`ls -iL $WORKFILE  | awk '{print $1}'`	# Windows doesn't support inodes
fi
 
for DIR in $SWS
do 
	SHARED_FILE=$DIR/$TYPE_DIR/$FILE
	if [ -r $SHARED_FILE ]
	then
		if [ "$IS_WINDOWS" = "1" ]
		then
			break		# Windows doesn't support inodes
		fi
		SHARED_INODE=`ls -iL $SHARED_FILE | awk '{print $1}'`
		if [ $SHARED_INODE -ne $WORKFILE_INODE ]
		then 
			break
		else
			SHARED_FILE=
		fi
	else
		SHARED_FILE=
	fi
done

# if shared file is not found 
if [ "$SHARED_FILE" = "" ] 
then
	# if private file is not up-to-date
	if [ "$DEBUG" = "1" ]
	then
		echo $DIFF $SS_WORKFILE
	fi
	eval $DIFF $SS_WORKFILE
	ret=$?
	if [ $ret = 1 ]
	then
		# check out local
		echo "-> Checking @B$FILE@B out"
		if [ "$DEBUG" = "1" ]
		then
			echo $CHECK_OUT
		fi
		eval $CHECK_OUT
	else
		if [ $ret = 2 ]
		then
			exit 1
		fi
	fi
	exit 0
fi

#SourceSafe expects \-style pathnames
SS_SHARED_FILE="`echo $SHARED_FILE | sed -e 's,/,\\\\\\\\,g' `"
if [ "$DEBUG" = "1" ]
then
	echo $DIFF $SS_SHARED_FILE
fi
eval $DIFF $SS_SHARED_FILE
ret=$?
 
# if shared file is not up-to-date
if [ $ret = 1 ]
then
	if [ "$DEBUG" = "1" ]
	then
		echo $DIFF $SS_WORKFILE
	fi
	eval $DIFF $SS_WORKFILE
	ret=$?
 
	# if private file is not up-to-date
	if [ $ret = 1 ]
	then
		# check out local
		echo "-> Checking @B$FILE@B out"
		if [ "$DEBUG" = "1" ]
		then
			echo $CHECK_OUT
		fi
		eval $CHECK_OUT
	else
		# if private file is a symbolic link
		if [ -h $WORKFILE ]
		then
			exit 0
		fi
		# private file is up-to-date but shared not
		echo "Touching private read-only file @B$FILE@B"
		if [ "$DEBUG" = "1" ]
		then
			echo touch $WORKFILE
		fi
		touch $WORKFILE
	fi
	exit 0
else
	if [ $ret = 2 ]
	then
		exit 1
	fi
fi

# shared file is up-to-date

# remove local
if [ "$DEBUG" = "1" ]
then
	echo rm -f $WORKFILE
fi
rm -f $WORKFILE
if [ $? = 0 ]
then
	echo "Private file @B$FILE@B is deleted, shared file is used"
	exit 0
fi

# file cannot be deleted
echo "Private file @B$FILE@B cannot be deleted"
exit 1
