/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... GPIO
* FILENAME...... csl_gpio.h
* DATE CREATED.. Wed 09/01/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... CSL service layer
* PREREQUISITS.. 
* VERSION.......  
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:  09/01/1999 
*   MODIFIED: 12/01/1999 Modified for TMS302C54xx
*   MODIFIED: 06/19/2000
*   MODIFIED: 08/21/2001 added new pin control functions
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (service layer interface file for the GPIO module)
*
*
*
\******************************************************************************/
#ifndef __CSL_GPIO_H_
#define __CSL_GPIO_H_

 
#include <csl_chiphal.h>
 
#if (_GPIO_SUPPORT)

#include <_csl.h>
#include <csl_gpiohal.h>

/****************************************\
* GPIO scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CSL_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/****************************************\
* GPIO static macro declarations          
\****************************************/

/****************************************\
* GPIO Register IDs
\****************************************/

/****************************************\
* GPIO PIN Enable and Config Macros
\****************************************/
#define GPIO_GPIO_RMK(tout, dir3, dir2, dir1, dir0)\
(Uint16)((GPIO_FMK(GPIO,TOUT,tout)) |\
         (GPIO_FMK(GPIO,DIR3,dir3)) |\
         (GPIO_FMK(GPIO,DIR2,dir2)) |\
         (GPIO_FMK(GPIO,DIR1,dir1)) |\
         (GPIO_FMK(GPIO,DIR0,dir0)) \
)

#define GPIO_GPIO_RMKS(tout_s, dir3_s, dir2_s, dir1_s, dir0_s)\
(Uint16)((GPIO_FMKS(GPIO,TOUT,tout_s)) |\
         (GPIO_FMKS(GPIO,DIR3,dir3_s)) |\
         (GPIO_FMKS(GPIO,DIR2,dir2_s)) |\
         (GPIO_FMKS(GPIO,DIR1,dir1_s)) |\
         (GPIO_FMKS(GPIO,DIR0,dir0_s)) \
)

#define GPIO_GPIO_DEFAULT                (0x0000u)

#define GPIO_GPIO_TOUT_ENABLE            (0x0001u)
#define GPIO_GPIO_TOUT_DISABLE           (0x0000u)
#define GPIO_GPIO_TOUT_DEFAULT            GPIO_GPIO_TOUT_DISABLE

#define GPIO_GPIO_DIR3_INPUT             (0x0000u)
#define GPIO_GPIO_DIR3_OUTPUT            (0x0001u)
#define GPIO_GPIO_DIR3_DEFAULT           GPIO_GPIO_DIR3_OUTPUT

#define GPIO_GPIO_DIR2_INPUT             (0x0000u)
#define GPIO_GPIO_DIR2_OUTPUT            (0x0001u)
#define GPIO_GPIO_DIR2_DEFAULT           GPIO_GPIO_DIR2_OUTPUT

#define GPIO_GPIO_DIR1_INPUT             (0x0000u)
#define GPIO_GPIO_DIR1_OUTPUT            (0x0001u)
#define GPIO_GPIO_DIR1_DEFAULT           GPIO_GPIO_DIR1_OUTPUT

#define GPIO_GPIO_DIR0_INPUT             (0x0000u)
#define GPIO_GPIO_DIR0_OUTPUT            (0x0001u)
#define GPIO_GPIO_DIR0_DEFAULT           GPIO_GPIO_DIR0_OUTPUT

#define GPIO_GPIO_DAT3_HI                (0x0001u)
#define GPIO_GPIO_DAT3_LOW               (0x0000u)
#define GPIO_GPIO_DAT3_DEFAULT           GPIO_GPIO_DAT3_LOW

#define GPIO_GPIO_DAT2_HI                (0x0001u)
#define GPIO_GPIO_DAT2_LOW               (0x0000u)
#define GPIO_GPIO_DAT2_DEFAULT           GPIO_GPIO_DAT2_LOW

#define GPIO_GPIO_DAT1_HI                (0x0001u)
#define GPIO_GPIO_DAT1_LOW               (0x0000u)
#define GPIO_GPIO_DAT1_DEFAULT           GPIO_GPIO_DAT1_LOW

#define GPIO_GPIO_DAT0_HI                (0x0001u)
#define GPIO_GPIO_DAT0_LOW               (0x0000u)
#define GPIO_GPIO_DAT0_DEFAULT           GPIO_GPIO_DAT0_LOW

#define GPIO_IO3                         ((Uint16)(0x0008))
#define GPIO_IO2                         ((Uint16)(0x0004))
#define GPIO_IO1                         ((Uint16)(0x0002))
#define GPIO_IO0                         ((Uint16)(0x0001))

#define GPIO_PIN3                        ((Uint16)(0x0008))
#define GPIO_PIN2                        ((Uint16)(0x0004))
#define GPIO_PIN1                        ((Uint16)(0x0002))
#define GPIO_PIN0                        ((Uint16)(0x0001))

#define GPIO_OUTPUT                      (0x0001u)
#define GPIO_INPUT                       (0x0000u)

#define GPIO_IO3_OUTPUT                  ((Uint16)(0x0008))
#define GPIO_IO2_OUTPUT                  ((Uint16)(0x0004))
#define GPIO_IO1_OUTPUT                  ((Uint16)(0x0002))
#define GPIO_IO0_OUTPUT                  ((Uint16)(0x0001))


#define GPIO_IO3_INPUT                   ((Uint16)(0x0000))
#define GPIO_IO2_INPUT                   ((Uint16)(0x0000))
#define GPIO_IO1_INPUT                   ((Uint16)(0x0000))
#define GPIO_IO0_INPUT                   ((Uint16)(0x0000))
 
 /*******************************************\
* GPIO: global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area by gpiodata.h */      
 
/****************************************\
* GPIO static typedef declarations
\****************************************/

#define GPIO_direction      _GPIO_pinDirection
#define GPIO_pinEnable      _GPIO_pinEnable
#define GPIO_pinDisable     _GPIO_pinDisable
#define GPIO_pinRead        _PGIO_pinRead
#define GPIO_pinWrite       _PGIO_pinWrite

CSLAPI int _GPIO_pinDirection(Uint32 pinId, Uint16 direction);
CSLAPI int _GPIO_pinWrite(Uint32 pinId, Uint16 val);
CSLAPI int _GPIO_pinDisable(Uint32 pinId);
CSLAPI int _GPIO_pinEnable(Uint32 pinId);
CSLAPI int _GPIO_pinRead(Uint32 pinId);

/****************************************\
* GPIO function declarations        
\****************************************/

#else
   #ifndef _GPIO_MOD_ /* GPIO_SUPPORT */
     #error GPIO Module Not Supported on Specified Target
   #endif
#endif /* GPIO_SUPPORT */

#endif /* _CSL_GPIO_H_ */
/******************************************************************************\
* End of csl_gpio.h
\******************************************************************************/


