/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... HPI
* FILENAME...... hpi.h
* DATE CREATED.. Wed 09/01/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... CSL service layer
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CRETAED:  09/01/1999 
*   MODIFIED: 12/01/1999 modified for TMS302C54xx
*   MODIFIED: 12/15/1999 Added GIO_init()
*   MODIFIED: 06/19/2000 made file names and #ifdefs consistent, cpluplus compatability
*------------------------------------------------------------------------------
* DESCRIPTION:  (service layer interface file for the HPI module)
\******************************************************************************/
#ifndef _CSL_HGPIO_H_
#define _CSL_HGPIO_H_    

#include <csl_chiphal.h>

#if (_HPI_GPIO_SUPPORT)

#include <_csl.h>
#include <csl_hpihal.h> 

/****************************************\
* HPI scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _GPIO_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/****************************************\
* HPI global macro declarations
\****************************************/

#define HPI_IO7                              ((Uint16)(0x0080))
#define HPI_IO6                              ((Uint16)(0x0040))
#define HPI_IO5                              ((Uint16)(0x0020))
#define HPI_IO4                              ((Uint16)(0x0010))
#define HPI_IO3                              ((Uint16)(0x0008))
#define HPI_IO2                              ((Uint16)(0x0004))
#define HPI_IO1                              ((Uint16)(0x0002))
#define HPI_IO0                              ((Uint16)(0x0001))

#define HPI_GPIOSR_IO7_MASK                  ((Uint16)(0x0080))
#define HPI_GPIOSR_IO6_MASK                  ((Uint16)(0x0040))
#define HPI_GPIOSR_IO5_MASK                  ((Uint16)(0x0020))
#define HPI_GPIOSR_IO4_MASK                  ((Uint16)(0x0010))
#define HPI_GPIOSR_IO3_MASK                  ((Uint16)(0x0008))
#define HPI_GPIOSR_IO2_MASK                  ((Uint16)(0x0004))
#define HPI_GPIOSR_IO1_MASK                  ((Uint16)(0x0002))
#define HPI_GPIOSR_IO0_MASK                  ((Uint16)(0x0001))

#if ((CHIP_5402) | (CHIP_5401))
#define HPI_GPIOCR_TOUT1_MASK                ((Uint16)(0x8000))
#endif

#define HPI_GPIOCR_DIR7_MASK                 ((Uint16)(0x0080))
#define HPI_GPIOCR_DIR6_MASK                 ((Uint16)(0x0040))
#define HPI_GPIOCR_DIR5_MASK                 ((Uint16)(0x0020))
#define HPI_GPIOCR_DIR4_MASK                 ((Uint16)(0x0010))
#define HPI_GPIOCR_DIR3_MASK                 ((Uint16)(0x0008))
#define HPI_GPIOCR_DIR2_MASK                 ((Uint16)(0x0004))
#define HPI_GPIOCR_DIR1_MASK                 ((Uint16)(0x0002))
#define HPI_GPIOCR_DIR0_MASK                 ((Uint16)(0x0001))

#define HPI_IO7_INPUT                ((Uint16)(0x0080))
#define HPI_IO6_INPUT                ((Uint16)(0x0040))
#define HPI_IO5_INPUT                ((Uint16)(0x0020))
#define HPI_IO4_INPUT                ((Uint16)(0x0010))
#define HPI_IO3_INPUT                ((Uint16)(0x0008))
#define HPI_IO2_INPUT                ((Uint16)(0x0004))
#define HPI_IO1_INPUT                ((Uint16)(0x0002))
#define HPI_IO0_INPUT                ((Uint16)(0x0001))

#define HPI_IO7_OUTPUT               ((Uint16)(0x0000))
#define HPI_IO6_OUTPUT               ((Uint16)(0x0000))
#define HPI_IO5_OUTPUT               ((Uint16)(0x0000))
#define HPI_IO4_OUTPUT               ((Uint16)(0x0000))
#define HPI_IO3_OUTPUT               ((Uint16)(0x0000))
#define HPI_IO2_OUTPUT               ((Uint16)(0x0000))
#define HPI_IO1_OUTPUT               ((Uint16)(0x0000))
#define HPI_IO0_OUTPUT               ((Uint16)(0x0000))


/*------------------------------------------*\
* Macros to GET/SET register and bit field
* values
\*------------------------------------------*/


/*******************************************\
* HPI global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area by hpidata.h */


/****************************************\
* HPI global variable declarations
\****************************************/

/****************************************\
* HPI global function declarations
\****************************************/

#define GPIO_direction      _HGPIO_pinDirection
#define GPIO_pinEnable      _HGPIO_pinEnable
#define GPIO_pinDisable     _HGPIO_pinDisable
#define GPIO_pinRead        _HGPIO_pinRead
#define GPIO_pinWrite       _HGPIO_pinWrite

CSLAPI int _HGPIO_pinDirection(Uint32 pinId, Uint16 direction);
CSLAPI int _HGPIO_pinWrite(Uint32 pinId, Uint16 val);
CSLAPI int _HGPIO_pinDisable(Uint32 pinId);
CSLAPI int _HGPIO_pinEnable(Uint32 pinId);
CSLAPI int _HGPIO_pinRead(Uint32 pinId);





/****************************************\
* HPI inline function declarations
\****************************************/

/****************************************\
* HPI inline function definitions
\****************************************/
#ifdef USEDEFS
#endif /* USEDEFS */

#else
  #ifndef _HPI_MOD_ /* HPI_SUPPORT */
    #error HPI Module Not Supported on SPecified Target
  #endif
#endif /* HPI_SUPPORT */

#endif /* _CSL_HPI_H_ */
/******************************************************************************\
* End of csl_hpi.h
\******************************************************************************/

