/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/*
 *  ======== c54.h ========
 *  C54 header file
 *
 */

#ifndef C54_
#define C54_

/*
 *  for backwards compatibility ...
 */
#include <atm.h>

#ifdef __cplusplus
extern "C" {
#endif

#define C54_and(dst, src)	( ATM_andu(dst, src), *dst )
#define C54_or(dst, src)	( ATM_oru(dst, src), *dst )

#define C54_clear(dst)		ATM_cleari(dst)
#define C54_set(dst)		ATM_seti(dst)

#define C54_dec(dst)		ATM_deci(dst)
#define C54_inc(dst)		ATM_inci(dst)

/*
 *  Interrupt Vector Id
 */
#define C54_RS		    0x0		/* Hardware RESET */

#define C54_INT0	    0x10	/* External User Interrupt #1 */
#define C54_INT1	    0x11	/* External User Interrupt #2 */
#define C54_INT2	    0x12	/* External User Interrupt #3 */
#define C54_TINT	    0x13	/* Internal Timer Interrupt */
#define C54_BRINT0	    0x14	/* Serial Port Receive Interrupt */
#define C54_BXINT0	    0x15	/* Serial Port Transmit Interrupt */
#define	C54_TRNT 	    0x16	/* TDM Port Receive Interrupt */
#define	C54_TXNT	    0x17	/* TDM Port Transmit Interrupt */
#define C54_INT3	    0x18	/* External User Interrupt #4 */

#ifndef	_CONF_

typedef volatile struct {
    Uns	    reserved;			    /* reserved for operand */
    Fxn	    isr;			    /* for plugged function isr */
} C54_Intvec;

#endif	/* _CONF_ */

/* interrupt mask register, interrupt flag register */
#define	C54_IMR		    (Uns *)0x0
#define C54_IFR		    (Uns *)0x1

#define	C54_MOINT0	    (1 << (C54_INT0 - 16))
#define	C54_MOINT1	    (1 << (C54_INT1 - 16))
#define	C54_MOINT2	    (1 << (C54_INT2 - 16))
#define	C54_MOTINT	    (1 << (C54_TINT - 16))
#define	C54_MOBRINT0	    (1 << (C54_BRINT0 - 16))
#define	C54_MOBXINT0        (1 << (C54_BXINT0 - 16))
#define	C54_MOTRNT	    (1 << (C54_TRNT - 16))
#define	C54_MOTXNT	    (1 << (C54_TXNT - 16))
#define	C54_MOINT3	    (1 << (C54_INT3 - 16))


/* processor mode status register, strongly recommended    *
 * not to modify it except at the system boot time	    */
#define C54_PMST	    (Uns *)0x1d

/* memory mapped I/O port */
#define C54_PA0		    (Uns *)0x50
#define C54_PA1		    (Uns *)0x51
#define C54_PA2		    (Uns *)0x52
#define C54_PA3		    (Uns *)0x53
#define C54_PA4		    (Uns *)0x54
#define C54_PA5		    (Uns *)0x55
#define C54_PA6		    (Uns *)0x56
#define C54_PA7		    (Uns *)0x57
#define C54_PA8		    (Uns *)0x58
#define C54_PA9		    (Uns *)0x59
#define C54_PA10	    (Uns *)0x5a
#define C54_PA11	    (Uns *)0x5b
#define C54_PA12	    (Uns *)0x5c
#define C54_PA13	    (Uns *)0x5d
#define C54_PA14	    (Uns *)0x5e
#define C54_PA15	    (Uns *)0x5f

/*
 *  Peripheral Control, Status and Data Registers
 */

#ifndef	_CONF_

/* Serial port registers */

typedef	volatile struct {
    Uns	    drecvreg;
    Uns	    dtranreg;
    Uns	    ctrlreg;
} C54_SRegs;

#define C54_SPREGS   ((C54_SRegs *)0x0020)	/* serial port registers */


/* C54 Timer */

typedef	volatile struct {
    Uns	    counter;
    Uns	    period;
    Uns	    control;
} C54_TRegs;

#define C54_TIMEREGS   ((C54_TRegs *)0x0024)	/* timer */


/* C54 TDM Serial Port */

typedef	volatile struct {
    Uns	    trcv;		/* data receive register */
    Uns	    tdxr;		/* data transmit register */
    Uns	    tspc;		/* serial port control register */
    Uns	    tcsr;		/* channel select register */
    Uns	    trta;		/* recv/trans address register */
    Uns	    trad;		/* receive address register */
} C54_TDMRegs;

#define C54_TDMREGS   ((C54_TDMRegs *)0x0030)	/* TDM Serial Port */


/*
 *  In line Assembly Macros for C54
 */

/*  disable interrupt */
#define	C54_disable()	    asm("   ssbx    intm");

/* enable interrupt */
#define	C54_enable()	    asm("   rsbx    intm");

extern Void C54_plug(Int devid, Fxn isr ); /* plug interrupt vector */

extern Uns C54_disableIMR(Uns mask);
extern Void C54_enableIMR(Uns mask); 

#endif	/*  _CONF_ */

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* C54_ */
