/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... CHIP
* FILENAME...... CHIP.h
* DATE CREATED.. Thu 08/19/1999 
* PROJECT....... MCRTE - multichannel runtime environment
* COMPONENT..... 
* PREREQUISITS.. stdinc.h, stdinchal.h, chiphal.h
*------------------------------------------------------------------------------
* HISTORY:
*   08/19/1999 (BWC) Created
*   11/23/1999 (KSB) Modified for TMS320C54xx
*  
*------------------------------------------------------------------------------
* DESCRIPTION:  (service layer interface file for the CHIP module)
*
*
*
\******************************************************************************/
#ifndef _CSL_CHIP_H_
#define _CSL_CHIP_H_
 
#include <csl_stdinc.h>
#include <csl_chiphal.h>

 
#if (_CHIP_SUPPORT)
/****************************************\
* CHIP scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CHIP_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* CHIP global macro declarations
\****************************************/
#define _CHIP_ENDIAN_LITTLE 1

/*------------------------------------------------*\
* CHIP MAP                               
*     MAP = 0,   MP/MC, DROM and OVLY bits are OFF
*     MAP = 1,   DROM bit is on
*     MAP = 2,   OVLY bit is on
*     MAP = 3,   Both DROM and OVLY Bits are on
*     MAP = 4,   MP/MC bit is on
*     MAP = 5,   MP/MC and DROM are on
*     MAP = 6,   MP/MC and OVLY bits are on
*     MAP - 7,   MP/MC, DROM, and OVLY bits are on
\*-------------------------------------------------*/
#define CHIP_MAP_0         0
#define CHIP_MAP_1         1
#define CHIP_MAP_2         2
#define CHIP_MAP_3         3
#define CHIP_MAP_4         4
#define CHIP_MAP_5         5
#define CHIP_MAP_6         6
#define CHIP_MAP_7         7    
  
/*******************************************\
* CHIP global macro definition : ROMABILITY
\*******************************************/ 
/* Reserved ROM Area for Chip Data */
            
/* None Data used by CHIP functions */

/****************************************\
* CHIP global typedef declarations
\****************************************/

/****************************************\
* CHIP global variable declarations
\****************************************/

/****************************************\
* CHIP global function declarations
\****************************************/

/****************************************\
* CHIP inline function declarations
\****************************************/
IDECL Uint32 CHIP_getCpuId();
IDECL Uint32 CHIP_getRevId();
#if (CHIP_5440)
IDECL Uint32 CHIP_getSubsysId();
#endif
IDECL Uint16 CHIP_getEndian();
IDECL Uint16 CHIP_getMapMode();



/****************************************\
* CHIP inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
IDEF Uint32 CHIP_getCpuId() {
#if (!(CHIP_5411 | CHIP_5412 | CHIP_5416 | CHIP_5421 | CHIP_5440 | CHIP_5441))
  return (_CHIP_CPU_ID);
#else
  return (Uint32)(CHIP_FGET(CSIDR,CHIPID));
#endif
}

/*----------------------------------------------------------------------------*/
IDEF Uint32 CHIP_getRevId() {
#if (!(CHIP_5411 | CHIP_5412 | CHIP_5416 | CHIP_5421))
   return (_CHIP_RevID);
#else
   return (Uint32)(CHIP_FGET(CSIDR,CHIPREVISION));
#endif
}

/*----------------------------------------------------------------------------*/
IDEF Uint32 CHIP_getSubsysId(){
#if (!(CHIP_5411 | CHIP_5412 | CHIP_5416 | CHIP_5421 | CHIP_5440 | CHIP_5441))
  return 0;
#else
  return (Uint32)(CHIP_FGET(CSIDR,SUBSYSID));
#endif
}

/*----------------------------------------------------------------------------*/
IDEF Uint16 CHIP_getEndian() {
   return _CHIP_ENDIAN_LITTLE;
}

/*----------------------------------------------------------------------------*/
IDEF Uint16 CHIP_getMapMode() {
  return (Uint16) ( (CHIP_FGET(PMST,DROM))|
                    ((CHIP_FGET(PMST,OVLY))<<1)|
                    ((CHIP_FGET(PMST,MPMC))<<2)
                  ); 
}
/*----------------------------------------------------------------------------*/
#endif /* USEDEFS */

#endif /* CHIP_SUPPORT */
#endif /* _CHIP_H_ */
/******************************************************************************\
* End of CHIP.h
\******************************************************************************/

