/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... CHIP
* FILENAME...... chiphal.h
* DATE CREATED.. Thu 08/19/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:  08/19/1999
*   MODIFIED: 06/19/2000
*   MODIFIED: 07/09/2001 added support for 5401 & 5471, removed 5472
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the CHIP module)
* 
* CHIP Control Registers Covered
*   CHIP_ST0     - control status register 0
*   CHIP_ST1     - control status register 1
*   CHIP_IFR     - interrupt flag register
*   CHIP_IMR     - interrupt mask register
*   CHIP_PMST    - processor mode control register
*   CHIP_CSIDR   - device ID register 5411, 5412, 5416, 5421, 5440, 5441
*
\******************************************************************************/
#ifndef _CSL_CHIPHAL_H_
#define _CSL_CHIPHAL_H_
/****************************************\
* include files
\****************************************/
#include <csl_stdinc.h>
#include <csl_stdinch.h>


/****************************************\
* CSL scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CHIP_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

#ifndef CHIP_ALL
  #define CHIP_ALL 0
#else
  #define _CHIP_CPU_ID   5402
  #define _CHIP_RevID    0
#endif

#ifndef CHIP_5401
  #define CHIP_5401 0
#else
  #define _CHIP_CPU_ID   5401
  #define _CHIP_RevID    0
#endif

#ifndef CHIP_5402
  #define CHIP_5402 0
#else
  #define _CHIP_CPU_ID   5402
  #define _CHIP_RevID    0
#endif

#ifndef CHIP_5409
  #define CHIP_5409 0
#else
  #define _CHIP_CPU_ID   5409
  #define _CHIP_RevID    0
#endif

#ifndef CHIP_5409A
  #define CHIP_5409A 0
#else
  #define _CHIP_CPU_ID   5409
  #define _CHIP_RevID    (Uint16)('A')
#endif

#ifndef CHIP_5411
  #define CHIP_5411 0
#else
  #define _CHIP_CPU_ID   5411
  #define _CHIP_RevID    0
#endif

#ifndef CHIP_5412
  #define CHIP_5412 0
#else
  #define _CHIP_CPU_ID   5412
  #define _CHIP_RevID    0
#endif

#ifndef CHIP_5410
  #define CHIP_5410 0
#else
  #define _CHIP_CPU_ID   5410
  #define _CHIP_RevID    0
#endif

#ifndef CHIP_5410A
  #define CHIP_5410A 0
#else
  #define _CHIP_CPU_ID    5410
  #define _CHIP_RevID     (Uint16)('A')
#endif

#ifndef CHIP_5416
  #define CHIP_5416 0
#else
  #define _CHIP_CPU_ID    5416
  #define _CHIP_RevId     0
#endif

#ifndef CHIP_5420
  #define CHIP_5420 0
#else
  #define _CHIP_CPU_ID   5420
  #define _CHIP_RevID    0
#endif
 
#ifndef CHIP_5421
  #define CHIP_5421 0
#else
  #define _CHIP_CPU_ID   5421
  #define _CHIP_RevID    0
#endif   

#ifndef CHIP_5471
  #define CHIP_5471 0
#else
  #define _CHIP_CPU_ID   5471
  #define _CHIP_RevID    0
#endif     

#ifdef CHIP_5470
  #undef CHIP_5471
  #define CHIP_5471 1
#endif  

#ifndef CHIP_5470
  #define CHIP_5470 0
#else
  #define _CHIP_CPU_ID   5470
  #define _CHIP_RevID    0
#endif   


#ifndef CHIP_54CST
   #define CHIP_54CST 0
#else
   #define _CHIP_CPU_ID 5403
   #define _CHIP_RevID  0
#endif

#ifndef CHIP_5403
   #define CHIP_5403 0
#else
   #define _CHIP_CPU_ID 5403
   #define _CHIP_RevID  0
#endif

#ifndef CHIP_5404
   #define CHIP_5404 0
#else
   #define _CHIP_CPU_ID 5404
   #define _CHIP_RevID  0
#endif

#ifndef CHIP_5406
   #define CHIP_5406 0
#else
   #define _CHIP_CPU_ID 5406
   #define _CHIP_RevID 0
#endif

#ifndef CHIP_5407
   #define CHIP_5407 0
#else
   #define _CHIP_CPU_ID 5407
   #define _CHIP_RevID 0
#endif


#ifndef CHIP_5440
  #define CHIP_5440 0
#else
  #define _CHIP_CPU_ID   5440
  #define _CHIP_RevID    0
#endif  

#ifndef CHIP_5441
  #define CHIP_5441 0
#else
  #define _CHIP_CPU_ID   5441
  #define _CHIP_RevID    0
#endif  

#ifndef OS_BIOS
#define OS_BIOS 0
#endif

#ifndef OS_SPOX
#define OS_SPOX 0
#endif

#ifndef OS_BARACUDA
#define OS_BARACUDA 0
#endif


#if (CHIP_ALL | CHIP_5401 | CHIP_5402 | CHIP_5409 | CHIP_5410 | CHIP_5411 | CHIP_5412)
  #define CHIP_SET_A 1
#else
  #define CHIP_SET_A 0
#endif

#if (CHIP_5409A | CHIP_5410A | CHIP_5416 | CHIP_5420 | CHIP_5421 | CHIP_5471 | CHIP_5440 | CHIP_5441)
  #define CHIP_SET_B 1
#else
  #define CHIP_SET_B 0
#endif

#if (CHIP_54CST | CHIP_5403 | CHIP_5404 | CHIP_5406 | CHIP_5407)
  #define CHIP_SET_C 1
#else
  #define CHIP_SET_C 0
#endif

#if (((CHIP_SET_A)==0) && ((CHIP_SET_B)==0) && ((CHIP_SET_C)==0))
#error NO CHIP DEFINED
#endif

#if (CHIP_ALL)
#undef CHIP_5402
#define CHIP_5402 1
#endif

#define CHIP_NONE 0

#define SUPPORT(cX, c0, c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, \
                c11, c12, c13, c14, c15, c16, c17, c18)\
 ( cX*CHIP_ALL|\
   c0*CHIP_5402 |\
   c1*CHIP_5409 |\
   c2*CHIP_5410 |\
   c3*CHIP_5416 |\
   c4*CHIP_5420 |\
   c5*CHIP_5421 |\
   c6*CHIP_5411|\
   c7*CHIP_5412|\
   c8*CHIP_5471|\
   c9*CHIP_5440|\
   c10*CHIP_5409A|\
   c11*CHIP_5410A|\
   c12*CHIP_5441|\
   c13*CHIP_5401|\
   c14*CHIP_54CST|\
   c15*CHIP_5403|\
   c16*CHIP_5406|\
   c17*CHIP_5404|\
   c18*CHIP_5407\
)
                               
 /*----------------------------------------------------------------------------*/
 /*                                     5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5*/
 /*                                     4 4 4 4 4 4 4 4 4 4 4 4 4 4 4 4 4 4 4 4*/
 /*                                     X 0 0 1 1 2 2 1 1 7 4 0 1 4 0 c 0 0 0 0*/
 /*                                     X 2 9 0 6 0 1 1 2 1 0 9 0 1 1 s 3 6 4 7*/
 /*                                                           A A     t        */
 /*----------------------------------------------------------------------------*/ 
#define _CHIP_54XX              SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _CHIP_SUPPORT           SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _CHIP_CPU_ID_SUPPORT    SUPPORT(0,0,0,0,1,0,1,1,1,0,1,0,0,1,0,0,0,0,0,0)
#define _CSLINIT_SUPPORT        SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _CSLLIB_SUPPORT         SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _DMA_SUPPORT            SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _DMA_CH_RLDR_SUPPORT    SUPPORT(1,0,0,0,1,0,1,1,1,0,1,1,1,1,0,0,0,0,0,0)
#define _DMA_EXT_DATA_SUPPORT   SUPPORT(1,0,1,0,1,0,1,1,1,0,1,1,1,1,0,1,1,1,1,1)
#define _DMA_GBL_XDP_SUPPORT    SUPPORT(1,0,1,0,1,0,1,1,1,0,0,1,1,0,0,1,1,1,1,1)
#define _DMA_CH_XDP_SUPPORT     SUPPORT(1,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0)
#define _DMA_NO_EXT_PRG_SUPPORT\
                                SUPPORT(0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,1,1,1,1,1)
#define _ERR_SUPPORT            SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _GPIO_SUPPORT           SUPPORT(0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0)
#define _HPI_GPIO_SUPPORT       SUPPORT(1,1,1,0,1,1,1,1,1,1,0,1,1,0,1,1,1,1,1,1)
#define _HPI_SUPPORT            SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _IRQ_SUPPORT            SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _MCBSP_SUPPORT          SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _MCBSP_ABIS_SUPPORT     SUPPORT(0,0,0,1,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0)
#define _MCBSP_128_CH_ENABLE_SUPPORT\
                                SUPPORT(1,0,0,0,1,0,1,1,1,0,1,1,1,1,0,0,0,0,0,0)
#define _MCBSP_SCLKME_SUPPORT\
                                SUPPORT(1,0,1,0,1,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0)
#define _SIG_SUPPORT            SUPPORT(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
#define _TIMER_SUPPORT          SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _TIMER_PRSC_MODE_SUPPORT\
                                SUPPORT(1,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0)
#define _EBUS_SUPPORT           SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _DAT_SUPPORT            SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _DAA_SUPPORT            SUPPORT(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0)
#define _UART_SUPPORT           SUPPORT(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1)
#define _PWR_SUPPORT            SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
#define _SECUREID_SUPPORT       SUPPORT(0,0,0,0,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0)
#define _WDTIM_SUPPORT          SUPPORT(1,0,0,0,0,0,0,0,1,0,1,0,0,1,0,0,0,0,0,0)
#define _I2C_SUPPORT            SUPPORT(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
#define _USB_SUPPORT            SUPPORT(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
#define _PLL_SUPPORT            SUPPORT(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)

/*----------------------------------------------------------------*/

/******************************************************************\
* Bit Field Manipulation and Data Type Definition Macros
\******************************************************************/
/******************************************************************\
* Bit Field Manipulation and Data Type Definition Macros
\******************************************************************/

#define _CHIP_PERBASE_ADDR      (0x0000u)
#define _CHIP_ST0_ADDR          (0x0006u)
#define _CHIP_ST1_ADDR          (0x0007u)
#define _CHIP_IFR_ADDR          (0x0001u)
#define _CHIP_IMR_ADDR          (0x0000u)
#define _CHIP_PMST_ADDR         (0x001du)

#define _CHIP_IMR               REG16(_CHIP_IMR_ADDR)
#define _CHIP_ST0               REG16(_CHIP_ST0_ADDR)
#define _CHIP_ST1               REG16(_CHIP_ST1_ADDR)
#define _CHIP_IFR               REG16(_CHIP_IFR_ADDR)
#define _CHIP_PMST              REG16(_CHIP_PMST_ADDR)

#define _ST0                     _CHIP_ST0
#define _ST1                     _CHIP_ST1
#define _IFR                     _CHIP_IFR
#define _IMR                     _CHIP_IMR
#define _PMST                    _CHIP_PMST



#define CHIP_ADDR(Reg)              _CHIP_##Reg##_ADDR
#define CHIP_RGET(Reg)              _CHIP_##Reg##_GET()
#define CHIP_RSET(Reg,Val)          _CHIP_##Reg##_SET(Val)
#define CHIP_RAOI(Reg,AND,OR,INV)   _CHIP_##Reg##_AOI(AND,OR,INV)
#define CHIP_FGET(Reg,Field)        _CHIP_##Reg##_FGET(Field)
#define CHIP_FSET(Reg,Field,Val)    _CHIP_##Reg##_FSET(Field,Val)
#define CHIP_FAOI(Reg,Field,AND,OR,INV)  _CHIP_##Reg##_FAOI(Field,AND,OR,INV)
#define CHIP_FMK(Reg,Field,Val)     _CHIP_##Reg##_##Field##_MK(Val)
#define CHIP_FMKS(Reg,Field,Sym)    _CHIP_FMK(Reg,Field,CHIP_##Reg##_##Field##_##Sym)


#define _CHIP_ST0_GET()             _REG_GET(_CHIP_ST0_ADDR)
#define _CHIP_ST0_SET(Val)          _REG_SET(_CHIP_ST0_ADDR,Val)
#define _CHIP_ST0_AOI(AND,OR,INV)   _REG_AOI(_CHIP_ST0_ADDR,AND,OR,INV)
#define _CHIP_ST0_FGET(Field)       _FIELD_GET(_CHIP_ST0_ADDR,_CHIP_ST0_##Field)
#define _CHIP_ST0_FSET(Field,Val)   _FIELD_SET(_CHIP_ST0_ADDR,_CHIP_ST0_##Field,Val)
#define _CHIP_ST0_FSETS(Field,Sym)  _CHIP_ST0_FSET(Field,_CHIP_ST0_##Field##_##Sym)
#define _CHIP_ST0_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_CHIP_ST0_ADDR,_CHIP_ST0_##Field,AND,OR,INV)

#define _CHIP_ST0_CFG(arp,tc,c,ova,ovb,dp)  ST0 = \
  (Uint16) (_CHIP_ST0_ARP_MK(arp)     |\
            _CHIP_ST0_OVA_MK(ova)     |\
            _CHIP_ST0_OVB_MK(ovb)     |\
            _CHIP_ST0_DP_MK(dp)        \
   )
 

#define _CHIP_ST1_GET()             _REG_GET(_CHIP_ST1_ADDR)
#define _CHIP_ST1_SET(Val)          _REG_SET(_CHIP_ST1_ADDR,Val)
#define _CHIP_ST1_AOI(AND,OR,INV)   _REG_AOI(_CHIP_ST1_ADDR,AND,OR,INV)
#define _CHIP_ST1_FGET(Field)       _FIELD_GET(_CHIP_ST1_ADDR,_CHIP_ST1_##Field)
#define _CHIP_ST1_FSET(Field,Val)   _FIELD_SET(_CHIP_ST1_ADDR,_CHIP_ST1_##Field,Val)
#define _CHIP_ST1_FSETS(Field,Sym)  _CHIP_ST1_FSET(Field,_CHIP_ST1_##Field##_##Sym)
#define _CHIP_ST1_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_CHIP_ST1_ADDR,_CHIP_ST1_##Field,AND,OR,INV)

#define _CHIP_ST1_CFG(xf,hm,sxm,c16,frct,cmpt,asm) ST1 = \
   (Uint16)(_CHIP_ST1_XF(xf)          |\
            _CHIP_ST1_HM(hm)          |\
            _CHIP_ST1_SXM(sxm)        |\
            _CHIP_ST1_C16(c16)        |\
            _CHIP_ST1_FRCT(frct)      |\
            _CHIP_ST1_CMPT(cmpt)      |\
            _CHIP_ST1_ASM(asm)         \
   )

#define _CHIP_PMST_GET()             _REG_GET(_CHIP_PMST_ADDR)
#define _CHIP_PMST_SET(Val)          _REG_SET(_CHIP_PMST_ADDR,Val)
#define _CHIP_PMST_AOI(AND,OR,INV)   _REG_AOI(_CHIP_PMST_ADDR,AND,OR,INV)
#define _CHIP_PMST_FGET(Field)       _FIELD_GET(_CHIP_PMST_ADDR,_CHIP_PMST_##Field)
#define _CHIP_PMST_FSET(Field,Val)   _FIELD_SET(_CHIP_PMST_ADDR,_CHIP_PMST_##Field,Val)
#define _CHIP_PMST_FSETS(Field,Sym)  _CHIP_PMST_FSET(Field,_CHIP_PMST_##Field##_##Sym)
#define _CHIP_PMST_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_CHIP_PMST_ADDR,_CHIP_PMST_##Field,AND,OR,INV)

#define _CHIP_PMST_CFG(iptr,mpmc,ovly,avis,drom,clkoff,smul,sst) PMST = \
  (Uint16)(_CHIP_PMST_IPTR_MK(iptr)     |\
           _CHIP_PMST_MPMC_MK(mpmc)     |\
           _CHIP_PMST_OVLY_MK(ovly)     |\
           _CHIP_PMST_AVIS_MK(avis)     |\
           _CHIP_PMST_DROM_MK(drom)     |\
           _CHIP_PMST_CLKOFF_MK(clkoff) |\
           _CHIP_PMST_SMUL_MK(smul)     |\
           _CHIP_PMST_SST_MK(sst)        \
   )


#define _CHIP_IFR_GET()             _REG_GET(_CHIP_IFR_ADDR)
#define _CHIP_IFR_SET(Val)          _REG_SET(_CHIP_IFR_ADDR,Val)
#define _CHIP_IFR_AOI(AND,OR,INV)   _REG_AOI(_CHIP_IFR_ADDR,AND,OR,INV)
#define _CHIP_IFR_FGET(Field)       _FIELD_GET(_CHIP_IFR_ADDR,_CHIP_IFR_##Field)
#define _CHIP_IFR_FSET(Field,Val)   _FIELD_SET(_CHIP_IFR_ADDR,_CHIP_IFR_##Field,Val)
#define _CHIP_IFR_FSETS(Field,Sym)  _CHIP_IFR_FSET(Field,_CHIP_IFR_##Field##_##Sym)
#define _CHIP_IFR_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_CHIP_IFR_ADDR,_CHIP_IFR_##Field,AND,OR,INV)
#define _CHIP_IFR_CFG(int0,int1,int2,tint0,rint0,xint0,dmac0,\
                     dmac1,int3,hint,rint1,xint1,dmac4,dmac5) IFR = \
   (Uint16) (_CHIP_IFR_INT0_MK(int0)      |\
             _CHIP_IFR_INT1_MK(int1)      |\
             _CHIP_IFR_INT2_MK(int2)      |\
             _CHIP_IFR_TINT0_MK(tint0)    |\
             _CHIP_IFR_RINT0_MK(rint0)    |\
             _CHIP_IFR_XINT0_MK(xint0)    |\
             _CHIP_IFR_DMAC0_MK(dmac0)    |\
             _CHIP_IFR_DMAC1_MK(dmac1)    |\
             _CHIP_IFR_INT3_MK(int3)      |\
             _CHIP_IFR_HINT_MK(hint)      |\
             _CHIP_IFR_RINT1_MK(rint1)    |\
             _CHIP_IFR_XINT1_MK(xint1)    |\
             _CHIP_IFR_DMAC4_MK(dmac4)    |\
             _CHIP_IFR-DMAC5_MK(dmac5)     \
    )
          
#define _CHIP_IMR_GET()             _REG_GET(_CHIP_IMR_ADDR)
#define _CHIP_IMR_SET(Val)          _REG_SET(_CHIP_IMR_ADDR,Val)
#define _CHIP_IMR_AOI(AND,OR,INV)   _REG_AOI(_CHIP_IMR_ADDR,AND,OR,INV)
#define _CHIP_IMR_FGET(Field)       _FIELD_GET(_CHIP_IMR_ADDR,_CHIP_IMR_##Field)
#define _CHIP_IMR_FSET(Field,Val)   _FIELD_SET(_CHIP_IMR_ADDR,_CHIP_IMR_##Field,Val)
#define _CHIP_IMR_FSETS(Field,Sym)  _CHIP_IMR_FSET(Field,_CHIP_IMR_##Field##_##Sym)
#define _CHIP_IMR_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_CHIP_IMR_ADDR,_CHIP_IMR_##Field,AND,OR,INV)

#define _CHIP_IMR_CFG(imr0,imr1,imr2,imr3,imr4,imr5,imr6,\
                     imr7,imr8,imr9,imr10,imr11,imr12,imr13) IMR = \
   (Uint16) (_CHIP_IMR_INT0_MK(imr0)      |\
             _CHIP_IMR_INT1_MK(imr1)      |\
             _CHIP_IMR_INT2_MK(imr2)      |\
             _CHIP_IMR_TINT0_MK(imr3)     |\
             _CHIP_IMR_RINT0_MK(imr4)     |\
             _CHIP_IMR_XINT0_MK(imr5)     |\
             _CHIP_IMR_DMAC0_MK(imr6)     |\
             _CHIP_IMR_DMAC1_MK(imr7)     |\
             _CHIP_IMR_INT3_MK(imr8)      |\
             _CHIP_IMR_HINT_MK(imr9)      |\
             _CHIP_IMR_RINT1_MK(imr10)    |\
             _CHIP_IMR_XINT1_MK(imr11)    |\
             _CHIP_IMR_DMAC4_MK(imr12)    |\
             _CHIP_IMR-DMAC5_MK(imr13)     \
    )


#if (_CHIP_CPU_ID_SUPPORT)
  #define _CHIP_CSIDR_ADDR         (0x003Eu)
  #define _CHIP_CSIDR              REG16(_CHIP_CSIDR_ADDR)
  #define _CSIDR                    _CHIP_CSIDR

  #define _CHIP_CSIDR_GET()             _REG_GET(_CHIP_CSIDR_ADDR)
  #define _CHIP_CSIDR_SET(Val)          _REG_SET(_CHIP_CSIDR_ADDR,Val)
  #define _CHIP_CSIDR_AOI(AND,OR,INV)   _REG_AOI(_CHIP_CSIDR_ADDR,AND,OR,INV)
  #define _CHIP_CSIDR_FGET(Field)       _FIELD_GET(_CHIP_CSIDR_ADDR,_CHIP_CSIDR_##Field)
  #define _CHIP_CSIDR_FSET(Field,Val)   _FIELD_SET(_CHIP_CSIDR_ADDR,_CHIP_CSIDR_##Field,Val)
  #define _CHIP_CSIDR_FSETS(Field,Sym)  _CHIP_CSIDR_FSET(Field,_CHIP_CSIDR_##Field##_##Sym)
  #define _CHIP_CSIDR_FAOI(Field,AND,OR,INV)\
    _FIELD_AOI(_CHIP_CSIDR_ADDR,_CHIP_CSIDR_##Field,AND,OR,INV)
#endif


/******************************************************************************\
* _CHIP_ST0 - control status register 0
*
* Fields:
*   (RW) _CHIP_ST0_ARP
*   (RW) _CHIP_ST0_TC
*   (RW) _CHIP_ST0_C
*   (RW) _CHIP_ST0_OVA
*   (RW) _CHIP_ST0_OVB
*   (RW) _CHIP_ST0_DP
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST0_ARP: Auxiliary Register Pointer
\*----------------------------------------------------------------------------*/ 
#define _CHIP_ST0_ARP_SHIFT          (0x000du)
#define _CHIP_ST0_ARP_MK(n)          (((Uint16)n & 0x0007u) << _CHIP_ST0_ARP_SHIFT)
#define _CHIP_ST0_ARP_MASK           (_CHIP_ST0_ARP_MK(7))
#define _CHIP_ST0_ARP_CLR            (~(_CHIP_ST0_ARP_MASK))

#define CHIP_ST0_ARP_AR0             (0x0000u)
#define CHIP_ST0_ARP_AR1             (0x0001u)
#define CHIP_ST0_ARP_AR2             (0x0002u)
#define CHIP_ST0_ARP_AR3             (0x0003u)
#define CHIP_ST0_ARP_AR4             (0x0004u)
#define CHIP_ST0_ARP_AR5             (0x0005u)
#define CHIP_ST0_ARP_AR6             (0x0006u)
#define CHIP_ST0_ARP_AR7             (0x0007u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST0_TC: Test/control flag
\*----------------------------------------------------------------------------*/ 
#define _CHIP_ST0_TC_SHIFT           (0x000cu)
#define _CHIP_ST0_TC_MK(n)           (((Uint16)n & 0x0001u) << _CHIP_ST0_TC_SHIFT)
#define _CHIP_ST0_TC_MASK            (_CHIP_ST0_TC_MK(1))
#define _CHIP_ST0_TC_CLR             (~(_CHIP_ST0_TC_MASK))

#define CHIP_ST0_TC_TRUE             (0x0001u)
#define CHIP_ST0_TC_FALSE            (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST0_C: Carry Bit
\*----------------------------------------------------------------------------*/ 
#define _CHIP_ST0_C_SHIFT            (0x000bu)
#define _CHIP_ST0_C_MK(n)            (((Uint16)(n) & 0x0001u) << _CHIP_ST0_C_SHIFT)
#define _CHIP_ST0_C_MASK             (_CHIP_ST0_C_MK(1))
#define _CHIP_ST0_C_CLR              (~(_CHIP_ST0_C_MASK))

#define CHIP_ST0_C_ON                (0x0001u)
#define CHIP_ST0_C_OFF               (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST0_OVA: Overflow mode bit for accumulator A
\*----------------------------------------------------------------------------*/ 
#define _CHIP_ST0_OVA_SHIFT          (0x000au)
#define _CHIP_ST0_OVA_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_ST0_OVA_SHIFT)
#define _CHIP_ST0_OVA_MASK           (_CHIP_ST0_OVA_MK(1))
#define _CHIP_ST0_OVA_CLR            (~(_CHIP_ST0_OVA_MASK))

#define CHIP_ST0_OVA_ON              (0x0001u)
#define CHIP_ST0_OVA_OFF             (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST0_OVB: Overflow mode bit for accumulator B
\*----------------------------------------------------------------------------*/ 
#define _CHIP_ST0_OVB_SHIFT          (0x0009u)
#define _CHIP_ST0_OVB_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_ST0_OVB_SHIFT)
#define _CHIP_ST0_OVB_MASK           (_CHIP_ST0_OVB_MK(1))
#define _CHIP_ST0_OVB_CLR            (~(_CHIP_ST0_OVB_MASK))

#define CHIP_ST0_OVB_ON              (0x0001u)
#define CHIP_ST0_OVB_OFF             (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST0_DP: Data memory page pointer
\*----------------------------------------------------------------------------*/ 
#define _CHIP_ST0_DP_SHIFT           (0x0000u)
#define _CHIP_ST0_DP_MK(n)           (((Uint16)(n) & 0x01ffu) << _CHIP_ST0_DP_SHIFT)
#define _CHIP_ST0_DP_MASK            (_CHIP_ST0_DP_MK(0x01ffu))
#define _CHIP_ST0_DP_CLR             (~(_CHIP_ST0_DP_MASK))


/******************************************************************************\
* _CHIP_ST1 - control status register 1
*
* Fields:
* (R)  _CHIP_ST1_BRAF
* (RW) _CHIP_ST1_CPL
* (RW) _CHIP_ST1_XF
* (RW) _CHIP_ST1_HM
* (RW) _CHIP_ST1_INTM
* (RW) _CHIP_ST1_OVM
* (RW) _CHIP_ST1_SXM
* (RW) _CHIP_ST1_C16
* (RW) _CHIP_ST1_FRCT
* (RW) _CHIP_ST1_CMPT
* (RW) _CHIP_ST1_ASM
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_BRAF: Repeat mode flag
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_BRAF_SHIFT         (0x000fu)
#define _CHIP_ST1_BRAF_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_ST1_BRAF_SHIFT)
#define _CHIP_ST1_BRAF_MASK          (_CHIP_ST1_BRAF_MK(1))
#define _CHIP_ST1_BRAF_CLR           (~(_CHIP_ST1_BRAF_MASK))

#define CHIP_ST1_BRAF_ON             (0x0001u)
#define CHIP_ST1_BRAF_OFF            (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_CPL: Compiler mode bit
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_CPL_SHIFT          (0x000eu)
#define _CHIP_ST1_CPL_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_ST1_CPL_SHIFT)
#define _CHIP_ST1_CPL_MASK           (_CHIP_ST1_CPL_MK(1))
#define _CHIP_ST1_CPL_CLR            (~(_CHIP_ST1_CPL_MASK))

#define CHIP_ST1_CPL_ON              (0x0001u)
#define CHIP_ST1_CPL_OFF             (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_XF: Reflects status of general purpose output XF pin
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_XF_SHIFT           (0x000du)
#define _CHIP_ST1_XF_MK(n)           (((Uint16)(n) & 0x0001u) << _CHIP_ST1_XF_SHIFT)
#define _CHIP_ST1_XF_MASK            (_CHIP_ST1_XF_MK(1))
#define _CHIP_ST1_XF_CLR             (~(_CHIP_ST1_XF_MASK))

#define CHIP_ST1_XF_HI               (0x0001u)
#define CHIP_ST1_XF_LOW              (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_HM: Processor HOLD mode bit
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_HM_SHIFT           (0x000cu)
#define _CHIP_ST1_HM_MK(n)           (((Uint16)(n) & 0x0001u) << _CHIP_ST1_HM_SHIFT)
#define _CHIP_ST1_HM_MASK            (_CHIP_ST1_HM_MK(1))
#define _CHIP_ST1_HM_CLR             (~(_CHIP_ST1_HM_MASK))

#define CHIP_ST1_HM_ENABLE           (0x0001u)
#define CHIP_ST1_HM_DISABLE          (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_INTM: Global Interrupt Enable/Disable
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_INTM_SHIFT         (0x000bu)
#define _CHIP_ST1_INTM_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_ST1_INTM_SHIFT)
#define _CHIP_ST1_INTM_MASK          (_CHIP_ST1_INTM_MK(1))
#define _CHIP_ST1_INTM_CLR           (~(_CHIP_ST1_INTM_MASK))

#define _CHIP_ST1_INTM_SET(RegAddr, Val)         HSBX_SET(INTM,Val)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_OVM: Overflow mode bit (determines saturation of ALU results)
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_OVM_SHIFT          (0x0009u)
#define _CHIP_ST1_OVM_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_ST1_OVM_SHIFT)
#define _CHIP_ST1_OVM_MASK           (_CHIP_ST1_OVM_MK(1))
#define _CHIP_ST1_OVM_CLR            (~(_CHIP_ST1_OVM_MASK))

#define _CHIP_ST1_OVM_SET(RegAddr, Val)        HSBX_SET(OVM,Val)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_SXM: Sign extnsion mode bit
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_SXM_SHIFT          (0x0008u)
#define _CHIP_ST1_SXM_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_ST1_SXM_SHIFT)
#define _CHIP_ST1_SXM_MASK           (_CHIP_ST1_SXM_MK(1))
#define _CHIP_ST1_SXM_CLR            (~(_CHIP_ST1_SXM_MASK))

#define CHIP_ST1_SXM_ON              (0x0001u)
#define CHIP_ST1_SXM_OFF             (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_C16: Dual 16-bit/Double precision arithmetic mode bit
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_C16_SHIFT          (0x0007u)
#define _CHIP_ST1_C16_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_ST1_C16_SHIFT)
#define _CHIP_ST1_C16_MASK           (_CHIP_ST1_C16_MK(1))
#define _CHIP_ST1_C16_CLR            (~(_CHIP_ST1_C16_MASK))

#define CHIP_ST1_C16_DUAL16BIT       (0x0001u)
#define CHIP_ST1_C16_DOUBLEPRECISION (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_FRCT: Fractional mode bit (multiplier output left shifted by 1)
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_FRCT_SHIFT         (0x0006u)
#define _CHIP_ST1_FRCT_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_ST1_FRCT_SHIFT)
#define _CHIP_ST1_FRCT_MASK          (_CHIP_ST1_FRCT_MK(1))
#define _CHIP_ST1_FRCT_CLR           (~(_CHIP_ST1_FRCT_MASK))

#define CHIP_ST1_FRCT_ENABLE         (0x0001u)
#define CHIP_ST1_FRCT_DISABLE        (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_CMPT: Compatability mode (c5x ARP adrressing compatability)
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_CMPT_SHIFT         (0x0005u)
#define _CHIP_ST1_CMPT_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_ST1_CMPT_SHIFT)
#define _CHIP_ST1_CMPT_MASK          (_CHIP_ST1_CMPT_MK(1))
#define _CHIP_ST1_CMPT_CLR           (~(_CHIP_ST1_CMPT_MASK))

#define CHIP_ST1_CMPT_C5X           (0x0001u)
#define CHIP_ST1_CMPT_C54NATIVE     (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_ST1_ASM: Accumulator shift mode bit
\*----------------------------------------------------------------------------*/
#define _CHIP_ST1_ASM_SHIFT          (0x0000u)
#define _CHIP_ST1_ASM_MK(n)          (((Uint16)(n) & 0x001fu) << _CHIP_ST1_ASM_SHIFT)
#define _CHIP_ST1_ASM_MASK           (_CHIP_ST1_ASM_MK(0x001fu))
#define _CHIP_ST1_ASM_CLR            (~(_CHIP_ST1_ASM_MASK))

/*---------------------------------------------------------------------------*\
* Macros to SET/GET and Configure globally the ST1 register
\*---------------------------------------------------------------------------*/

/******************************************************************************\
* _CHIP_IFR - interrupt flag register
*
* Fields:
*   (RW)  _CHIP_IFR_INT0         external interrupt #0
*   (RW)  _CHIP_IFR_INT1         external interrupt #1
*   (RW)  _CHIP_IFR_INT2         external interrupt #2
*   (RW)  _CHIP_IFR_TINT/TINT0   ** timer #0 interrupt
*   (RW)  _CHIP_IFR_RINT0        MCBSP #0 receive interrupt
*   (RW)  _CHIP_IFR_XINT0        MCBSP #0 transmit interrupt
*   (RW)  _CHIP_IFR_DMAC0        DMA #0 interrupt
*   (RW)  _CHIP_IFR_TINT1/DMAC1  ** timer #1 interrupt/ DMA Channel #1 interrupt
*   (RW)  _CHIP_IFR_INT3         external interrupt #3
*   (RW)  _CHIP_IFR_HINT         Host-to-DSP interrupt (HPI)
*   (RW)  _CHIP_IFR_RINT1/DMAC2  ** MCBSP #1 receive interrupt/ DMA Channel #2 interrupt
*   (RW)  _CHIP_IFR_XINT1/DMAC3  ** MCBSP #1 transmit interrupt/ DMA Channel #3 interrupt
*   (RW)  _CHIP_IFR_DMAC4        DMA CHannel #4 interrupt
*   (RW)  _CHIP_IFR_DMAC5        DMA Channel #5 interrupt
*
*   ** 5401/5402 are only CHIPtypes with more than one timer,
*      TINT0 is the flag for timer #0 on 5401/5402, the same bit corresponds to
*             the interrupt flag for the single timer on 5409,5410,5416,5420
*   ** TINT1 is the interrupt flag for timer #1 on 5401/5402 or the interrupt flag
*            for DMA channel #1 based in interrupt select in DMA control
*   ** RINT1 and DMAC2 share the same interrupt bit in the IFR, which one is active
*            depends on value of interrupt select in the DMA control  
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_DMAC5: DMA Channel #5 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_DMAC5_SHIFT          (0x000du)
#define _CHIP_IFR_DMAC5_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_DMAC5_SHIFT)
#define _CHIP_IFR_DMAC5_MASK           (_CHIP_IFR_DMAC5_MK(1))
#define _CHIP_IFR_DMAC5_CLR            (~(_CHIP_IFR_DMAC5_MASK))

#define CHIP_IFR_DMAC5_TRUE            (0x0001u)
#define CHIP_IFR_DMAC5_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_DMAC4:  DMA Channel #4 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_DMAC4_SHIFT          (0x000cu)
#define _CHIP_IFR_DMAC4_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_DMAC4_SHIFT)
#define _CHIP_IFR_DMAC4_MASK           (_CHIP_IFR_DMAC4_MK(1))
#define _CHIP_IFR_DMAC4_CLR            (~(_CHIP_IFR_DMAC4_MASK))

#define CHIP_IFR_DMAC4_TRUE            (0x0001u)
#define CHIP_IFR_DMAC4_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_XINT1: MCBSP Serial port #1 transmit interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_XINT1_SHIFT          (0x000bu)
#define _CHIP_IFR_XINT1_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_XINT1_SHIFT)
#define _CHIP_IFR_XINT1_MASK           (_CHIP_IFR_XINT1_MK(1))
#define _CHIP_IFR_XINT1_CLR            (~(_CHIP_IFR_XINT1_MASK))

#define CHIP_IFR_XINT1_TRUE            (0x0001u)
#define CHIP_IFR_XINT1_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_DMAC3: DMA Channel #3 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_DMAC3_SHIFT          (0x000bu)
#define _CHIP_IFR_DMAC3_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_DMAC3_SHIFT)
#define _CHIP_IFR_DMAC3_MASK           (_CHIP_IFR_DMAC3_MK(1))
#define _CHIP_IFR_DMAC3_CLR            (~(_CHIP_IFR_DMAC3_MASK))

#define CHIP_IFR_DMAC3_TRUE            (0x0001u)
#define CHIP_IFR_DMAC3_FALSE           (0x0000u)
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_RINT1: MCBSP Serial port #2 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_RINT1_SHIFT          (0x000au)
#define _CHIP_IFR_RINT1_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_RINT1_SHIFT)
#define _CHIP_IFR_RINT1_MASK           (_CHIP_IFR_RINT1_MK(1))
#define _CHIP_IFR_RINT1_CLR            (~(_CHIP_IFR_RINT1_MASK))

#define CHIP_IFR_RINT1_TRUE            (0x0001u)
#define CHIP_IFR_RINT1_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_DMAC2: DMA Channel #2 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_DMAC2_SHIFT          (0x000au)
#define _CHIP_IFR_DMAC2_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_DMAC2_SHIFT)
#define _CHIP_IFR_DMAC2_MASK           (_CHIP_IFR_DMAC2_MK(1))
#define _CHIP_IFR_DMAC2_CLR            (~(_CHIP_IFR_DMAC2_MASK))

#define CHIP_IFR_DMAC2_TRUE            (0x0001u)
#define CHIP_IFR_DMAC2_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_HINT: Host-to-DSP (HPI) interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_HINT_SHIFT          (0x0009u)
#define _CHIP_IFR_HINT_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_HINT_SHIFT)
#define _CHIP_IFR_HINT_MASK           (_CHIP_IFR_HINT_MK(1))
#define _CHIP_IFR_HINT_CLR            (~(_CHIP_IFR_HINT_MASK))

#define CHIP_IFR_HINT_TRUE            (0x0001u)
#define CHIP_IFR_HINT_FALSE           (0x0000u)
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_INT3: External interrupt #3
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_INT3_SHIFT          (0x0008u)
#define _CHIP_IFR_INT3_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IFR_INT3_SHIFT)
#define _CHIP_IFR_INT3_MASK           (_CHIP_IFR_INT3_MK(1))
#define _CHIP_IFR_INT3_CLR            (~(_CHIP_IFR_INT3_MASK))

#define CHIP_IFR_INT3_TRUE            (0x0001u)
#define CHIP_IFR_INT3_FALSE           (0x0000u)

#if (CHIP_5401 | CHIP_5402 | CHIP_5471 | CHIP_5472)
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_TINT1: Timer #1 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_TINT1_SHIFT        (0x0007u)
#define _CHIP_IFR_TINT1_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_TINT1_SHIFT)
#define _CHIP_IFR_TINT1_MASK         (_CHIP_IFR_TINT1_MK(1))
#define _CHIP_IFR_TINT1_CLR          (~(_CHIP_IFR_TINT1_MASK))

#define CHIP_IFR_TINT1_TRUE            (0x0001u)
#define CHIP_IFR_TINT1_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_DMAC1: DMA Channel #1 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_DMAC1_SHIFT        (0x0007u)
#define _CHIP_IFR_DMAC1_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_DMAC1_SHIFT)
#define _CHIP_IFR_DMAC1_MASK         (_CHIP_IFR_DMAC1_MK(1))
#define _CHIP_IFR_DMAC1_CLR          (~(_CHIP_IFR_DMAC1_MASK))

#define CHIP_IFR_DMAC1_TRUE            (0x0001u)
#define CHIP_IFR_DMAC1_FALSE           (0x0000u)

#endif

#if (!(CHIP_5401 | CHIP_5402 | CHIP_5471) && (!CHIP_ALL))
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_XINT2: MCBSP #2 transmit interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_XINT2_SHIFT        (0x0007u)
#define _CHIP_IFR_XINT2_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_XINT2_SHIFT)
#define _CHIP_IFR_XINT2_MASK         (_CHIP_IFR_XINT2_MK(1))
#define _CHIP_IFR_XINT2_CLR          (~(_CHIP_IFR_XINT2_MASK))

#define CHIP_IFR_XINT2_TRUE            (0x0001u)
#define CHIP_IFR_XINT2_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_DMAC1: MCBSP #2 transmit interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_DMAC1_SHIFT        (0x0007u)
#define _CHIP_IFR_DMAC1_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_DMAC1_SHIFT)
#define _CHIP_IFR_DMAC1_MASK         (_CHIP_IFR_DMAC1_MK(1))
#define _CHIP_IFR_DMAC1_CLR          (~(_CHIP_IFR_DMAC1_MASK))

#define CHIP_IFR_DMAC1_TRUE            (0x0001u)
#define CHIP_IFR_DMAC1_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_RINT2: MCBSP #2 receive interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_RINT2_SHIFT        (0x0006u)
#define _CHIP_IFR_RINT2_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_RINT2_SHIFT)
#define _CHIP_IFR_RINT2_MASK         (_CHIP_IFR_RINT2_MK(1))
#define _CHIP_IFR_RINT2_CLR          (~(_CHIP_IFR_RINT2_MASK))

#define CHIP_IFR_RINT2_TRUE            (0x0001u)
#define CHIP_IFR_RINT2_FALSE           (0x0000u)

#endif

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_DMAC0: DMA Channel #0 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_DMAC0_SHIFT        (0x0006u)
#define _CHIP_IFR_DMAC0_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_DMAC0_SHIFT)
#define _CHIP_IFR_DMAC0_MASK         (_CHIP_IFR_DMAC0_MK(1))
#define _CHIP_IFR_DMAC0_CLR          (~(_CHIP_IFR_DMAC0_MASK))

#define CHIP_IFR_DMAC0_TRUE            (0x0001u)
#define CHIP_IFR_DMAC0_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_XINT0: MCBSP #0 transmit interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_XINT0_SHIFT        (0x0005u)
#define _CHIP_IFR_XINT0_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_XINT0_SHIFT)
#define _CHIP_IFR_XINT0_MASK         (_CHIP_IFR_XINT0_MK(1))
#define _CHIP_IFR_XINT0_CLR          (~(_CHIP_IFR_XINT0_MASK))

#define CHIP_IFR_XINT0_TRUE            (0x0001u)
#define CHIP_IFR_XINT0_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_RINT0: MCBSP #0 receive interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_RINT0_SHIFT        (0x0004u)
#define _CHIP_IFR_RINT0_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_RINT0_SHIFT)
#define _CHIP_IFR_RINT0_MASK         (_CHIP_IFR_RINT0_MK(1))
#define _CHIP_IFR_RINT0_CLR          (~(_CHIP_IFR_RINT0_MASK))

#define CHIP_IFR_RINT0_TRUE            (0x0001u)
#define CHIP_IFR_RINT0_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_TINT0: Timer #0 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_TINT0_SHIFT        (0x0003u)
#define _CHIP_IFR_TINT0_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IFR_TINT0_SHIFT)
#define _CHIP_IFR_TINT0_MASK         (_CHIP_IFR_TINT0_MK(1))
#define _CHIP_IFR_TINT0_CLR          (~(_CHIP_IFR_TINT0_MASK))

#define CHIP_IFR_TINT0_TRUE            (0x0001u)
#define CHIP_IFR_TINT0_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_INT2: External interrupt #2 flag
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_INT2_SHIFT         (0x0002u)
#define _CHIP_IFR_INT2_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IFR_INT2_SHIFT)
#define _CHIP_IFR_INT2_MASK          (_CHIP_IFR_INT2_MK(1))
#define _CHIP_IFR_INT2_CLR           (~(_CHIP_IFR_INT2_MASK))

#define CHIP_IFR_INT2_TRUE            (0x0001u)
#define CHIP_IFR_INT2_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_INT1: External interrupt #1 flag
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_INT1_SHIFT         (0x0001u)
#define _CHIP_IFR_INT1_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IFR_INT1_SHIFT)
#define _CHIP_IFR_INT1_MASK          (_CHIP_IFR_INT1_MK(1))
#define _CHIP_IFR_INT1_CLR           (~(_CHIP_IFR_INT1_MASK))

#define CHIP_IFR_INT1_TRUE            (0x0001u)
#define CHIP_IFR_INT1_FALSE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IFR_INT0: External interrupt #0 flag
\*----------------------------------------------------------------------------*/
#define _CHIP_IFR_INT0_SHIFT         (0x0000u)
#define _CHIP_IFR_INT0_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IFR_INT0_SHIFT)
#define _CHIP_IFR_INT0_MASK          (_CHIP_IFR_INT0_MK(1))
#define _CHIP_IFR_INT0_CLR           (~(_CHIP_IFR_INT0_MASK))

#define CHIP_IFR_INT0_TRUE            (0x0001u)
#define CHIP_IFR_INT0_FALSE           (0x0000u)

/*---------------------------------------------------------------------------*\
* Macros to SET/GET and Configure globally the IFR register
\*---------------------------------------------------------------------------*/
/******************************************************************************\
* _CHIP_IMR - interrupt flag register
*
* Fields:
*   (RW)  _CHIP_IMR_INT0         external interrupt #0
*   (RW)  _CHIP_IMR_INT1, WDTINT external interrupt #1, Watch Dog Timer int (5440 only)
*   (RW)  _CHIP_IMR_INT2         external interrupt #2
*   (RW)  _CHIP_IMR_TINT/TINT0   ** timer #0 interrupt
*   (RW)  _CHIP_IMR_RINT0        MCBSP #0 receive interrupt
*   (RW)  _CHIP_IMR_XINT0        MCBSP #0 transmit interrupt
*   (RW)  _CHIP_IMR_DMAC0        DMA #0 interrupt
*   (RW)  _CHIP_IMR_TINT1/DMAC1  ** timer #1 interrupt/ DMA Channel #1 interrupt
*   (RW)  _CHIP_IMR_INT3         external interrupt #3
*   (RW)  _CHIP_IMR_HINT         Host-to-DSP interrupt (HPI)
*   (RW)  _CHIP_IMR_RINT1/DMAC2  ** MCBSP #1 receive interrupt/ DMA Channel #2 interrupt
*   (RW)  _CHIP_IMR_XINT1/DMAC3  ** MCBSP #1 transmit interrupt/ DMA Channel #3 interrupt
*   (RW)  _CHIP_IMR_DMAC4        DMA CHannel #4 interrupt
*   (RW)  _CHIP_IMR_DMAC5        DMA Channel #5 interrupt
*
*   ** 5401/5402 are the only CHIPs with more than one timer,
*      TINT0 is the flag for timer #0 on 5401/5402, the same bit corresponds to
*             the interrupt flag for the single timer on 5409,5410,5416,5420
*   ** TINT1 is the interrupt flag for timer #1 on 5401/5402 or the interrupt flag
*            for DMA channel #1 based in interrupt select in DMA control
*   ** RINT1 and DMAC2 share the same interrupt bit in the IFR, which one is active
*            depends on value of interrupt select in the DMA control  
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_DMAC5: DMA Channel #5 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_DMAC5_SHIFT        (0x000du)
#define _CHIP_IMR_DMAC5_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC5_SHIFT)
#define _CHIP_IMR_DMAC5_MASK         (_CHIP_IMR_DMAC5_MK(1))
#define _CHIP_IMR_DMAC5_CLR          (~(_CHIP_IMR_DMAC5_MASK))

#define CHIP_IMR_DMAC5_ENABLE            (0x0001u)
#define CHIP_IMR_DMAC5_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_DMAC4:  DMA Channel #4 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_DMAC4_SHIFT        (0x000cu)
#define _CHIP_IMR_DMAC4_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC4_SHIFT)
#define _CHIP_IMR_DMAC4_MASK         (_CHIP_IMR_DMAC4_MK(1))
#define _CHIP_IMR_DMAC4_CLR          (~(_CHIP_IMR_DMAC4_MASK))

#define CHIP_IMR_DMAC4_ENABLE            (0x0001u)
#define CHIP_IMR_DMAC4_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_XINT1: MCBSP Serial port #1 transmit interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_XINT1_SHIFT        (0x000bu)
#define _CHIP_IMR_XINT1_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IMR_XINT1_SHIFT)
#define _CHIP_IMR_XINT1_MASK         (_CHIP_IMR_XINT1_MK(1))
#define _CHIP_IMR_XINT1_CLR          (~(_CHIP_IMR_XINT1_MASK))

#define CHIP_IMR_XINT1_ENABLE            (0x0001u)
#define CHIP_IMR_XINT1_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_DMAC3: DMA Channel #3 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_DMAC3_SHIFT        (0x000bu)
#define _CHIP_IMR_DMAC3_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC3_SHIFT)
#define _CHIP_IMR_DMAC3_MASK         (_CHIP_IMR_DMAC3_MK(1))
#define _CHIP_IMR_DMAC3_CLR          (~(_CHIP_IMR_DMAC3_MASK))

#define CHIP_IMR_DMAC3_ENABLE            (0x0001u)
#define CHIP_IMR_DMAC3_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_RINT1: MCBSP Serial port #2 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_RINT1_SHIFT        (0x000au)
#define _CHIP_IMR_RINT1_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IMR_RINT1_SHIFT)
#define _CHIP_IMR_RINT1_MASK         (_CHIP_IMR_RINT1_MK(1))
#define _CHIP_IMR_RINT1_CLR          (~(_CHIP_IMR_RINT1_MASK))

#define CHIP_IMR_RINT1_ENABLE            (0x0001u)
#define CHIP_IMR_RINT1_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_DMAC2: DMA Channel #2 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_DMAC2_SHIFT        (0x000au)
#define _CHIP_IMR_DMAC2_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC2_SHIFT)
#define _CHIP_IMR_DMAC2_MASK         (_CHIP_IMR_DMAC2_MK(1))
#define _CHIP_IMR_DMAC2_CLR          (~(_CHIP_IMR_DMAC2_MASK))

#define CHIP_IMR_DMAC2_ENABLE            (0x0001u)
#define CHIP_IMR_DMAC2_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_HINT: Host-to-DSP (HPI) interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_HINT_SHIFT         (0x0009u)
#define _CHIP_IMR_HINT_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IMR_HINT_SHIFT)
#define _CHIP_IMR_HINT_MASK          (_CHIP_IMR_HINT_MK(1))
#define _CHIP_IMR_HINT_CLR           (~(_CHIP_IMR_HINT_MASK))

#define CHIP_IMR_HINT_ENABLE            (0x0001u)
#define CHIP_IMR_HINT_DISABLE           (0x0000u)

#if (!CHIP_5540)
  /*----------------------------------------------------------------------------*\
  * (RW) _CHIP_IMR_INT3: External interrupt #3
  \*----------------------------------------------------------------------------*/
  #define _CHIP_IMR_INT3_SHIFT       (0x0008u)
  #define _CHIP_IMR_INT3_MK(n)       (((Uint16)(n) & 0x0001u) << _CHIP_IMR_INT3_SHIFT)
  #define _CHIP_IMR_INT3_MASK        (_CHIP_IMR_INT3_MK(1))
  #define _CHIP_IMR_INT3_CLR         (~(_CHIP_IMR_INT3_MASK))

  #define CHIP_IMR_INT3_ENABLE            (0x0001u)
  #define CHIP_IMR_INT3_DISABLE           (0x0000u)

#endif  /* !CHIP_5440 */

#if (CHIP_5401 | CHIP_5402 | CHIP_5471 | CHIP_5472)
/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_TINT1: Timer #1 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_TINT1_SHIFT       (0x0007u)
#define _CHIP_IMR_TINT1_MK(n)       (((Uint16)(n) & 0x0001u) << _CHIP_IMR_TINT1_SHIFT)
#define _CHIP_IMR_TINT1_MASK        (_CHIP_IMR_TINT1_MK(1))
#define _CHIP_IMR_TINT1_CLR         (~(_CHIP_IMR_TINT1_MASK))

#define CHIP_IMR_TINT1_ENABLE            (0x0001u)
#define CHIP_IMR_TINT1_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_DMAC1: DMA Channel #1 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_DMAC1_SHIFT       (0x0007u)
#define _CHIP_IMR_DMAC1_MK(n)       (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC1_SHIFT)
#define _CHIP_IMR_DMAC1_MASK        (_CHIP_IMR_DMAC1_MK(1))
#define _CHIP_IMR_DMAC1_CLR       (~(_CHIP_IMR_DMAC1_MASK))

#define CHIP_IMR_DMAC1_ENABLE            (0x0001u)
#define CHIP_IMR_DMAC1_DISABLE           (0x0000u)

#endif

#if (!(CHIP_5401 | CHIP_5402 | CHIP_5471) && (!CHIP_ALL))
  /*----------------------------------------------------------------------------*\
  * (RW) _CHIP_IMR_XINT2: MCBSP #2 transmit interrupt
  \*----------------------------------------------------------------------------*/
  #define _CHIP_IMR_XINT2_SHIFT      (0x0007u)
  #define _CHIP_IMR_XINT2_MK(n)      (((Uint16)(n) & 0x0001u) << _CHIP_IMR_XINT2_SHIFT)
  #define _CHIP_IMR_XINT2_MASK       (_CHIP_IMR_XINT2_MK(1))
  #define _CHIP_IMR_XINT2_CLR        (~(_CHIP_IMR_XINT2_MASK))

  #define CHIP_IMR_XINT2_ENABLE            (0x0001u)
  #define CHIP_IMR_XTIN2_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
  * (RW) _CHIP_IMR_DMAC1: MCBSP #2 transmit interrupt
  \*----------------------------------------------------------------------------*/
  #define _CHIP_IMR_DMAC1_SHIFT      (0x0007u)
  #define _CHIP_IMR_DMAC1_MK(n)      (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC1_SHIFT)
  #define _CHIP_IMR_DMAC1_MASK       (_CHIP_IMR_DMAC1_MK(1))
  #define _CHIP_IMR_DMAC1_CLR        (~(_CHIP_IMR_DMAC1_MASK))

  #define CHIP_IMR_DMAC1_ENABLE            (0x0001u)
  #define CHIP_IMR_DMAC1_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
  * (RW) _CHIP_IMR_RINT2: MCBSP #2 receive interrupt
  \*----------------------------------------------------------------------------*/
  #define _CHIP_IMR_RINT2_SHIFT      (0x0006u)
  #define _CHIP_IMR_RINT2_MK(n)      (((Uint16)(n) & 0x0001u) << _CHIP_IMR_RINT2_SHIFT)
  #define _CHIP_IMR_RINT2_MASK       (_CHIP_IMR_RINT2_MK(1))
  #define _CHIP_IMR_RINT2_CLR        (~(_CHIP_IMR_RINT2_MASK))

  #define CHIP_IMR_RINT2_ENABLE            (0x0001u)
  #define CHIP_IMR_RINT2_DISABLE           (0x0000u)

#endif  /* (CHIP_5409 | CHIP_5410 | CHIP_5416 | CHIP_5420 | CHIP_5440) */

#if (CHIP_5471 | CHIP_5472)
  /*----------------------------------------------------------------------------*\
  * (RW) _CHIP_IMR_DMAC1: MCBSP #2 transmit interrupt
  \*----------------------------------------------------------------------------*/
  #define _CHIP_IMR_DMAC1_SHIFT        (0x0007u)
  #define _CHIP_IMR_DMAC1_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC1_SHIFT)
  #define _CHIP_IMR_DMAC1_MASK         (_CHIP_IMR_DMAC1_MK(1))
  #define _CHIP_IMR_DMAC1_CLR          (~(_CHIP_IMR_DMAC1_MASK))
  
  #define CHIP_IMR_DMAC1_ENABLE            (0x0001u)
  #define CHIP_IMR_DMAC1_DISABLE           (0x0000u)

#endif /* CHIP_5471 */

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_DMAC0: DMA Channel #0 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_DMAC0_SHIFT         (0x0006u)
#define _CHIP_IMR_DMAC0_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IMR_DMAC0_SHIFT)
#define _CHIP_IMR_DMAC0_MASK          (_CHIP_IMR_DMAC0_MK(1))
#define _CHIP_IMR_DMAC0_CLR           (~(_CHIP_IMR_DMAC0_MASK))

#define CHIP_IMR_DMAC0_ENABLE            (0x0001u)
#define CHIP_IMR_DMAC0_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_XINT0: MCBSP #0 transmit interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_XINT0_SHIFT         (0x0005u)
#define _CHIP_IMR_XINT0_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IMR_XINT0_SHIFT)
#define _CHIP_IMR_XINT0_MASK          (_CHIP_IMR_XINT0_MK(1))
#define _CHIP_IMR_XINT0_CLR           (~(_CHIP_IMR_XINT0_MASK))

#define CHIP_IMR_XINT0_ENABLE            (0x0001u)
#define CHIP_IMR_XTIN0_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_RINT0: MCBSP #0 receive interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_RINT0_SHIFT         (0x0004u)
#define _CHIP_IMR_RINT0_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IMR_RINT0_SHIFT)
#define _CHIP_IMR_RINT0_MASK          (_CHIP_IMR_RINT0_MK(1))
#define _CHIP_IMR_RINT0_CLR           (~(_CHIP_IMR_RINT0_MASK))

#define CHIP_IMR_RINT0_ENABLE            (0x0001u)
#define CHIP_IMR_RINT0_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_TINT0: Timer #0 interrupt
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_TINT0_SHIFT         (0x0003u)
#define _CHIP_IMR_TINT0_MK(n)         (((Uint16)(n) & 0x0001u) << _CHIP_IMR_TINT0_SHIFT)
#define _CHIP_IMR_TINT0_MASK          (_CHIP_IMR_TINT0_MK(1))
#define _CHIP_IMR_TINT0_CLR           (~(_CHIP_IMR_TINT0_MASK))

#define CHIP_IMR_TINT0_ENABLE            (0x0001u)
#define CHIP_IMR_TINT0_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_INT2: External interrupt #2 flag
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_INT2_SHIFT          (0x0002u)
#define _CHIP_IMR_INT2_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IMR_INT2_SHIFT)
#define _CHIP_IMR_INT2_MASK           (_CHIP_IMR_INT2_MK(1))
#define _CHIP_IMR_INT2_CLR            (~(_CHIP_IMR_INT2_MASK))

#define CHIP_IMR_INT2_ENABLE            (0x0001u)
#define CHIP_IMR_INT2_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_INT1: External interrupt #1 flag
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_INT1_SHIFT          (0x0001u)
#define _CHIP_IMR_INT1_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IMR_INT1_SHIFT)
#define _CHIP_IMR_INT1_MASK           (_CHIP_IMR_INT1_MK(1))
#define _CHIP_IMR_INT1_CLR            (~(_CHIP_IMR_INT1_MASK))

#define CHIP_IMR_INT1_ENABLE            (0x0001u)
#define CHIP_IMR_INT1_DISABLE           (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_IMR_INT0: External interrupt #0 flag
\*----------------------------------------------------------------------------*/
#define _CHIP_IMR_INT0_SHIFT          (0x0000u)
#define _CHIP_IMR_INT0_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_IMR_INT0_SHIFT)
#define _CHIP_IMR_INT0_MASK           (_CHIP_IMR_INT0_MK(1))
#define _CHIP_IMR_INT0_CLR            (~(_CHIP_IMR_INT0_MASK))

#define CHIP_IMR_INT0_ENABLE            (0x0001u)
#define CHIP_IMR_INT0_DISABLE           (0x0000u)

/*---------------------------------------------------------------------------*\
* Macros to SET/GET and Confgirue globally the IMR register
\*---------------------------------------------------------------------------*/
/******************************************************************************\
* _CHIP_PMST - Prcoessor mode status register
*
* Fields: 
*   (RW)   _CHIP_PMST_IPTR
*   (RW)   _CHIP_PMST_MPMC
*   (RW)   _CHIP_PMST_OVLY
*   (RW)   _CHIP_PMST_AVIS
*   (RW)   _CHIP_PMST_DROM
*   (RW)   _CHIP_PMST_CLKOFF
*   (RW)   _CHIP_PMST_SMUL
*   (RW)   _CHIP_PMST_SST
*
\******************************************************************************/

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_IPTR: interrupt vector pointer
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_IPTR_SHIFT          (0x0007u)
#define _CHIP_PMST_IPTR_MK(n)          (((Uint16)(n) & 0x01ffu) << _CHIP_PMST_IPTR_SHIFT)
#define _CHIP_PMST_IPTR_MASK           (_CHIP_PMST_IPTR_MK(0x1ffu))
#define _CHIP_PMST_IPTR_CLR            (~(_CHIP_PMST_IPTR_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_MPMC: micro-processor/microcontroller mode bit
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_MPMC_SHIFT          (0x0006u)
#define _CHIP_PMST_MPMC_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_PMST_MPMC_SHIFT)
#define _CHIP_PMST_MPMC_MASK           (_CHIP_PMST_MPMC_MK(1))
#define _CHIP_PMST_MPMC_CLR            (~(_CHIP_PMST_MPMC_MASK))

#define CHIP_PMST_MPMC_ON              (0x0001u)
#define CHIP_PMST_MPMC_OFF             (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_OVLY: ovly ram enable bit
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_OVLY_SHIFT          (0x0005u)
#define _CHIP_PMST_OVLY_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_PMST_OVLY_SHIFT)
#define _CHIP_PMST_OVLY_MASK           (_CHIP_PMST_OVLY_MK(1))
#define _CHIP_PMST_OVLY_CLR            (~(_CHIP_PMST_OVLY_MASK))

#define CHIP_PMST_OVLY_ON              (0x0001u)
#define CHIP_PMST_OVLY_OFF             (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_AVIS: address visibility mode bit
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_AVIS_SHIFT          (0x0004u)
#define _CHIP_PMST_AVIS_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_PMST_AVIS_SHIFT)
#define _CHIP_PMST_AVIS_MASK           (_CHIP_PMST_AVIS_MK(1))
#define _CHIP_PMST_AVIS_CLR            (~(_CHIP_PMST_AVIS_MASK))

#define _CHIP_PMST_AVIS_ENABLED        (0x0001u)
#define _CHIP_PMST_AVIS_DISABLED       (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_DROM: data rom enable bit
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_DROM_SHIFT          (0x0003u)
#define _CHIP_PMST_DROM_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_PMST_DROM_SHIFT)
#define _CHIP_PMST_DROM_MASK           (_CHIP_PMST_DROM_MK(1))
#define _CHIP_PMST_DROM_CLR            (~(_CHIP_PMST_DROM_MASK))

#define CHIP_PMST_DROM_ENABLED         (0x0001u)
#define CHIP_PMST_DROM_DISABLED        (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_CLKOFF: enable/disable clkout
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_CLKOFF_SHIFT        (0x0002u)
#define _CHIP_PMST_CLKOFF_MK(n)        (((Uint16)(n) & 0x0001u) << _CHIP_PMST_CLKOFF_SHIFT)
#define _CHIP_PMST_CLKOFF_MASK         (_CHIP_PMST_CLKOFF_MK(1))
#define _CHIP_PMST_CLKOFF_CLR          (~(_CHIP_PMST_CLKOFF_MASK))

#define CHIP_PMST_CLKOFF_CLKOUTENABLE      (0x0001u)
#define CHIP_PMST_CLKOFF_CLKOUTDISABLE     (0x0000u)


/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_SMUL: enable/disable saturation on multiplication
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_SMUL_SHIFT          (0x0001u)
#define _CHIP_PMST_SMUL_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_PMST_SMUL_SHIFT)
#define _CHIP_PMST_SMUL_MASK           (_CHIP_PMST_SMUL_MK(1))
#define _CHIP_PMST_SMUL_CLR            (~(_CHIP_PMST_SMUL_MASK))

#define CHIP_PMST_SMUL_ENABLE          (0x0001u)
#define CHIP_PMST_SMUL_DISABLE         (0x0000u)

/*----------------------------------------------------------------------------*\
* (RW) _CHIP_PMST_SST: enable/disable saturation on store
\*----------------------------------------------------------------------------*/
#define _CHIP_PMST_SST_SHIFT          (0x0000u)
#define _CHIP_PMST_SST_MK(n)          (((Uint16)(n) & 0x0001u) << _CHIP_PMST_SST_SHIFT)
#define _CHIP_PMST_SST_MASK           (_CHIP_PMST_SST_MK(1))
#define _CHIP_PMST_SST_CLR            (~(_CHIP_PMST_SST_MASK))

#define CHIP_PMST_SST_ENABLE          (0x0001u)
#define CHIP_PMST_SST_DISABLE         (0x0000u)

/*---------------------------------------------------------------------------*\
* Macros to SET/GET and Confgirue globally the PMST register
\*---------------------------------------------------------------------------*/

#if (_CHIP_CPU_ID_SUPPORT)
  /******************************************************************************\
  * _CHIP_PMST - Prcoessor mode status register
  *
  * Fields: 
  *   (R)   _CHIP_CSIDR_CHIPID
  *   (R)   _CHIP_CSIDR_CHIPREVISION
  *   (R)   _CHIP_CSIDR_SUBSYSID
  *
  \******************************************************************************/
  /*----------------------------------------------------------------------------*\
  * (R) _CHIP_CSIDR_CHIPID: CPU identification number
  \*----------------------------------------------------------------------------*/
  #define _CHIP_CSIDR_CHIPID_SHIFT        (0x0008u)
  #define _CHIP_CSIDR_CHIPID_MK(n)        (((Uint16)(n) & 0x00FFu) << _CHIP_CSIDR_CHIPID_SHIFT)
  #define _CHIP_CSIDR_CHIPID_MASK         (_CHIP_CSIDR_CHIPID_MK(0x00FFu))
  #define _CHIP_CSIDR_CHIPID_CLR          (~(_CHIP_CSIDR_CHIPID_MASK))

  #if (!((CHIP_5440) | (CHIP_5441)))
    /*----------------------------------------------------------------------------*\
    * (R) _CHIP_CSIDR_CHIPREVISION: CPU revision number
    \*----------------------------------------------------------------------------*/
    #define _CHIP_CSIDR_CHIPREVISION_SHIFT  (0x0004u)
    #define _CHIP_CSIDR_CHIPREVISION_MK(n)  (((Uint16)(n) & 0x000Fu) << _CHIP_CSIDR_CHIPREVISION_SHIFT)
    #define _CHIP_CSIDR_CHIPREVISION_MASK   (_CHIP_CSIDR_CHIPREVISION_MK(0x000Fu))
    #define _CHIP_CSIDR_CHIPREVISION_CLR    (~(_CHIP_CSIDR_CHIPREVISION_MASK))

  #endif /* CHIP_5440 | CHIP_5441 */

  /*----------------------------------------------------------------------------*\
  * (R) _CHIP_CSIDR_SUBSYSID: CPU sub system identification number
  \*----------------------------------------------------------------------------*/
  #define _CHIP_CSIDR_SUBSYSID_SHIFT      (0x0000u)
  #define _CHIP_CSIDR_SUBSYSID_MK(n)      (((Uint16)(n) & 0x000Fu) << _CHIP_CSIDR_SUBSYSID_SHIFT)
  #define _CHIP_CSIDR_SUBSYSID_MASK       (_CHIP_CSIDR_SUBSYSID_MK(0x000Fu))
  #define _CHIP_CSIDR_SUBSYSID_CLR        (~(_CHIP_CSIDR_SUBSYSID_MASK))

#endif /* CHIP_5411 | CHIP_5412 | CHIP_5416 | CHIP_5421 | CHIP_5440 */

#endif /* _CSL_CHIPHAL_H_ */
/******************************************************************************\
* End of csl_chiphal.h
\******************************************************************************/

