/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/*****************************************************************************\
*           Copyright (C) 2000 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... DAA
* FILENAME...... csl_daa.h
* DATE CREATED.. Wed 02/01/2000
* PROJECT....... Chip Support Library
* COMPONENT.....
* PREREQUISITES..
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:       02/01/2001
*   LAST MODIFIED: 10/16/2001 removed handles, FGET/FSET macros, and all field specific functions
*                  02/23/2001 included Params struct. and setParams fxn.
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the DAA module)
*
*
*
\******************************************************************************/

#ifndef _CSL_DAA_H_
#define _CSL_DAA_H_

#include <csl_stdinc.h>
#include <csl_stdinch.h>
#include <csl_csldat.h>
#include <csl_chiphal.h>
#include <csl_daahal.h>
/* #include <csl_daadat.h> */
#include <csl_mcbsp.h>

#ifdef __cplusplus
extern "C" {
#endif

#if (_DAA_SUPPORT)
/****************************************\
* DAA scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"
#else
#define CSLAPI extern
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _DAA_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

typedef void (*DAA_CallBack) (void* pID, Uint16 task, Uint16 arg);
typedef void (*DAA_RstFxn) (Uint16);


/******************************************************************************\
* Macros
\******************************************************************************/



/******************************************************************************\
* Types
\******************************************************************************/

/* Testing/Loopback Modes */
#define DAA_STARTUP_TEST                 (0x0000)          /* start-up test mode (default) */
#define DAA_ISO_DIGITAL                  (0x0001)          /* isolation link digital loopback */
#define DAA_ANALOG                       (0x0002)          /* analog loopback */
#define DAA_INTERNAL_ANALOG              (0x0003)          /* internal analog loopback */


/******************************************************************************\
* Register Field Values
\******************************************************************************/

/* Control 1 Register field values */
#define DAA_CTRL1_SB_16bits              (0x0001u)         /* 16-bit serial data transfers */
#define DAA_CTRL1_SB_15bits              (0x0000u)         /* 15-bit serial data transfers */
#define DAA_CTRL1_DL_ENABLE              (0x0002u)         /* Enable isolation link digital loopback */
#define DAA_CTRL1_DL_DISABLE             (0x0000u)         /* Disable isolation link digital loopback */
#define DAA_CTRL1_SR_RESET               (0x0080u)         /* Reset bits to their reset value */
#define DAA_CTRL1_SR_UNRESET             (0x0000u)         /* Normal operation */

#define DAA_CTRL1_RMK(sb, dl, sr)((Uint16)(\
    (DAA_FMK(CTRL1,SB, sb))|\
    (DAA_FMK(CTRL1,DL, dl))|\
    (DAA_FMK(CTRL1,SR, sr))\
 )\
)

#define DMA_CTRL1_RMKS(sb_sym, dl_sym, sr_sym)((Uint16)(\
    (DAA_FMKS(CTRL1,SB, sb_sym))|\
    (DAA_FMKS(CTRL1,DL, dl_sym))|\
    (DAA_FMKS(CTRL1,SR, sr_sym))\
 )\
)


/* Control 2 Register field values */
#define DAA_CTRL2_RXE_ENABLE             (0x0001u)         /* Receive path enabled */
#define DAA_CTRL2_RXE_DISABLE            (0x0000u)         /* Receive path disabled */
#define DAA_CTRL2_HBE_ENABLE             (0x0002u)         /* Connects Hybrid in transmit path */
#define DAA_CTRL2_HBE_DISABLE            (0x0000u)         /* Disconnects Hybrid in transmit path */
#define DAA_CTRL2_AL_ENABLE              (0x0008u)         /* Enable analog loopback */
#define DAA_CTRL2_AL_DISABLE             (0x0000u)         /* Disable analog loopback */

#define DAA_CTRL2_RMK(rxe, hbe, al)((Uint16)(\
    (DAA_FMK(CTRL2,RXE, rxe))|\
    (DAA_FMK(CTRL2,HBE, hbe))|\
    (DAA_FMK(CTRL2,AL, al))\
 )\
)

#define DMA_CTRL2_RMKS(rxe_sym, hbe_sym, al_sym)((Uint16)(\
    (DAA_FMKS(CTRL2,RXE, rxe_sym))|\
    (DAA_FMKS(CTRL2,HBE, hbe_sym))|\
    (DAA_FMKS(CTRL2,AL, al_sym))\
 )\
)


/* DAA Control 1 Register field values */
#define DAA_DAACTRL1_OH_OFFHOOK          (0x0001u)         /* Set DAA off-hook */
#define DAA_DAACTRL1_OH_ONHOOK           (0x0000u)         /* Set DAA on-hook */
#define DAA_DAACTRL1_RDT_TRUE            (0x0004u)         /* Ring detect true */
#define DAA_DAACTRL1_RDT_FALSE           (0x0000u)         /* Ring detect false */
#define DAA_DAACTRL1_ONHM_ENABLE         (0x0008u)         /* Enable on-hook CID path */
#define DAA_DAACTRL1_ONHM_DISABLE        (0x0000u)         /* Disable on-hook CID path */
#define DAA_DAACTRL1_RDTP_TRUE           (0x0020u)         /* Ring detect positive true */
#define DAA_DAACTRL1_RDTP_FALSE          (0x0000u)         /* Ring detect positive false */
#define DAA_DAACTRL1_RDTN_TRUE           (0x0040u)         /* Ring detect negative true */
#define DAA_DAACTRL1_RDTN_FALSE          (0x0000u)         /* Ring detect negative false */

#define DAA_DAACTRL1_RMK(oh, rdt, onhm, rdtp, rdtn)((Uint16)(\
    (DAA_FMK(DAACTRL1,OH, oh))|\
    (DAA_FMK(DAACTRL1,RDT, rdt))|\
    (DAA_FMK(DAACTRL1,ONHM, onhm))|\
    (DAA_FMK(DAACTRL1,RDTP, rdtp))|\
    (DAA_FMK(DAACTRL1,RDTN, rdtn))\
 )\
)

#define DMA_DAACTRL1_RMKS(oh_sym, rdt_sym, onhm_sym, rdtp_sym, rdtn_sym)((Uint16)(\
    (DAA_FMKS(DAACTRL1,OH, oh_sym))|\
    (DAA_FMKS(DAACTRL1,RDT, rdt_sym))|\
    (DAA_FMKS(DAACTRL1,ONHM, onhm_sym))|\
    (DAA_FMKS(DAACTRL1,RDTP, rdtp_sym))|\
    (DAA_FMKS(DAACTRL1,RDTN, rdtn_sym))\
 )\
)


/* DAA Control 2 Register field values */
#define DAA_DAACTRL2_PDN_ENABLE          (0x0008u)         /* power down system side chip */
#define DAA_DAACTRL2_PDN_DISABLE         (0x0000u)         /* power up system side chip */
#define DAA_DAACTRL2_PDL_ENABLE          (0x0010u)         /* power down line side chip */
#define DAA_DAACTRL2_PDL_DISABLE         (0x0000u)         /* power up line side chip */

#define DAA_DAACTRL2_RMK(pdn, pdl)((Uint16)(\
    (DAA_FMK(DAACTRL2,PDN, pdn))|\
    (DAA_FMK(DAACTRL2,PDL, pdl))\
 )\
)

#define DMA_DAACTRL2_RMKS(pdn_sym, pdl_sym)((Uint16)(\
    (DAA_FMKS(DAACTRL2,PDN, pdn_sym))|\
    (DAA_FMKS(DAACTRL2,PDL, pdl_sym))\
 )\
)


/* Sample Rate Control Register field values */
#define DAA_SRCTRL_SRC_7200              (0x0000u)         /* 7200 Hz. */
#define DAA_SRCTRL_SRC_8000              (0x0001u)         /* 8000 Hz. */
#define DAA_SRCTRL_SRC_8229              (0x0002u)         /* 8229 Hz. */
#define DAA_SRCTRL_SRC_8400              (0x0003u)         /* 8400 Hz. */
#define DAA_SRCTRL_SRC_9000              (0x0004u)         /* 9000 Hz. */
#define DAA_SRCTRL_SRC_9600              (0x0005u)         /* 9600 Hz. */
#define DAA_SRCTRL_SRC_10286             (0x0006u)         /* 10286 Hz. */

#define DAA_SRCTRL_RMK(src)((Uint16)(\
    (DAA_FMK(SRCTRL,SRC, src))\
 )\
)

#define DMA_SRCTRL_RMKS(src_sym)((Uint16)(\
    (DAA_FMKS(SRCTRL,SRC, src_sym))\
 )\
)


/* Chip A Revision Register field values */
#define DAA_CPAREV_RMK(reva)((Uint16)(\
    (DAA_FMK(CPAREV,REVA, reva))\
 )\
)

#define DMA_CPAREV_RMKS()((Uint16)(\
 )\
)


/* Line Side Status Register field values */
#define DAA_LSS_FDT_LOCKED               (0x0040u)         /* ISOcap link frame locked */
#define DAA_LSS_FDT_UNLOCKED             (0x0000u)         /* ISOcap link frame not locked */
#define DAA_LSS_CLE_TRUE                 (0x0080u)         /* ISOcap communication link down */
#define DAA_LSS_CLE_FALSE                (0x0000u)         /* ISOcap communication link is operating correctly */

#define DAA_LSS_RMK(fdt, cle, lcs)((Uint16)(\
    (DAA_FMK(LSS,FDT, fdt))|\
    (DAA_FMK(LSS,CLE, cle))|\
    (DAA_FMK(LSS,LCS, lcs))\
 )\
)

#define DMA_LSS_RMKS(fdt_sym, cle_sym)((Uint16)(\
    (DAA_FMKS(LSS,FDT, fdt_sym))|\
    (DAA_FMKS(LSS,CLE, cle_sym))\
 )\
)


/* Chip B Revision Register field values */
#define DAA_CPBREV_CBID_INTERNATIONAL    (0x0040u)         /* Line side has international support */
#define DAA_CPBREV_CBID_DOMESTIC         (0x0000u)         /* Line side is domestic only */

#define DAA_CPBREV_RMK(cbid, revb)((Uint16)(\
    (DAA_FMK(CPBREV,CBID, cbid))|\
    (DAA_FMK(CPBREV,REVB, revb))\
 )\
)

#define DMA_CPBREV_RMKS(cbid_sym)((Uint16)(\
    (DAA_FMKS(CPBREV,CBID, cbid_sym))|\
 )\
)


/* $$$ Line Side Validation??? Daisy Chain Control Register field values */
#define DAA_DCC_SAFE_ERR                 (0x0001u)         /* Incorrect line-side device detected */
#define DAA_DCC_SAFE_OK                  (0x0000u)         /* Correct line-side device detected */
#define DAA_DCC_CIP_TRUE                 (0x0001u)         /* Line-side device check in progress */
#define DAA_DCC_CIP_FALSE                (0x0000u)         /* Line-side device check not in progress */
#define DAA_DCC_CHK_NOT_DONE             (0x0001u)         /* Line-side device check done */
#define DAA_DCC_CHK_DONE                 (0x0000u)         /* Line-side device check not done */

#define DAA_DCC_RMK(safe, cip, chk)((Uint16)(\
    (DAA_FMK(DCC,SAFE, safe))|\
    (DAA_FMK(DCC,CIP, cip))\
    (DAA_FMK(DCC,CHK, chk))\
 )\
)

#define DMA_DCC_RMKS(safe_sym, cip_sym, chk_sym)((Uint16)(\
    (DAA_FMKS(DCC,SAFE, safe_sym))|\
    (DAA_FMKS(DCC,CIP, cip_sym))\
    (DAA_FMKS(DCC,CHK, chk_sym))\
 )\
)


/* TX/RX Gain Control Register field values */
#define DAA_GCR_ARX_ATT_0db           (0x0000u)         /* 0db Attenuation */
#define DAA_GCR_ARX_ATT_1db           (0x0001u)         /* 1db Attenuation */
#define DAA_GCR_ARX_ATT_2.2db         (0x0002u)         /* 2.2db Attenuation */
#define DAA_GCR_ARX_ATT_3.5db         (0x0003u)         /* 3.5db Attenuation */
#define DAA_GCR_ARX_ATT_5db           (0x0004u)         /* 5db Attenuation */

#define DAA_GCR_ARX_GAIN_0db          (0x0000u)         /* 0db Gain */
#define DAA_GCR_ARX_GAIN_3db          (0x0001u)         /* 3db Gain */
#define DAA_GCR_ARX_GAIN_6db          (0x0002u)         /* 6db Gain */
#define DAA_GCR_ARX_GAIN_9db          (0x0003u)         /* 9db Gain */
#define DAA_GCR_ARX_GAIN_12db         (0x0004u)         /* 12db Gain */

#define DAA_GCR_RXM_MUTE              (0x0008u)         /* Mute Receiver */
#define DAA_GCR_RXM_NOT_MUTE          (0x0000u)         /* Receiver not Mute */

#define DAA_GCR_ATX_ATT_0db           (0x0000u)         /* 0db Attenuation */
#define DAA_GCR_ATX_ATT_3db           (0x0010u)         /* 3db Attenuation */
#define DAA_GCR_ATX_ATT_6db           (0x0020u)         /* 6db Attenuation */
#define DAA_GCR_ATX_ATT_9db           (0x0030u)         /* 9db Attenuation */
#define DAA_GCR_ATX_ATT_12db          (0x0040u)         /* 12db Attenuation */

#define DAA_GCR_TXM_MUTE              (0x0080u)         /* Mute Receiver */
#define DAA_GCR_TXM_NOT_MUTE          (0x0000u)         /* Receiver not Mute */

#define DAA_GCR_RMK(arx, rxm, atx, txm)((Uint16)(\
    (DAA_FMK(GCR,ARX, arx))|\
    (DAA_FMK(GCR,RXM, rxm))|\
    (DAA_FMK(GCR,ATX, atx))|\
    (DAA_FMK(GCR,TXM, txm))\
 )\
)

#define DMA_GCR_RMKS(arx_sym, rxm_sym, atx_sym, txm_sym)((Uint16)(\
    (DAA_FMKS(GCR,ARX, arx_sym))|\
    (DAA_FMKS(GCR,RXM, rxm_sym))|\
    (DAA_FMKS(GCR,ATX, atx_sym))|\
    (DAA_FMKS(GCR,TXM, txm_sym))\
 )\
)


/* International Control 1 Register field values */
#define DAA_ICTRL1_RT_11to22V            (0x0000u)         /* Ringer threshold is 11 to 22Vrms */
#define DAA_ICTRL1_RT_17to33V            (0x0001u)         /* Ringer threshold is 17 to 33Vrms */
#define DAA_ICTRL1_RZ_MAXIMUM_IMP        (0x0000u)         /* Maximum (high) ringer impedance */
#define DAA_ICTRL1_RZ_SYNTHESIZED_IMP    (0x0002u)         /* Synthesized ringer impedance */
#define DAA_ICTRL1_DCT_LOW_VOLTAGE       (0x0000u)         /* Low voltage mode */
#define DAA_ICTRL1_DCT_JAPAN             (0x0004u)         /* Japan mode */
#define DAA_ICTRL1_DCT_FCC               (0x0008u)         /* FCC mode */
#define DAA_ICTRL1_DCT_CTR21             (0x000Cu)         /* CTR21 mode */
#define DAA_ICTRL1_ACT_REAL_IMP          (0x0000u)         /* Real impedance selected */
#define DAA_ICTRL1_ACT_COMPLEX_IMP       (0x0020u)         /* Complex impedance selected */
#define DAA_ICTRL1_OHS_FAST              (0x0000u)         /* Fast on-hook speed */
#define DAA_ICTRL1_OHS_SLOW              (0x0040u)         /* Slow on-hook speed */
#define DAA_ICTRL1_OFF_SQL2_NORMAL       (0x0000u)         /* Normal operation */
#define DAA_ICTRL1_OFF_SQL2_DC_DISABLE   (0x0080u)         /* DC termination disabled */
#define DAA_ICTRL1_OFF_SQL2_SQ_ENABLE    (0x0080u)         /* Enhanced squelch function enabled */

#define DAA_ICTRL1_RMK(rt, rz, dct, act, ohs, off_sql2)((Uint16)(\
    (DAA_FMK(ICTRL1,RT, rt))|\
    (DAA_FMK(ICTRL1,RZ, rz))|\
    (DAA_FMK(ICTRL1,DCT, dct))|\
    (DAA_FMK(ICTRL1,ACT, act))|\
    (DAA_FMK(ICTRL1,OHS, ohs))|\
    (DAA_FMK(ICTRL1,OFF_SQL2, off_sql2))\
 )\
)

#define DMA_ICTRL1_RMKS(rt_sym, rz_sym, dct_sym, act_sym, ohs_sym, off_sql2_sym)((Uint16)(\
    (DAA_FMKS(ICTRL1,RT, rt_sym))|\
    (DAA_FMKS(ICTRL1,RZ, rz_sym))|\
    (DAA_FMKS(ICTRL1,DCT, dct_sym))|\
    (DAA_FMKS(ICTRL1,ACT, act_sym))|\
    (DAA_FMKS(ICTRL1,OHS, ohs_sym))|\
    (DAA_FMKS(ICTRL1,OFF_SQL2, off_sql2_sym))\
 )\
)


/* International Control 2 Register field values */
#define DAA_ICTRL2_BTD_FALSE             (0x0000u)         /* No billing tone detected */
#define DAA_ICTRL2_BTD_TRUE              (0x0001u)         /* Billing tone detected */
#define DAA_ICTRL2_ROV_NORMAL            (0x0000u)         /* Normal receive input level */
#define DAA_ICTRL2_ROV_EXCESS            (0x0002u)         /* Excessive receive input level */
#define DAA_ICTRL2_BTE_DISABLE           (0x0000u)         /* Billing tone protect disable */
#define DAA_ICTRL2_BTE_ENABLE            (0x0004u)         /* Billing tone protect enable */
#define DAA_ICTRL2_OPE_DISABLE           (0x0000u)         /* Overload protect disable */
#define DAA_ICTRL2_OPE_ENABLE            (0x0008u)         /* Overload protect enable */
#define DAA_ICTRL2_LIM_DISABLE           (0x0000u)         /* Current limit disable */
#define DAA_ICTRL2_LIM_ENABLE            (0x0010u)         /* Current limit enable */
#define DAA_ICTRL2_CALD_ENABLE           (0x0000u)         /* Auto-calibration enable */
#define DAA_ICTRL2_CALD_DISABLE          (0x0020u)         /* Auto-calibration disable */
#define DAA_ICTRL2_MCAL_NO               (0x0000u)         /* No manual calibration */
#define DAA_ICTRL2_MCAL_INIT             (0x0040u)         /* Initiate manual calibration */

#define DAA_ICTRL2_RMK(btd, rov, bte, ope, lim, cald, mcal)((Uint16)(\
    (DAA_FMK(ICTRL2,BTD, btd))|\
    (DAA_FMK(ICTRL2,ROV, rov))|\
    (DAA_FMK(ICTRL2,BTE, bte))|\
    (DAA_FMK(ICTRL2,OPE, ope))|\
    (DAA_FMK(ICTRL2,LIM, lim))|\
    (DAA_FMK(ICTRL2,CALD, cald))|\
    (DAA_FMK(ICTRL2,MCAL, mcal))\
 )\
)

#define DMA_ICTRL2_RMKS(btd_sym, rov_sym, bte_sym, ope_sym, lim_sym, cald_sym, mcal_sym)((Uint16)(\
    (DAA_FMKS(ICTRL2,BTD, btd_sym))|\
    (DAA_FMKS(ICTRL2,ROV, rov_sym))|\
    (DAA_FMKS(ICTRL2,BTE, bte_sym))|\
    (DAA_FMKS(ICTRL2,OPE, ope_sym))|\
    (DAA_FMKS(ICTRL2,LIM, lim_sym))|\
    (DAA_FMKS(ICTRL2,CALD, cald_sym))|\
    (DAA_FMKS(ICTRL2,MCAL, mcal_sym))\
 )\
)


/* International Control 3 Register field values */
#define DAA_ICTRL3_SQLH_NORMAL           (0x0000u)         /* Normal operation */
#define DAA_ICTRL3_SQLH_ENABLE           (0x0001u)         /* Squelch function enable */
#define DAA_ICTRL3_RFWE_HALF             (0x0000u)         /* Half wave rectification */
#define DAA_ICTRL3_RFWE_FULL             (0x0002u)         /* Full wave rectification */
#define DAA_ICTRL3_MODE_DISABLE          (0x0000u)         /* On-hook line monitor ADC and line voltage monitor disable */
#define DAA_ICTRL3_MODE_ENABLE           (0x0004u)         /* On-hook line monitor ADC and line voltage monitor enable */
#define DAA_ICTRL3_FLVM_NORMAL           (0x0000u)         /* Normal operation */
#define DAA_ICTRL3_FLVM_FORCE            (0x0008u)         /* Force low voltage DC termination */
#define DAA_ICTRL3_VOL_NORMAL            (0x0000u)         /* Normal operation */
#define DAA_ICTRL3_VOL_LOWER             (0x0010u)         /* Lower DC voltage */
#define DAA_ICTRL3_FJM_NORMAL            (0x0000u)         /* Normal gain */
#define DAA_ICTRL3_FJM_FORCE             (0x0020u)         /* Force Japan DC termination mode */
#define DAA_ICTRL3_DIAL_NORMAL           (0x0000u)         /* Normal operation */
#define DAA_ICTRL3_DIAL_INCREASE         (0x0040u)         /* Increase headroom for DTMF dialing */
#define DAA_ICTRL3_FULL_DEFAULT          (0x0000u)         /* Default full scale */
#define DAA_ICTRL3_FULL_3.2dBm           (0x0080u)         /* Transmit/receive full scale = +/- 3.2dBm */

#define DAA_ICTRL3_RMK(sqlh, rfwe, mode, flvm, vol, fjm, dial, full)((Uint16)(\
    (DAA_FMK(ICTRL3,SQLH, sqlh))|\
    (DAA_FMK(ICTRL3,RFWE, rfwe))|\
    (DAA_FMK(ICTRL3,MODE, mode))|\
    (DAA_FMK(ICTRL3,FLVM, flvm))|\
    (DAA_FMK(ICTRL3,VOL, vol))|\
    (DAA_FMK(ICTRL3,FJM, fjm))|\
    (DAA_FMK(ICTRL3,DIAL, dial))|\
    (DAA_FMK(ICTRL3,FULL, full))\
 )\
)

#define DMA_ICTRL3_RMKS(sqlh_sym, rfwe_sym, mode_sym, flvm_sym, vol_sym, fjm_sym, dial_sym, full_sym)((Uint16)(\
    (DAA_FMKS(ICTRL3,SQLH, sqlh_sym))|\
    (DAA_FMKS(ICTRL3,RFWE, rfwe_sym))|\
    (DAA_FMKS(ICTRL3,MODE, mode_sym))|\
    (DAA_FMKS(ICTRL3,FLVM, flvm_sym))|\
    (DAA_FMKS(ICTRL3,VOL, vol_sym))|\
    (DAA_FMKS(ICTRL3,FJM, fjm_sym))|\
    (DAA_FMKS(ICTRL3,DIAL, dial_sym))|\
    (DAA_FMKS(ICTRL3,FULL, full_sym))\
 )\
)


/* International Control 4 Register field values */
#define DAA_ICTRL4_OPD_INACTIVE          (0x0000u)         /* Overload protection inactive */
#define DAA_ICTRL4_OPD_ACTIVE            (0x0001u)         /* Overload protection active */
#define DAA_ICTRL4_DOD_NORMAL            (0x0000u)         /* Normal operation */
#define DAA_ICTRL4_DOD_ACTIVE            (0x0002u)         /* Line supply dropout detected when on-hook */
#define DAA_ICTRL4_OVL_NORMAL            (0x0000u)         /* Normal receive input level */
#define DAA_ICTRL4_OVL_EXCESS            (0x0004u)         /* Excessive receive input level */

#define DAA_ICTRL4_RMK(opd, dod, ovl, lvcs)((Uint16)(\
    (DAA_FMK(ICTRL4,OPD, opd))|\
    (DAA_FMK(ICTRL4,DOD, dod))|\
    (DAA_FMK(ICTRL4,OVL, ovl))|\
    (DAA_FMK(ICTRL4,LVCS, lvcs))\
 )\
)

#define DMA_ICTRL4_RMKS(opd_sym, dod_sym, ovl_sym)((Uint16)(\
    (DAA_FMKS(ICTRL4,OPD, opd_sym))|\
    (DAA_FMKS(ICTRL4,DOD, dod_sym))|\
    (DAA_FMKS(ICTRL4,OVL, ovl_sym))\
 )\
)


/* Country Name defines */
#define DAA_AUSTRALIA                    DAA_AUSTRALIA_ICTRL1,  \
                                         DAA_AUSTRALIA_ICTRL2,  \
                                         DAA_AUSTRALIA_ICTRL3
#define DAA_BULGARIA                     DAA_BULGARIA_ICTRL1,   \
                                         DAA_BULGARIA_ICTRL2,   \
                                         DAA_BULGARIA_ICTRL3
#define DAA_CHINA                        DAA_CHINA_ICTRL1,      \
                                         DAA_CHINA_ICTRL2,      \
                                         DAA_CHINA_ICTRL3
#define DAA_CTR21                        DAA_CTR21_ICTRL1,      \
                                         DAA_CTR21_ICTRL2,      \
                                         DAA_CTR21_ICTRL3
#define DAA_CZECH_REPUBLIC               DAA_CZECH_REPUBLIC_ICTRL1,  \
                                         DAA_CZECH_REPUBLIC_ICTRL2,  \
                                         DAA_CZECH_REPUBLIC_ICTRL3
#define DAA_FCC                          DAA_FCC_ICTRL1,        \
                                         DAA_FCC_ICTRL2,        \
                                         DAA_FCC_ICTRL3
#define DAA_USA                          DAA_FCC_ICTRL1,        \
                                         DAA_FCC_ICTRL2,        \
                                         DAA_FCC_ICTRL3
#define DAA_HUNGARY                      DAA_HUNGARY_ICTRL1,    \
                                         DAA_HUNGARY_ICTRL2,    \
                                         DAA_HUNGARY_ICTRL3
#define DAA_JAPAN                        DAA_JAPAN_ICTRL1,      \
                                         DAA_JAPAN_ICTRL2,      \
                                         DAA_JAPAN_ICTRL3
#define DAA_MALAYSIA                     DAA_MALAYSIA_ICTRL1,   \
                                         DAA_MALAYSIA_ICTRL2,   \
                                         DAA_MALAYSIA_ICTRL3
#define DAA_NEW_ZEALAND                  DAA_NEW_ZEALAND_ICTRL1,  \
                                         DAA_NEW_ZEALAND_ICTRL2,  \
                                         DAA_NEW_ZEALAND_ICTRL3
#define DAA_PHILIPPINES                  DAA_PHILIPPINES_ICTRL1,  \
                                         DAA_PHILIPPINES_ICTRL2,  \
                                         DAA_PHILIPPINES_ICTRL3
#define DAA_POLAND                       DAA_POLAND_ICTRL1,     \
                                         DAA_POLAND_ICTRL2,     \
                                         DAA_POLAND_ICTRL3
#define DAA_SINGAPORE                    DAA_SINGAPORE_ICTRL1,  \
                                         DAA_SINGAPORE_ICTRL2,  \
                                         DAA_SINGAPORE_ICTRL3
#define DAA_SLOVAKIA                     DAA_SLOVAKIA_ICTRL1,   \
                                         DAA_SLOVAKIA_ICTRL2,   \
                                         DAA_SLOVAKIA_ICTRL3,
#define DAA_SLOVENIA                     DAA_SLOVENIA_ICTRL1,   \
                                         DAA_SLOVENIA_ICTRL2,   \
                                         DAA_SLOVENIA_ICTRL3
#define DAA_SOUTH_AFRICA                 DAA_SOUTH_AFRICA_ICTRL1,  \
                                         DAA_SOUTH_AFRICA_ICTRL2,  \
                                         DAA_SOUTH_AFRICA_ICTRL3
#define DAA_SOUTH_KOREA                  DAA_SOUTH_KOREA_ICTRL1,   \
                                         DAA_SOUTH_KOREA_ICTRL2,   \
                                         DAA_SOUTH_KOREA_ICTRL3


/* International Control register 1 Country Settings */
#define DAA_AUSTRALIA_ICTRL1             (0x0064u)
#define DAA_BULGARIA_ICTRL1              (0x0008u)
#define DAA_CHINA_ICTRL1                 (0x0004u)
#define DAA_CTR21_ICTRL1                 (0x000Cu)         /* see Note 1 */
#define DAA_CZECH_REPUBLIC_ICTRL1        (0x0028u)
#define DAA_FCC_ICTRL1                   (0x0008u)         /* USA */
#define DAA_HUNGARY_ICTRL1               (0x0008u)
#define DAA_JAPAN_ICTRL1                 (0x0004u)
#define DAA_MALAYSIA_ICTRL1              (0x0004u)
#define DAA_NEW_ZEALAND_ICTRL1           (0x0028u)
#define DAA_PHILIPPINES_ICTRL1           (0x0004u)
#define DAA_POLAND_ICTRL1                (0x0008u)
#define DAA_SINGAPORE_ICTRL1             (0x0008u)
#define DAA_SLOVAKIA_ICTRL1              (0x0008u)
#define DAA_SLOVENIA_ICTRL1              (0x0028u)
#define DAA_SOUTH_AFRICA_ICTRL1          (0x0068u)
#define DAA_SOUTH_KOREA_ICTRL1           (0x0004u)


/* International Control register 2 Country Settings */
#define DAA_AUSTRALIA_ICTRL2             (0x0000u)
#define DAA_BULGARIA_ICTRL2              (0x0000u)
#define DAA_CHINA_ICTRL2                 (0x0000u)
#define DAA_CTR21_ICTRL2                 (0x0010u)         /* see Note 1 */
#define DAA_CZECH_REPUBLIC_ICTRL2        (0x0000u)
#define DAA_FCC_ICTRL2                   (0x0000u)         /* USA */
#define DAA_HUNGARY_ICTRL2               (0x0000u)
#define DAA_JAPAN_ICTRL2                 (0x0000u)
#define DAA_MALAYSIA_ICTRL2              (0x0000u)
#define DAA_NEW_ZEALAND_ICTRL2           (0x0000u)
#define DAA_PHILIPPINES_ICTRL2           (0x0000u)
#define DAA_POLAND_ICTRL2                (0x0000u)
#define DAA_SINGAPORE_ICTRL2             (0x0000u)
#define DAA_SLOVAKIA_ICTRL2              (0x0000u)
#define DAA_SLOVENIA_ICTRL2              (0x0000u)
#define DAA_SOUTH_AFRICA_ICTRL2          (0x0000u)
#define DAA_SOUTH_KOREA_ICTRL2           (0x0000u)


/* International Control register 3 Country Settings */
#define DAA_AUSTRALIA_ICTRL3             (0x0000u)
#define DAA_BULGARIA_ICTRL3              (0x0000u)
#define DAA_CHINA_ICTRL3                 (0x0000u)
#define DAA_CTR21_ICTRL3                 (0x0000u)         /* see Note 1 */
#define DAA_CZECH_REPUBLIC_ICTRL3        (0x0000u)
#define DAA_FCC_ICTRL3                   (0x0000u)         /* USA */
#define DAA_HUNGARY_ICTRL3               (0x0000u)
#define DAA_JAPAN_ICTRL3                 (0x0000u)
#define DAA_MALAYSIA_ICTRL3              (0x0000u)
#define DAA_NEW_ZEALAND_ICTRL3           (0x0000u)
#define DAA_PHILIPPINES_ICTRL3           (0x0010u)
#define DAA_POLAND_ICTRL3                (0x0000u)
#define DAA_SINGAPORE_ICTRL3             (0x0000u)
#define DAA_SLOVAKIA_ICTRL3              (0x0000u)
#define DAA_SLOVENIA_ICTRL3              (0x0000u)
#define DAA_SOUTH_AFRICA_ICTRL3          (0x0000u)
#define DAA_SOUTH_KOREA_ICTRL3           (0x0000u)


/* CLKDV bit settings (for internal DAA only) */
#define DAA_DAACLKDV_FULL     0
#define DAA_DAACLKDV_HALF     1
#define DAA_DAACLKDV_UNCHANGED 2


/* Circular buffer control structure */
typedef struct
{
  Int16   *pBuffer;                      /* pointer to the beginning of the circular buffer */
  Uint16  bufSize;                       /* size of the circular buffer */
  Int16   *pHead;                        /* pointer for reading data from Rx Interrupt */
  Int16   *pTail;                        /* pointer for writing data from Tx Interrupt */
  Int16   *pCurrent;                     /* pointer for reading/writing data for the user */
  Uint16  isOverflow;                    /* private flag for overflow */
  Uint16  circBufOffset;                 /* initial circular buffer offset */
} DAA_CircBufCtrl;


/******************************************************************************\
* DAA Params Structure Type
\******************************************************************************/
typedef struct
{
    Uint16 txAttenuation;                /* analog transmit attenuation */
    Uint16 rxGain;                       /* cid receive attenuation/analog receive gain */
    Uint16 sampleRateReg7;               /* sample rate control - register 7 */
    Uint16 sampleRateReg8;               /* sample rate control - register 8 */
    Uint16 sampleRateReg9;               /* sample rate control - register 9 */
    Uint16 sampleRateReg10;              /* sample rate control - register 10 */
    Uint16 ictrl1;                       /* international control register 1 value */
    Uint16 ictrl2;                       /* international control register 2 value */
    Uint16 ictrl3;                       /* international control register 3 value */
} DAA_Params;


/******************************************************************************\
* private object    ***** not to be used by application code *****
\******************************************************************************/

typedef struct {
    MCBSP_Handle mcbspHandle;            /* McBSP 2 Handle */
    Int16 state;                         /* current control and read/write state */
    Uint16 regRequest;                   /* DAA register request - read or write */
    CSLBool isIORegReady;                /* Flag to indicate register IO complete */
    Uint16 regValue;                     /* Value of DAA register value just read or to be written */
    Uint16 regIndex;                     /* Index of DAA register value just read or to be written */
    Uint16 buffLength;                   /* buffer length for DAA read/write function */
    Int16 delayCount;                    /* counter used to implement delay based on sampling rate */
    void *pID;                           /* void pointer to channel ID */
    DAA_CallBack dataCallBack;           /* DAA data callback function pointer */
    DAA_CallBack ctrlCallBack;           /* DAA control callback function pointer */
    DAA_CircBufCtrl daaCircBufCtrl;      /* circular buffer ctrl structure */
} DAA_PrivateObj, *DAA_Handle;



/******************************************************************************\
* DAA Device Setup Structure Type
\******************************************************************************/
typedef struct {
    DAA_Params    *params;               /* DAA parameters (initial register values) */
    DAA_Handle    daaHandle;             /* pointer to DAA private object created by user */
    Uint16        mcbspPort;             /* MCBSP port the DAA is connected to */
                                         /* MCBSP_PORT2 (for internal DAA) */
    Int16         *pCircBuf;             /* pointer to the circular buffer or NULL if */
                                         /* the circular buffer isn't used */
    Uint16        circBufSize;           /* circular buffer size */
    Uint16        circBufOffset;         /* Initial circular buffer offset */
    Uint16        dataLength;            /* Length of data buffer (callback size) */
    void          *pID;                  /* void pointer to channel ID */
    DAA_CallBack  dataCallBack;          /* pointer to user-defined data call back function */
    DAA_CallBack  ctrlCallBack;          /* pointer to user-defined control call back function */
    DAA_RstFxn    reset;                 /* pointer to DAA hardware reset control function */
} DAA_DevSetup;


/******************************************************************************\
* DAA Multiple Device Setup Structure Type
\******************************************************************************/
typedef struct {
    Uint16        numDevs;               /* number of devices to be set up */
    DAA_DevSetup  **dev;                 /* pointer to array of device setup structure pointers */
} DAA_Setup;


/******************************************************************************\
* Private DAA macros    ***** not to be used by application code *****
\******************************************************************************/
/* states */
#define _DAA_SKIP_READ                   (0x0000)
#define _DAA_SKIP_WRITE                  (0x0001)
#define _DAA_NO_SKIP                     (0x0002)

/* register read/write requests */
#define _DAA_NONE                        (0x0000)
#define _DAA_REG_READ                    (0x0001)
#define _DAA_REG_WRITE                   (0x0002)

/* data read/write tasks */
#define _DAA_DATA                        (0x0004)

/* delay task complete flag */
#define _DAA_DELAY                       (0x0010)

/* overflow event passed to the callback fxn (only if circ buf is used) */
#define _DAA_OVERFLOW                    (0x0020)


/******************************************************************************\
* Function prototypes
\******************************************************************************/

extern void DAA_setup (DAA_Setup *setup);
extern void DAA_close (DAA_Handle handle);
extern CSLBool DAA_rset (DAA_Handle handle, Uint16 reg, Uint16 value);
extern CSLBool DAA_rget (DAA_Handle handle, Uint16 reg);
extern Int16 DAA_readWrite(DAA_Handle handle, Int16* dataBuff, Uint16 size);
extern CSLBool DAA_delay (DAA_Handle handle, Uint16 count);
extern Int16 DAA_availability (DAA_Handle handle);
extern void DAA_resetInternalBuffer (DAA_Handle handle);
extern void DAA_start (DAA_Handle handle);
extern void DAA_reset (Uint16 flag);


/* DAA ISR function */
extern void DAA_isr (DAA_Handle handle);

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* _DAA_SUPPORT */
#endif /* _CSL_DAA_H_ */
/******************************************************************************\
* End of csl_daa.h
\******************************************************************************/

