/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/*****************************************************************************\
*           Copyright (C) 2001 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... DAA
* FILENAME...... csl_daahal.h
* DATE CREATED.. Wed 02/01/2001
* PROJECT....... Chip Support Lbibrary
* COMPONENT..... 
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:    02/01/2001 
*   LAST MODIFIED:  02/22/2001 cpluplus compatability
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the DAA module)
*
*
*
\******************************************************************************/

#ifndef _CSL_DAAHAL_H_
#define _CSL_DAAHAL_H_

#include <csl_stdinc.h>
#include <csl_stdinch.h>
#include <csl_csldat.h>
#include <csl_chiphal.h>

#ifdef __cplusplus
extern "C" {
#endif

#if (_DAA_SUPPORT)
/****************************************\
* DAA scope and inline control macros
\****************************************/
#ifdef _DAA_cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CSL_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/****************************************\
* DAA register macro declarations
\****************************************/
#define DAA_RGETH(handle,REG)            DAA_rget(handle,_DAA_##REG##_ADDR)
#define DAA_RSETH(handle,REG,VAL)        DAA_rset(handle,_DAA_##REG##_ADDR,VAL)
#define DAA_ADDR(Reg)                    _DAA_##Reg##_ADDR
#define DAA_FMK(Reg,Field,Val)           _DAA_##Reg##_##Field##_MK(Val)
#define DAA_FMKS(Reg,Field,Sym)          _DAA_##Reg##_##Field##_MK(DAA_##Reg##_##Field##_##Sym)



/*****************************************************************************\
* DAA Register Names
\*****************************************************************************/
#define DAA_CTRL1                       (0x0001u)         /* Control 1 Register */
#define DAA_CTRL2                       (0x0002u)         /* Control 2 Register */
#define DAA_CTRL3                       (0x0003u)         /* Control 3 Register */
#define DAA_CTRL4                       (0x0004u)         /* Control 4 Register */
#define DAA_CTRL5                       (0x0005u)         /* Control 5 Register */
#define DAA_DAACTRL1                    (0x0005u)         /* DAA Control 1 Register */
#define DAA_CTRL6                       (0x0006u)         /* Control 6 Register */
#define DAA_DAACTRL2                    (0x0006u)         /* DAA Control 2 Register */
#define DAA_CTRL7                       (0x0007u)         /* Control 7 Register */
#define DAA_CTRL8                       (0x0008u)         /* Control 8 Register */
#define DAA_CTRL9                       (0x0009u)         /* Control 9 Register */
#define DAA_SRCTRL                      (0x0009u)         /* Sample Rate Control Register */
#define DAA_CTRL10                      (0x000Au)         /* Control 10 Register */
#define DAA_CTRL11                      (0x000Bu)         /* Control 11 Register */
#define DAA_CPAREV                      (0x000Bu)         /* Chip A Revision Register */
#define DAA_CTRL12                      (0x000Cu)         /* Control 12 Register */
#define DAA_LSS                         (0x000Cu)         /* Line Side Status Register */
#define DAA_CTRL13                      (0x000Du)         /* Control 13 Register */
#define DAA_CPBREV                      (0x000Du)         /* Chip B Revision Register */
#define DAA_CTRL14                      (0x000Eu)         /* Control 14 Register */
#define DAA_DCCTRL                      (0x000Eu)         /* Daisy Chain Control Register */
#define DAA_CTRL15                      (0x000Fu)         /* Control 15 Register */
#define DAA_GCR                         (0x000Fu)         /* TX/RX Gain Control Register */
#define DAA_CTRL16                      (0x0010u)         /* Control 16 Register */
#define DAA_ICTRL1                      (0x0010u)         /* International Control 1 Register */
#define DAA_CTRL17                      (0x0011u)         /* Control 17 Register */
#define DAA_ICTRL2                      (0x0011u)         /* International Control 2 Register */
#define DAA_CTRL18                      (0x0012u)         /* Control 18 Register */
#define DAA_ICTRL3                      (0x0012u)         /* International Control 3 Register */
#define DAA_CTRL19                      (0x0013u)         /* Control 19 Register */
#define DAA_ICTRL4                      (0x0013u)         /* International Control 4 Register */


/*****************************************************************************\
* DAA Register Addresses
\*****************************************************************************/
#define _DAA_CTRL1_ADDR                 (0x0100u)         /* Control 1 Register */
#define _DAA_CTRL2_ADDR                 (0x0200u)         /* Control 2 Register */
#define _DAA_DAACTRL1_ADDR              (0x0500u)         /* DAA Control 1 Register */
#define _DAA_DAACTRL2_ADDR              (0x0600u)         /* DAA Control 2 Register */
#define _DAA_CTRL7_ADDR                 (0x0700u)         /* Control 7 Register */
#define _DAA_CTRL8_ADDR                 (0x0800u)         /* Control 8 Register */
#define _DAA_CTRL9_ADDR                 (0x0900u)         /* Control 9 Register */
#define _DAA_SRCTRL_ADDR                (0x0900u)         /* Sample Rate Control Register */
#define _DAA_CTRL10_ADDR                (0x0A00u)         /* Control 10 Register */
#define _DAA_CPAREV_ADDR                (0x0B00u)         /* Chip A Revision Register */
#define _DAA_LSS_ADDR                   (0x0C00u)         /* Line Side Status Register */
#define _DAA_CPBREV_ADDR                (0x0D00u)         /* Chip B Revision Register */
#define _DAA_DCCTRL_ADDR                (0x0E00u)         /* Daisy Chain Control Register */
#define _DAA_GCR_ADDR                   (0x0F00u)         /* TX/RX Gain Control Register */
#define _DAA_ICTRL1_ADDR                (0x1000u)         /* International Control 1 Register */
#define _DAA_ICTRL2_ADDR                (0x1100u)         /* International Control 2 Register */
#define _DAA_ICTRL3_ADDR                (0x1200u)         /* International Control 3 Register */
#define _DAA_ICTRL4_ADDR                (0x1300u)         /* International Control 4 Register */


/*****************************************************************************\
* _DAA_CTRL1 : Control 1 Register
*
* Fields:
* (RW) _DAA_CTRL1_SB
* (RW) _DAA_CTRL1_DL
* (RW) _DAA_CTRL1_SR
* 
\*****************************************************************************/

#define _DAA_CTRL1_SHIFT                (0x0000u)
#define _DAA_CTRL1_MK(n)                (((Uint16)(n) & 0x0083u)<<_DAA_CTRL1_SHIFT)
#define _DAA_CTRL1_MASK                 (_DAA_CTRL1_MK(0x0083))
#define _DAA_CTRL1_CLR                  (~(_DAA_CTRL1_MASK))

/*****************************************************************************\
* _DAA_CTRL1_SB: Serial Digital Interface Mode (16 or 15 bits)
\*****************************************************************************/
#define _DAA_CTRL1_SB_SHIFT             (0x0000u)
#define _DAA_CTRL1_SB_MK(n)             (((Uint16)(n) & 0x0001u)<<_DAA_CTRL1_SB_SHIFT)
#define _DAA_CTRL1_SB_MASK              (_DAA_CTRL1_SB_MK(1))
#define _DAA_CTRL1_SB_CLR               (~(_DAA_CTRL1_SB_MASK))

/*****************************************************************************\
* _DAA_CTRL1_DL: Isolation digital Loopback
\*****************************************************************************/
#define _DAA_CTRL1_DL_SHIFT             (0x0001u)
#define _DAA_CTRL1_DL_MK(n)             (((Uint16)(n) & 0x0001u)<<_DAA_CTRL1_DL_SHIFT)
#define _DAA_CTRL1_DL_MASK              (_DAA_CTRL1_DL_MK(1))
#define _DAA_CTRL1_DL_CLR               (~(_DAA_CTRL1_DL_MASK))

/*****************************************************************************\
* _DAA_CTRL1_SR: Software Reset
\*****************************************************************************/
#define _DAA_CTRL1_SR_SHIFT             (0x0007u)
#define _DAA_CTRL1_SR_MK(n)             (((Uint16)(n) & 0x0001u)<<_DAA_CTRL1_SR_SHIFT)
#define _DAA_CTRL1_SR_MASK              (_DAA_CTRL1_SR_MK(1))
#define _DAA_CTRL1_SR_CLR               (~(_DAA_CTRL1_SR_MASK))


/*****************************************************************************\
* _DAA_CTRL2 : Control 2 Register
*
* Fields:
* (RW) _DAA_CTRL2_RXE
* (RW) _DAA_CTRL2_HBE
* (RW) _DAA_CTRL2_AL
* 
\*****************************************************************************/

#define _DAA_CTRL2_SHIFT                (0x0000u)
#define _DAA_CTRL2_MK(n)                (((Uint16)(n) & 0x000Bu)<<_DAA_CTRL2_SHIFT)
#define _DAA_CTRL2_MASK                 (_DAA_CTRL2_MK(0x000B))
#define _DAA_CTRL2_CLR                  (~(_DAA_CTRL2_MASK))

/*****************************************************************************\
* _DAA_CTRL2_RXE: Receive Enable
\*****************************************************************************/
#define _DAA_CTRL2_RXE_SHIFT            (0x0000u)
#define _DAA_CTRL2_RXE_MK(n)            (((Uint16)(n) & 0x0001u)<<_DAA_CTRL2_RXE_SHIFT)
#define _DAA_CTRL2_RXE_MASK             (_DAA_CTRL2_RXE_MK(1))
#define _DAA_CTRL2_RXE_CLR              (~(_DAA_CTRL2_RXE_MASK))

/*****************************************************************************\
* _DAA_CTRL2_HBE: Hybrid Enable
\*****************************************************************************/
#define _DAA_CTRL2_HBE_SHIFT            (0x0001u)
#define _DAA_CTRL2_HBE_MK(n)            (((Uint16)(n) & 0x0001u)<<_DAA_CTRL2_HBE_SHIFT)
#define _DAA_CTRL2_HBE_MASK             (_DAA_CTRL2_HBE_MK(1))
#define _DAA_CTRL2_HBE_CLR              (~(_DAA_CTRL2_HBE_MASK))

/*****************************************************************************\
* _DAA_CTRL2_AL: Analog Loopback
\*****************************************************************************/
#define _DAA_CTRL2_AL_SHIFT             (0x0003u)
#define _DAA_CTRL2_AL_MK(n)             (((Uint16)(n) & 0x0001u)<<_DAA_CTRL2_AL_SHIFT)
#define _DAA_CTRL2_AL_MASK              (_DAA_CTRL2_AL_MK(1))
#define _DAA_CTRL2_AL_CLR               (~(_DAA_CTRL2_AL_MASK))


/*****************************************************************************\
* _DAA_DAACTRL1 : DAA Control 1 Register
*
* Fields:
* (RW) _DAA_DAACTRL1_OH
* (R)  _DAA_DAACTRL1_RDT
* (RW) _DAA_DAACTRL1_ONHM
* (R)  _DAA_DAACTRL1_RDTP
* (R)  _DAA_DAACTRL1_RDTN
* 
\*****************************************************************************/

#define _DAA_DAACTRL1_SHIFT             (0x0000u)
#define _DAA_DAACTRL1_MK(n)             (((Uint16)(n) & 0x006Du)<<_DAA_DAACTRL1_SHIFT)
#define _DAA_DAACTRL1_MASK              (_DAA_DAACTRL1_MK(0x006D))
#define _DAA_DAACTRL1_CLR               (~(_DAA_DAACTRL1_MASK))

/*****************************************************************************\
* _DAA_DAACTRL1_OH: Off-Hook
\*****************************************************************************/
#define _DAA_DAACTRL1_OH_SHIFT             (0x0000u)
#define _DAA_DAACTRL1_OH_MK(n)             (((Uint16)(n) & 0x0001u)<<_DAA_DAACTRL1_OH_SHIFT)
#define _DAA_DAACTRL1_OH_MASK              (_DAA_DAACTRL1_OH_MK(1))
#define _DAA_DAACTRL1_OH_CLR               (~(_DAA_DAACTRL1_OH_MASK))

/*****************************************************************************\
* _DAA_DAACTRL1_RDT: Ring Detect
\*****************************************************************************/
#define _DAA_DAACTRL1_RDT_SHIFT            (0x0002u)
#define _DAA_DAACTRL1_RDT_MK(n)            (((Uint16)(n) & 0x0001u)<<_DAA_DAACTRL1_RDT_SHIFT)
#define _DAA_DAACTRL1_RDT_MASK             (_DAA_DAACTRL1_RDT_MK(1))
#define _DAA_DAACTRL1_RDT_CLR              (~(_DAA_DAACTRL1_RDT_MASK))

/*****************************************************************************\
* _DAA_DAACTRL1_ONHM: On-Hook Line Monitor
\*****************************************************************************/
#define _DAA_DAACTRL1_ONHM_SHIFT           (0x0003u)
#define _DAA_DAACTRL1_ONHM_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_DAACTRL1_ONHM_SHIFT)
#define _DAA_DAACTRL1_ONHM_MASK            (_DAA_DAACTRL1_ONHM_MK(1))
#define _DAA_DAACTRL1_ONHM_CLR             (~(_DAA_CTRL1_ONHM_MASK))

/*****************************************************************************\
* _DAA_DAACTRL1_RDTP: Ring Detect Positive
\*****************************************************************************/
#define _DAA_DAACTRL1_RDTP_SHIFT           (0x0005u)
#define _DAA_DAACTRL1_RDTP_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_DAACTRL1_RDTP_SHIFT)
#define _DAA_DAACTRL1_RDTP_MASK            (_DAA_DAACTRL1_RDTP_MK(1))
#define _DAA_DAACTRL1_RDTP_CLR             (~(_DAA_DAACTRL1_RDTP_MASK))

/*****************************************************************************\
* _DAA_DAACTRL1_RDTN: Ring Detect Negative
\*****************************************************************************/
#define _DAA_DAACTRL1_RDTN_SHIFT           (0x0006u)
#define _DAA_DAACTRL1_RDTN_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_DAACTRL1_RDTN_SHIFT)
#define _DAA_DAACTRL1_RDTN_MASK            (_DAA_DAACTRL1_RDTN_MK(1))
#define _DAA_DAACTRL1_RDTN_CLR             (~(_DAA_DAACTRL1_RDTN_MASK))


/*****************************************************************************\
* _DAA_DAACTRL2 : DAA Control 2 Register
*
* Fields:
* (RW) _DAA_DAACTRL2_PDL
* (RW) _DAA_DAACTRL2_PDN
* 
\*****************************************************************************/

#define _DAA_DAACTRL2_SHIFT             (0x0000u)
#define _DAA_DAACTRL2_MK(n)             (((Uint16)(n) & 0x0018u)<<_DAA_DAACTRL2_SHIFT)
#define _DAA_DAACTRL2_MASK              (_DAA_DAACTRL2_MK(0x0018u))
#define _DAA_DAACTRL2_CLR               (~(_DAA_DAACTRL2_MASK))

/*****************************************************************************\
* _DAA_DAACTRL2_PDN: Power Down
\*****************************************************************************/
#define _DAA_DAACTRL2_PDN_SHIFT         (0x0003u)
#define _DAA_DAACTRL2_PDN_MK(n)         (((Uint16)(n) & 0x0001u)<<_DAA_DAACTRL2_PDN_SHIFT)
#define _DAA_DAACTRL2_PDN_MASK          (_DAA_DAACTRL2_PDN_MK(1))
#define _DAA_DAACTRL2_PDN_CLR           (~(_DAA_DAACTRL2_PDN_MASK))

/*****************************************************************************\
* _DAA_DAACTRL2_PDL: Power Down Line-Side Chip
\*****************************************************************************/
#define _DAA_DAACTRL2_PDL_SHIFT         (0x0004u)
#define _DAA_DAACTRL2_PDL_MK(n)         (((Uint16)(n) & 0x0001u)<<_DAA_DAACTRL2_PDL_SHIFT)
#define _DAA_DAACTRL2_PDL_MASK          (_DAA_DAACTRL2_PDL_MK(1))
#define _DAA_DAACTRL2_PDL_CLR           (~(_DAA_DAACTRL2_PDL_MASK))

/*****************************************************************************\
* _DAA_SRCTRL : Sample Rate Control Register
*
* Fields:
* (RW) _DAA_SRCTRL_SRC
* 
\*****************************************************************************/
#define _DAA_SRCTRL_SHIFT               (0x0000u)
#define _DAA_SRCTRL_MK(n)               (((Uint16)(n) & 0x0007u)<<_DAA_SRCTRL_SHIFT)
#define _DAA_SRCTRL_MASK                (_DAA_SRCTRL_MK(0x0007))
#define _DAA_SRCTRL_CLR                 (~(_DAA_SRCTRL_MASK))

/*****************************************************************************\
* _DAA_SRCTRL_SRC: Sample Rate Control
\*****************************************************************************/
#define _DAA_SRCTRL_SRC_SHIFT           (0x0000u)
#define _DAA_SRCTRL_SRC_MK(n)           (((Uint16)(n) & 0x0007u)<<_DAA_SRCTRL_SRC_SHIFT)
#define _DAA_SRCTRL_SRC_MASK            (_DAA_SRCTRL_SRC_MK(7))
#define _DAA_SRCTRL_SRC_CLR             (~(_DAA_SRCTRL_SRC_MASK))


/*****************************************************************************\
* _DAA_CPAREV: Chip A Revision Register
*
* Fields:
* (R)  _DAA_CPAREV_REVA
* 
\*****************************************************************************/
#define _DAA_CPAREV_SHIFT               (0x0000u)
#define _DAA_CPAREV_MK(n)               (((Uint16)(n) & 0x000Fu)<<_DAA_CPAREV_SHIFT)
#define _DAA_CPAREV_MASK                (_DAA_CPAREV_MK(0x000F))
#define _DAA_CPAREV_CLR                 (~(_DAA_CPAREV_MASK))

/*****************************************************************************\
* _DAA_CPAREV_REVA: Chip A Revision
\*****************************************************************************/
#define _DAA_CPAREV_REVA_SHIFT          (0x0000u)
#define _DAA_CPAREV_REVA_MK(n)          (((Uint16)(n) & 0x000Fu)<<_DAA_CPAREV_REVA_SHIFT)
#define _DAA_CPAREV_REVA_MASK           (_DAA_CPAREV_REVA_MK(0x000F))
#define _DAA_CPAREV_REVA_CLR            (~(_DAA_CPAREV_REVA_MASK))


/*****************************************************************************\
* _DAA_LSS : Line Side Status Register
*
* Fields:
* (R)  _DAA_LSS_LCS
* (R)  _DAA_LSS_FDT
* (RW) _DAA_LSS_CLE
* 
\*****************************************************************************/
#define _DAA_LSS_SHIFT                  (0x0000u)
#define _DAA_LSS_MK(n)                  (((Uint16)(n) & 0x00CFu)<<_DAA_LSS_SHIFT)
#define _DAA_LSS_MASK                   (_DAA_LSS_MK(0x00CF))
#define _DAA_LSS_CLR                    (~(_DAA_LSS_MASK))

/*****************************************************************************\
* _DAA_LSS_LCS: Loop Current Sense
\*****************************************************************************/
#define _DAA_LSS_LCS_SHIFT           (0x0000u)
#define _DAA_LSS_LCS_MK(n)           (((Uint16)(n) & 0x000Fu)<<_DAA_LSS_LCS_SHIFT)
#define _DAA_LSS_LCS_MASK            (_DAA_LSS_LCS_MK(0x000F))
#define _DAA_LSS_LCS_CLR             (~(_DAA_LSS_LCS_MASK))

/*****************************************************************************\
* _DAA_LSS_FDT: Frame Detect
\*****************************************************************************/
#define _DAA_LSS_FDT_SHIFT           (0x0006u)
#define _DAA_LSS_FDT_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_LSS_FDT_SHIFT)
#define _DAA_LSS_FDT_MASK            (_DAA_LSS_FDT_MK(1))
#define _DAA_LSS_FDT_CLR             (~(_DAA_LSS_FDT_MASK))

/*****************************************************************************\
* _DAA_LSS_CLE: Communications (ISOcap) Error
\*****************************************************************************/
#define _DAA_LSS_CLE_SHIFT           (0x0007u)
#define _DAA_LSS_CLE_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_LSS_CLE_SHIFT)
#define _DAA_LSS_CLE_MASK            (_DAA_LSS_CLE_MK(1))
#define _DAA_LSS_CLE_CLR             (~(_DAA_LSS_CLE_MASK))


/*****************************************************************************\
* _DAA_CPBREV: Chip B Revision Register
*
* Fields:
* (R)  _DAA_CPBREV_REVB
* (R)  _DAA_CPBREV_CBID
* 
\*****************************************************************************/
#define _DAA_CPBREV_SHIFT               (0x0000u)
#define _DAA_CPBREV_MK(n)               (((Uint16)(n) & 0x007Fu)<<_DAA_CPBREV_SHIFT)
#define _DAA_CPBREV_MASK                (_DAA_CPBREV_MK(0x007F))
#define _DAA_CPBREV_CLR                 (~(_DAA_CPBREV_MASK))

/*****************************************************************************\
* _DAA_CPBREV_REVB: Chip B Revision
\*****************************************************************************/
#define _DAA_CPBREV_REVB_SHIFT          (0x0002u)
#define _DAA_CPBREV_REVB_MK(n)          (((Uint16)(n) & 0x000Fu)<<_DAA_CPBREV_REVB_SHIFT)
#define _DAA_CPBREV_REVB_MASK           (_DAA_CPBREV_REVB_MK(0x000F))
#define _DAA_CPBREV_REVB_CLR            (~(_DAA_CPBREV_REVB_MASK))

/*****************************************************************************\
* _DAA_CPBREV_CBID: Chip B ID
\*****************************************************************************/
#define _DAA_CPBREV_CBID_SHIFT          (0x0006u)
#define _DAA_CPBREV_CBID_MK(n)          (((Uint16)(n) & 0x0001u)<<_DAA_CPBREV_CBID_SHIFT)
#define _DAA_CPBREV_CBID_MASK           (_DAA_CPBREV_CBID_MK(1))
#define _DAA_CPBREV_CBID_CLR            (~(_DAA_CPBREV_CBID_MASK))


/*****************************************************************************\
* _DAA_DCCTRL: Daisy Chain Control Register
*
* Fields:
* (R)  _DAA_DCCTRL_SAFE
* (R)  _DAA_DCCTRL_CIP
* (R)  _DAA_DCCTRL_CHK
* 
\*****************************************************************************/
#define _DAA_DCCTRL_SHIFT               (0x0000u)
#define _DAA_DCCTRL_MK(n)               (((Uint16)(n) & 0x0007u)<<_DAA_DCCTRL_SHIFT)
#define _DAA_DCCTRL_MASK                (_DAA_DCCTRL_MK(0x0007))
#define _DAA_DCCTRL_CLR                 (~(_DAA_DCCTRL_MASK))

/*****************************************************************************\
* _DAA_DCCTRL_SAFE: Line-Side Chip Verification Result
\*****************************************************************************/
#define _DAA_DCCTRL_SAFE_SHIFT          (0x0000u)
#define _DAA_DCCTRL_SAFE_MK(n)          (((Uint16)(n) & 0x0001u)<<_DAA_DCCTRL_SAFE_SHIFT)
#define _DAA_DCCTRL_SAFE_MASK           (_DAA_DCCTRL_SAFE_MK(1))
#define _DAA_DCCTRL_SAFE_CLR            (~(_DAA_DCCTRL_SAFE_MASK))

/*****************************************************************************\
* _DAA_DCCTRL_CIP: Line-Side Chip Verification In Progress
\*****************************************************************************/
#define _DAA_DCCTRL_CIP_SHIFT           (0x0001u)
#define _DAA_DCCTRL_CIP_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_DCCTRL_CIP_SHIFT)
#define _DAA_DCCTRL_CIP_MASK            (_DAA_DCCTRL_CIP_MK(1))
#define _DAA_DCCTRL_CIP_CLR             (~(_DAA_DCCTRL_CIP_MASK))

/*****************************************************************************\
* _DAA_DCCTRL_CHK: Line-Side Chip Verification Result
\*****************************************************************************/
#define _DAA_DCCTRL_CHK_SHIFT           (0x0002u)
#define _DAA_DCCTRL_CHK_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_DCCTRL_CHK_SHIFT)
#define _DAA_DCCTRL_CHK_MASK            (_DAA_DCCTRL_CHK_MK(1))
#define _DAA_DCCTRL_CHK_CLR             (~(_DAA_DCCTRL_CHK_MASK))


/*****************************************************************************\
* _DAA_GCR : TX/RX Gain Control Register
*
* Fields:
* (RW) _DAA_GCR_ARX
* (RW) _DAA_GCR_RXM
* (RW) _DAA_GCR_ATX
* (RW) _DAA_GCR_TXM
* 
\*****************************************************************************/
#define _DAA_GCR_SHIFT               (0x0000u)
#define _DAA_GCR_MK(n)               (((Uint16)(n) & 0x00FFu)<<_DAA_GCR_SHIFT)
#define _DAA_GCR_MASK                (_DAA_GCR_MK(0x00FF))
#define _DAA_GCR_CLR                 (~(_DAA_GCR_MASK))

/*****************************************************************************\
* _DAA_GCR_ARX: Analog Receive Gain/On-Hook Line Monitor Receive Attenuation
\*****************************************************************************/
#define _DAA_GCR_ARX_SHIFT           (0x0000u)
#define _DAA_GCR_ARX_MK(n)           (((Uint16)(n) & 0x0007u)<<_DAA_GCR_ARX_SHIFT)
#define _DAA_GCR_ARX_MASK            (_DAA_GCR_ARX_MK(7))
#define _DAA_GCR_ARX_CLR             (~(_DAA_GCR_ARX_MASK))

/*****************************************************************************\
* _DAA_GCR_RXM: Receive Mute
\*****************************************************************************/
#define _DAA_GCR_RXM_SHIFT           (0x0003u)
#define _DAA_GCR_RXM_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_GCR_RXM_SHIFT)
#define _DAA_GCR_RXM_MASK            (_DAA_GCR_RXM_MK(1))
#define _DAA_GCR_RXM_CLR             (~(_DAA_GCR_RXM_MASK))

/*****************************************************************************\
* _DAA_GCR_ATX: Analog Transmit Attenuation
\*****************************************************************************/
#define _DAA_GCR_ATX_SHIFT           (0x0004u)
#define _DAA_GCR_ATX_MK(n)           (((Uint16)(n) & 0x0007u)<<_DAA_GCR_ATX_SHIFT)
#define _DAA_GCR_ATX_MASK            (_DAA_GCR_ATX_MK(7))
#define _DAA_GCR_ATX_CLR             (~(_DAA_GCR_ATX_MASK))

/*****************************************************************************\
* _DAA_GCR_TXM: Receive Mute
\*****************************************************************************/
#define _DAA_GCR_TXM_SHIFT           (0x0007u)
#define _DAA_GCR_TXM_MK(n)           (((Uint16)(n) & 0x0001u)<<_DAA_GCR_TXM_SHIFT)
#define _DAA_GCR_TXM_MASK            (_DAA_GCR_TXM_MK(1))
#define _DAA_GCR_TXM_CLR             (~(_DAA_GCR_TXM_MASK))


/*****************************************************************************\
* _DAA_ICTRL1 : International Control 1 Register
*
* Fields:
* (RW) _DAA_ICTRL1_RT
* (RW) _DAA_ICTRL1_RZ
* (RW) _DAA_ICTRL1_DCT
* (RW) _DAA_ICTRL1_ACT
* (RW) _DAA_ICTRL1_OHS
* (RW) _DAA_ICTRL1_ACT
* (RW) _DAA_ICTRL1_OFF_SQL2
* 
\*****************************************************************************/
#define _DAA_ICTRL1_SHIFT            (0x0000u)
#define _DAA_ICTRL1_MK(n)            (((Uint16)(n) & 0x00EFu)<<_DAA_ICTRL1_SHIFT)
#define _DAA_ICTRL1_MASK             (_DAA_ICTRL1_MK(0x00EF))
#define _DAA_ICTRL1_CLR              (~(_DAA_ICTRL1_MASK))

/*****************************************************************************\
* _DAA_ICTRL1_RT: Ringer Threshold Select
\*****************************************************************************/
#define _DAA_ICTRL1_RT_SHIFT         (0x0000u)
#define _DAA_ICTRL1_RT_MK(n)         (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL1_RT_SHIFT)
#define _DAA_ICTRL1_RT_MASK          (_DAA_ICTRL1_RT_MK(1))
#define _DAA_ICTRL1_RT_CLR           (~(_DAA_ICTRL1_RT_MASK))

/*****************************************************************************\
* _DAA_ICTRL1_RZ: Ringer Impedance
\*****************************************************************************/
#define _DAA_ICTRL1_RZ_SHIFT         (0x0001u)
#define _DAA_ICTRL1_RZ_MK(n)         (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL1_RZ_SHIFT)
#define _DAA_ICTRL1_RZ_MASK          (_DAA_ICTRL1_RZ_MK(1))
#define _DAA_ICTRL1_RZ_CLR           (~(_DAA_ICTRL1_RZ_MASK))

/*****************************************************************************\
* _DAA_ICTRL1_DCT: DC Termination Select
\*****************************************************************************/
#define _DAA_ICTRL1_DCT_SHIFT        (0x0002u)
#define _DAA_ICTRL1_DCT_MK(n)        (((Uint16)(n) & 0x0003u)<<_DAA_ICTRL1_DCT_SHIFT)
#define _DAA_ICTRL1_DCT_MASK         (_DAA_ICTRL1_DCT_MK(3))
#define _DAA_ICTRL1_DCT_CLR          (~(_DAA_ICTRL1_DCT_MASK))

/*****************************************************************************\
* _DAA_ICTRL1_ACT: AC Termination Select
\*****************************************************************************/
#define _DAA_ICTRL1_ACT_SHIFT        (0x0005u)
#define _DAA_ICTRL1_ACT_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL1_ACT_SHIFT)
#define _DAA_ICTRL1_ACT_MASK         (_DAA_ICTRL1_ACT_MK(1))
#define _DAA_ICTRL1_ACT_CLR          (~(_DAA_ICTRL1_ACT_MASK))

/*****************************************************************************\
* _DAA_ICTRL1_OHS: On-Hook Speed
\*****************************************************************************/
#define _DAA_ICTRL1_OHS_SHIFT        (0x0006u)
#define _DAA_ICTRL1_OHS_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL1_OHS_SHIFT)
#define _DAA_ICTRL1_OHS_MASK         (_DAA_ICTRL1_OHS_MK(1))
#define _DAA_ICTRL1_OHS_CLR          (~(_DAA_ICTRL1_OHS_MASK))

/*****************************************************************************\
* _DAA_ICTRL1_OFF_SQL2: DC Termination Off/Enhanced Ring Detect Network Squelch
\*****************************************************************************/
#define _DAA_ICTRL1_OFF_SQL2_SHIFT   (0x0007u)
#define _DAA_ICTRL1_OFF_SQL2_MK(n)   (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL1_OFF_SQL2_SHIFT)
#define _DAA_ICTRL1_OFF_SQL2_MASK    (_DAA_ICTRL1_OFF_SQL2_MK(1))
#define _DAA_ICTRL1_OFF_SQL2_CLR     (~(_DAA_ICTRL1_OFF_SQL2_MASK))


/*****************************************************************************\
* _DAA_ICTRL2 : International Control 2 Register
*
* Fields:
* (RW) _DAA_ICTRL2_BTD
* (RW) _DAA_ICTRL2_ROV
* (RW) _DAA_ICTRL2_BTE
* (RW) _DAA_ICTRL2_OPE
* (RW) _DAA_ICTRL2_LIM
* (RW) _DAA_ICTRL2_CALD
* (RW) _DAA_ICTRL2_MCAL
* 
\*****************************************************************************/
#define _DAA_ICTRL2_SHIFT            (0x0000u)
#define _DAA_ICTRL2_MK(n)            (((Uint16)(n) & 0x007Fu)<<_DAA_ICTRL2_SHIFT)
#define _DAA_ICTRL2_MASK             (_DAA_ICTRL2_MK(0x007F))
#define _DAA_ICTRL2_CLR              (~(_DAA_ICTRL2_MASK))

/*****************************************************************************\
* _DAA_ICTRL2_BTD: Billing Tone Detected
\*****************************************************************************/
#define _DAA_ICTRL2_BTD_SHIFT        (0x0000u)
#define _DAA_ICTRL2_BTD_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL2_BTD_SHIFT)
#define _DAA_ICTRL2_BTD_MASK         (_DAA_ICTRL2_BTD_MK(1))
#define _DAA_ICTRL2_BTD_CLR          (~(_DAA_ICTRL2_BTD_MASK))

/*****************************************************************************\
* _DAA_ICTRL2_ROV: Receive Overload
\*****************************************************************************/
#define _DAA_ICTRL2_ROV_SHIFT        (0x0001u)
#define _DAA_ICTRL2_ROV_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL2_ROV_SHIFT)
#define _DAA_ICTRL2_ROV_MASK         (_DAA_ICTRL2_ROV_MK(1))
#define _DAA_ICTRL2_ROV_CLR          (~(_DAA_ICTRL2_ROV_MASK))

/*****************************************************************************\
* _DAA_ICTRL2_BTE: Billing Tone Protect Enable
\*****************************************************************************/
#define _DAA_ICTRL2_BTE_SHIFT        (0x0002u)
#define _DAA_ICTRL2_BTE_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL2_BTE_SHIFT)
#define _DAA_ICTRL2_BTE_MASK         (_DAA_ICTRL2_BTE_MK(1))
#define _DAA_ICTRL2_BTE_CLR          (~(_DAA_ICTRL2_BTE_MASK))

/*****************************************************************************\
* _DAA_ICTRL2_OPE: Overload Protect Enable
\*****************************************************************************/
#define _DAA_ICTRL2_OPE_SHIFT        (0x0003u)
#define _DAA_ICTRL2_OPE_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL2_OPE_SHIFT)
#define _DAA_ICTRL2_OPE_MASK         (_DAA_ICTRL2_OPE_MK(1))
#define _DAA_ICTRL2_OPE_CLR          (~(_DAA_ICTRL2_OPE_MASK))

/*****************************************************************************\
* _DAA_ICTRL2_LIM: Current Limit
\*****************************************************************************/
#define _DAA_ICTRL2_LIM_SHIFT        (0x0004u)
#define _DAA_ICTRL2_LIM_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL2_LIM_SHIFT)
#define _DAA_ICTRL2_LIM_MASK         (_DAA_ICTRL2_LIM_MK(1))
#define _DAA_ICTRL2_LIM_CLR          (~(_DAA_ICTRL2_LIM_MASK))

/*****************************************************************************\
* _DAA_ICTRL2_CALD: Auto-Calibration Disable
\*****************************************************************************/
#define _DAA_ICTRL2_CALD_SHIFT       (0x0005u)
#define _DAA_ICTRL2_CALD_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL2_CALD_SHIFT)
#define _DAA_ICTRL2_CALD_MASK        (_DAA_ICTRL2_CALD_MK(1))
#define _DAA_ICTRL2_CALD_CLR         (~(_DAA_ICTRL2_CALD_MASK))

/*****************************************************************************\
* _DAA_ICTRL2_MCAL: Manual Calibration
\*****************************************************************************/
#define _DAA_ICTRL2_MCAL_SHIFT       (0x0006u)
#define _DAA_ICTRL2_MCAL_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL2_MCAL_SHIFT)
#define _DAA_ICTRL2_MCAL_MASK        (_DAA_ICTRL2_MCAL_MK(1))
#define _DAA_ICTRL2_MCAL_CLR         (~(_DAA_ICTRL2_MCAL_MASK))


/*****************************************************************************\
* _DAA_ICTRL3 : International Control 3 Register
*
* Fields:
* (RW) _DAA_ICTRL3_SQLH
* (RW) _DAA_ICTRL3_RFWE
* (RW) _DAA_ICTRL3_MODE
* (RW) _DAA_ICTRL3_FLVM
* (RW) _DAA_ICTRL3_VOL
* (RW) _DAA_ICTRL3_FJM
* (RW) _DAA_ICTRL3_DIAL
* (RW) _DAA_ICTRL3_FULL
* 
\*****************************************************************************/
#define _DAA_ICTRL3_SHIFT            (0x0000u)
#define _DAA_ICTRL3_MK(n)            (((Uint16)(n) & 0x00FFu)<<_DAA_ICTRL3_SHIFT)
#define _DAA_ICTRL3_MASK             (_DAA_ICTRL3_MK(0x00FF))
#define _DAA_ICTRL3_CLR              (~(_DAA_ICTRL3_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_SQLH: Ring Detect Network Squelch
\*****************************************************************************/
#define _DAA_ICTRL3_SQLH_SHIFT       (0x0000u)
#define _DAA_ICTRL3_SQLH_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_SQLH_SHIFT)
#define _DAA_ICTRL3_SQLH_MASK        (_DAA_ICTRL3_SQLH_MK(1))
#define _DAA_ICTRL3_SQLH_CLR         (~(_DAA_ICTRL3_SQLH_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_RFWE: Ring Detector Full Wave Rectifier Enable
\*****************************************************************************/
#define _DAA_ICTRL3_RFWE_SHIFT       (0x0001u)
#define _DAA_ICTRL3_RFWE_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_RFWE_SHIFT)
#define _DAA_ICTRL3_RFWE_MASK        (_DAA_ICTRL3_RFWE_MK(1))
#define _DAA_ICTRL3_RFWE_CLR         (~(_DAA_ICTRL3_RFWE_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_MODE: Mode Control
\*****************************************************************************/
#define _DAA_ICTRL3_MODE_SHIFT       (0x0002u)
#define _DAA_ICTRL3_MODE_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_MODE_SHIFT)
#define _DAA_ICTRL3_MODE_MASK        (_DAA_ICTRL3_MODE_MK(1))
#define _DAA_ICTRL3_MODE_CLR         (~(_DAA_ICTRL3_MODE_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_FLVM: Force Low Voltage DC Termination Mode
\*****************************************************************************/
#define _DAA_ICTRL3_FLVM_SHIFT       (0x0003u)
#define _DAA_ICTRL3_FLVM_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_FLVM_SHIFT)
#define _DAA_ICTRL3_FLVM_MASK        (_DAA_ICTRL3_FLVM_MK(1))
#define _DAA_ICTRL3_FLVM_CLR         (~(_DAA_ICTRL3_FLVM_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_VOL: Line Voltage Adjust
\*****************************************************************************/
#define _DAA_ICTRL3_VOL_SHIFT        (0x0004u)
#define _DAA_ICTRL3_VOL_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_VOL_SHIFT)
#define _DAA_ICTRL3_VOL_MASK         (_DAA_ICTRL3_VOL_MK(1))
#define _DAA_ICTRL3_VOL_CLR          (~(_DAA_ICTRL3_VOL_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_FJM: Force Japan DC Termination Mode
\*****************************************************************************/
#define _DAA_ICTRL3_FJM_SHIFT        (0x0005u)
#define _DAA_ICTRL3_FJM_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_FJM_SHIFT)
#define _DAA_ICTRL3_FJM_MASK         (_DAA_ICTRL3_FJM_MK(1))
#define _DAA_ICTRL3_FJM_CLR          (~(_DAA_ICTRL3_FJM_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_DIAL: DTMF Dialing Mode
\*****************************************************************************/
#define _DAA_ICTRL3_DIAL_SHIFT       (0x0006u)
#define _DAA_ICTRL3_DIAL_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_DIAL_SHIFT)
#define _DAA_ICTRL3_DIAL_MASK        (_DAA_ICTRL3_DIAL_MK(1))
#define _DAA_ICTRL3_DIAL_CLR         (~(_DAA_ICTRL3_DIAL_MASK))

/*****************************************************************************\
* _DAA_ICTRL3_FULL: Full Scale
\*****************************************************************************/
#define _DAA_ICTRL3_FULL_SHIFT       (0x0007u)
#define _DAA_ICTRL3_FULL_MK(n)       (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL3_FULL_SHIFT)
#define _DAA_ICTRL3_FULL_MASK        (_DAA_ICTRL3_FULL_MK(1))
#define _DAA_ICTRL3_FULL_CLR         (~(_DAA_ICTRL3_FULL_MASK))



/*****************************************************************************\
* _DAA_ICTRL4 : International Control 4 Register
*
* Fields:
* (R) _DAA_ICTRL4_OPD
* (R) _DAA_ICTRL4_DOD
* (R) _DAA_ICTRL4_OVL
* (R) _DAA_ICTRL4_LVCS
* 
\*****************************************************************************/
#define _DAA_ICTRL4_SHIFT            (0x0000u)
#define _DAA_ICTRL4_MK(n)            (((Uint16)(n) & 0x00FFu)<<_DAA_ICTRL4_SHIFT)
#define _DAA_ICTRL4_MASK             (_DAA_ICTRL4_MK(0x00FF))
#define _DAA_ICTRL4_CLR              (~(_DAA_ICTRL4_MASK))

/*****************************************************************************\
* _DAA_ICTRL4_OPD: Overload Protect Detected
\*****************************************************************************/
#define _DAA_ICTRL4_OPD_SHIFT        (0x0000u)
#define _DAA_ICTRL4_OPD_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL4_OPD_SHIFT)
#define _DAA_ICTRL4_OPD_MASK         (_DAA_ICTRL4_OPD_MK(1))
#define _DAA_ICTRL4_OPD_CLR          (~(_DAA_ICTRL4_OPD_MASK))

/*****************************************************************************\
* _DAA_ICTRL4_DOD: Recal/Dropout Detect
\*****************************************************************************/
#define _DAA_ICTRL4_DOD_SHIFT        (0x0001u)
#define _DAA_ICTRL4_DOD_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL4_DOD_SHIFT)
#define _DAA_ICTRL4_DOD_MASK         (_DAA_ICTRL4_DOD_MK(1))
#define _DAA_ICTRL4_DOD_CLR          (~(_DAA_ICTRL4_DOD_MASK))

/*****************************************************************************\
* _DAA_ICTRL4_OVL: Overload Detected
\*****************************************************************************/
#define _DAA_ICTRL4_OVL_SHIFT        (0x0002u)
#define _DAA_ICTRL4_OVL_MK(n)        (((Uint16)(n) & 0x0001u)<<_DAA_ICTRL4_OVL_SHIFT)
#define _DAA_ICTRL4_OVL_MASK         (_DAA_ICTRL4_OVL_MK(1))
#define _DAA_ICTRL4_OVL_CLR          (~(_DAA_ICTRL4_OVL_MASK))

/*****************************************************************************\
* _DAA_ICTRL4_LVCS: Line Voltage/Current sense
\*****************************************************************************/
#define _DAA_ICTRL4_LVCS_SHIFT       (0x0003u)
#define _DAA_ICTRL4_LVCS_MK(n)       (((Uint16)(n) & 0x001Fu)<<_DAA_ICTRL4_LVCS_SHIFT)
#define _DAA_ICTRL4_LVCS_MASK        (_DAA_ICTRL4_LVCS_MK(1))
#define _DAA_ICTRL4_LVCS_CLR         (~(_DAA_ICTRL4_LVCS_MASK))

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* _DAA_SUPPORT */
#endif /* _CSL_DAAHAL_H_ */
/******************************************************************************\
* End of csl_daahal.h
\******************************************************************************/

