/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... DAT
* FILENAME...... dat.h
* DATE CREATED.. Thu 11/11/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... CSL service layer
* PREREQUISITS..
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:  11/11/1999 
*   MODIFIED: 06/19/2000 for cplusplus compatability
*   MODIFIED: 08/13/2001 renamed DAT_copy2D -> DAT_copy2d
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (service layer interface file for the DAT module)
*
*
*
\******************************************************************************/
#ifndef _CSL_DAT_H_
#define _CSL_DAT_H_


#include <_csl.h>
#include <csl_datdat.h>
#include <csl_dma.h>

#if (_DAT_SUPPORT)    

/****************************************\
* DAT scope and inline control macros
\****************************************/
#undef  USEDEFS
#undef  IDECL
#undef  IDEF

/****************************************\
* CSL scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _DAT_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/****************************************\
* DAT global macro declarations
\****************************************/
#if (_DMA_SUPPORT)
  #define DAT_CHA_ANY           DMA_CHA_ANY
  #define DAT_CHA0              DMA_CHA0
  #define DAT_CHA1              DMA_CHA1
  #define DAT_CHA2              DMA_CHA2
  #define DAT_CHA3              DMA_CHA3
  #define DAT_CHA4              DMA_CHA4
  #define DAT_CHA5              DMA_CHA5
  #define DAT_PRI_LOW           0
  #define DAT_PRI_HIGH          1

  #define DAT_SRC_NOMOD          0x0000u
  #define DAT_SRC_POSTDEC        0x0020u
  #define DAT_SRC_INDEX_OFFSET   0x0030u

  #define DAT_1D2D              0x0015u
  #define DAT_2D1D              0x0051u
  #define DAT_2D2D              0x0056u

  #define DAT_1D2D_POSTDEC      0x0025u
  #define DAT_2D1D_POSTDEC      0x0052u

  #define DAT_1D2D_NOMOD        0x0005u
  #define DAT_2D1D_NOMOD        0x0050u

  #define DAT_SIND_MASK         0x00F0u
  #define DAT_DIND_MASK         0x000Fu

#if ((!(CHIP_5402|CHIP_5471|CHIP_5472)) | CHIP_ALL)
  #define DAT_IO_SPACE_NOSHIFT      0x0003u
  #define DAT_PROGRAM_SPACE_NOSHIFT 0x0001u

  #define DAT_PROGRAM_SPACE         (Uint32)((Uint32)(0x0001u)) << 28)
  #define DAT_IO_SPACE              (Uint32)((Uint32)(0x0003u)) << 28)
#endif

  #define DAT_DATA_SPACE_NOSHIFT    0x0002u
  #define DAT_DATA_SPACE            (Uint32)(((Uint32)(0x0002u)) << 28)

#endif

/* error codes */
#define DAT_ERR_MAJOR            (ERR_BASE_DAT)
#define DAT_ERR_ALLOC            (0x00000000)
#define DAT_ERR_INVALID_HANDLE   (0x00000001)
#define DAT_ERR_NOT_OPEN         (0x00000002)
/* open flags */
#define DAT_OPEN_2D    1



/*******************************************\
* DMA global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area by datdata.h */
 
/* Data definition */
#define  Dat_Initialized             DAT_SYM(0)
#define  Dat_EventId                 DAT_SYM(1)
#define  Dat_ChaPriority             DAT_SYM(2)
#define  Dat_SubmitMask              DAT_SYM(3)
#define  Dat_OpenFlag                DAT_SYM(4)
#define  Dat_hDma                    DAT_SYM(5)

#define  DAT_HDAT   (\
                      (DAT_Handle)  (\
                      (&(((DAT_PrivateObj *)Dat_hDma)[0]))\
                      )\
                    )

/* Definition below was added for backwards compatability */
/* for old 2D copy routine                                */

#define DAT_copy2D           DAT_copy2d

/****************************************\
* DAT global function declarations
\****************************************/
CSLAPI void DAT_init();
CSLAPI DAT_Handle DAT_open(int ChaNum, int Priority, Uint32 Flags);
CSLAPI void DAT_close(DAT_Handle hDat);
CSLAPI Uint16 DAT_copy(DAT_Handle hDat, Uint32 Src , Uint32 Dst , Uint16 ElemCnt);
CSLAPI Uint16 DAT_copy2d(DAT_Handle hDat, Uint16 Type, Uint32 Src, Uint32 Dst, Uint16 LineLen, Uint16 LineCnt, Uint16 LinePitch);
CSLAPI Uint16 DAT_fill(DAT_Handle hDat, Uint32 Dst , Uint16 ElemCnt, Uint32 Value);
CSLAPI void DAT_wait(DAT_Handle hDat);

/****************************************\
* DAT inline function declarations
\****************************************/

/****************************************\
* DAT inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
#endif /* USEDEFS */

#endif /* DAT_SUPPORT */
#endif /* _CSL_DAT_H_ */
/******************************************************************************\
* End of CSL_dat.h
\******************************************************************************/
