/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/*****************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... DMA
* FILENAME...... csl_dma.h
* DATE CREATED.. Fri 06/11/1999 
* PROJECT....... Chip Support Lbibrary
* COMPONENT..... 
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:  06/11/1999 
*   MODIFIED: 06/19/2000 cpluplus compatability
*   MODIFIED: 08/12/2001 trimmed #include
*   MODIFIED: 08/13/2001 removed 5472 replaced with 5471
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the DMA module)
*
*
*
\******************************************************************************/
#ifndef _CSL_DMA_H_
#define _CSL_DMA_H_

#include <_csl.h>
#include <csl_dmahal.h>

#if (_DMA_SUPPORT) 
/****************************************\
* CSL scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _DMA_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* DMA global macro declarations
\****************************************/
#define DMA_CHA_CNT        (_DMA_CHA_CNT)


#define DMA_GBLREG_CNT     (32)


/* DMA_Open() flags */
#define DMA_OPEN_RESET     (0x00000001)

/* error codes */
#define DMA_ERR_MAJOR            (ERR_BASE_DMA)
#define DMA_ERR_ALLOC            (0x00000000)
#define DMA_ERR_INVALID_HANDLE   (0x00000001)
#define DMA_ERR_GLOBAL_ALLOC     (0x00000002)

/* channel identifiers for DMA_Open() */
#define DMA_CHA_ANY  (-1)
#define DMA_CHA0    (0)
#define DMA_CHA1    (1)
#define DMA_CHA2    (2)
#define DMA_CHA3    (3)
#define DMA_CHA4    (4)
#define DMA_CHA5    (5)

/* define a debuging assertion macro for validating channel handles */
#ifdef _MCRTE_DEBUG
  #define DMA_ASSERT_HANDLE(hDma,RetExp) \
    if (hDma == INV) { \
      ERR_submit(DMA_ERR_MAJOR, DMA_ERR_INVALID_HANDLE); \
      RetExp; \
    } 
#else
  #define DMA_ASSERT_HANDLE(hDma,RetExp) 
#endif                                

/*-----------------------------------------------------------------------*/
/* Macros to enable GET/SET of inidvidual control registers              */
/*-----------------------------------------------------------------------*/


/***********************************************\
* Subbank addressing without autoincrement
\***********************************************/



/*-----------------------------------------------------------------------*/
/* The following macros are used to construct peripheral register        */
/* values based on symbolic constants. They will be useful to initialize */
/* the DMA_Config structure in a readable way.                           */
/*-----------------------------------------------------------------------*/

/*----------------------------------------------------*/
/* DMA Channel Priority and Control Register (DMPREC) */
/*----------------------------------------------------*/
#if (_DMA_CH_RLDR_SUPPORT)
  #define DMA_DMPREC_RMK(free,autoix,chpri,intosel,chenable) ((Uint16)(\
      (DMA_FMK(DMPREC,FREE,free))      |\
      (DMA_FMK(DMPREC,AUTOIX,autoix))  |\
      (DMA_FMK(DMPREC,DPRC,chpri))     |\
      (DMA_FMK(DMPREC,INTOSEL,intosel))|\
      (DMA_FMK(DMPREC,DE,chenable))\
    )\
  )  

  #define DMA_DMPREC_RMKS(free_sym,autoix_sym,chpri_sym,intosel_sym,chenable_sym)\
   ((Uint16)(\
      (DMA_FMKS(DMPREC,FREE,free_sym))      |\
      (DMA_FMKS(DMPREC,AUTOIX,atuoix_sym))  |\
      (DMA_FMKS(DMPREC,DPRC,chpri_sym))     |\
      (DMA_FMKS(DMPREC,INTOSEL,intosel_sym))|\
      (DMA_FMKS(DMPREC,DE,chenable_sym))\
    )\
  )
#else  
  #define DMA_DMPREC_RMK(free,chpri,intosel,chenable) ((Uint16)(\
      (DMA_FMK(DMPREC,FREE,free))    |\
      (DMA_FMK(DMPREC,DPRC,chpri))   |\
      (DMA_FMK(DMPREC,INTOSEL,intosel))|\
      (DMA_FMK(DMPREC,DE,chenable))\
    )\
  )  

  #define DMA_DMPREC_RMKS(free_sym,chpri_sym,intosel_sym,chenable_sym)\
   ((Uint16)(\
      (DMA_FMKS(DMPREC,FREE,free_sym))    |\
      (DMA_FMKS(DMPREC,DPRC,chpri_sym))   |\
      (DMA_FMKS(DMPREC,INTOSEL,intosel_sym))|\
      (DMA_FMKS(DMPREC,DE,chenable_sym))\
    )\
  )  
#endif

/* default register value */
#define DMA_DMPREC_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMPREC_FREE_ON                      (0x0001u)
#define DMA_DMPREC_FREE_OFF                     (0x0000u)

#define DMA_DMPREC_AUTOIX_USE_DMA0              (0x0000u)
#define DMA_DMPREC_AUTOIX_USE_CHAN              (0x0001u)
#define DMA_DMPREC_AUTOIX_DEFAULT               DMA_DMPREC_AUTOIX_USE_DMA0

#define DMA_DMPREC_DE_OF(x)                     ((Uint16)(x))
#define DMA_DMPREC_DPRC_OF(x)                   ((Uint16)(x))

#define DMA_DMPREC_DPRC5_HI                     (0x0020u)
#define DMA_DMPREC_DPRC4_HI                     (0x0010u)
#define DMA_DMPREC_DPRC3_HI                     (0x0008u)
#define DMA_DMPREC_DPRC2_HI                     (0x0004u)
#define DMA_DMPREC_DPRC1_HI                     (0x0002u)
#define DMA_DMPREC_DPRC0_HI                     (0x0001u)

#define DMA_PRIORITY_HI					(0x0001u)
#define DMA_PRIORIRY_LO					(0x0000u)

/* field values */
#if (CHIP_5401 | CHIP_5402 | CHIP_5409 | CHIP_5409A | CHIP_5420 | CHIP_5421 | CHIP_5471)
  #define DMA_DMPREC_INTOSEL_NONE               (0x0000u)
  #define DMA_DMPREC_INTOSEL_CH2_CH3            (0x0001u)
  #define DMA_DMPREC_INTOSEL_CH0_TO_CH3         (0x0002u)
#endif

#if (CHIP_54CST | CHIP_5403 | CHIP_5406 | CHIP_5404 | CHIP_5407)
  #define DMA_DMPREC_INTOSEL_CH4_CH5            (0x0000u)
  #define DMA_DMPREC_INTOSEL_CH2_CH3            (0x0001u)
  #define DMA_DMPREC_INTOSEL_CH2_TO_CH5         (0x0001u)
  #define DMA_DMPREC_INTOSEL_CH0_TO_CH5         (0x0002u)
#endif

#if (CHIP_5410 | CHIP_5410A | CHIP_5416 | CHIP_5420 | CHIP_5421)
  #define DMA_DMPREC_INTOSEL_CH4_CH5        (0x0000u)
  #define DMA_DMPREC_INTOSEL_CH2_CH3        (0x0001u)
  #define DMA_DMPREC_INTOSEL_CH2_TO_CH5     (0x0001u)
  #define DMA_DMPREC_INTOSEL_CH0_TO_CH5     (0x0002u)
#else
  #if (CHIP_5440 | CHIP_5441)
    #define DMA_DMPREC_INTOSEL_NONE        (0x0000u)
    #define DMA_DMPREC_INTOSEL_CH2_CH3     (0x0001u)
    #define DMA_DMPREC_INTOSEL_CH1_TO_CH3  (0x0002u)
 #endif
#endif



#define DMA_DMPREC_DE5_ENABLE                  (0x0020u)
#define DMA_DMPREC_DE4_ENABLE                  (0x0010u)
#define DMA_DMPREC_DE3_ENABLE                  (0x0008u)
#define DMA_DMPREC_DE2_ENABLE                  (0x0004u)
#define DMA_DMPREC_DE1_ENABLE                  (0x0002u)
#define DMA_DMPREC_DE0_ENABLE                  (0x0001u)

/*-----------------------------------------------------*/
/* DMA Sync vent and Framecount Register (DMSFC)       */
/*-----------------------------------------------------*/
/* make register value based on symbolic constants     */

#define DMA_DMSFC_RMK(dsyn, dblw, framecnt)((Uint16)(\
    (DMA_FMK(DMSFC,DSYN, dsyn))|\
    (DMA_FMK(DMSFC,DBLW, dblw))|\
    (DMA_FMK(DMSFC,FRAMECNT, framecnt))\
 )\
)

#define DMA_DMSFC_RMKS(dsyn_sym, dblw_sym, framecnt_sym)((Uint16)(\
    (DMA_FMKS(DMSFC,DSYN, dsyn_sym))|\
    (DMA_FMKS(DMSFC,DBLW, dblw_sym))|\
    (DMA_FMKS(DMSFC,FRAMECNT, framecnt_sym))\
 )\
)

/* register value */
#define DMA_DMSFC_DEFAULT                      (0x0000u)

/* field values */

#define DMA_DMSFC_DSYN_DEFAULT                 (0x0000u)
#if (CHIP_5401 | CHIP_5402)
 #define DMA_DMSFC_DSYN_NONE                   (0x0000u)
 #define DMA_DMSFC_DSYN_REVT0                  (0x0001u)
 #define DMA_DMSFC_DSYN_XEVT0	                 (0x0002u)
 #define DMA_DMSFC_DSYN_REVT1	                 (0x0005u)
 #define DMA_DMSFC_DSYN_XEVT1	                 (0x0006u)
 #define DMA_DMSFC_DSYN_TINT0	                 (0x000Du)
 #define DMA_DMSFC_DSYN_INT3		           (0x000Eu)
 #define DMA_DMSFC_DSYN_TINT1                  (0x000Fu)
#endif

#if (CHIP_54CST | CHIP_5403 | CHIP_5406 | CHIP_5404 | CHIP_5407)
 #define DMA_DMSFC_DSYN_NONE                   (0x0000u)
 #define DMA_DMSFC_DSYN_REVT0                  (0x0001u)
 #define DMA_DMSFC_DSYN_XEVT0	                 (0x0002u)
 #define DMA_DMSFC_DSYN_REVT2                  (0x0003u)
 #define DMA_DMSFC_DSYN_XEVT2                  (0x0004u)
 #define DMA_DMSFC_DSYN_REVT1	                 (0x0005u)
 #define DMA_DMSFC_DSYN_XEVT1	                 (0x0006u)
 #define DMA_DMSFC_DSYN_UART                   (0x0007u)
 #define DMA_DMSFC_DSYN_TINT0	                 (0x000Du)
 #define DMA_DMSFC_DSYN_INT3		           (0x000Eu)
 #define DMA_DMSFC_DSYN_TINT1                  (0x000Fu)
#endif

#if (CHIP_5409 | CHIP_5409A | CHIP_5471)
 #define DMA_DMSFC_DSYN_NONE                   (0x0000u)
 #define DMA_DMSFC_DSYN_REVT0                  (0x0001u)
 #define DMA_DMSFC_DSYN_XEVT0                  (0x0002u)
 #define DMA_DMSFC_DSYN_REVT2	                 (0x0003u)
 #define DMA_DMSFC_DSYN_XEVT2	                 (0x0004u)
 #define DMA_DMSFC_DSYN_REVT1	                 (0x0005u)
 #define DMA_DMSFC_DSYN_XEVT1	                 (0x0006u)
 #define DMA_DMSFC_DSYN_TINT0	                 (0x000Du)
 #define DMA_DMSFC_DSYN_INT3	                 (0x000Eu)
#endif

#if (CHIP_5410 | CHIP_5410A | CHIP_5416)
  #define DMA_DMSFC_DSYN_NONE                  (0x0000u)
  #define DMA_DMSFC_DSYN_REVT0                 (0x0001u)
  #define DMA_DMSFC_DSYN_XEVT0                 (0x0002u)
  #define DMA_DMSFC_DSYN_REVT2                 (0x0003u)
  #define DMA_DMSFC_DSYN_XEVT2                 (0x0004u)
  #define DMA_DMSFC_DSYN_REVT1                 (0x0005u)
  #define DMA_DMSFC_DSYN_XEVT1                 (0x0006u)

  #define DMA_DMSFC_DSYN_REVTA0                (0x0007u)
  #define DMA_DMSFC_DSYN_XEVTA0                (0x0008u)
  #define DMA_DMSFC_DSYN_REVTA2                (0x0009u)
  #define DMA_DMSFC_DSYN_XEVTA2                (0x000Au)
  #define DMA_DMSFC_DSYN_REVTA1                (0x000Bu)
  #define DMA_DMSFC_DSYN_XEVTA1                (0x000Cu)
  #define DMA_DMSFC_DSYN_TINT0                 (0x000Du)
  #define DMA_DMSFC_DSYN_INT3                  (0x000Eu)
#endif

#if (CHIP_5420 | CHIP_5421)
  #define DMA_DMSFC_DSYN_NONE                  (0x0000u)
  #define DMA_DMSFC_DSYN_REVT0                 (0x0001u)
  #define DMA_DMSFC_DSYN_XEVT0                 (0x0002u)
  #define DMA_DMSFC_DSYN_REVT2                 (0x0003u)
  #define DMA_DMSFC_DSYN_XEVT2                 (0x0004u)
  #define DMA_DMSFC_DSYN_REVT1                 (0x0005u)
  #define DMA_DMSFC_DSYN_XEVT1                 (0x0006u)
  #define DMA_DMSFC_DSYN_FIFO_REVT             (0x0007u)
  #define DMA_DMSFC_DSYN_FIFO_XEVT             (0x0008u)
#endif  

#if (CHIP_5440 | CHIP_5441)
  #define DMA_DMSFC_DSYN_NONE                  (0x0000u)
  #define DMA_DMSFC_DSYN_REVT0                 (0x0001u)
  #define DMA_DMSFC_DSYN_XEVT0                 (0x0002u)
  #define DMA_DMSFC_DSYN_REVT2                 (0x0003u)
  #define DMA_DMSFC_DSYN_XEVT2                 (0x0004u)
  #define DMA_DMSFC_DSYN_REVT1                 (0x0005u)
  #define DMA_DMSFC_DSYN_XEVT1                 (0x0006u)
#endif

#define DMA_DMSFC_DBLW_DEFAULT                 (0x0000u)
#define DMA_DMSFC_DBLW_OFF                     (0x0000u)
#define DMA_DMSFC_DBLW_ON                      (0x0001u)

#define DMA_DMSFC_FRAMECNT_DEFAULT             (0x0000u)
#define DMA_DMSFC_FRAMECNT_OF(x)               ((Uint16)(x))

/*----------------------------------------*/
/* Transfer Mode Control Register (DMMCR) */
/*----------------------------------------*/
/* make register value based on symbolic constants */
#if (_DMA_EXT_DATA_SUPPORT)
#define DMA_DMMCR_RMK(autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd) ((Uint16)(\
  (DMA_FMK(DMMCR,AUTOINIT, autoinit))|\
  (DMA_FMK(DMMCR,DINM, dinm))|\
  (DMA_FMK(DMMCR,IMOD, imod))|\
  (DMA_FMK(DMMCR,CTMOD, ctmod))|\
  (DMA_FMK(DMMCR,SLAXS, slaxs))|\
  (DMA_FMK(DMMCR,SIND, sind))|\
  (DMA_FMK(DMMCR,DMS, dms))|\
  (DMA_FMK(DMMCR,DLAXS, dlaxs))|\
  (DMA_FMK(DMMCR,DIND, dind))|\
  (DMA_FMK(DMMCR,DMD, dmd))\
  )\
)  
#define DMA_DMMCR_RMKS(autoinit_sym, dinm_sym, imod_sym, ctmod_sym, slaxs_sym,\
   sind_sym, dms_sym, dlaxs_sym, dind_sym, dmd_sym) ((Uint16)(\
  (DMA_FMKS(DMMCR,AUTOINIT, autoinit_sym))|\
  (DMA_FMKS(DMMCR,DINM, dinm_sym))|\
  (DMA_FMKS(DMMCR,IMOD, imod_sym))|\
  (DMA_FMKS(DMMCR,CTMOD, ctmod_sym))|\
  (DMA_FMKS(DMMCR,SLAXS, slaxs_sym))|\
  (DMA_FMKS(DMMCR,SIND, sind_sym))|\
  (DMA_FMKS(DMMCR,DMS, dms_sym))|\
  (DMA_FMKS(DMMCR,DLAXS, dlaxs_sym))|\
  (DMA_FMKS(DMMCR,DIND, dind_sym))|\
  (DMA_FMKS(DMMCR,DMD, dmd_sym))\
  )\
)  
#else
#define DMA_DMMCR_RMK(autoinit, dinm, imod, ctmod, sind, dms, dind, dmd) ((Uint16)(\
  (DMA_FMK(DMMCR,AUTOINIT, autoinit))|\
  (DMA_FMK(DMMCR,DINM, dinm))|\
  (DMA_FMK(DMMCR,IMOD, imod))|\
  (DMA_FMK(DMMCR,CTMOD, ctmod))|\
  (DMA_FMK(DMMCR,SIND, sind))|\
  (DMA_FMK(DMMCR,DMS, dms))|\
  (DMA_FMK(DMMCR,DIND, dind))|\
  (DMA_FMK(DMMCR,DMD, dmd))\
  )\
)  
#define DMA_DMMCR_RMKS(autoinit_sym, dinm_sym, imod_sym, ctmod_sym, sind_sym,\
 dms_sym, dind_sym, dmd_sym) ((Uint16)(\
  (DMA_FMKS(DMMCR,AUTOINIT, autoinit_sym))|\
  (DMA_FMKS(DMMCR,DINM, dinm_sym))|\
  (DMA_FMKS(DMMCR,IMOD, imod_sym))|\
  (DMA_FMKS(DMMCR,CTMOD, ctmod_sym))|\
  (DMA_FMKS(DMMCR,SIND, sind_sym))|\
  (DMA_FMKS(DMMCR,DMS, dms_sym))|\
  (DMA_FMKS(DMMCR,DIND, dind_sym))|\
  (DMA_FMKS(DMMCR,DMD, dmd_sym))\
  )\
)  
#endif

/* default register value */
#define DMA_DMMCR_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMMCR_AUTOINIT_DEFAULT             (0x0000u)
#define DMA_DMMCR_AUTOINIT_ON                  (0x0001u)
#define DMA_DMMCR_AUTOINIT_OFF                 (0x0000u)

#define DMA_DMMCR_DINM_DEFAULT                 (0x0000u)
#define DMA_DMMCR_DINM_ON                      (0x0001u)
#define DMA_DMMCR_DINM_OFF                     (0x0000u)

#define DMA_DMMCR_IMOD_DEFAULT                 (0x0000u)
#define DMA_DMMCR_IMOD_FULL_ONLY               (0x0000u)
#define DMA_DMMCR_IMOD_HALF_AND_FULL           (0x0001u)
#define DMA_DMMCR_IMOD_BLOCK_ONLY              (0x0000u)
#define DMA_DMMCR_IMOD_FRAME_AND_BLOCK         (0x0001u)

#define DMA_DMMCR_CTMOD_DEFAULT                (0x0000u)
#define DMA_DMMCR_CTMOD_MULTIFRAME             (0x0000u)
#define DMA_DMMCR_CTMOD_ABU                    (0x0001u)

#define DMA_DMMCR_SIND_DEFAULT                 (0x0000u)
#define DMA_DMMCR_SIND_NOMOD                   (0x0000u)
#define DMA_DMMCR_SIND_POSTINC                 (0x0001u)
#define DMA_DMMCR_SIND_POSTDEC                 (0x0002u)
#define DMA_DMMCR_SIND_DMIDX0                  (0x0003u)
#define DMA_DMMCR_SIND_DMIDX1                  (0x0004u)
#define DMA_DMMCR_SIND_DMFRI0                  (0x0005u)
#define DMA_DMMCR_SIND_DMFRI1                  (0x0006u)

#define DMA_DMMCR_DMS_DEFAULT                  (0x0000u)
#define DMA_DMMCR_DMS_PROGRAM                  (0x0000u)
#define DMA_DMMCR_DMS_DATA                     (0x0001u)
#define DMA_DMMCR_DMS_IO                       (0x0002u)

#define DMA_DMMCR_DIND_DEFAULT                 (0x0000u)
#define DMA_DMMCR_DIND_NOMOD                   (0x0000u)
#define DMA_DMMCR_DIND_POSTINC                 (0x0001u)
#define DMA_DMMCR_DIND_POSTDEC                 (0x0002u)
#define DMA_DMMCR_DIND_DMIDX0                  (0x0003u)
#define DMA_DMMCR_DIND_DMIDX1                  (0x0004u)
#define DMA_DMMCR_DIND_DMFRI0                  (0x0005u)
#define DMA_DMMCR_DIND_DMFRI1                  (0x0006u)

#define DMA_DMMCR_DMD_DEFAULT                  (0x0000u)
#define DMA_DMMCR_DMD_PROGRAM                  (0x0000u)
#define DMA_DMMCR_DMD_DATA                     (0x0001u)
#define DMA_DMMCR_DMD_IO                       (0x0002u)

#if (_DMA_EXT_DATA_SUPPORT)
#define DMA_DMMCR_SLAXS_DEFAULT                (0x0000u)
#define DMA_DMMCR_SLAXS_OFF                    (0x0000u)
#define DMA_DMMCR_SLAXS_ON                     (0x0001u)
#define DMA_DMMCR_DLAXS_OFF                    (0x0000u)
#define DMA_DMMCR_DLAXS_ON                     (0x0001u)
#endif
        
/*--------------------*/
/* SRC register       */
/*--------------------*/
/* make register value based on symbolic constants */
#define DMA_DMSRC_RMK(src) ((Uint16)(\
    DMA_FMK(DMSRC,SRC,src)\
  )\
) 

/* default register value */
#define DMA_DMSRC_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMSRC_SRC_OF(x)                    ((Uint16)(x))

/*-----------------------------*/
/* Source page register DMSRCP */
/*-----------------------------*/
#define DMA_DMSRCP_RMK(page) ((Uint16)(\
  DMA_FMK(DMSRCP,PAGE,page)\
 )\
)

/* default register values */
#define DMA_DMSRCP_DEFAULT                     (0x0000u)
                                               
/* field values */
#define DMA_DMSRCP_PAGE_OF(x)                  ((Uint16)(x))

/*--------------------*/
/* DST register       */
/*--------------------*/
/* make register value based on symbolic constants */
#define DMA_DMDST_RMK(dst) ((Uint16)(\
    DMA_FMK(DMDST,DST,dst)\
  )\
)  

/* default register value */
#define DMA_DMDST_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMDST_DST_OF(x)                    ((Uint16)(x))

/*----------------------------------*/
/* Destinstion page register DMDSTP */
/*----------------------------------*/
#define DMA_DMDSTP_RMK(page) ((Uint16)(\
  DMA_FMK(DMDSTP,PAGE,page)\
 )\
)

/* default register values */
#define DMA_DMDSTP_DEFAULT                     (0x0000u)

/* field values */
#define DMA_DMDSTP_PAGE_OF(x)                  ((Uint16)(x))


/*----------------------------*/
/* Element count  register    */
/*----------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMCTR_RMK(elecnt) ((Uint16)(\
    DMA_FMK(DMCTR,ELECNT,elecnt)\
  )\
)  

/* default register value */
#define DMA_DMCTR_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMCTR_ELECNT_OF(x)                 ((Uint16)(x))

/*-------------------------*/
/* GBLCNT register (DMGCR) */
/*-------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMGCR_RMK(elecnt) ((Uint16)(\
    DMA_FMK(DMGCR,ELECNT,elecnt)\
  )\
) 

/* default register value */
#define DMA_DMGCR_DEFAULT                     (0x0000u)

/* field values */
#define DMA_DMGCR_ELECNT_OF(x)                ((Uint16)(x))

/*-------------------------------------*/
/* Global frame count register (DMGFR) */
/*-------------------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMGFR_RMK(framecnt) ((Uint16)(\
    DMA_FMK(DMGFR,FRAMECNT,framecnt)\
  )\
)  

/* default register value */
#define DMA_DMGFR_DEFAULT                     (0x0000u)

/* field values */
#define DMA_DMGFR_FRAMECNT_OF(x)              ((Uint16)(x))

/*-------------------------------*/
/* Global index register (DMIDX0) */
/*-------------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMIDX0_RMK(eleidx) ((Uint16)(\
    DMA_FMK(DMIDX0,ELEIDX,eleidx)\
  )\
)  

/* default register value */
#define DMA_DMIDX0_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMIDX0_ELEIDX_OF(x)                 ((Uint16)(x))

/*-------------------------------*/
/* Global index register (DMIDX1) */
/*-------------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMIDX1_RMK(eleidx) ((Uint16)(\
    DMA_FMK(DMIDX1,ELEIDX,eleidx)\
  )\
)  

/* default register value */
#define DMA_DMIDX1_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMIDX1_ELEIDX_OF(x)                 ((Uint16)(x))

/*-------------------------------------*/
/* Global frame index register (DMFRI0) */
/*-------------------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMFRI0_RMK(frameidx) ((Uint16)(\
    DMA_FMK(DMFRI0,FRAMEIDX,frameidx)\
  )\
)  

/* default register value */
#define DMA_DMFRI0_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMFRI0_FRAMEIDX_OF(x)               ((Uint16)(x))

/*-------------------------------------*/
/* Global frame index register (DMFRI1) */
/*-------------------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMFRI1_RMK(frameidx) ((Uint16)(\
    DMA_FMK(DMFRI1,FRAMEIDX,frameidx)\
  )\
)  

/* default register value */
#define DMA_DMFRI1_DEFAULT                      (0x0000u)

/* field values */
#define DMA_DMFRI1_FRAMEIDX_OF(x)               ((Uint16)(x))

/*----------------------------------*/
/* Global source address register   */
/*----------------------------------*/
/* make register value based on symbolic constants */
#define DMA_DMGSA_RMK(gbladdr) ((Uint16)(\
    DMA_FMK(DMGSA,GSA,gbladdr)\
  )\
) 

/* default register value */
#define DMA_DMGSA_DEFAULT                    (0x0000u)

/* field values */
#define DMA_DMGSA_GSA_OF(x)              ((Uint16)(x))

/*---------------------------------------*/
/* Global desintation address register   */
/*---------------------------------------*/

/* make register value based on symbolic constants */
#define DMA_DMGDA_RMK(gbladdr) ((Uint16)(\
    DMA_FMK(DMGDA,GDA,gbladdr)\
  )\
)  


/* default register value */
#define DMA_DMGDA_DEFAULT                    (0x0000u)

/* field values */
#define DMA_DMGDA_GDA_OF(x)                  ((Uint16)(x))

#if (_DMA_EXT_DATA_SUPPORT)
 /*----------------------------------------------*/
 /* Global Extended Program Source Page Register */
 /*----------------------------------------------*/
 #define DMA_DMSRCDP_RMK(dmsrcdp) ((Uint16) (\
   DMA_FMK(DMSRCDP,DMSRCDP,dmsrcdp)\
 )

 /* default registe value */
 #define DMA_DMSRCDP_DEFAULT                  (0x0000u)

 /* field values */
 #define DMA_DMSRCDP_DMSRCDP_OF(x)             ((Uint16)(x))

 /*---------------------------------------------------*/
 /* Global Extended Program Destination Page Register */
 /*---------------------------------------------------*/
 #define DMA_DMDSTDP_RMK(dmdstdp) ((Uint16) (\
   DMA_FMK(DMDSTDP,DMDSTDP, dmdstdp)\
 )

 /* default registe value */
 #define DMA_DMDSTDP_DEFAULT                  (0x0000u)

 /* field values */
 #define DMA_DMDSTDP_DMDSTDP_OF(x)             ((Uint16)(x))

#endif /* DMA_EXT_DATA_SUPPORT */

/*****************************************************\
* Global Register Allocation Mask Constants
\*****************************************************/
#define DMA_GBL_DMIDX0           0x0001u
#define DMA_GBL_DMFRI0           0x0002u
#define DMA_GBL_NDX0           0x0003u
#define DMA_GBL_DMIDX1           0x0004u
#define DMA_GBL_DMFRI1           0x0008u
#define DMA_GBL_NDX1           0x000Cu

#if (!(_DMA_CH_RLDR_SUPPORT))
#define DMA_GBL_DMGSA            0x0010u
#define DMA_GBL_DMGDA            0x0020u
#define DMA_GBL_DMGCR            0x0040u
#define DMA_GBL_DMGFR            0x0080u
#define DMA_GBL_RLDR             (DMA_GBL_DMGSA | DMA_GBL_DMGDA | DMA_GBL_DMGCR | DMA_GBL_DMGFR)
#endif

#define DMA_GBL_DMSRCP           0x0100u
#define DMA_GBL_DMDSTP           0x0200u
#define DMA_GBL_DMIDXANY         0x1000u
#define DMA_GBL_ALL              0xFFFFu

#if ((_DMA_EXT_DATA_SUPPORT) && (!(_DMA_CH_XDP_SUPPORT)))
  #define DMA_GBL_DMSRCDP           0x0400u
  #define DMA_GBL_DMDSTDP           0x0800u
#endif

#define DMA_SRC_PROGRAM_SPACE	   0x00C0u
#define DMA_SRC_DATA_SPACE       0x0040u

#define DMA_DST_PROGRAM_SPACE    0x0003u
#define DMA_DST_DATA_SPACE       0x0001u

/****************************************\
* DMA global typedef declarations
\****************************************/

typedef void (*DMA_AdrPtr)();

/* channel handle type */
typedef struct {
  Uint32 Private;
} *DMA_Handle;

/* private object, not to be used by application code */


/* channel configuration structure */

typedef struct {
  Uint16 priority;
#if (_DMA_CH_RLDR_SUPPORT)
  Uint16 autoix;
#endif
  Uint16 dmmcr;
  Uint16 dmsfc;
  DMA_AdrPtr dmsrc;
  DMA_AdrPtr dmdst;
  Uint16 dmctr;
#if (_DMA_CH_RLDR_SUPPORT)
  DMA_AdrPtr dmgsa;
  DMA_AdrPtr dmgda;
  Uint16 dmgcr;
  Uint16 dmgfr;
#endif
#if (_DMA_CH_XDP_SUPPORT)
  Uint16 dmsrcdp;
  Uint16 dmdstdp;
#endif
} DMA_Config;


typedef enum {
  DMA_GBL_SRCP_ID    = 0,
  DMA_GBL_DSTP_ID    = 1,
  DMA_GBL_IDX0_ID    = 2,
  DMA_GBL_IDX1_ID    = 3,
  DMA_GBL_FRI0_ID    = 4,
  DMA_GBL_FRI1_ID    = 5,
  DMA_GBL_XSRCP_ID   = 6,
  DMA_GBL_XDSTP_ID   = 7,

  DMA_GBL_DMGSA_ID   = 8,
  DMA_GBL_DMGSA0_ID  = 8,
  DMA_GBL_DMGSA1_ID  = 9,
  DMA_GBL_DMGSA2_ID  = 10,
  DMA_GBL_DMGSA3_ID  = 11,
  DMA_GBL_DMGSA4_ID  = 12,
  DMA_GBL_DMGSA5_ID  = 13,

  DMA_GBL_DMGDA_ID   = 14,
  DMA_GBL_DMGDA0_ID  = 14,
  DMA_GBL_DMGDA1_ID  = 15,
  DMA_GBL_DMGDA2_ID  = 16,
  DMA_GBL_DMGDA3_ID  = 17,
  DMA_GBL_DMGDA4_ID  = 18,
  DMA_GBL_DMGDA5_ID  = 19,

  DMA_GBL_DMGCR_ID   = 20,
  DMA_GBL_DMGCR0_ID  = 20,
  DMA_GBL_DMGCR1_ID  = 21,
  DMA_GBL_DMGCR2_ID  = 22,
  DMA_GBL_DMGCR3_ID  = 23,
  DMA_GBL_DMGCR4_ID  = 24,
  DMA_GBL_DMGCR5_ID  = 25,

  DMA_GBL_DMGFR_ID   = 26,
  DMA_GBL_DMGFR0_ID  = 26,
  DMA_GBL_DMGFR1_ID  = 27,
  DMA_GBL_DMGFR2_ID  = 28,
  DMA_GBL_DMGFR3_ID  = 29,
  DMA_GBL_DMGFR4_ID  = 30,
  DMA_GBL_DMGFR5_ID  = 31

} DMA_GblRegId;


typedef enum {
  DMA_GBLDMSRCP_MASK = 0x0001,
  DMA_GBLDMDSTP_MASK = 0x0002,
  DMA_GBLDMIDX0_MASK = 0x0004,
  DMA_GBLDMFRI0_MASK = 0x0008,
  DMA_GBLDMIDX1_MASK = 0x0010,
  DMA_GBLDMFRI1_MASK = 0x0020,
  DMA_GBLDMGSA_MASK  = 0x0040,
  DMA_GBLDMGDA_MASK  = 0x0080,
  DMA_GBLDMGCR_MASK  = 0x0100,
  DMA_GBLDMGFR_MASK  = 0x0200,
  DMA_GBLDMSRCDP_MASK = 0x0400,
  DMA_GBLDMDSTDP_MASK = 0x0800
}DMA_GblMask;

typedef struct {
    Uint16 free;
#if (_DMA_CH_RLDR_SUPPORT)
    Uint16 autoix;
#endif
    Uint16 gbldmsrcp;
    Uint16 gbldmdstp;
    Uint16 gbldmidx0;
    Uint16 gbldmfri0;
    Uint16 gbldmidx1;
    Uint16 gbldmfri1;
#if (!(_DMA_CH_RLDR_SUPPORT))
    DMA_AdrPtr  gbldmgsa;
    DMA_AdrPtr  gbldmgda;
    Uint16 gbldmgcr;
    Uint16 gbldmgfr;
#endif
#if ((_DMA_EXT_DATA_SUPPORT) && (!(_DMA_CH_XDP_SUPPORT)))
    Uint16 gbldmsrcdp;
    Uint16 gbldmdstdp;
#endif
  } DMA_GblConfig;

/*******************************************\
* DMA global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area by dmadata.h */
 
/* Data definition */

#define DMA_hCha(n) (CSL_DMA_DATA.Dma[n])
#define DMA_hCha0   (CSL_DMA_DATA.Dma[0])
#define DMA_hCha1   (CSL_DMA_DATA.Dma[1])
#define DMA_hCha2   (CSL_DMA_DATA.Dma[2])
#define DMA_hCha3   (CSL_DMA_DATA.Dma[3])
#define DMA_hCha4   (CSL_DMA_DATA.Dma[4])
#define DMA_hCha5   (CSL_DMA_DATA.Dma[5])

#define DMA_GBL     (CSL_DMA_DATA.GblRegs)

/****************************************\
* DMA global function declarations
\****************************************/                                                                                                                                                                                                                                                                                     
CSLAPI  void DMA_reset(DMA_Handle hDma);
CSLAPI  void DMA_resetGbl(DMA_Handle hDma);
CSLAPI  void DMA_globalGetConfig(Uint16 RegMask, DMA_GblConfig *Config);

CSLAPI  DMA_Handle DMA_open(int ChaNum, Uint32 Flags);
CSLAPI  void DMA_close(DMA_Handle hDma);

CSLAPI  void   DMA_globalConfig(Uint16 RegMask, DMA_GblConfig *Config);
#if ((_DMA_CH_RLDR_SUPPORT) && (!(_DMA_CH_XDP_SUPPORT)))
  CSLAPI void DMA_globalConfigArgs(Uint16 RegMask, Uint16 free, Uint16 autoix, Uint16 intosel, Uint16 dmidx0, Uint16 dmfri0, 
       Uint16 dmidx1, Uint16 dmfri1, Uint16 dmsrcp, Uint16 dmdstp, Uint16 dmsrcdp, Uint16 dmdstdp);
#elif ((_DMA_CH_XDP_SUPPORT) && (_DMA_CH_RLDR_SUPPORT))
  CSLAPI void DMA_globalConfigArgs(Uint16 RegMask, Uint16 free, Uint16 autoix, Uint16 intosel, Uint16 dmidx0, Uint16 dmfri0, 
       Uint16 dmidx1, Uint16 dmfri1, Uint16 dmsrcp, Uint16 dmdstp);
#elif (_DMA_GBL_XDP_SUPPORT)
  CSLAPI void DMA_globalConfigArgs(Uint16 RegMask, Uint16 free, Uint16 intosel, Uint16 dmidx0, Uint16 dmfri0, Uint16 dmidx1, 
       Uint16 dmfri1, Uint16 dmgsa, Uint16 dmgda, Uint16 dmgcr, Uint16 dmgfr, Uint16 dmsrcp,
       Uint16 dmdstp, Uint16 dmsrcdp, Uint16 dmdstdp);
#else
  CSLAPI void DMA_globalConfigArgs(Uint16 RegMask, Uint16 free, Uint16 intosel, Uint16 dmidx0, Uint16 dmfri0, Uint16 dmidx1, 
       Uint16 dmfri1, Uint16 dmgsa, Uint16 dmgda, Uint16 dmgcr, Uint16 dmgfr, Uint16 dmsrcp,
       Uint16 dmdstp);
#endif
 
                                          
/****************************************\
* DMA inline function declarations
\****************************************/
IDECL Uint16 DMA_getEventId(DMA_Handle hDma);
IDECL Uint16 DMA_getStatus(DMA_Handle hDma);

IDECL void   DMA_start(DMA_Handle hDma);
IDECL void   DMA_stop(DMA_Handle hDma);
IDECL void   DMA_pause(DMA_Handle hDma);
IDECL void   DMA_config(DMA_Handle hDma, DMA_Config *Config);
#if ((_DMA_CH_RLDR_SUPPORT) && (!_DMA_CH_XDP_SUPPORT))
 IDECL void DMA_configArgs(DMA_Handle hDma, Uint16 priority, Uint16 autoix, Uint16 dmmcr, Uint16 dmsfc,
     DMA_AdrPtr dmsrc, DMA_AdrPtr dmdst, Uint16 dmctr, DMA_AdrPtr dmgsa, 
     DMA_AdrPtr dmgda, Uint16 dmgcr, Uint16 dmgfr);
#elif ((_DMA_CH_RLDR_SUPPORT) && (_DMA_CH_XDP_SUPPORT))
 IDECL void DMA_configArgs(DMA_Handle hDma, Uint16 priority, Uint16 autoix, Uint16 dmmcr, Uint16 dmsfc,
     DMA_AdrPtr dmsrc, DMA_AdrPtr dmdst, Uint16 dmctr, DMA_AdrPtr dmgsa, DMA_AdrPtr dmgda, 
     Uint16 dmgcr, Uint16 dmgfr);
#else
 IDECL void DMA_configArgs(DMA_Handle hDma, Uint16 priority, Uint16 dmmcr, Uint16 dmsfc,
     DMA_AdrPtr dmsrc, DMA_AdrPtr dmdst, Uint16 dmctr);
#endif  

IDECL void   DMA_getConfig(DMA_Handle hDma, DMA_Config *Config);
IDECL void   DMA_autoStart(DMA_Handle hDma);

IDECL Uint16 DMA_globalAlloc(Uint16 RegMask);
IDECL void   DMA_globalFree(Uint16 RegMask);
IDECL void   DMA_setPriority(DMA_Handle hDma, Uint16 val);
IDECL Uint16 DMA_getPriority(DMA_Handle hDma);
IDECL Uint16 DMA_getAllocated(DMA_Handle hDma);
IDECL void   DMA_setAllocated(DMA_Handle hDma);
IDECL Uint16 DMA_getChan(DMA_Handle hDma);

/****************************************\
* DMA inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
IDEF Uint16 DMA_getEventId(DMA_Handle hDma) {
  return (Uint16)(((DMA_PrivateObj*)hDma)->EventId);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 DMA_getStatus(DMA_Handle hDma) {
  return _DMA_DMPREC_DECH_GET(((DMA_PrivateObj*)hDma)->ChaNum);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 DMA_getAllocated(DMA_Handle hDma){
 return (CSL_SYS_DATA.DmaAllocMask & (1u<<((DMA_PrivateObj*)hDma)->ChaNum));
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_setAllocated(DMA_Handle hDma){
  CSL_SYS_DATA.DmaAllocMask |= (1u<<((DMA_PrivateObj*)hDma)->ChaNum);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 DMA_getChan(DMA_Handle hDma){
 return (Uint16)(((DMA_PrivateObj*)(hDma))->ChaNum);
} 
/*----------------------------------------------------------------------------*/
IDEF void DMA_start(DMA_Handle hDma) {
  _DMA_DMPREC_DECH_SET(((DMA_PrivateObj*)(hDma))->ChaNum, 1);
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_stop(DMA_Handle hDma) {
  _DMA_DMPREC_DECH_SET(((DMA_PrivateObj*)hDma)->ChaNum, 0);
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_pause(DMA_Handle hDma) {
  _DMA_DMPREC_DECH_SET(((DMA_PrivateObj*)hDma)->ChaNum, 0);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 DMA_getPriority(DMA_Handle hDma) {
  return (_DMA_DMPREC_DPRCCH_GET(((DMA_PrivateObj*)hDma)->ChaNum));
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_setPriority(DMA_Handle hDma, Uint16 val) {
  _DMA_DMPREC_DPRCCH_SET(((DMA_PrivateObj*)hDma)->ChaNum, val);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 DMA_getIntosel(DMA_Handle hDma) {
  return (DMA_FGET(DMPREC,INTOSEL));
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_autoStart(DMA_Handle hDma) {
  DMA_FSETH(hDma,DMMCR,AUTOINIT,1);
  _DMA_DMPREC_DECH_SET(((DMA_PrivateObj*)hDma)->ChaNum, 1);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 DMA_globalAlloc(Uint16 RegMask){
  Uint16 allocmask = RegMask;
  Uint16 tmp;

  if (RegMask == 0x0000u) return (CSL_SYS_DATA.DmaGblAllocMask);

#if (!(_DMA_CH_RLDR_SUPPORT))
  if (RegMask & DMA_GBL_RLDR)                     
     allocmask |= DMA_GBL_RLDR;
#endif

  if (RegMask & DMA_GBL_DMIDXANY) {                
    tmp = (DMA_GBL_NDX0 & CSL_SYS_DATA.DmaGblAllocMask) ? 
             (DMA_GBL_NDX1 & CSL_SYS_DATA.DmaGblAllocMask) ? 0 : DMA_GBL_NDX1
                : DMA_GBL_NDX0;
    if (tmp == 0) return 0x000u;
    allocmask &= (~DMA_GBL_DMIDXANY);
  }
  else { 
   if (RegMask & (DMA_GBL_DMIDX0 | DMA_GBL_DMFRI0)) 
      allocmask |= DMA_GBL_NDX0;
   if (RegMask & (DMA_GBL_DMIDX1 | DMA_GBL_DMFRI1))
      allocmask |= DMA_GBL_NDX1;
  }
  if (allocmask & CSL_SYS_DATA.DmaGblAllocMask) return 0x0000u;
  CSL_SYS_DATA.DmaGblAllocMask |= allocmask;
  return allocmask;
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_globalFree(Uint16 RegMask){
  Uint16 freemask = RegMask;
  if (RegMask & DMA_GBL_NDX0)
     freemask |= DMA_GBL_NDX0;
  if (RegMask & DMA_GBL_NDX1)
     freemask |= DMA_GBL_NDX1;
#if (!(_DMA_CH_RLDR_SUPPORT))
    if (RegMask & DMA_GBL_RLDR);
       freemask |= DMA_GBL_RLDR;
#endif
  CSL_SYS_DATA.DmaGblAllocMask &= (~freemask);
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_config(DMA_Handle hDma, DMA_Config *Config) {

  int old_intm;

  DMA_ASSERT_HANDLE(hDma,return);

  old_intm = IRQ_globalDisable();
  _DMA_DMPREC_DPRCCH_SET(((DMA_PrivateObj*)(hDma))->ChaNum, Config->priority);
  DMA_RSET(DMSA,((Uint16)(((DMA_PrivateObj*)hDma)->DmsrcAddr)));
  DMA_RSETI(DMSRC,((Uint16)((Uint32)(Config->dmsrc)&0xFFFFu)));
  DMA_RSETI(DMDST,((Uint16)((Uint32)(Config->dmdst)&0xFFFFu)));
  DMA_RSETI(DMCTR,Config->dmctr); 
  DMA_RSETI(DMSFC,Config->dmsfc);
  DMA_RSETI(DMMCR,Config->dmmcr); 
#if (_DMA_CH_RLDR_SUPPORT)
  DMA_RSET(DMSA,((Uint16)(((DMA_PrivateObj*)hDma)->DmgsaAddr)));
  DMA_RSETI(DMGSA,((Uint16)((Uint32)(Config->dmgsa)&0xFFFFu)));
  DMA_RSETI(DMGDA,((Uint16)((Uint32)(Config->dmgda)&0xFFFFu)));
  DMA_RSETI(DMGCR,Config->dmgcr);
  DMA_RSETI(DMGFR,Config->dmgfr);
#endif

#if (_DMA_CH_XDP_SUPPORT)
  DMA_RSET(DMSA,((Uint16)(((DMA_PrivateObj*)hDma)->DmsrcdpAddr)));
  DMA_RSETI(DMSRCDP,Config->dmsrcdp);
  DMA_RSETI(DMDSTDP,Config->dmdstdp);
#endif
  IRQ_globalRestore(old_intm);
  return;
}
/*----------------------------------------------------------------------------*/
IDEF void DMA_getConfig(DMA_Handle hDma, DMA_Config *Config) {
#if (_DMA_CH_RLDR_SUPPORT)
  Uint16 gsa_start = _DMA_DMGSA0_ADDR;
#endif
  int old_intm;

  DMA_ASSERT_HANDLE(hDma,return);

  old_intm = IRQ_globalDisable();

  Config->priority = _DMA_DMPREC_DPRCCH_GET((((DMA_PrivateObj*)hDma)->ChaNum));
  DMA_RSET(DMSA,((Uint16)(((DMA_PrivateObj*)hDma)->DmsrcAddr)));
  Config->dmsrc = (DMA_AdrPtr)(DMA_RGETI(DMSRC));
  Config->dmdst = (DMA_AdrPtr)(DMA_RGETI(DMDST));
  Config->dmctr = DMA_RGETI(DMCTR); 
  Config->dmsfc = DMA_RGETI(DMSFC);
  Config->dmmcr = DMA_RGETI(DMMCR);
 
 #if (_DMA_CH_RLDR_SUPPORT)
  if (Config->autoix)
    gsa_start = (Uint16)(((DMA_PrivateObj*)(hDma))->DmgsaAddr);

  DMA_RSET(DMSA,gsa_start);
  Config->dmgsa = (DMA_AdrPtr)(DMA_RGETI(DMGSA));
  Config->dmgda = (DMA_AdrPtr)(DMA_RGETI(DMGDA));
  Config->dmgcr = DMA_RGETI(DMGCR);
  Config->dmgfr = DMA_RGETI(DMGFR);
#endif

#if (_DMA_CH_XDP_SUPPORT)
  DMA_RSET(DMSA,((Uint16)((DMA_PrivateObj*)hDma)->DmsrcdpAddr));
  Config->dmsrcdp = DMA_RGETI(DMSRCDP);
  Config->dmdstdp = DMA_RGETI(DMDSTDP);
#endif


  IRQ_globalRestore(old_intm);
  return;
}

/*----------------------------------------------------------------------------*/
#if ((_DMA_CH_RLDR_SUPPORT) && (!_DMA_CH_XDP_SUPPORT))
 IDEF void DMA_configArgs(DMA_Handle hDma, Uint16 priority, Uint16 autoix, Uint16 dmmcr, Uint16 dmsfc,
     DMA_AdrPtr dmsrc, DMA_AdrPtr dmdst, Uint16 dmctr, DMA_AdrPtr dmgsa, DMA_AdrPtr dmgda, 
     Uint16 dmgcr, Uint16 dmgfr){
     Uint16 gsa_start = _DMA_DMGSA0_ADDR;

#elif ((_DMA_CH_RLDR_SUPPORT) && (_DMA_CH_XDP_SUPPORT))
 IDEF void DMA_configArgs(DMA_Handle hDma, Uint16 priority, Uint16 autoix, Uint16 dmmcr, Uint16 dmsfc,
     DMA_AdrPtr dmsrc, DMA_AdrPtr dmdst, Uint16 dmctr, DMA_AdrPtr dmgsa, DMA_AdrPtr dmgda, 
     Uint16 dmgcr, Uint16 dmgfr){
     Uint16 gsa_start = _DMA_DMGSA0_ADDR;

#else
 IDEF void DMA_configArgs(DMA_Handle hDma, Uint16 priority, Uint16 dmmcr, Uint16 dmsfc,
     DMA_AdrPtr dmsrc, DMA_AdrPtr dmdst, Uint16 dmctr){
#endif  
  int old_intm;
#if (_DMA_CH_XDP_SUPPORT)
  Uint16 dmsrcdp, dmdstdp;
#endif


  DMA_ASSERT_HANDLE(hDma,return);

  old_intm = IRQ_globalDisable();

  _DMA_DMPREC_DPRCCH_SET(((DMA_PrivateObj*)hDma)->ChaNum, priority);
  DMA_RSET(DMSA,((Uint16)(((DMA_PrivateObj*)hDma)->DmsrcAddr)));
  DMA_RSETI(DMSRC,(Uint16)((Uint32)dmsrc & 0xFFFFu));
  DMA_RSETI(DMDST,(Uint16)((Uint32)dmdst & 0xFFFFu));
  DMA_RSETI(DMCTR,dmctr); 
  DMA_RSETI(DMSFC,dmsfc);
  DMA_RSETI(DMMCR,dmmcr);
#if (_DMA_CH_RLDR_SUPPORT)
  if (autoix)
     gsa_start = (Uint16)(((DMA_PrivateObj*)hDma)->DmgsaAddr);
  _DMA_DMSA = gsa_start;
  DMA_RSETI(DMGSA,(Uint16)((Uint32)dmgsa & 0xFFFFu));
  DMA_RSETI(DMGDA,(Uint16)((Uint32)dmgda & 0xFFFFu));
  DMA_RSETI(DMGCR,dmgcr);
  DMA_RSETI(DMGFR,dmgfr);
#endif
#if (_DMA_CH_XDP_SUPPORT)
  DMA_RSET(DMSA,((Uint16)(((DMA_PrivateObj*)hDma)->DmsrcdpAddr)));
  dmsrcdp = (Uint16)(((Uint32)dmgsa >> 16) & 0xFFFFu);
  dmdstdp = (Uint16)(((Uint32)dmgda >> 16) & 0xFFFFu);
  DMA_RSETI(DMSRCDP,dmsrcdp);
  DMA_RSETI(DMDSTDP,dmdstdp);
#endif

  IRQ_globalRestore(old_intm);
  return;
}
#endif /* USEDEFS */

#elif (!(_DMA_MOD_)) /* DMA_SUPPORT */
  #error DMA Module Not Support on Specified Target
#endif /* DMA_SUPPORT */
#endif /* _CSL_DMA_H_ */
/******************************************************************************\
* End of csl_dma.h
\******************************************************************************/

