/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 2000 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... DMA
* FILENAME...... csl_dmadatB.h
* DATE CREATED.. Thu 05/31/2001 
* PROJECT....... Chip Support Library
* COMPONENT..... CSL service layer
* PREREQUISITS..
*------------------------------------------------------------------------------
* HISTORY:
*   LAST MODIFIED:  05/31/2001  
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (DMA Data Initialization for DMA's with indivudual channel
*                reload registers and global extern data/program support)
*
*
\******************************************************************************/
#ifndef _CSL_DMA_DATAB_H_
#define _CSL_DMA_DATAB_H_

/*============================================================*/
/*============= DMA Data Object Initialization ===============*/
/*============================================================*/

#define CSL_DMADATAINIT \
{ /* Dma Channel 0 initialization data */\
  0x0016,     /* Channel 0 Event Id */\
  0x0000,     /* Channel Number */\
  0x0000,     /* DMSRC SubAddress */\
  0x0001,     /* DMDST SubAddress */\
  0x0002,     /* DMCTR Subaddress */\
  0x0003,     /* DMSFC Subaddress */\
  0x0004,     /* DMMCR Subaddress */\
  0x0024,     /* DMGSA Subaddress */\
  0x0025,     /* DMGDA Subaddress */\
  0x0026,     /* DMGCR Subaddress */\
  0x0027,     /* DMGFR Subaddress */\
  /* Dma Channel 1 initialization data */\
  0x0017,     /* Channel 1 EventId */\
  0x0001,     /* Channel Number */\
  0x0005,     /* DMSRC Subaddress */\
  0x0006,     /* DMDST Subaddress */\
  0x0007,     /* DMCTR Subaddress */\
  0x0008,     /* DMSFC Subaddress */\
  0x0009,     /* DMMCR Subaddress */\
  0x002A,     /* DMGSA Subaddress */\
  0x002B,     /* DMGDA Subaddress */\
  0x002C,     /* DMGCR Subaddress */\
  0x002D,     /* DMGFR Subaddress */\
  /* Dma Channel 2 initialization data */\
  0x001A,     /* DMA Channel 2 EventId */\
  0x0002,     /* Channel Number */\
  0x000A,     /* DMSRC Subaddress */\
  0x000B,     /* DMDST Subaddress */\
  0x000C,     /* DMCTR Subaddress */\
  0x000D,     /* DMSFC Subaddress */\
  0x000E,     /* DMMCR Subaddress */\
  0x002E,     /* DMGSA Subaddress */\
  0x002F,     /* DMGDA Subaddress */\
  0x0030,     /* DMGCR Subaddress */\
  0x0031,     /* DMGFR Subaddress */\
  /* Dma Channel 3 initialization data */\
  0x001B,     /* DMA Channel 3 EventId */\
  0x0003,     /* Channel Number */\
  0x000F,     /* DMSRC Subaddress */\
  0x0010,     /* DMDST Subaddress */\
  0x0011,     /* DMCTR Subaddress */\
  0x0012,     /* DMSFC Subaddress */\
  0x0013,     /* DMMCR Subaddress */\
  0x0032,     /* DMGSA Subaddress */\
  0x0033,     /* DMGDA Subaddress */\
  0x0034,     /* DMGCR Subaddress */\
  0x0035,     /* DMGFR Subaddress */\
  /* Dma Channel 4 initialization data */\
  0x001C,     /* DMA Channel 4 EventId */\
  0x0004,     /* Channel Number */\
  0x0014,     /* DMSRC Subaddress */\
  0x0015,     /* DMDST Subaddress */\
  0x0016,     /* DMCTR Subaddress */\
  0x0017,     /* DMSFC Subaddress */\
  0x0018,     /* DMMCR Subaddress */\
  0x0036,     /* DMGSA Subaddress */\
  0x0037,     /* DMGDA Subaddress */\
  0x0038,     /* DMGCR Subaddress */\
  0x0039,     /* DMGFR Subaddress */\
 /* Dma Channel 5 initialization data */\
  0x001D,     /* DMA Channel 5 EventId */\
  0x0005,     /* Channel Number */\
  0x0019,     /* DMSRC Subaddress */\
  0x001A,     /* DMDST Subaddress */\
  0x001B,     /* DMCTR Subaddress */\
  0x001C,     /* DMSFC Subaddress */\
  0x001D,     /* DMMCR Subaddress */\
  0x003A,     /* DMGSA Subaddress */\
  0x003B,     /* DMGDA Subaddress */\
  0x003C,     /* DMGCR Subaddress */\
  0x003D,     /* DMGFR Subaddress */\
/* DMA Global Registers (Shared Among Channels) */\
  0x001E,     /* DMSRCP Subaddress */\
  0x001F,     /* DMDSTP Subaddress */\
  0x0020,     /* DMIDX0 Subaddress */\
  0x0021,     /* DMFRI0 Subaddress */\
  0x0022,     /* DMIDX1 Subaddress */\
  0x0023,     /* DMFRI1 Subaddress */\
  0x0028,     /* DMSRCDP Subaddress */\
  0x0029      /* DMDSTDP Subaddress */\
}

/*============================================================*/
/*============= Structure Definitions ========================*/
/*============================================================*/
/* private object, not to be used by application code */

/* private object, not to be used by application code */
typedef struct {
  Uint16 DmsrcpAddr;
  Uint16 DmdstpAddr;
  Uint16 Dmidx0Addr;
  Uint16 Dmidx1Addr;
  Uint16 Dmfri0Addr;
  Uint16 Dmfri1Addr;
  Uint16 DmsrcdpAddr;
  Uint16 DmdstdpAddr;
} DMA_GblPrivateObj;

typedef struct {
  Uint16 EventId;
  Uint16 ChaNum; 
  Uint16 DmsrcAddr;
  Uint16 DmdstAddr;
  Uint16 DmctrAddr;
  Uint16 DmsfcAddr;
  Uint16 DmmcrAddr;
  Uint16 DmgsaAddr;
  Uint16 DmgdaAddr;
  Uint16 DmgcrAddr;
  Uint16 DmgfrAddr;
} DMA_PrivateObj;

#endif   /* _CSL_DMA_DATA_H_ */
