/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... DMA - DMA module
* FILENAME...... dmahal.h
* DATE CREATED.. Fri 03/12/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   03/12/1999 (BWC) Created
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the DMA module)
*
*
*
\******************************************************************************/
#ifndef _DMAHAL_H_
#define _DMAHAL_H_

#include <csl_chiphal.h>

#if (_DMA_SUPPORT) 

/****************************************\
* DMA scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  __DMA_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/****************************************\
* _DMA global macro declarations
\****************************************/

#define DMA_RGET(Reg)                     _DMA_##Reg##_GET()
#define DMA_RSET(Reg,Val)                 _DMA_##Reg##_SET(Val)
#define DMA_RGETI(Reg)                    _SUBREG_GETI(_DMA_DMSDI_ADDR)
#define DMA_RSETI(Reg,Val)                _SUBREG_SETI(_DMA_DMSDI_ADDR,Val)
#define DMA_FGET(Reg,Field)               _DMA_##Reg##_FGET(##Field)
#define DMA_FSET(Reg,Field,Val)           _DMA_##Reg##_FSET(##Field,Val)
#define DMA_FSETS(Reg,Field,Sym)          _DMA_##Reg##_FSETS(##Field,Sym)
#define DMA_ADDR(Reg)                     _DMA_##Reg##_ADDR
#define DMA_FMKS(Reg,Field,Sym)           _DMA_##Reg##_##Field##_MK(DMA_##Reg##_##Field##_##Sym)
#define DMA_FMK(Reg,Field,Val)            _DMA_##Reg##_##Field##_MK(Val)
#define DMA_RAOI(Reg,AND,OR,INV)          _DMA_##Reg##_AOI(AND,OR,INV)
#define DMA_FAOI(Reg,Field,AND,OR,INV)    _DMA_##Reg##_FAOI(##Field,AND,OR,INV)

#define DMA_RGETH(Handle,Reg)            _DMA_##Reg##_GET((((DMA_PrivateObj*)(Handle))->ChaNum))
#define DMA_RSETH(Handle,Reg,Val)        _DMA_##Reg##_SET((((DMA_PrivateObj*)(Handle))->ChaNum),Val)
#define DMA_FGETH(Handle,Reg,Field)      _DMA_##Reg##_FGET((((DMA_PrivateObj*)(Handle))->ChaNum),##Field)
#define DMA_FSETH(Handle,Reg,Field,Val)  _DMA_##Reg##_FSET((((DMA_PrivateObj*)(Handle))->ChaNum),##Field,Val)
#define DMA_FSETSH(Handle,Reg,Field,Sym) DMA_##Reg##_FSET(Handle,Field,DMA_##Reg##_##Field##_##Sym)
#define DMA_RAOIH(Handle,Reg,AND,OR,INV) _DMA_##Reg##_AOI(((DMA_PrivateObj*)(Handle))->ChaNum,AND,OR,INV)
#define DMA_FAOIH(Handle,Reg,Field,AND,OR,INV)\
                                          _DMA_##Reg##_FAOI(((DMA_PrivateObj*)(Handle))->ChaNum,##Field,AND,OR,INV)
#define DMA_ADDRH(Handle,Reg)            _DMA_##Reg##_ADDRH(((DMA_PrivateObj*)(Handle))->ChaNum)

#define DMA_RGET_H(Handle,Reg)            _DMA_##Reg##_GET((((DMA_PrivateObj*)(Handle))->ChaNum))
#define DMA_RSET_H(Handle,Reg,Val)        _DMA_##Reg##_SET((((DMA_PrivateObj*)(Handle))->ChaNum),Val)
#define DMA_FGET_H(Handle,Reg,Field)      _DMA_##Reg##_FGET((((DMA_PrivateObj*)(Handle))->ChaNum),##Field)
#define DMA_FSET_H(Handle,Reg,Field,Val)  _DMA_##Reg##_FSET((((DMA_PrivateObj*)(Handle))->ChaNum),##Field,Val)
#define DMA_FSETS_H(Handle,Reg,Field,Sym) DMA_##Reg##_FSET(Handle,Field,DMA_##Reg##_##Field##_##Sym)
#define DMA_RAOI_H(Handle,Reg,AND,OR,INV) _DMA_##Reg##_AOI(((DMA_PrivateObj*)(Handle))->ChaNum,AND,OR,INV)
#define DMA_FAOI_H(Handle,Reg,Field,AND,OR,INV)\
                                          _DMA_##Reg##_FAOI(((DMA_PrivateObj*)(Handle))->ChaNum,##Field,AND,OR,INV)
#define DMA_ADDR_H(Handle,Reg)            _DMA_##Reg##_ADDRH(((DMA_PrivateObj*)(Handle))->ChaNum)

#define _DMA_DMSA_GET()                   _REG_GET(_DMA_DMSA_ADDR)
#define _DMA_DMSA_SET(Val)                _REG_SET(_DMA_DMSA_ADDR,Val)


/*============================================================================*\
* misc constants and macros
\*============================================================================*/
  #define _DMA_CHANNEL_CNT            (6)
  #define _DMA_GBLADDR_CNT            (10)
  #define _DMA_GBLIDX_CNT             (2)
  #define _DMA_GBLCNT_CNT             (2)


#define _DMA_CHA_CNT            (6)

/*============================================================================*\
* memory mapped register addresses
\*============================================================================*/
#define _DMA_BASE_ADDR              (_CHIP_PERBASE_ADDR+0x0054u)
#define _DMA_DMPREC_ADDR            (_DMA_BASE_ADDR+0x0000u)
#define _DMA_DMSA_ADDR              (_DMA_BASE_ADDR+0x0001u)
#define _DMA_DMSDI_ADDR             (_DMA_BASE_ADDR+0x0002u)
#define _DMA_DMSDN_ADDR             (_DMA_BASE_ADDR+0x0003u)

/*===========================================================================*\
* DMA memory mapped register addresses 
\*===========================================================================*/

#define _DMA_DMPREC                  REG16(_DMA_DMPREC_ADDR)
#define _DMA_DMSA                    REG16(_DMA_DMSA_ADDR)
#define _DMA_DMSDI                   REG16(_DMA_DMSDI_ADDR)
#define _DMA_DMSDN                   REG16(_DMA_DMSDN_ADDR)

#define _DMPREC                      REG16(_DMA_DMPREC_ADDR)
#define _DMSA                        REG16(_DMA_DMSA_ADDR)
#define _DMSDI                       REG16(_DMA_DMSDI_ADDR)
#define _DMSDN                       REG16(_DMA_DMSDN_ADDR)

/*============================================================================*\
* Subbank memory mapped register addresses
\*============================================================================*/

#define _DMA_DMSRC0_ADDR		(0x0000)
#define _DMA_DMDST0_ADDR		(0x0001)
#define _DMA_DMCTR0_ADDR		(0x0002)
#define _DMA_DMSFC0_ADDR		(0x0003)
#define _DMA_DMMCR0_ADDR		(0x0004)

#define _DMA_DMSRC1_ADDR		(0x0005)
#define _DMA_DMDST1_ADDR		(0x0006)
#define _DMA_DMCTR1_ADDR		(0x0007)
#define _DMA_DMSFC1_ADDR		(0x0008)
#define _DMA_DMMCR1_ADDR		(0x0009)

#define _DMA_DMSRC2_ADDR		(0x000A)
#define _DMA_DMDST2_ADDR		(0x000B)
#define _DMA_DMCTR2_ADDR		(0x000C)
#define _DMA_DMSFC2_ADDR		(0x000D)
#define _DMA_DMMCR2_ADDR		(0x000E)

#define _DMA_DMSRC3_ADDR		(0x000F)
#define _DMA_DMDST3_ADDR		(0x0010)
#define _DMA_DMCTR3_ADDR		(0x0011)
#define _DMA_DMSFC3_ADDR		(0x0012)
#define _DMA_DMMCR3_ADDR		(0x0013)

#define _DMA_DMSRC4_ADDR		(0x0014)
#define _DMA_DMDST4_ADDR		(0x0015)
#define _DMA_DMCTR4_ADDR		(0x0016)
#define _DMA_DMSFC4_ADDR		(0x0017)
#define _DMA_DMMCR4_ADDR		(0x0018)

#define _DMA_DMSRC5_ADDR		(0x0019)
#define _DMA_DMDST5_ADDR		(0x001A)
#define _DMA_DMCTR5_ADDR		(0x001B)
#define _DMA_DMSFC5_ADDR		(0x001C)
#define _DMA_DMMCR5_ADDR		(0x001D)

/*============================================================================*\
* Subbank memory mapped register addresses
\*============================================================================*/

#define _DMA_DMSRCP_ADDR		(0x001E)
#define _DMA_DMDSTP_ADDR		(0x001F)
#define _DMA_DMIDX0_ADDR		(0x0020)
#define _DMA_DMIDX1_ADDR		(0x0021)
#define _DMA_DMFRI0_ADDR		(0x0022)
#define _DMA_DMFRI1_ADDR		(0x0023)

#define _DMA_DMSRCP_ADDR		(0x001E)
#define _DMA_DMDSTP_ADDR		(0x001F)
#define _DMA_DMIDX0_ADDR		(0x0020)
#define _DMA_DMIDX1_ADDR		(0x0021)
#define _DMA_DMFRI0_ADDR		(0x0022)
#define _DMA_DMFRI1_ADDR		(0x0023)

#define _DMA_DMSRCP      		(0x001E)
#define _DMA_DMDSTP                 (0x001F)
#define _DMA_DMIDX0                 (0x0020)
#define _DMA_DMIDX1                 (0x0021)
#define _DMA_DMFRI0                 (0x0022)
#define _DMA_DMFRI1                 (0x0023)



#if (_DMA_CH_RLDR_SUPPORT)
  #define _DMA_DMGSA0_ADDR          (0x0024)
  #define _DMA_DMGDA0_ADDR          (0x0025)
  #define _DMA_DMGCR0_ADDR          (0x0026)
  #define _DMA_DMGFR0_ADDR          (0x0027)
#else
  #define _DMA_DMGSA_ADDR           (0x0024)
  #define _DMA_DMGDA_ADDR           (0x0025)
  #define _DMA_DMGCR_ADDR           (0x0026)
  #define _DMA_DMGFR_ADDR           (0x0027)
#endif

#if ((_DMA_EXT_DATA_SUPPORT) && (!(_DMA_CH_XDP_SUPPORT)))
  #define _DMA_DMSRCDP_ADDR         (0x0028)
  #define _DMA_DMDSTDP_ADDR         (0x0029)
#endif

#if (_DMA_CH_RLDR_SUPPORT)
  #define _DMA_DMGSA1_ADDR          (0x002A)
  #define _DMA_DMGDA1_ADDR          (0x002B)
  #define _DMA_DMGCR1_ADDR          (0x002C)
  #define _DMA_DMGFR1_ADDR          (0x002D)

  #define _DMA_DMGSA2_ADDR          (0x002E)
  #define _DMA_DMGDA2_ADDR          (0x002F)
  #define _DMA_DMGCR2_ADDR          (0x0030)
  #define _DMA_DMGFR2_ADDR          (0x0031)

  #define _DMA_DMGSA3_ADDR          (0x0032)
  #define _DMA_DMGDA3_ADDR          (0x0033)
  #define _DMA_DMGCR3_ADDR          (0x0034)
  #define _DMA_DMGFR3_ADDR          (0x0035)

  #define _DMA_DMGSA4_ADDR          (0x0036)
  #define _DMA_DMGDA4_ADDR          (0x0037)
  #define _DMA_DMGCR4_ADDR          (0x0038)
  #define _DMA_DMGFR4_ADDR          (0x0039)

  #define _DMA_DMGSA5_ADDR          (0x003A)
  #define _DMA_DMGDA5_ADDR          (0x003B)
  #define _DMA_DMGCR5_ADDR          (0x003C)
  #define _DMA_DMGFR5_ADDR          (0x003D)
#endif

#if (_DMA_CH_XDP_SUPPORT)
  #define _DMA_DMSRCDP0_ADDR        (0x003E)
  #define _DMA_DMDSTDP0_ADDR        (0x003F)
  #define _DMA_DMSRCDP1_ADDR        (0x0040)
  #define _DMA_DMDSTDP1_ADDR        (0x0041)
  #define _DMA_DMSRCDP2_ADDR        (0x0042)
  #define _DMA_DMDSTDP2_ADDR        (0x0043)
  #define _DMA_DMSRCDP3_ADDR        (0x0044)
  #define _DMA_DMDSTDP3_ADDR        (0x0045)
  #define _DMA_DMSRCDP4_ADDR        (0x0046)
  #define _DMA_DMDSTDP4_ADDR        (0x0047)
  #define _DMA_DMSRCDP5_ADDR        (0x0048)
  #define _DMA_DMDSTDP5_ADDR        (0x0049)
#endif

/********************************************************\
* Global DMA subbank register addresses 
\********************************************************/

#define _DMSRCP				 (_DMA_DMSRCP_ADDR)
#define _DMDSTP				 (_DMA_DMDSTP_ADDR)
#define _DMIDX0				 (_DMA_DMIDX0_ADDR)
#define _DMIDX1				 (_DMA_DMIDX1_ADDR)
#define _DMFRI0				 (_DMA_DMFRI0_ADDR)
#define _DMFRI1				 (_DMA_DMFRI1_ADDR)


#if (_DMA_CH_RLDR_SUPPORT)
  #define _DMGSA0                     (_DMA_DMGSA0_ADDR)
  #define _DMGDA0                     (_DMA_DMGDA0_ADDR)
  #define _DMGCR0                     (_DMA_DMGCR0_ADDR)
  #define _DMGFR0                     (_DMA_DMGFR0_ADDR)

  #define _DMGSA1                     (_DMA_DMGSA1_ADDR)
  #define _DMGDA1                     (_DMA_DMGDA1_ADDR)
  #define _DMGCR1                     (_DMA_DMGCR1_ADDR)
  #define _DMGFR1                     (_DMA_DMGFR1_ADDR)

  #define _DMGSA2                     (_DMA_DMGSA2_ADDR)
  #define _DMGDA2                     (_DMA_DMGDA2_ADDR)
  #define _DMGCR2                     (_DMA_DMGCR2_ADDR)
  #define _DMGFR2                     (_DMA_DMGFR2_ADDR)

  #define _DMGSA3                     (_DMA_DMGSA3_ADDR)
  #define _DMGDA3                     (_DMA_DMGDA3_ADDR)
  #define _DMGCR3                     (_DMA_DMGCR3_ADDR)
  #define _DMGFR3                     (_DMA_DMGFR3_ADDR)

  #define _DMGSA4                     (_DMA_DMGSA4_ADDR) 
  #define _DMGDA4                     (_DMA_DMGDA4_ADDR)
  #define _DMGCR4                     (_DMA_DMGCR4_ADDR)
  #define _DMGFR4                     (_DMA_DMGFR4_ADDR)

  #define _DMGSA5                     (_DMA_DMGSA5_ADDR)
  #define _DMGDA5                     (_DMA_DMGDA5_ADDR)
  #define _DMGCR5                     (_DMA_DMGCR5_ADDR)
  #define _DMGFR5                     (_DMA_DMGFR5_ADDR)
#else

  #define _DMGSA                      (_DMA_DMGSA_ADDR)
  #define _DMGDA                      (_DMA_DMGDA_ADDR)
  #define _DMGCR                      (_DMA_DMGCR_ADDR)
  #define _DMGFR                      (_DMA_DMGFR_ADDR)
#endif


#if ((_DMA_EXT_DATA_SUPPORT) && (!(_DMA_CH_XDP_SUPPORT)))
  #define _DMA_DMSRCDP                (_DMA_DMSRCDP_ADDR)
  #define _DMA_DMDSTDP                (_DMA_DMDSTDP_ADDR)

  #define _DMSRCDP                    (_DMA_DMSRCDP_ADDR)
  #define _DMDSTDP                    (_DMA_DMDSTDP_ADDR)
#endif

#if (_DMA_CH_XDP_SUPPORT)

  #define _DMSRCDP0                    (_DMA_DMSRCDP0_ADDR)
  #define _DMDSTDP0                    (_DMA_DMDSTDP0_ADDR)
  #define _DMSRCDP1                    (_DMA_DMSRCDP1_ADDR)
  #define _DMDSTDP1                    (_DMA_DMDSTDP1_ADDR)
  #define _DMSRCDP2                    (_DMA_DMSRCDP2_ADDR)
  #define _DMDSTDP2                    (_DMA_DMDSTDP2_ADDR)
  #define _DMSRCDP3                    (_DMA_DMSRCDP3_ADDR)
  #define _DMDSTDP3                    (_DMA_DMDSTDP3_ADDR)
  #define _DMSRCDP4                    (_DMA_DMSRCDP4_ADDR)
  #define _DMDSTDP4                    (_DMA_DMDSTDP4_ADDR)
  #define _DMSRCDP5                    (_DMA_DMSRCDP5_ADDR)
  #define _DMDSTDP5                    (_DMA_DMDSTDP5_ADDR)

#endif


                 
/********************************************************\
* Channel subbank register addresses 
\********************************************************/

#define _DMSRC0                      (_DMA_DMSRC0_ADDR)
#define _DMDST0				 (_DMA_DMDST0_ADDR)
#define _DMCTR0				 (_DMA_DMCTR0_ADDR)
#define _DMSFC0				 (_DMA_DMSFC0_ADDR)
#define _DMMCR0				 (_DMA_DMMCR0_ADDR)

#define _DMSRC1				 (_DMA_DMSRC1_ADDR)
#define _DMDST1				 (_DMA_DMDST1_ADDR)
#define _DMCTR1				 (_DMA_DMCTR1_ADDR)
#define _DMSFC1				 (_DMA_DMSFC1_ADDR)
#define _DMMCR1				 (_DMA_DMMCR1_ADDR)

#define _DMSRC2				 (_DMA_DMSRC2_ADDR)
#define _DMDST2				 (_DMA_DMDST2_ADDR)
#define _DMCTR2				 (_DMA_DMCTR2_ADDR)
#define _DMSFC2				 (_DMA_DMSFC2_ADDR)
#define _DMMCR2				 (_DMA_DMMCR2_ADDR)

#define _DMSRC3				 (_DMA_DMSRC3_ADDR)
#define _DMDST3				 (_DMA_DMDST3_ADDR)
#define _DMCTR3				 (_DMA_DMCTR3_ADDR)
#define _DMSFC3				 (_DMA_DMSFC3_ADDR)
#define _DMMCR3				 (_DMA_DMMCR3_ADDR)

#define _DMSRC4				 (_DMA_DMSRC4_ADDR)
#define _DMDST4				 (_DMA_DMDST4_ADDR)
#define _DMCTR4				 (_DMA_DMCTR4_ADDR)
#define _DMSFC4				 (_DMA_DMSFC4_ADDR)
#define _DMMCR4				 (_DMA_DMMCR4_ADDR)

#define _DMSRC5				 (_DMA_DMSRC5_ADDR)
#define _DMDST5				 (_DMA_DMDST5_ADDR)
#define _DMCTR5				 (_DMA_DMCTR5_ADDR)
#define _DMSFC5				 (_DMA_DMSFC5_ADDR)
#define _DMMCR5				 (_DMA_DMMCR5_ADDR)


/********************************************************\
* Macros to reference channel registers by channnel #
\********************************************************/

#define _DMSRC_BASE			(0x0000u)
#define _DMDST_BASE			(0x0001u)
#define _DMCTR_BASE			(0x0002u)
#define _DMSFC_BASE			(0x0003u)
#define _DMMCR_BASE			(0x0004u)
#define _DMGSA_BASE                 (0x0024u)
#define _DMGDA_BASE                 (0x0025u)
#define _DMGCR_BASE                 (0x0026u)
#define _DMGFR_BASE                 (0x0027u)

#define _DMA_CH_SIZE			(0x0005u)
#define _DMA_RELOAD_REG_SZ          (0x0004u)

#define __DMSRC(n)                   (_DMSRC_BASE + _DMA_CH_SIZE * n)
#define __DMDST(n)                   (_DMDST_BASE + _DMA_CH_SIZE * n)
#define __DMCTR(n)                   (_DMCTR_BASE + _DMA_CH_SIZE * n)
#define __DMSFC(n)                   (_DMSFC_BASE + _DMA_CH_SIZE * n)
#define __DMMCR(n)                   (_DMMCR_BASE + _DMA_CH_SIZE * n)

#define _DMA_DMSRC_ADDRH(Chan)       __DMSRC(Chan)
#define _DMA_DMDST_ADDRH(Chan)       __DMDST(Chan)
#define _DMA_DMCTR_ADDRH(Chan)       __DMCTR(Chan)
#define _DMA_DMSFC_ADDRH(Chan)       __DMSFC(Chan)
#define _DMA_DMMCR_ADDRH(Chan)       __DMMCR(Chan)

#if (_DMA_CH_RLDR_SUPPORT)
 #define __DMGSA(n)                   (_DMGSA_BASE + ((n!=0)*2 + (n * _DMA_RELOAD_REG_SZ)))
 #define __DMGDA(n)                   (_DMGDA_BASE + ((n!=0)*2 + (n * _DMA_RELOAD_REG_SZ)))
 #define __DMGCR(n)                   (_DMGCR_BASE + ((n!=0)*2 + (n * _DMA_RELOAD_REG_SZ)))
 #define __DMGFR(n)                   (_DMGFR_BASE + ((n!=0)*2 + (n * _DMA_RELOAD_REG_SZ)))

 #define _DMA_DMGSA_ADDRH(Chan)     __DMGSA(Chan)
 #define _DMA_DMGDA_ADDRH(Chan)     __DMGDA(Chan)
 #define _DMA_DMGCR_ADDRH(Chan)     __DMGCR(Chan)
 #define _DMA_DMGFR_ADDRH(Chan)     __DMGFR(Chan)
#endif

#if (_DMA_CH_XDP_SUPPORT)			
 #define _DMSRCDP_BASE_ADDR          _DMSRCDP0
 #define _DMDSTDP_BASE_ADDR          _DMDSTDP0

 #define __DMSRCDP(n)                (_DMSRCDP_BASE_ADDR + n * 2)
 #define __DMDSTDP(n)                (_DMDSTDP_BASE_ADDR + n * 2)
  
 #define _DMA_DMSRCDP_ADDRH(Chan)   __DMSRCDP(Chan)
 #define _DMA_DMDSTDP_ADDRH(Chan)   __DMDSTDP(Chan)
#endif

/*============================================================================*\
* DMA Channel Priority and Enable Control (DMPREC) Bit Fields
\*============================================================================*/
#define _DMA_DMPREC_SET(Val)\
  _REG_SET(_DMA_DMPREC_ADDR, Val)

#define _DMA_DMPREC_AOI(AND,OR,INV)\
  _REG_AOI(_DMA_DMPREC_ADDR, AND, OR, INV)

#define _DMA_DMPREC_GET()\
  _REG_GET(_DMA_DMPREC_ADDR)

#if (_DMA_CH_RLDR_SUPPORT)
#define _DMA_DMPREC_CFG(free,autoix,chpri,intosel,chenable) REG16(_DMA_DMPREC_ADDR) = ((Uint16)(\
    _FIELD_SHIFT(_DMA_DMPREC_FREE,free) |\
    _FIELD_SHIFT(_DMA_DMPREC_AUTOIX,autoix)|\
    _FIELD_SHIFT(_DMA_DMPREC_DPRC,chpri)|\
    _FIELD_SHIFT(_DMA_DMPREC_INTOSEL,intosel)|\
    _FIELD_SHIFT(_DMA_DMPREC_DE,chenable)\
  )\
)  
#else
#define _DMA_DMPREC_CFG(free,chpri,intosel,chenable) REG16(_DMA_DMPREC_ADDR) = ((Uint16)(\
    _FIELD_SHIFT(_DMA_DMPREC_FREE,free) |\
    _FIELD_SHIFT(_DMA_DMPREC_DPRC,chpri)|\
    _FIELD_SHIFT(_DMA_DMPREC_INTOSEL,intosel)|\
    _FIELD_SHIFT(_DMA_DMPREC_DE,chenable)\
  )\
)  
#endif

#define _DMA_DMPREC_FGET(Field)\
  _FIELD_GET(_DMA_DMPREC_ADDR, _DMA_DMPREC_##Field)

#define _DMA_DMPREC_FSET(Field,Val)\
  _FIELD_SET(_DMA_DMPREC_ADDR, _DMA_DMPREC_##Field, Val)

#define _DMA_DMPREC_FSETS(Field,Sym)\
  _FIELD_SET(_DMA_DMPREC_ADDR, _DMA_DMPREC_##Field, DMA_DMPREC_##Field##_##Sym)


#define _DMA_DMPREC_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_DMA_DMPREC_ADDR, _DMA_DMPREC_##Field, AND, OR, INV)

/*----------------------------------------------------------------------------*\
* DMA DMPREC Free 
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_FREE_SHIFT       (0x000fu)
#define _DMA_DMPREC_FREE_MK(n)       (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_FREE_SHIFT)
#define _DMA_DMPREC_FREE_MASK        (_DMA_DMPREC_FREE_MK(1))
#define _DMA_DMPREC_FREE_CLR         (~(_DMA_DMPREC_FREE_MASK))

#if (_DMA_CH_RLDR_SUPPORT)
/*----------------------------------------------------------------------------*\
* DMA DMPREC Autoix 
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_AUTOIX_SHIFT       (0x000eu)
#define _DMA_DMPREC_AUTOIX_MK(n)       (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_AUTOIX_SHIFT)
#define _DMA_DMPREC_AUTOIX_MASK        (_DMA_DMPREC_AUTOIX_MK(1))
#define _DMA_DMPREC_AUTOIX_CLR         (~(_DMA_DMPREC_AUTOIX_MASK))
#endif

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DPRC: Channel Priority
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DPRC_SHIFT       (0x0008u)
#define _DMA_DMPREC_DPRC_MK(n)       (((Uint16)(n) & 0x0003fu) << _DMA_DMPREC_DPRC_SHIFT)
#define _DMA_DMPREC_DPRC_MASK  	 (_DMA_DMPREC_DPRC_MK(0x003fu))
#define _DMA_DMPREC_DPRC_CLR  	 (~(_DMA_DMPREC_DPRC_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DPRC0: Channel #0 Priority
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DPRC0_SHIFT      (0x0008u)
#define _DMA_DMPREC_DPRC0_MK(n)	 (((Uint16)(n) & 0x00001) << _DMA_DMPREC_DPRC0_SHIFT)
#define _DMA_DMPREC_DPRC0_MASK  	 (_DMA_DMPREC_DPRC0_MK(1))
#define _DMA_DMPREC_DPRC0_CLR  	 (~(_DMA_DMPREC_DPRC0_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DPRC1: Channel #1 Priority
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DPRC1_SHIFT      (0x0009u)
#define _DMA_DMPREC_DPRC1_MK(n)      (((Uint16)(n) & 0x00001) << _DMA_DMPREC_DPRC1_SHIFT)
#define _DMA_DMPREC_DPRC1_MASK       (_DMA_DMPREC_DPRC1_MK(1))
#define _DMA_DMPREC_DPRC1_CLR        (~(_DMA_DMPREC_DPRC1_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DPRC2: Channel #2 Priority
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DPRC2_SHIFT       (0x000au)
#define _DMA_DMPREC_DPRC2_MK(n)       (((Uint16)(n) & 0x00001) << _DMA_DMPREC_DPRC2_SHIFT)
#define _DMA_DMPREC_DPRC2_MASK        (_DMA_DMPREC_DPRC2_MK(1))
#define _DMA_DMPREC_DPRC2_CLR 	  (~(_DMA_DMPREC_DPRC2_MASK))


/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DPCR3: Channel #3 Priority
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DPRC3_SHIFT       (0x000bu)
#define _DMA_DMPREC_DPRC3_MK(n)       (((Uint16)(n) & 0x00001) << _DMA_DMPREC_DPRC3_SHIFT)
#define _DMA_DMPREC_DPRC3_MASK  	  (_DMA_DMPREC_DPRC3_MK(1))
#define _DMA_DMPREC_DPRC3_CLR   	  (~(_DMA_DMPREC_DPRC3_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DPRC4: Channel #4 Priority
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DPRC4_SHIFT       (0x000cu)
#define _DMA_DMPREC_DPRC4_MK(n)       (((Uint16)(n) & 0x00001) << _DMA_DMPREC_DPRC4_SHIFT)
#define _DMA_DMPREC_DPRC4_MASK  	  (_DMA_DMPREC_DPRC4_MK(1))
#define _DMA_DMPREC_DPRC4_CLR 	  (~(_DMA_DMPREC_DPRC4_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DPRC5: Channel #5 Priority
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DPRC5_SHIFT          (0x000du)
#define _DMA_DMPREC_DPRC5_MK(n)          (((Uint16)(n) & 0x00001) << _DMA_DMPREC_DPRC5_SHIFT)
#define _DMA_DMPREC_DPRC5_MASK  	     (_DMA_DMPREC_DPRC5_MK(1))
#define _DMA_DMPREC_DPRC5_CLR 	     (~(_DMA_DMPREC_DPRC5_MASK))

/*-------------------------------------------------------------------*\
* The following macros set/get individual channel priority bits
\*-------------------------------------------------------------------*/ 
#define _DMA_DMPREC_DPRCCH_SHIFT          (0x0008u)
#define _DMA_DMPREC_DPRCCH_MK(ch,n)       ((((Uint16)(n) & 0x0001u)<< (ch & 0xf)) << _DMA_DMPREC_DPRCCH_SHIFT)
#define _DMA_DMPREC_DPRCCH_MASK(ch)       (_DMA_DMPREC_DPRCCH_MK(ch,1))
#define _DMA_DMPREC_DPRCCH_CLR(ch)        (~(_DMA_DMPREC_DPRCCH_MASK(ch)))

#define _DMA_DMPREC_DPRCCH_GET(Chan)\
  ((Uint16)( \
  (REG16(_DMA_DMPREC_ADDR)&_DMA_DMPREC_DPRCCH_MASK(Chan))>>(_DMA_DMPREC_DPRCCH_SHIFT + Chan) \
   )\
)

#define _DMA_DMPREC_DPRCCH_SET(Chan, Val)\
   REG16(_DMA_DMPREC_ADDR)=(Uint16)(\
  (REG16(_DMA_DMPREC_ADDR)& _DMA_DMPREC_DPRCCH_CLR(Chan))|\
  ((Uint16)_DMA_DMPREC_DPRCCH_MK(Chan,Val))\
  )

/*----------------------------------------------------------------------------*\
* DMA DMPREC Interrupt Select
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_INTOSEL_SHIFT     (0x0006u)
#define _DMA_DMPREC_INTOSEL_MK(n)	 (((Uint16)(n) & 0x0003u) << _DMA_DMPREC_INTOSEL_SHIFT)
#define _DMA_DMPREC_INTOSEL_MASK	 (_DMA_DMPREC_INTOSEL_MK(3))
#define _DMA_DMPREC_INTOSEL_CLR	 (~(_DMA_DMPREC_INTOSEL_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DE: Channel Enable/Disable (sets entire field)
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DE_SHIFT           (0x0000u)
#define _DMA_DMPREC_DE_MK(n)           (((Uint16)(n) & 0x003Fu) << _DMA_DMPREC_DE_SHIFT)
#define _DMA_DMPREC_DE_MASK            (_DMA_DMPREC_DE_MK(0x3F))
#define _DMA_DMPREC_DE_CLR             (~(_DMA_DMPREC_DE_MASK))

/*-------------------------------------------------------------------*\
* The following macros set/get individual channel enable/disable bits
\*-------------------------------------------------------------------*/ 
#define _DMA_DMPREC_DECH_SHIFT         (0x0000u)
#define _DMA_DMPREC_DECH_MK(ch,n)      ((((Uint16)(n) & 0x0001u)<< ch) << _DMA_DMPREC_DECH_SHIFT)
#define _DMA_DMPREC_DECH_MASK(ch)      (_DMA_DMPREC_DECH_MK(ch,1))
#define _DMA_DMPREC_DECH_CLR(ch)       (~(_DMA_DMPREC_DECH_MASK(ch)))

#define _DMA_DMPREC_DECH_GET(Chan)\
  (Uint16)( \
  (REG16(_DMA_DMPREC_ADDR)&_DMA_DMPREC_DECH_MASK(Chan))>>_DMA_DMPREC_DECH_SHIFT \
   ) 

#define _DMA_DMPREC_DECH_SET(Chan, Val)\
  REG16(_DMA_DMPREC_ADDR)=(Uint16)( \
  (REG16(_DMA_DMPREC_ADDR)& _DMA_DMPREC_DECH_CLR(Chan))|\
  ((Uint16)_DMA_DMPREC_DECH_MK(Chan,Val))\
  )

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DE0: Channel #0 Enable/Disable
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DE0_SHIFT          (0x0000u)
#define _DMA_DMPREC_DE0_MK(n)          (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_DE0_SHIFT)
#define _DMA_DMPREC_DE0_MASK           (_DMA_DMPREC_DE0_MK(1))
#define _DMA_DMPREC_DE0_CLR            (~(_DMA_DMPREC_DE0_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DE1: Channel #1 Enable/Disable
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DE1_SHIFT          (0x0001u)
#define _DMA_DMPREC_DE1_MK(n)          (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_DE1_SHIFT)
#define _DMA_DMPREC_DE1_MASK           (_DMA_DMPREC_DE1_MK(1))
#define _DMA_DMPREC_DE1_CLR            (~(_DMA_DMPREC_DE1_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DE2: Channel #2 Enable/DisableChannel
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DE2_SHIFT           (0x0002u)
#define _DMA_DMPREC_DE2_MK(n)           (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_DE2_SHIFT)
#define _DMA_DMPREC_DE2_MASK            (_DMA_DMPREC_DE2_MK(1))
#define _DMA_DMPREC_DE2_CLR             (~(_DMA_DMPREC_DE2_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DE3: Channel #3 Enable/Disable
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DE3_SHIFT           (0x0003u)
#define _DMA_DMPREC_DE3_MK(n)           (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_DE3_SHIFT)
#define _DMA_DMPREC_DE3_MASK            (_DMA_DMPREC_DE3_MK(1))
#define _DMA_DMPREC_DE3_CLR             (~(_DMA_DMPREC_DE3_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DE4: Channel #4 Enable/Disable
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DE4_SHIFT           (0x0004u)
#define _DMA_DMPREC_DE4_MK(n)           (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_DE4_SHIFT)
#define _DMA_DMPREC_DE4_MASK            (_DMA_DMPREC_DE4_MK(1))
#define _DMA_DMPREC_DE4_CLR             (~(_DMA_DMPREC_DE4_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMPREC_DE5: Channel #5 Enable/Disable
\*----------------------------------------------------------------------------*/
#define _DMA_DMPREC_DE5_SHIFT           (0x0005u)
#define _DMA_DMPREC_DE5_MK(n)           (((Uint16)(n) & 0x0001u) << _DMA_DMPREC_DE5_SHIFT)
#define _DMA_DMPREC_DE5_MASK            (_DMA_DMPREC_DE5_MK(1))
#define _DMA_DMPREC_DE5_CLR             (~(_DMA_DMPREC_DE5_MASK))

/*********************************************************************\
* DMA Sync Event and Frame Count (DMSFC) SubBank Register Bit Fields
*
* Fields:
*
*  _DMA_DMSFC_DSYN
*  _DMA_DMSFC_DBLW
*  _DMA_DMSFC_FRAMECOUNT
\*********************************************************************/

/*----------------------------------------------------------------------------*\
* _DMA_DMSFC_DSYN: Event synchronization
\*----------------------------------------------------------------------------*/
#define _DMA_DMSFC_DSYN_SHIFT        (0x000cu)
#define _DMA_DMSFC_DSYN_MK(n)        (((Uint16)(n) & 0x000fu)<< _DMA_DMSFC_DSYN_SHIFT)
#define _DMA_DMSFC_DSYN_MASK         (_DMA_DMSFC_DSYN_MK(0x000Fu))
#define _DMA_DMSFC_DSYN_CLR          (~(_DMA_DMSFC_DSYN_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMSFC_DBLW: Enable/disable 32 bit transfers (double word)
\*----------------------------------------------------------------------------*/
#define _DMA_DMSFC_DBLW_SHIFT       (0x000bu)
#define _DMA_DMSFC_DBLW_MK(n)       (((Uint16)(n) & 0x0001u)<< _DMA_DMSFC_DBLW_SHIFT)
#define _DMA_DMSFC_DBLW_MASK        (_DMA_DMSFC_DBLW_MK(1))
#define _DMA_DMSFC_DBLW_CLR         (~(_DMA_DMSFC_DBLW_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMSFC_FRAMECNT: Frame count
\*----------------------------------------------------------------------------*/
#define _DMA_DMSFC_FRAMECNT_SHIFT     (0x0000u)
#define _DMA_DMSFC_FRAMECNT_MK(n)     (((Uint16)(n) & 0x00ffu)<< _DMA_DMSFC_FRAMECNT_SHIFT)
#define _DMA_DMSFC_FRAMECNT_MASK      (_DMA_DMSFC_FRAMECNT_MK(0x00FFu))
#define _DMA_DMSFC_FRAMECNT_CLR       (~(_DMA_DMSFC_FRAMECNT_MASK))


/*----------------------------------------------------------------------------*\
* _DMA_DMSFC: Register macros
\*----------------------------------------------------------------------------*/

#define _DMA_DMSFC_GET(Chan)\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSFC(Chan))

#define _DMA_DMSFC_SET(Chan, Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSFC(Chan), Val)

#define _DMA_DMSFC_AOI(Chan, AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSFC(Chan), AND, OR, INV)

#define _DMA_DMSFC_FGET(Chan,Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSFC(Chan), _DMA_DMSFC_##Field)

#define _DMA_DMSFC_FSET(Chan, Field, Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSFC(Chan), _DMA_DMSFC_##Field, Val)

#define _DMA_DMSFC_FAOI(Chan, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSFC(Chan),  _DMA_DMSFC_##Field, AND, OR, INV)

#define _DMA_DMSFC_CFG(Chan, dsyn, dblw, framecount)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSFC(Chan),\
              (_DMA_DMSFC_DSYN_MK(dsyn)    |\
               _DMA_DMSFC_DBLW_MK(dblw)    |\
               _DMA_DMSFC_FRAMECOUNT(framecount))\
             )


#define _DMA_DMSFC0_GET()                               _DMA_DMSFC_GET(0)
#define _DMA_DMSFC0_SET(Val)                            _DMA_DMSFC_SET(0,Val)
#define _DMA_DMSFC0_AOI(AND,OR,INV)                     _DMA_DMSFC_AOX(0,AND,OR,INV)
#define _DMA_DMSFC0_FGET(Field)                         _DMA_DMSFC_FGET(0,##Field)
#define _DMA_DMSFC0_FSET(Field,Val)                     _DMA_DMSFC_FSET(0,##Field,Val)
#define _DMA_DMSFC0_FSETS(Field,Sym)                    _DMA_DMSFC_FSET(0,DMA_DMSFC_##Field##_##Sym)
#define _DMA_DMSFC0_FAOI(Field,AND,OR,INV)              _DMA_DMSFC_FAOI(0,##Field,AND,OR,INV)
#define _DMA_DMSFC0_CFG(dsyn, dblw, framecount)         _DMA_DMSFC_CFG(0,dsyn,dblw,framecount)

#define _DMA_DMSFC1_GET()                               _DMA_DMSFC_GET(1)
#define _DMA_DMSFC1_SET(Val)                            _DMA_DMSFC_SET(1,Val)
#define _DMA_DMSFC1_AOI(AND,OR,INV)                     _DMA_DMSFC_AOI(1,AND,OR,INV)
#define _DMA_DMSFC1_FGET(Field)                         _DMA_DMSFC_FGET(1,##Field)
#define _DMA_DMSFC1_FSET(Field,Val)                     _DMA_DMSFC_FSET(1,##Field,Val)
#define _DMA_DMSFC1_FSETS(Field,Sym)                    _DMA_DMSFC_FSET(1,DMA_DMSFC_##Field##_##Sym)
#define _DMA_DMSFC1_FAOI(Field,AND,OR,INV)              _DMA_DMSFC_FAOI(1,##Field,AND,OR,INV)
#define _DMA_DMSFC1_CFG(dsyn, dblw, framecount)         _DMA_DMSFC_CFG(1,dsyn,dblw,framecount)

#define _DMA_DMSFC2_GET()                               _DMA_DMSFC_GET(2)
#define _DMA_DMSFC2_SET(Val)                            _DMA_DMSFC_SET(2,Val)
#define _DMA_DMSFC2_AOI(AND,OR,INV)                     _DMA_DMSFC_AOI(2,AND,OR,INV)
#define _DMA_DMSFC2_FGET(Field)                         _DMA_DMSFC_FGET(2,##Field)
#define _DMA_DMSFC2_FSET(Field,Val)                     _DMA_DMSFC_FSET(2,##Field,Val)
#define _DMA_DMSFC2_FSETS(Field,Sym)                    _DMA_DMSFC_FSET(2,DMA_DMSFC_##Field##_##Sym)
#define _DMA_DMSFC2_FAOI(Field,AND,OR,INV)              _DMA_DMSFC_FAOI(2,##Field,AND,OR,INV)
#define _DMA_DMSFC2_CFG(dsyn, dblw, framecount)         _DMA_DMSFC_CFG(2,dsyn,dblw,framecount)

#define _DMA_DMSFC3_GET()                               _DMA_DMSFC_GET(3)
#define _DMA_DMSFC3_SET(Val)                            _DMA_DMSFC_SET(3,Val)
#define _DMA_DMSFC3_AOI(AND,OR,INV)                     _DMA_DMSFC_AOI(3,AND,OR,INV)
#define _DMA_DMSFC3_FGET(Field)                         _DMA_DMSFC_FGET(3,##Field)
#define _DMA_DMSFC3_FSET(Field,Val)                     _DMA_DMSFC_FSET(3,##Field,Val)
#define _DMA_DMSFC3_FSETS(Field,Sym)                    _DMA_DMSFC_FSET(3,DMA_DMSFC_##Field##_##Sym)
#define _DMA_DMSFC3_FAOI(Field,AND,OR,INV)              _DMA_DMSFC_FAOI(3,##Field,AND,OR,INV)
#define _DMA_DMSFC3_CFG(dsyn, dblw, framecount)         _DMA_DMSFC_CFG(3,dsyn,dblw,framecount)

#define _DMA_DMSFC4_GET()                               _DMA_DMSFC_GET(4)
#define _DMA_DMSFC4_SET(Val)                            _DMA_DMSFC_SET(4,Val)
#define _DMA_DMSFC4_AOI(AND,OR,INV)                     _DMA_DMSFC_AOI(4,AND,OR,INV)
#define _DMA_DMSFC4_FGET(Field)                         _DMA_DMSFC_FGET(4,##Field)
#define _DMA_DMSFC4_FSET(Field,Val)                     _DMA_DMSFC_FSET(4,##Field,Val)
#define _DMA_DMSFC4_FSETS(Field,Sym)                    _DMA_DMSFC_FSET(4,DMA_DMSFC_##Field##_##Sym)
#define _DMA_DMSFC4_FAOI(Field,AND,OR,INV)              _DMA_DMSFC_FAOI(4,##Field,AND,OR,INV)
#define _DMA_DMSFC4_CFG(dsyn, dblw, framecount)         _DMA_DMSFC_CFG(4,dsyn,dblw,framecount)

#define _DMA_DMSFC5_GET()                               _DMA_DMSFC_GET(5)
#define _DMA_DMSFC5_SET(Val)                            _DMA_DMSFC_SET(5,Val)
#define _DMA_DMSFC5_AOI(AND,OR,INV)                     _DMA_DMSFC_AOI(5,AND,OR,INV)
#define _DMA_DMSFC5_FGET(Field)                         _DMA_DMSFC_FGET(5,##Field)
#define _DMA_DMSFC5_FSET(Field,Val)                     _DMA_DMSFC_FSET(5,##Field,Val)
#define _DMA_DMSFC5_FSETS(Field,Sym)                    _DMA_DMSFC_FSET(5,DMA_DMSFC_##Field##_##Sym)
#define _DMA_DMSFC5_FAOI(Field,AND,OR,INV)              _DMA_DMSFC_FAOI(5,##Field,AND,OR,INV)
#define _DMA_DMSFC5_CFG(dsyn, dblw, framecount)         _DMA_DMSFC_CFG(5,dsyn,dblw,framecount)



/*******************************************************************************\
* DMA Transfer Mode Control (DMMCR) SubBank Register Bit Fields
* 
* Fields:
*  _DMA_DMMCR_AUOTINIT
*  _DMA_DMMCR_DINM
*  _DMA_DMCCR_IMOD
*  _DMA_DMCCR_CTMOD
*  _DMA_DMMCR_SIND
*  _DMA_DMCCR_DMS
*  _DMA_DMMCR_DIND
*  _DMA_DMCCR_DMD
\******************************************************************************/

/*----------------------------------------------------------------------------*\
* Register Macros
\*----------------------------------------------------------------------------*/

#define _DMA_DMMCR_GET(Chan)\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan))

#define _DMA_DMMCR_SET(Chan, Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan), Val)

#define _DMA_DMMCR_AOI(Chan, AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan), AND, OR, INV)

#define _DMA_DMMCR_FGET(Chan,Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan), _DMA_DMMCR_##Field)

#define _DMA_DMMCR_FSET(Chan, Field, Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan), _DMA_DMMCR_##Field, Val)

#define _DMA_DMMCR_FAOI(Chan, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan), _DMA_DMMCR_##Field, AND, OR, INV)

#if (_DMA_EXT_DATA_SUPPORT)
#define _DMA_DMMCR_CFG(Chan,\
        autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan),\
              (_DMA_DMMCR_DMD_MK(dmd)     |\
               _DMA_DMMCR_DIND_MK(dind)   |\
               _DMA_DMMCR_DLAXS_MK(dlaxs) |\
               _DMA_DMMCR_DMS_MK(dms)     |\
               _DMA_DMMCR_SIND_MK(sind)   |\
               _DMA_DMMCR_SLAXS_MK(slaxs) |\
               _DMA_DMMCR_CTMOD_MK(ctmod) |\
               _DMA_DMMCR_IMOD_MK(imod)   |\
               _DMA_DMMCR_DINM_MK(dinm)   |\
               _DMA_DMMCR_AUTOINIT_MK(autoinit))\
             )
#else
#define _DMA_DMMCR_CFG(Chan,\
        autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMMCR(Chan),\
              (_DMA_DMMCR_DMD_MK(dmd)     |\
               _DMA_DMMCR_DIND_MK(dind)   |\
               _DMA_DMMCR_DMS_MK(dms)     |\
               _DMA_DMMCR_SIND_MK(sind)   |\
               _DMA_DMMCR_CTMOD_MK(ctmod) |\
               _DMA_DMMCR_IMOD_MK(imod)   |\
               _DMA_DMMCR_DINM_MK(dinm)   |\
               _DMA_DMMCR_AUTOINIT_MK(autoinit))\
             )
#endif

#define _DMA_DMMCR0_GET()                       _DMA_DMMCR_GET(0)
#define _DMA_DMMCR0_SET(Val)                    _DMA_DMMCR_SET(0,Val)
#define _DMA_DMMCR0_AOI(AND,OR,INV)             _DMA_DMMCR_AOX(0,AND,OR,INV)
#define _DMA_DMMCR0_FGET(Field)                 _DMA_DMMCR_FGET(0,##Field)
#define _DMA_DMMCR0_FSET(Field,Val)             _DMA_DMMCR_FSET(0,##Field,Val)
#define _DMA_DMMCR0_FSETS(Field,Sym)            _DMA_DMMCR_FSET(0,DMA_DMMCR_##Field##_##Sym)

#define _DMA_DMMCR0_FAOI(Field,AND,OR,INV)      _DMA_DMMCR_FAOI(0,##Field,AND,OR,INV)

#if (_DMA_EXT_DATA_SUPPORT)
  #define _DMA_DMMCR0_CFG(autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)\
    _DMA_DMMCR_CFG(0, autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)
#else
  #define _DMA_DMMCR0_CFG(autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)\
    _DMA_DMMCR_CFG(0, autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)
#endif

#define _DMA_DMMCR1_GET()                       _DMA_DMMCR_GET(1)
#define _DMA_DMMCR1_SET(Val)                    _DMA_DMMCR_SET(1,Val)
#define _DMA_DMMCR1_AOI(AND,OR,INV)             _DMA_DMMCR_AOI(1,AND,OR,INV)
#define _DMA_DMMCR1_FGET(Field)                 _DMA_DMMCR_FGET(1,##Field)
#define _DMA_DMMCR1_FSET(Field,Val)             _DMA_DMMCR_FSET(1,##Field,Val)
#define _DMA_DMMCR1_FSETS(Field,Sym)            _DMA_DMMCR_FSET(1,DMA_DMMCR_##Field##_##Sym)
#define _DMA_DMMCR1_FAOI(Field,AND,OR,INV)      _DMA_DMMCR_FAOI(1,##Field,AND,OR,INV)

#if (_DMA_EXT_DATA_SUPPORT)
  #define _DMA_DMMCR1_CFG(autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)\
    _DMA_DMMCR_CFG(1, autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)
#else
  #define _DMA_DMMCR1_CFG(autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)\
    _DMA_DMMCR_CFG(1, autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)
#endif

#define _DMA_DMMCR2_GET()                       _DMA_DMMCR_GET(2)
#define _DMA_DMMCR2_SET(Val)                    _DMA_DMMCR_SET(2,Val)
#define _DMA_DMMCR2_AOI(AND,OR,INV)             _DMA_DMMCR_AOI(2,AND,OR,INV)
#define _DMA_DMMCR2_FGET(Field)                 _DMA_DMMCR_FGET(2,##Field)
#define _DMA_DMMCR2_FSET(Field,Val)             _DMA_DMMCR_FSET(2,##Field,Val)
#define _DMA_DMMCR2_FSETS(Field,Sym)            _DMA_DMMCR_FSET(2,DMA_DMMCR_##Field##_##Sym)
#define _DMA_DMMCR2_FAOI(Field,AND,OR,INV)      _DMA_DMMCR_FAOI(2,##Field,AND,OR,INV)

#if (_DMA_EXT_DATA_SUPPORT)
  #define _DMA_DMMCR2_CFG(autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)\
    _DMA_DMMCR_CFG(2, autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)
#else
  #define _DMA_DMMCR2_CFG(autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)\
    _DMA_DMMCR_CFG(2, autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)
#endif

#define _DMA_DMMCR3_GET()                       _DMA_DMMCR_GET(3)
#define _DMA_DMMCR3_SET(Val)                    _DMA_DMMCR_SET(3,Val)
#define _DMA_DMMCR3_AOI(AND,OR,INV)             _DMA_DMMCR_AOI(3,AND,OR,INV)
#define _DMA_DMMCR3_FGET(Field)                 _DMA_DMMCR_FGET(3,##Field)
#define _DMA_DMMCR3_FSET(Field,Val)             _DMA_DMMCR_FSET(3,##Field,Val)
#define _DMA_DMMCR3_FSETS(Field,Sym)            _DMA_DMMCR_FSET(3,DMA_DMMCR_##Field##_##Sym)
#define _DMA_DMMCR3_FAOI(Field,AND,OR,INV)      _DMA_DMMCR_FAOI(3,##Field,AND,OR,INV)

#if (_DMA_EXT_DATA_SUPPORT)
  #define _DMA_DMMCR3_CFG(autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)\
    _DMA_DMMCR_CFG(3, autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)
#else
  #define _DMA_DMMCR3_CFG(autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)\
    _DMA_DMMCR_CFG(3, autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)
#endif

#define _DMA_DMMCR4_GET()                       _DMA_DMMCR_GET(4)
#define _DMA_DMMCR4_SET(Val)                    _DMA_DMMCR_SET(4,Val)
#define _DMA_DMMCR4_AOI(AND,OR,INV)             _DMA_DMMCR_AOI(4,AND,OR,INV)
#define _DMA_DMMCR4_FGET(Field)                 _DMA_DMMCR_FGET(4,##Field)
#define _DMA_DMMCR4_FSETS(Field,Sym)            _DMA_DMMCR_FSET(4,DMA_DMMCR_##Field##_##Sym)
#define _DMA_DMMCR4_FSET(Field,Val)             _DMA_DMMCR_FSET(4,##Field,Val)
#define _DMA_DMMCR4_FAOI(Field,AND,OR,INV)      _DMA_DMMCR_FAOI(4,##Field,AND,OR,INV)

#if (_DMA_EXT_DATA_SUPPORT)
  #define _DMA_DMMCR4_CFG(autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)\
    _DMA_DMMCR_CFG(4, autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)
#else
  #define _DMA_DMMCR4_CFG(autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)\
    _DMA_DMMCR_CFG(4, autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)
#endif

#define _DMA_DMMCR5_GET()                       _DMA_DMMCR_GET(5)
#define _DMA_DMMCR5_SET(Val)                    _DMA_DMMCR_SET(5,Val)
#define _DMA_DMMCR5_AOI(AND,OR,INV)             _DMA_DMMCR_AOI(5,AND,OR,INV)
#define _DMA_DMMCR5_FGET(Field)                 _DMA_DMMCR_FGET(5,##Field)
#define _DMA_DMMCR5_FSET(Field,Val)             _DMA_DMMCR_FSET(5,##Field,Val)
#define _DMA_DMMCR5_FSETS(Field,Sym)            _DMA_DMMCR_FSET(5,DMA_DMMCR_##Field##_##Sym)
#define _DMA_DMMCR5_FAOI(Field,AND,OR,INV)      _DMA_DMMCR_FAOI(5,##Field,AND,OR,INV)

#if (_DMA_EXT_DATA_SUPPORT)
  #define _DMA_DMMCR5_CFG(autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)\
    _DMA_DMMCR_CFG(5, autoinit, dinm, imod, ctmod, slaxs, sind, dms, dlaxs, dind, dmd)
#else
  #define _DMA_DMMCR5_CFG(autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)\
    _DMA_DMMCR_CFG(5, autoinit, dinm, imod, ctmod, sind, dms, dind, dmd)
#endif


/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_AUTOINIT: Autoinitialization enable/disable
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_AUTOINIT_SHIFT     (0x000fu)
#define _DMA_DMMCR_AUTOINIT_MK(n)   (((Uint16)(n) & 0x0001u)<< _DMA_DMMCR_AUTOINIT_SHIFT)
#define _DMA_DMMCR_AUTOINIT_MASK       (_DMA_DMMCR_AUTOINIT_MK(1))
#define _DMA_DMMCR_AUTOINIT_CLR       (~(_DMA_DMMCR_AUTOINIT_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_DINM: Enable/disable DMA interrupt
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_DINM_SHIFT         (0x000eu)
#define _DMA_DMMCR_DINM_MK(n)         (((Uint16)(n) & 0x0001u)<< _DMA_DMMCR_DINM_SHIFT)
#define _DMA_DMMCR_DINM_MASK          (_DMA_DMMCR_DINM_MK(1))
#define _DMA_DMMCR_DINM_CLR           (~(_DMA_DMMCR_DINM_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_IMOD: Interrupt mode bit 
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_IMOD_SHIFT         (0x000du)
#define _DMA_DMMCR_IMOD_MK(n)         (((Uint16)(n) & 0x0001u)<< _DMA_DMMCR_IMOD_SHIFT)
#define _DMA_DMMCR_IMOD_MASK          (_DMA_DMMCR_IMOD_MK(1))
#define _DMA_DMMCR_IMOD_CLR           (~(_DMA_DMMCR_IMOD_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_CTMOD: DMA Transfer Counter mode (ABU or Multi-frame) 
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_CTMOD_SHIFT          (0x000cu)
#define _DMA_DMMCR_CTMOD_MK(n)          (((Uint16)(n) & 0x0001u)<< _DMA_DMMCR_CTMOD_SHIFT)
#define _DMA_DMMCR_CTMOD_MASK           (_DMA_DMMCR_CTMOD_MK(1))
#define _DMA_DMMCR_CTMOD_CLR            (~(_DMA_DMMCR_CTMOD_MASK))

#if (_DMA_EXT_DATA_SUPPORT)
/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_SLAXS: Extended Program Source Enable/Disable 
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_SLAXS_SHIFT         (0x000bu)
#define _DMA_DMMCR_SLAXS_MK(n)         (((Uint16)(n) & 0x0001u)<< _DMA_DMMCR_SLAXS_SHIFT)
#define _DMA_DMMCR_SLAXS_MASK          (_DMA_DMMCR_SLAXS_MK(1))
#define _DMA_DMMCR_SLAXS_CLR           (~(_DMA_DMMCR_SLAXS_MASK))

#endif   /* _DMA_EXT_DATA_SUPPORT */

/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_SIND: DMA Souce address index mode
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_SIND_SHIFT         (0x0008u)
#define _DMA_DMMCR_SIND_MK(n)         (((Uint16)(n) & 0x0007u)<< _DMA_DMMCR_SIND_SHIFT)
#define _DMA_DMMCR_SIND_MASK          (_DMA_DMMCR_SIND_MK(7))
#define _DMA_DMMCR_SIND_CLR           (~(_DMA_DMMCR_SIND_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_DMS: DMA Souce address space select (I/O, Data, Program)
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_DMS_SHIFT          (0x0006u)
#define _DMA_DMMCR_DMS_MK(n)          (((Uint16)(n) & 0x0003u)<< _DMA_DMMCR_DMS_SHIFT)
#define _DMA_DMMCR_DMS_MASK           (_DMA_DMMCR_DMS_MK(3))
#define _DMA_DMMCR_DMS_CLR            (~(_DMA_DMMCR_DMS_MASK))

#if (_DMA_EXT_DATA_SUPPORT)
/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_DLAXS: Extended Data Source Enable/Disable 
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_DLAXS_SHIFT          (0x0005u)
#define _DMA_DMMCR_DLAXS_MK(n)          (((Uint16)(n) & 0x0001u)<< _DMA_DMMCR_DLAXS_SHIFT)
#define _DMA_DMMCR_DLAXS_MASK           (_DMA_DMMCR_DLAXS_MK(1))
#define _DMA_DMMCR_DLAXS_CLR            (~(_DMA_DMMCR_DLAXS_MASK))

#endif   /* _DMA_EXT_DATA_SUPPORT */

/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_DIND: DMA Destination address index mode
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_DIND_SHIFT          (0x0002u)
#define _DMA_DMMCR_DIND_MK(n)          (((Uint16)(n) & 0x0007u)<< _DMA_DMMCR_DIND_SHIFT)
#define _DMA_DMMCR_DIND_MASK           (_DMA_DMMCR_DIND_MK(7))
#define _DMA_DMMCR_DIND_CLR            (~(_DMA_DMMCR_DIND_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMMCR_DMD: DMA Destination address space select (I/O, Data, Program)
\*----------------------------------------------------------------------------*/
#define _DMA_DMMCR_DMD_SHIFT           (0x0000u)
#define _DMA_DMMCR_DMD_MK(n)           (((Uint16)(n) & 0x0003u)<< _DMA_DMMCR_DMD_SHIFT)
#define _DMA_DMMCR_DMD_MASK            (_DMA_DMMCR_DMD_MK(3))
#define _DMA_DMMCR_DMD_CLR             (~(_DMA_DMMCR_DMD_MASK))

/*******************************************************************************\
* _DMA_DMSRC Source Address Register
* 
* Fields:
*  _DMA_DMSRC_SRC
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMSRC_SRC: DMA transfer source address
\*----------------------------------------------------------------------------*/
#define _DMA_DMSRC_SRC_SHIFT          (0x0000u)
#define _DMA_DMSRC_SRC_MK(n)          (((Uint16)(n) & 0xffffu)<< _DMA_DMSRC_SRC_SHIFT)
#define _DMA_DMSRC_SRC_MASK           (_DMA_DMSRC_SRC_MK(0xffffu))
#define _DMA_DMSRC_SRC_CLR            (~(_DMA_DMSRC_SRC_MASK))

/*----------------------------------------------------------------------------*\
*  Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMSRC_GET(Chan)\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRC(Chan))

#define _DMA_DMSRC_SET(Chan, Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRC(Chan), Val)

#define _DMA_DMSRC_AOI(Chan, AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRC(Chan), AND, OR, INV)

#define _DMA_DMSRC_FGET(Chan, Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRC(Chan), _DMA_DMSRC_##Field)

#define _DMA_DMSRC_FSET(Chan, Field, Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRC(Chan), _DMA_DMSRC_##Field, Val)

#define _DMA_DMSRC_FAOI(Chan, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRC(Chan), _DMA_DMSRC_##Field, AND, OR, INV)

#define _DMA_DMSRC_CFG(n,Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRC(n), Val)

#define _DMA_DMSRC0_GET()                            _DMA_DMSRC_GET(0)
#define _DMA_DMSRC0_SET(Val)                         _DMA_DMSRC_SET(0,Val)
#define _DMA_DMSRC0_AOI(AND,OR,INV)                  _DMA_DMSRC_AOI(0,AND,OR,INV)
#define _DMA_DMSRC0_FGET(Field)                      _DMA_DMSRC_FGET(0,##Field)
#define _DMA_DMSRC0_FSET(Field,Val)                  _DMA_DMSRC_FSET(0,##Field,Val)
#define _DMA_DMSRC0_FSETS(Field,Sym)                 _DMA_DMSRC_FSET(0,DMA_DMSRC_##Field##_##Sym)
#define _DMA_DMSRC0_FAOI(Field,AND,OR,INV)           _DMA_DMSRC_FAOI(0,##Field,AND,OR,INV)
#define _DMA_DMSRC0_CFG(Val)                         _DMA_DMSRC_CFG(0,Val)

#define _DMA_DMSRC1_GET()                            _DMA_DMSRC_GET(1)
#define _DMA_DMSRC1_SET(Val)                         _DMA_DMSRC_SET(1,Val)
#define _DMA_DMSRC1_AOI(AND,OR,INV)                  _DMA_DMSRC_AOI(1,AND,OR,INV)
#define _DMA_DMSRC1_FGET(Field)                      _DMA_DMSRC_FGET(1,##Field)
#define _DMA_DMSRC1_FSET(Field,Val)                  _DMA_DMSRC_FSET(1,##Field,Val)
#define _DMA_DMSRC1_FSETS(Field,Val)                 _DMA_DMSRC_FSET(1,DMA_DMSRC_##Field##_##Sym)
#define _DMA_DMSRC1_FAOI(Field,AND,OR,INV)           _DMA_DMSRC_FAOI(1,##Field,AND,OR,INV)
#define _DMA_DMSRC1_CFG(Val)                         _DMA_DMSRC_CFG(1,Val)

#define _DMA_DMSRC2_GET()                            _DMA_DMSRC_GET(2)
#define _DMA_DMSRC2_SET(Val)                         _DMA_DMSRC_SET(2,Val)
#define _DMA_DMSRC2_AOI(AND,OR,INV)                  _DMA_DMSRC_AOI(2,AND,OR,INV)
#define _DMA_DMSRC2_FGET(Field)                      _DMA_DMSRC_FGET(2,##Field)
#define _DMA_DMSRC2_FSET(Field,Val)                  _DMA_DMSRC_FSET(2,##Field,Val)
#define _DMA_DMSRC2_FSETS(Field,Val)                 _DMA_DMSRC_FSET(2,DMA_DMSRC_##Field##_##Sym)
#define _DMA_DMSRC2_FAOI(Field,AND,OR,INV)           _DMA_DMSRC_FAOI(2,##Field,AND,OR,INV)
#define _DMA_DMSRC2_CFG(Val)                         _DMA_DMSRC_CFG(2,Val)

#define _DMA_DMSRC3_GET()                            _DMA_DMSRC_GET(3)
#define _DMA_DMSRC3_SET(Val)                         _DMA_DMSRC_SET(3,Val)
#define _DMA_DMSRC3_AOI(AND,OR,INV)                  _DMA_DMSRC_AOI(3,AND,OR,INV)
#define _DMA_DMSRC3_FGET(Field)                      _DMA_DMSRC_FGET(3,##Field)
#define _DMA_DMSRC3_FSET(Field,Val)                  _DMA_DMSRC_FSET(3,##Field,Val)
#define _DMA_DMSRC3_FSETS(Field,Val)                 _DMA_DMSRC_FSET(3,DMA_DMSRC_##Field##_##Sym)
#define _DMA_DMSRC3_FAOI(Field,AND,OR,INV)           _DMA_DMSRC_FAOI(3,##Field,AND,OR,INV)
#define _DMA_DMSRC3_CFG(Val)                         _DMA_DMSRC_CFG(3,Val)

#define _DMA_DMSRC4_GET()                            _DMA_DMSRC_GET(4)
#define _DMA_DMSRC4_SET(Val)                         _DMA_DMSRC_SET(4,Val)
#define _DMA_DMSRC4_AOI(AND,OR,INV)                  _DMA_DMSRC_AOI(4,AND,OR,INV)
#define _DMA_DMSRC4_FGET(Field)                      _DMA_DMSRC_FGET(4,##Field)
#define _DMA_DMSRC4_FSET(Field,Val)                  _DMA_DMSRC_FSET(4,##Field,Val)
#define _DMA_DMSRC4_FSETS(Field,Val)                 _DMA_DMSRC_FSET(4,DMA_DMSRC_##Field##_##Sym)
#define _DMA_DMSRC4_FAOI(Field,AND,OR,INV)           _DMA_DMSRC_FAOI(4,##Field,AND,OR,INV)
#define _DMA_DMSRC4_CFG(Val)                         _DMA_DMSRC_CFG(4,Val)

#define _DMA_DMSRC5_GET()                            _DMA_DMSRC_GET(5)
#define _DMA_DMSRC5_SET(Val)                         _DMA_DMSRC_SET(5,Val)
#define _DMA_DMSRC5_AOI(AND,OR,INV)                  _DMA_DMSRC_AOI(5,AND,OR,INV)
#define _DMA_DMSRC5_FGET(Field)                      _DMA_DMSRC_FGET(5,##Field)
#define _DMA_DMSRC5_FSETS(Field,Val)                 _DMA_DMSRC_FSET(5,DMA_DMSRC_##Field##_##Sym)
#define _DMA_DMSRC5_FSET(Field,Val)                  _DMA_DMSRC_FSET(5,##Field,Val)
#define _DMA_DMSRC5_FAOI(Field,AND,OR,INV)           _DMA_DMSRC_FAOI(5,##Field,AND,OR,INV)
#define _DMA_DMSRC5_CFG(Val)                         _DMA_DMSRC_CFG(5,Val)


/*******************************************************************************\
* _DMA_DMDST Destination Address Register
* 
* Fields:
*  _DMA_DMDST_DST
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMDST_GET(Chan)\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDST(Chan))

#define _DMA_DMDST_SET(Chan,Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDST(Chan), Val)

#define _DMA_DMDST_AOI(Chan, AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDST(Chan), AND, OR, INV)

#define _DMA_DMDST_FGET(Chan,Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDST(Chan),\
  _DMA_DMDST_##Field)

#define _DMA_DMDST_FSET(Chan, Field, Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDST(Chan),\
  _DMA_DMDST_##Field, Val)

#define _DMA_DMDST_FAOI(Chan, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDST(Chan),\
  _DMA_DMDST_##Field, AND, OR, INV)

#define _DMA_DMDST_CFG(Chan, Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDST(Chan), Val)

 
#define _DMA_DMDST0_GET()                            _DMA_DMDST_GET(0)
#define _DMA_DMDST0_SET(Val)                         _DMA_DMDST_SET(0,Val)
#define _DMA_DMDST0_AOI(AND,OR,INV)                  _DMA_DMDST_AOI(0,AND,OR,INV)
#define _DMA_DMDST0_FGET(Field)                      _DMA_DMDST_FGET(0,##Field)
#define _DMA_DMDST0_FSET(Field,Val)                  _DMA_DMDST_FSET(0,##Field,Val)
#define _DMA_DMDST0_FSETS(Field,Sym)                 _DMA_DMDST_FSET(0,DMA_DMDST_##Field##_##Sym)
#define _DMA_DMDST0_FAOI(Field,AND,OR,INV)           _DMA_DMDST_FAOI(0,##Field,AND,OR,INV)
#define _DMA_DMDST0_CFG(Val)                         _DMA_DMDST_CFG(0,Val)

#define _DMA_DMDST1_GET()                            _DMA_DMDST_GET(1)
#define _DMA_DMDST1_SET(Val)                         _DMA_DMDST_SET(1,Val)
#define _DMA_DMDST1_AOI(AND,OR,INV)                  _DMA_DMDST_AOI(1,AND,OR,INV)
#define _DMA_DMDST1_FGET(Field)                      _DMA_DMDST_FGET(1,##Field)
#define _DMA_DMDST1_FSET(Field,Val)                  _DMA_DMDST_FSET(1,##Field,Val)
#define _DMA_DMDST1_FSETS(Field,Sym)                 _DMA_DMDST_FSET(1,DMA_DMDST_##Field##_##Sym)
#define _DMA_DMDST1_FAOI(Field,AND,OR,INV)           _DMA_DMDST_FAOI(1,##Field,AND,OR,INV)
#define _DMA_DMDST1_CFG(Val)                         _DMA_DMDST_CFG(1,Val)

#define _DMA_DMDST2_GET()                            _DMA_DMDST_GET(2)
#define _DMA_DMDST2_SET(Val)                         _DMA_DMDST_SET(2,Val)
#define _DMA_DMDST2_AOI(AND,OR,INV)                  _DMA_DMDST_AOI(2,AND,OR,INV)
#define _DMA_DMDST2_FGET(Field)                      _DMA_DMDST_FGET(2,##Field)
#define _DMA_DMDST2_FSET(Field,Val)                  _DMA_DMDST_FSET(2,##Field,Val)
#define _DMA_DMDST2_FSETS(Field,Sym)                 _DMA_DMDST_FSET(2,DMA_DMDST_##Field##_##Sym)
#define _DMA_DMDST2_FAOI(Field,AND,OR,INV)           _DMA_DMDST_FAOI(2,##Field,AND,OR,INV)
#define _DMA_DMDST2_CFG(Val)                         _DMA_DMDST_CFG(2,Val)

#define _DMA_DMDST3_GET()                            _DMA_DMDST_GET(3)
#define _DMA_DMDST3_SET(Val)                         _DMA_DMDST_SET(3,Val)
#define _DMA_DMDST3_AOI(AND,OR,INV)                  _DMA_DMDST_AOI(3,AND,OR,INV)
#define _DMA_DMDST3_FGET(Field)                      _DMA_DMDST_FGET(3,##Field)
#define _DMA_DMDST3_FSET(Field,Val)                  _DMA_DMDST_FSET(3,##Field,Val)
#define _DMA_DMDST3_FSETS(Field,Sym)                 _DMA_DMDST_FSET(3,DMA_DMDST_##Field##_##Sym)
#define _DMA_DMDST3_FAOI(Field,AND,OR,INV)           _DMA_DMDST_FAOI(3,##Field,AND,OR,INV)
#define _DMA_DMDST3_CFG(Val)                         _DMA_DMDST_CFG(3,Val)

#define _DMA_DMDST4_GET()                            _DMA_DMDST_GET(4)
#define _DMA_DMDST4_SET(Val)                         _DMA_DMDST_SET(4,Val)
#define _DMA_DMDST4_AOI(AND,OR,INV)                  _DMA_DMDST_AOI(4,AND,OR,INV)
#define _DMA_DMDST4_FGET(Field)                      _DMA_DMDST_FGET(4,##Field)
#define _DMA_DMDST4_FSET(Field,Val)                  _DMA_DMDST_FSET(4,##Field,Val)
#define _DMA_DMDST4_FSETS(Field,Sym)                 _DMA_DMDST_FSET(4,DMA_DMDST_##Field##_##Sym)
#define _DMA_DMDST4_FAOI(Field,AND,OR,INV)           _DMA_DMDST_FAOI(4,##Field,AND,OR,INV)
#define _DMA_DMDST4_CFG(Val)                         _DMA_DMDST_CFG(4,Val)

#define _DMA_DMDST5_GET()                            _DMA_DMDST_GET(5)
#define _DMA_DMDST5_SET(Val)                         _DMA_DMDST_SET(5,Val)
#define _DMA_DMDST5_AOI(AND,OR,INV)                  _DMA_DMDST_AOI(5,AND,OR,INV)
#define _DMA_DMDST5_FGET(Field)                      _DMA_DMDST_FGET(5,##Field)
#define _DMA_DMDST5_FSET(Field,Val)                  _DMA_DMDST_FSET(5,##Field,Val)
#define _DMA_DMDST5_FSETS(Field,Sym)                 _DMA_DMDST_FSET(5,DMA_DMDST_##Field##_##Sym)
#define _DMA_DMDST5_FAOI(Field,AND,OR,INV)           _DMA_DMDST_FAOI(5,##Field,AND,OR,INV)
#define _DMA_DMDST5_CFG(Val)                         _DMA_DMDST_CFG(5,Val)

/*----------------------------------------------------------------------------*\
* _DMA_DMDST_DST: DMA transfer source address
\*----------------------------------------------------------------------------*/
#define _DMA_DMDST_DST_SHIFT          (0x0000u)
#define _DMA_DMDST_DST_MK(n)          (((Uint16)(n) & 0xffffu)<< _DMA_DMDST_DST_SHIFT)
#define _DMA_DMDST_DST_MASK           (_DMA_DMDST_DST_MK(0xffffu))
#define _DMA_DMDST_DST_CLR            (~(_DMA_DMDST_DST_MASK))

/*******************************************************************************\
* _DMA_DMCTR DMA Element Count Register
* 
* Fields:
*  _DMA_DMCTR_ELECNT
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMCTR: Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMCTR_GET(Chan)\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMCTR(Chan))

#define _DMA_DMCTR_SET(Chan, Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMCTR(Chan), Val)

#define _DMA_DMCTR_AOI(Chan, AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMCTR(Chan), AND, OR, INV)

#define _DMA_DMCTR_FGET(Chan, Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMCTR(Chan),\
  _DMA_DMCTR_##Field)

#define _DMA_DMCTR_FSET(Chan, Field, Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMCTR(Chan),\
  _DMA_DMCTR_##Field, Val)

#define _DMA_DMCTR_FAOI(Chan, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMCTR(Chan),\
  _DMA_DMCTR_##Field, AND, OR, INV)

#define _DMA_DMCTR_CFG(Chan, Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMCTR(Chan), Val)

#define _DMA_DMCTR0_GET()                     _DMA_DMCTR_GET(0)
#define _DMA_DMCTR0_SET(Val)                  _DMA_DMCTR_SET(0,Val)
#define _DMA_DMCTR0_AOI(AND,OR,INV)           _DMA_DMCTR_AOI(0,AND,OR,INV)
#define _DMA_DMCTR0_FGET(Field)               _DMA_DMCTR_FGET(0,##Field)
#define _DMA_DMCTR0_FSET(Field,Val)           _DMA_DMCTR_FSET(0,##Field,Val)
#define _DMA_DMCTR0_FSETS(Field,Sym)          _DMA_DMCTR_FSET(0,DMA_DMCTR_##Field##_##Sym)
#define _DMA_DMCTR0_FAOI(Field,AND,OR,INV)    _DMA_DMCTR_FAOI(0,##Field,AND,OR,INV)
#define _DMA_DMCTR0_CFG(Val)                  _DMA_DMCTR_CFG(0,Val)

#define _DMA_DMCTR1_GET()                     _DMA_DMCTR_GET(1)
#define _DMA_DMCTR1_SET(Val)                  _DMA_DMCTR_SET(1,Val)
#define _DMA_DMCTR1_AOI(AND,OR,INV)           _DMA_DMCTR_AOI(1,AND,OR,INV)
#define _DMA_DMCTR1_FGET(Field)               _DMA_DMCTR_FGET(1,##Field)
#define _DMA_DMCTR1_FSET(Field,Val)           _DMA_DMCTR_FSET(1,##Field,Val)
#define _DMA_DMCTR1_FSETS(Field,Sym)          _DMA_DMCTR_FSET(1,DMA_DMCTR_##Field##_##Sym)
#define _DMA_DMCTR1_FAOI(Field,AND,OR,INV)    _DMA_DMCTR_FAOI(1,##Field,AND,OR,INV)
#define _DMA_DMCTR1_CFG(Val)                  _DMA_DMCTR_CFG(1,Val)

#define _DMA_DMCTR2_GET()                     _DMA_DMCTR_GET(2)
#define _DMA_DMCTR2_SET(Val)                  _DMA_DMCTR_SET(2,Val)
#define _DMA_DMCTR2_AOI(AND,OR,INV)           _DMA_DMCTR_AOI(2,AND,OR,INV)
#define _DMA_DMCTR2_FGET(Field)               _DMA_DMCTR_FGET(2,##Field)
#define _DMA_DMCTR2_FSET(Field,Val)           _DMA_DMCTR_FSET(2,##Field,Val)
#define _DMA_DMCTR2_FSETS(Field,Sym)          _DMA_DMCTR_FSET(2,DMA_DMCTR_##Field##_##Sym)
#define _DMA_DMCTR2_FAOI(Field,AND,OR,INV)    _DMA_DMCTR_FAOI(2,##Field,AND,OR,INV)
#define _DMA_DMCTR2_CFG(Val)                  _DMA_DMCTR_CFG(2,Val)

#define _DMA_DMCTR3_GET()                     _DMA_DMCTR_GET(3)
#define _DMA_DMCTR3_SET(Val)                  _DMA_DMCTR_SET(3,Val)
#define _DMA_DMCTR3_AOI(AND,OR,INV)           _DMA_DMCTR_AOI(3,AND,OR,INV)
#define _DMA_DMCTR3_FGET(Field)               _DMA_DMCTR_FGET(3,##Field)
#define _DMA_DMCTR3_FSET(Field,Val)           _DMA_DMCTR_FSET(3,##Field,Val)
#define _DMA_DMCTR3_FSETS(Field,Sym)          _DMA_DMCTR_FSET(3,DMA_DMCTR_##Field##_##Sym)
#define _DMA_DMCTR3_FAOI(Field,AND,OR,INV)    _DMA_DMCTR_FAOI(3,##Field,AND,OR,INV)
#define _DMA_DMCTR3_CFG(Val)                  _DMA_DMCTR_CFG(3,Val)

#define _DMA_DMCTR4_GET()                     _DMA_DMCTR_GET(4)
#define _DMA_DMCTR4_SET(Val)                  _DMA_DMCTR_SET(4,Val)
#define _DMA_DMCTR4_AOI(AND,OR,INV)           _DMA_DMCTR_AOI(4,AND,OR,INV)
#define _DMA_DMCTR4_FGET(Field)               _DMA_DMCTR_FGET(4,##Field)
#define _DMA_DMCTR4_FSET(Field,Val)           _DMA_DMCTR_FSET(4,##Field,Val)
#define _DMA_DMCTR4_FSETS(Field,Sym)          _DMA_DMCTR_FSET(4,DMA_DMCTR_##Field##_##Sym)
#define _DMA_DMCTR4_FAOI(Field,AND,OR,INV)    _DMA_DMCTR_FAOI(4,##Field,AND,OR,INV)
#define _DMA_DMCTR4_CFG(Val)                  _DMA_DMCTR_CFG(4,Val)

#define _DMA_DMCTR5_GET()                     _DMA_DMCTR_GET(5)
#define _DMA_DMCTR5_SET(Val)                  _DMA_DMCTR_SET(5,Val)
#define _DMA_DMCTR5_AOI(AND,OR,INV)           _DMA_DMCTR_AOI(5,AND,OR,INV)
#define _DMA_DMCTR5_FGET(Field)               _DMA_DMCTR_FGET(5,##Field)
#define _DMA_DMCTR5_FSET(Field,Val)           _DMA_DMCTR_FSET(5,##Field,Val)
#define _DMA_DMCTR5_FSETS(Field,Sym)          _DMA_DMCTR_FSET(5,DMA_DMCTR_##Field##_##Sym)
#define _DMA_DMCTR5_FAOI(Field,AND,OR,INV)    _DMA_DMCTR_FAOX(5,##Field,AND,OR,INV)
#define _DMA_DMCTR5_CFG(Val)                  _DMA_DMCTR_CFG(5,Val)

/*----------------------------------------------------------------------------*\
* _DMA_DMCTR_ELECNT: Number of elements to transfer - 1
\*----------------------------------------------------------------------------*/
#define _DMA_DMCTR_ELECNT_SHIFT           (0x0000u)
#define _DMA_DMCTR_ELECNT_MK(n)           (((Uint16)(n) & 0xffffu)<< _DMA_DMCTR_ELECNT_SHIFT)
#define _DMA_DMCTR_ELECNT_MASK            (_DMA_DMCTR_ELECNT_MK(0xffffu))
#define _DMA_DMCTR_ELECNT_CLR             (~(_DMA_DMCTR_ELECNT_MASK))

/*------------------------------------------------------------------------------*\
* DMA GLOBAL/SHARED REGISTER DEFINITIONS
\*------------------------------------------------------------------------------*/

/*******************************************************************************\
* _DMA_DMSRCP Global Source Program Page Address Register
* 
* Fields:
*  _DMA_DMSRCP_PAGE
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMSRCP_PAGE: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMSRCP_PAGE_SHIFT           (0x0000u)
#define _DMA_DMSRCP_PAGE_MK(n)           (((Uint16)(n) & 0x007fu)<< _DMA_DMSRCP_PAGE_SHIFT)
#define _DMA_DMSRCP_PAGE_MASK            (_DMA_DMSRCP_PAGE_MK(0x007fu))
#define _DMA_DMSRCP_PAGE_CLR             (~(_DMA_DMSRCP_PAGE_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMSRCP: Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMSRCP_GET()\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCP_ADDR)

#define _DMA_DMSRCP_SET(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCP_ADDR, Val)

#define _DMA_DMSRCP_AOI(AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCP_ADDR, AND, OR, INV)

#define _DMA_DMSRCP_FGET(Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCP_ADDR, _DMA_DMSRCP_##Field)

#define _DMA_DMSRCP_FSET(Field,Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCP_ADDR, _DMA_DMSRCP_##Field, Val)

#define _DMA_DMSRCP_FAOI(Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCP_ADDR, _DMA_DMSRCP_##Field, AND, OR, INV)

#define _DMA_DMSRCP_CFG(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCP_ADDR, Val)

/*******************************************************************************\
* _DMA_DMDSTP Global Destination Program Page Address Register
* 
* Fields:
*  _DMA_DMDSTP_PAGE
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMDSTP_PAGE: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMDSTP_PAGE_SHIFT           (0x0000u)
#define _DMA_DMDSTP_PAGE_MK(n)           (((Uint16)(n) & 0x007fu)<< _DMA_DMDSTP_PAGE_SHIFT)
#define _DMA_DMDSTP_PAGE_MASK            (_DMA_DMDSTP_PAGE_MK(0x007fu))
#define _DMA_DMDSTP_PAGE_CLR             (~(_DMA_DMDSTP_PAGE_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMDSTP: Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMDSTP_GET()\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTP_ADDR)

#define _DMA_DMDSTP_SET(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTP_ADDR, Val)

#define _DMA_DMDSTP_AOI(AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTP_ADDR, AND, OR, INV)

#define _DMA_DMDSTP_FGET(Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTP_ADDR,\
  _DMA_DMDSTP_##Field)

#define _DMA_DMDSTP_FSET(Field, Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTP_ADDR,\
  _DMA_DMDSTP_##Field, Val)

#define _DMA_DMDSTP_FAOI(Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTP_ADDR,\
  _DMA_DMDSTP_##Field, AND, OR, INV)

#define _DMA_DMDSTP_CFG(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTP_ADDR, Val)

/*******************************************************************************\
* _DMA_DMIDX0 Global Element Index Register #0
* 
* Fields:
*  _DMA_DMIDX0_ELEIDX
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMIDX0_ELEIDX: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMIDX0_ELEIDX_SHIFT          (0x0000u)
#define _DMA_DMIDX0_ELEIDX_MK(n)          (((Uint16)(n) & 0xffffu)<< _DMA_DMIDX0_ELEIDX_SHIFT)
#define _DMA_DMIDX0_ELEIDX_MASK           (_DMA_DMIDX0_ELEIDX_MK(0xffffu))
#define _DMA_DMIDX0_ELEIDX_CLR            (~(_DMA_DMIDX0_ELEIDX_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMIDX0: Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMIDX0_GET()\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX0_ADDR)

#define _DMA_DMIDX0_SET(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX0_ADDR, Val)

#define _DMA_DMIDX0_AOI(AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX0_ADDR, AND, OR, INV)

#define _DMA_DMIDX0_FGET(Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX0_ADDR,\
  _DMA_DMIDX0_##Field)

#define _DMA_DMIDX0_FSET(Field,Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX0_ADDR,\
  _DMA_DMIDX0_##Field, Val)

#define _DMA_DMIDX0_FAOI(Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX0_ADDR,\
  _DMA_DMIDX0_##Field, AND, OR, INV)

#define _DMA_DMIDX0_CFG(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX0_ADDR, Val)

/*******************************************************************************\
* _DMA_DMIDX1 Global Element Index Register #1
* 
* Fields:
*  _DMA_DMIDX1_ELEIDX
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMIDX1_ELEIDX: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMIDX1_ELEIDX_SHIFT           (0x0000u)
#define _DMA_DMIDX1_ELEIDX_MK(n)           (((Uint16)(n) & 0xffffu)<< _DMA_DMIDX1_ELEIDX_SHIFT)
#define _DMA_DMIDX1_ELEIDX_MASK            (_DMA_DMIDX1_ELEIDX_MK(0xffffu))
#define _DMA_DMIDX1_ELEIDX_CLR             (~(_DMA_DMIDX1_ELEIDX_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMIDX1: Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMIDX1_GET()\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR)

#define _DMA_DMIDX1_SET(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR, Val)

#define _DMA_DMIDX1_AOI(AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR, AND, OR, INV)

#define _DMA_DMIDX1_FGET(Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR,\
  _DMA_DMIDX1_##Field)

#define _DMA_DMIDX1_FSET(Field,Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR,\
  _DMA_DMIDX1_##Field, Val)

#define _DMA_DMIDX1_FAOI(Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR,\
  _DMA_DMIDX1_##Field, AND, OR, INV)

#define _DMA_DMIDX1_CFG(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR, Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMIDX1_ADDR, Val)

/*******************************************************************************\
* _DMA_DMFRI0 Global Frame Index Register #0
* 
* Fields:
*  _DMA_DMFRI0_FRAMEIDX
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMFRI0_FRAMEIDX: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMFRI0_FRAMEIDX_SHIFT           (0x0000u)
#define _DMA_DMFRI0_FRAMEIDX_MK(n)           (((Uint16)(n) & 0xffffu)<< _DMA_DMFRI0_FRAMEIDX_SHIFT)
#define _DMA_DMFRI0_FRAMEIDX_MASK            (_DMA_DMFRI0_FRAMEIDX_MK(0xffffu))
#define _DMA_DMFRI0_FRAMEIDX_CLR             (~(_DMA_DMFRI0_FRAMEIDX_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMFRI0: Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMFRI0_GET()\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI0_ADDR)

#define _DMA_DMFRI0_SET(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI0_ADDR, Val)

#define _DMA_DMFRI0_AOI(AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI0_ADDR, Val)

#define _DMA_DMFRI0_FGET(Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI0_ADDR,\
  _DMA_DMFRI0_FRAMEIDX)

#define _DMA_DMFRI0_FSET(Field,Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI0_ADDR,\
  _DMA_DMFRI0_##Field, Val)

#define _DMA_DMFRI0_FAOI(Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI0_ADDR,\
  _DMA_DMFRI0_##Field, AND, OR, INV)

#define _DMA_DMFRI0_CFG(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI0_ADDR, Val)

/*******************************************************************************\
* _DMA_DMFRI1 Global Frame Index Register #1
* 
* Fields:
*  _DMA_DMFRI1_FRAMEIDX
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMFRI1_FRAMEIDX: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMFRI1_FRAMEIDX_SHIFT           (0x0000u)
#define _DMA_DMFRI1_FRAMEIDX_MK(n)           (((Uint16)(n) & 0xffffu)<< _DMA_DMFRI1_FRAMEIDX_SHIFT)
#define _DMA_DMFRI1_FRAMEIDX_MASK            (_DMA_DMFRI1_FRAMEIDX_MK(0xffffu))
#define _DMA_DMFRI1_FRAMEIDX_CLR             (~(_DMA_DMFRI1_FRAMEIDX_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMFRI1: Register Macros
\*----------------------------------------------------------------------------*/
#define _DMA_DMFRI1_GET()\
  _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI1_ADDR)

#define _DMA_DMFRI1_SET(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI1_ADDR, Val)

#define _DMA_DMFRI1_AOI(AND, OR, INV)\
  _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI1_ADDR, AND, OR, INV)

#define _DMA_DMFRI1_FGET(Field)\
  _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI1_ADDR,\
  _DMA_DMFRI1_##Field)

#define _DMA_DMFRI1_FSET(Field, Val)\
  _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI1_ADDR,\
  _DMA_DMFRI1_##Field, Val)

#define _DMA_DMFRI1_FAOI(Field, AND, OR, INV)\
  _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI1_ADDR,\
  _DMA_DMFRI1_##Field, AND, OR, INV)

#define _DMA_DMFRI1_CFG(Val)\
  _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMFRI1_ADDR, Val)

/*******************************************************************************\
* _DMA_DMGSA Global Source Address Register (autoinit)
* 
* Fields:
*  _DMA_DMGSA_GSA
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMGSA_GSA: Global Source Address Register
\*----------------------------------------------------------------------------*/
#define _DMA_DMGSA_GSA_SHIFT          (0x0000u)
#define _DMA_DMGSA_GSA_MK(n)          (((Uint16)(n) & 0xffffu)<< _DMA_DMGSA_GSA_SHIFT)
#define _DMA_DMGSA_GSA_MASK           (_DMA_DMGSA_GSA_MK(0xffffu))
#define _DMA_DMGSA_GSA_CLR            (~(_DMA_DMGSA_GSA_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMGSA: Register Macros
\*----------------------------------------------------------------------------*/
#if (_DMA_CH_RLDR_SUPPORT)
  
  #define _DMA_DMGSA_GET(Chan)\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan))

  #define _DMA_DMGSA_SET(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan), Val)

  #define _DMA_DMGSA_AOI(Chan, AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan), AND, OR, INV)

  #define _DMA_DMGSA_FGET(Chan, Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan),\
    _DMA_DMGSA_##Field)

  #define _DMA_DMGSA_FSET(Chan, Field, Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan),\
    _DMA_DMGSA_##Field, Val)

  #define _DMA_DMGSA_FSETS(Chan, Field, Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan),\
    _DMA_DMGSA_##Field, DMA_DMGSA_##Field##_##Sym)

  #define _DMA_DMGSA_FAOI(Chan, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan),\
    _DMA_DMGSA_##Field, AND, OR, INV)

  #define _DMA_DMGSA_CFG(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGSA(Chan), Val)
 
  #define _DMA_DMGSA0_GET()                     _DMA_DMGSA_GET(0)
  #define _DMA_DMGSA0_SET(Val)                  _DMA_DMGSA_SET(0,Val)
  #define _DMA_DMGSA0_AOI(AND,OR,INV)           _DMA_DMGSA_AOI(0,AND,OR,INV)
  #define _DMA_DMGSA0_FGET(Field)               _DMA_DMGSA_FGET(0,##Field)
  #define _DMA_DMGSA0_FSET(Field,Val)           _DMA_DMGSA_FSET(0,##Field,Val)
  #define _DMA_DMGSA0_FSETS(Field,Sym)          _DMA_DMGSA_FSETS(0,##Field,Sym)
  #define _DMA_DMGSA0_FAOI(Field,AND,OR,INV)    _DMA_DMGSA_FAOI(0,##Field,AND,OR,INV)
  #define _DMA_DMGSA0_CFG(Val)                  _DMA_DMGSA_CFG(0,Val)

  #define _DMA_DMGSA1_GET()                     _DMA_DMGSA_GET(1)
  #define _DMA_DMGSA1_SET(Val)                  _DMA_DMGSA_SET(1,Val)
  #define _DMA_DMGSA1_AOI(AND,OR,INV)           _DMA_DMGSA_AOI(1,AND,OR,INV)
  #define _DMA_DMGSA1_FGET(Field)               _DMA_DMGSA_FGET(1,##Field)
  #define _DMA_DMGSA1_FSET(Field,Val)           _DMA_DMGSA_FSET(1,##Field,Val)
  #define _DMA_DMGSA1_FSETS(Field,Sym)          _DMA_DMGSA_FSETS(1,##Field,Sym)
  #define _DMA_DMGSA1_FAOI(Field,AND,OR,INV)    _DMA_DMGSA_FAOI(1,##Field,AND,OR,INV)
  #define _DMA_DMGSA1_CFG(Val)                  _DMA_DMGSA_CFG(1,Val)

  #define _DMA_DMGSA2_GET()                     _DMA_DMGSA_GET(2)
  #define _DMA_DMGSA2_SET(Val)                  _DMA_DMGSA_SET(2,Val)
  #define _DMA_DMGSA2_AOI(AND,OR,INV)           _DMA_DMGSA_AOI(2,AND,OR,INV)
  #define _DMA_DMGSA2_FGET(Field)               _DMA_DMGSA_FGET(2,##Field)
  #define _DMA_DMGSA2_FSET(Field,Val)           _DMA_DMGSA_FSET(2,##Field,Val)
  #define _DMA_DMGSA2_FSETS(Field,Sym)          _DMA_DMGSA_FSETS(2,##Field,Sym)
  #define _DMA_DMGSA2_FAOI(Field,AND,OR,INV)    _DMA_DMGSA_FAOI(2,##Field,AND,OR,INV)
  #define _DMA_DMGSA2_CFG(Val)                  _DMA_DMGSA_CFG(2,Val)

  #define _DMA_DMGSA3_GET()                     _DMA_DMGSA_GET(3)
  #define _DMA_DMGSA3_SET(Val)                  _DMA_DMGSA_SET(3,Val)
  #define _DMA_DMGSA3_AOI(AND,OR,INV)           _DMA_DMGSA_AOI(3,AND,OR,INV)
  #define _DMA_DMGSA3_FGET(Field)               _DMA_DMGSA_FGET(3,##Field)
  #define _DMA_DMGSA3_FSET(Field,Val)           _DMA_DMGSA_FSET(3,##Field,Val)
  #define _DMA_DMGSA3_FSETS(Field,Sym)          _DMA_DMGSA_FSETS(3,##Field,Sym)
  #define _DMA_DMGSA3_FAOI(Field,AND,OR,INV)    _DMA_DMGSA_FAOI(3,##Field,AND,OR,INV)
  #define _DMA_DMGSA3_CFG(Val)                  _DMA_DMGSA_CFG(3,Val)

  #define _DMA_DMGSA4_GET()                     _DMA_DMGSA_GET(4)
  #define _DMA_DMGSA4_SET(Val)                  _DMA_DMGSA_SET(4,Val)
  #define _DMA_DMGSA4_AOI(AND,OR,INV)           _DMA_DMGSA_AOI(4,AND,OR,INV)
  #define _DMA_DMGSA4_FGET(Field)               _DMA_DMGSA_FGET(4,##Field)
  #define _DMA_DMGSA4_FSET(Field,Val)           _DMA_DMGSA_FSET(4,##Field,Val)
  #define _DMA_DMGSA4_FSETS(Field,Sym)          _DMA_DMGSA_FSETS(4,##Field,Sym)
  #define _DMA_DMGSA4_FAOI(Field,AND,OR,INV)    _DMA_DMGSA_FAOI(4,##Field,AND,OR,INV)
  #define _DMA_DMGSA4_CFG(Val)                  _DMA_DMGSA_CFG(4,Val)

  #define _DMA_DMGSA5_GET()                     _DMA_DMGSA_GET(5)
  #define _DMA_DMGSA5_SET(Val)                  _DMA_DMGSA_SET(5,Val)
  #define _DMA_DMGSA5_AOI(AND,OR,INV)           _DMA_DMGSA_AOI(5,AND,OR,INV)
  #define _DMA_DMGSA5_FGET(Field)               _DMA_DMGSA_FGET(5,##Field)
  #define _DMA_DMGSA5_FSET(Field,Val)           _DMA_DMGSA_FSET(5,##Field,Val)
  #define _DMA_DMGSA5_FSETS(Field,Sym)          _DMA_DMGSA_FSETS(5,##Field,Sym)
  #define _DMA_DMGSA5_FAOI(Field,AND,OR,INV)    _DMA_DMGSA_FAOI(5,##Field,AND,OR,INV)
  #define _DMA_DMGSA5_CFG(Val)                  _DMA_DMGSA_CFG(5,Val)

#else

  #define _DMA_DMGSA_GET()\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR)

  #define _DMA_DMGSA_SET(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR, Val)

  #define _DMA_DMGSA_AOI(AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR, AND, OR, INV)

  #define _DMA_DMGSA_FGET(Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR,\
    _DMA_DMGSA_##Field)

  #define _DMA_DMGSA_FSET(Field,Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR,\
    _DMA_DMGSA_##Field, Val)

  #define _DMA_DMGSA_FSETS(Field,Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR,\
    _DMA_DMGSA_##Field, DMA_DMGSA_##Field##_##Sym)


  #define _DMA_DMGSA_FAOI(Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR,\
    _DMA_DMGSA_##Field, AND, OR, INV)

#define _DMA_DMGSA_CFG(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGSA_ADDR, Val)

#endif


/*******************************************************************************\
* _DMA_DMGDA Global Destination Address Register (autoinit)
* 
* Fields:
*  _DMA_DMGDA_GDA
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMGDA_GDA: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMGDA_GDA_SHIFT            (0x0000u)
#define _DMA_DMGDA_GDA_MK(n)            (((Uint16)(n) & 0xffffu)<< _DMA_DMGDA_GDA_SHIFT)
#define _DMA_DMGDA_GDA_MASK             (_DMA_DMGDA_GDA_MK(0xffffu))
#define _DMA_DMGDA_GDA_CLR              (~(_DMA_DMGDA_GDA_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMGDA: Register Macros
\*----------------------------------------------------------------------------*/
#if (_DMA_CH_RLDR_SUPPORT)
  
  #define _DMA_DMGDA_GET(Chan)\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan))

  #define _DMA_DMGDA_SET(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan), Val)

  #define _DMA_DMGDA_AOI(Chan, AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan), AND, OR, INV)

  #define _DMA_DMGDA_FGET(Chan, Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan),\
    _DMA_DMGDA_##Field)

  #define _DMA_DMGDA_FSET(Chan, Field, Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan),\
    _DMA_DMGDA_##Field, Val)

  #define _DMA_DMGDA_FSETS(Chan, Field, Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan),\
    _DMA_DMGDA_##Field, DMA_DMGDA_##Field##_##Sym)


  #define _DMA_DMGDA_FAOI(Chan, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan),\
    _DMA_DMGDA_##Field, AND, OR, INV)

  #define _DMA_DMGDA_CFG(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGDA(Chan), Val)
 
  #define _DMA_DMGDA0_GET()                     _DMA_DMGDA_GET(0)
  #define _DMA_DMGDA0_SET(Val)                  _DMA_DMGDA_SET(0,Val)
  #define _DMA_DMGDA0_AOI(AND,OR,INV)           _DMA_DMGDA_AOI(0,AND,OR,INV)
  #define _DMA_DMGDA0_FGET(Field)               _DMA_DMGDA_FGET(0,##Field)
  #define _DMA_DMGDA0_FSET(Field,Val)           _DMA_DMGDA_FSET(0,##Field,Val)
  #define _DMA_DMGDA0_FSETS(Field,Sym)          _DMA_DMGDA_FSETS(0,##Field,Sym)
  #define _DMA_DMGDA0_FAOI(Field,AND,OR,INV)    _DMA_DMGDA_FAOI(0,##Field,AND,OR,INV)
  #define _DMA_DMGDA0_CFG(Val)                  _DMA_DMGDA_CFG(0,Val)

  #define _DMA_DMGDA1_GET()                     _DMA_DMGDA_GET(1)
  #define _DMA_DMGDA1_SET(Val)                  _DMA_DMGDA_SET(1,Val)
  #define _DMA_DMGDA1_AOI(AND,OR,INV)           _DMA_DMGDA_AOI(1,AND,OR,INV)
  #define _DMA_DMGDA1_FGET(Field)               _DMA_DMGDA_FGET(1,##Field)
  #define _DMA_DMGDA1_FSET(Field,Val)           _DMA_DMGDA_FSET(1,##Field,Val)
  #define _DMA_DMGDA1_FSETS(Field,Sym)          _DMA_DMGDA_FSETS(1,##Field,Sym)
  #define _DMA_DMGDA1_FAOI(Field,AND,OR,INV)    _DMA_DMGDA_FAOI(1,##Field,AND,OR,INV)
  #define _DMA_DMGDA1_CFG(Val)                  _DMA_DMGDA_CFG(1,Val)

  #define _DMA_DMGDA2_GET()                     _DMA_DMGDA_GET(2)
  #define _DMA_DMGDA2_SET(Val)                  _DMA_DMGDA_SET(2,Val)
  #define _DMA_DMGDA2_AOI(AND,OR,INV)           _DMA_DMGDA_AOI(2,AND,OR,INV)
  #define _DMA_DMGDA2_FGET(Field)               _DMA_DMGDA_FGET(2,##Field)
  #define _DMA_DMGDA2_FSET(Field,Val)           _DMA_DMGDA_FSET(2,##Field,Val)
  #define _DMA_DMGDA2_FSETS(Field,Sym)          _DMA_DMGDA_FSETS(2,##Field,Sym)
  #define _DMA_DMGDA2_FAOI(Field,AND,OR,INV)    _DMA_DMGDA_FAOI(2,##Field,AND,OR,INV)
  #define _DMA_DMGDA2_CFG(Val)                  _DMA_DMGDA_CFG(2,Val)

  #define _DMA_DMGDA3_GET()                     _DMA_DMGDA_GET(3)
  #define _DMA_DMGDA3_SET(Val)                  _DMA_DMGDA_SET(3,Val)
  #define _DMA_DMGDA3_AOI(AND,OR,INV)           _DMA_DMGDA_AOI(3,AND,OR,INV)
  #define _DMA_DMGDA3_FGET(Field)               _DMA_DMGDA_FGET(3,##Field)
  #define _DMA_DMGDA3_FSET(Field,Val)           _DMA_DMGDA_FSET(3,##Field,Val)
  #define _DMA_DMGDA3_FSETS(Field,Sym)          _DMA_DMGDA_FSETS(3,##Field,Sym)
  #define _DMA_DMGDA3_FAOI(Field,AND,OR,INV)    _DMA_DMGDA_FAOI(3,##Field,AND,OR,INV)
  #define _DMA_DMGDA3_CFG(Val)                  _DMA_DMGDA_CFG(3,Val)

  #define _DMA_DMGDA4_GET()                     _DMA_DMGDA_GET(4)
  #define _DMA_DMGDA4_SET(Val)                  _DMA_DMGDA_SET(4,Val)
  #define _DMA_DMGDA4_AOI(AND,OR,INV)           _DMA_DMGDA_AOI(4,AND,OR,INV)
  #define _DMA_DMGDA4_FGET(Field)               _DMA_DMGDA_FGET(4,##Field)
  #define _DMA_DMGDA4_FSET(Field,Val)           _DMA_DMGDA_FSET(4,##Field,Val)
  #define _DMA_DMGDA4_FSETS(Field,Sym)          _DMA_DMGDA_FSETS(4,##Field,Sym)
  #define _DMA_DMGDA4_FAOI(Field,AND,OR,INV)    _DMA_DMGDA_FAOI(4,##Field,AND,OR,INV)
  #define _DMA_DMGDA4_CFG(Val)                  _DMA_DMGDA_CFG(4,Val)

  #define _DMA_DMGDA5_GET()                     _DMA_DMGDA_GET(5)
  #define _DMA_DMGDA5_SET(Val)                  _DMA_DMGDA_SET(5,Val)
  #define _DMA_DMGDA5_AOI(AND,OR,INV)           _DMA_DMGDA_AOI(5,AND,OR,INV)
  #define _DMA_DMGDA5_FGET(Field)               _DMA_DMGDA_FGET(5,##Field)
  #define _DMA_DMGDA5_FSET(Field,Val)           _DMA_DMGDA_FSET(5,##Field,Val)
  #define _DMA_DMGDA5_FSETS(Field,Sym)          _DMA_DMGDA_FSETS(5,##Field,Sym)
  #define _DMA_DMGDA5_FAOI(Field,AND,OR,INV)    _DMA_DMGDA_FAOI(5,##Field,AND,OR,INV)
  #define _DMA_DMGDA5_CFG(Val)                  _DMA_DMGDA_CFG(5,Val)

#else

  #define _DMA_DMGDA_GET()\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR)

  #define _DMA_DMGDA_SET(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR, Val)

  #define _DMA_DMGDA_AOI(AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR, AND, OR, VAL)

  #define _DMA_DMGDA_FGET(Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR,\
    _DMA_DMGDA_##Field)

  #define _DMA_DMGDA_FSET(Field,Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR,\
    _DMA_DMGDA_##Field, Val)

  #define _DMA_DMGDA_FSETS(Field,Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR,\
    _DMA_DMGDA_##Field, DMA_DMGDA_##Field##_##Sym)

  #define _DMA_DMGDA_FAOI(Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR,\
    _DMA_DMGDA_##Field, AND, OR, INV)

#define _DMA_DMGDA_CFG(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGDA_ADDR, Val)

#endif
/*******************************************************************************\
* _DMA_DMGCR Global Element Count Register (autoinit)
* 
* Fields:
*  _DMA_DMGCR_ELECNT
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMGCR_ELECNT: Extended memory page for program source
\*----------------------------------------------------------------------------*/
#define _DMA_DMGCR_ELECNT_SHIFT          (0x0000u)
#define _DMA_DMGCR_ELECNT_MK(n)          (((Uint16)(n) & 0xffffu)<< _DMA_DMGCR_ELECNT_SHIFT)
#define _DMA_DMGCR_ELECNT_MASK           (_DMA_DMGCR_ELECNT_MK(0xffffu))
#define _DMA_DMGCR_ELECNT_CLR            (~(_DMA_DMGCR_ELECNT_MASK))

/*----------------------------------------------------------------------------*\
* _DMA_DMGCR: Register Macros
\*----------------------------------------------------------------------------*/
#if (_DMA_CH_RLDR_SUPPORT)
  
  #define _DMA_DMGCR_GET(Chan)\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan))

  #define _DMA_DMGCR_SET(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan), Val)

  #define _DMA_DMGCR_AOI(Chan, AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan), AND, OR, INV)

  #define _DMA_DMGCR_FGET(Chan, Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan),\
    _DMA_DMGCR_##Field)

  #define _DMA_DMGCR_FSET(Chan, Field, Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan),\
    _DMA_DMGCR_##Field, Val)

  #define _DMA_DMGCR_FSETS(Chan, Field, Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan),\
    _DMA_DMGCR_##Field, DMA_DMGCR_##Field##_##Sym)

  #define _DMA_DMGCR_FAOI(Chan, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan),\
    _DMA_DMGCR_##Field, AND, OR, INV)

  #define _DMA_DMGCR_CFG(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGCR(Chan), Val)
 
  #define _DMA_DMGCR0_GET()                     _DMA_DMGCR_GET(0)
  #define _DMA_DMGCR0_SET(Val)                  _DMA_DMGCR_SET(0,Val)
  #define _DMA_DMGCR0_AOI(AND,OR,INV)           _DMA_DMGCR_AOI(0,AND,OR,INV)
  #define _DMA_DMGCR0_FGET(Field)               _DMA_DMGCR_FGET(0,##Field)
  #define _DMA_DMGCR0_FSET(Field,Val)           _DMA_DMGCR_FSET(0,##Field,Val)
  #define _DMA_DMGCR0_FSETS(Field,Sym)          _DMA_DMGCR_FSETS(0,##Field,Sym)
  #define _DMA_DMGCR0_FAOI(Field,AND,OR,INV)    _DMA_DMGCR_FSET(0,##Field,AND,OR,INV)
  #define _DMA_DMGCR0_CFG(Val)                  _DMA_DMGCR_CFG(0,Val)

  #define _DMA_DMGCR1_GET()                     _DMA_DMGCR_GET(1)
  #define _DMA_DMGCR1_SET(Val)                  _DMA_DMGCR_SET(1,Val)
  #define _DMA_DMGCR1_AOI(AND,OR,INV)           _DMA_DMGCR_AOI(1,AND,OR,INV)
  #define _DMA_DMGCR1_FGET(Field)               _DMA_DMGCR_FGET(1,##Field)
  #define _DMA_DMGCR1_FSET(Field,Val)           _DMA_DMGCR_FSET(1,##Field,Val)
  #define _DMA_DMGCR1_FSETS(Field,Sym)          _DMA_DMGCR_FSETS(1,##Field,Sym)
  #define _DMA_DMGCR1_FAOI(Field,AND,OR,INV)    _DMA_DMGCR_FAOI(1,##Field,AND,OR,INV)
  #define _DMA_DMGCR1_CFG(Val)                  _DMA_DMGCR_CFG(1,Val)

  #define _DMA_DMGCR2_GET()                     _DMA_DMGCR_GET(2)
  #define _DMA_DMGCR2_SET(Val)                  _DMA_DMGCR_SET(2,Val)
  #define _DMA_DMGCR2_AOI(AND,OR,INV)           _DMA_DMGCR_AOI(2,AND,OR,INV)
  #define _DMA_DMGCR2_FGET(Field)               _DMA_DMGCR_FGET(2,##Field)
  #define _DMA_DMGCR2_FSET(Field,Val)           _DMA_DMGCR_FSET(2,##Field,Val)
  #define _DMA_DMGCR2_FSETS(Field,Sym)          _DMA_DMGCR_FSETS(2,##Field,Sym)
  #define _DMA_DMGCR2_FAOI(Field,AND,OR,INV)    _DMA_DMGCR_FAOI(2,##Field,AND,OR,INV)
  #define _DMA_DMGCR2_CFG(Val)                  _DMA_DMGCR_CFG(2,Val)

  #define _DMA_DMGCR3_GET()                     _DMA_DMGCR_GET(3)
  #define _DMA_DMGCR3_SET(Val)                  _DMA_DMGCR_SET(3,Val)
  #define _DMA_DMGCR3_AOI(AND,OR,INV)           _DMA_DMGCR_AOI(3,AND,OR,INV)
  #define _DMA_DMGCR3_FGET(Field)               _DMA_DMGCR_FGET(3,##Field)
  #define _DMA_DMGCR3_FSETS(Field,Sym)          _DMA_DMGCR_FSETS(3,##Field,Sym)
  #define _DMA_DMGCR3_FSET(Field,Val)           _DMA_DMGCR_FSET(3,##Field,Val)
  #define _DMA_DMGCR3_FAOI(Field,AND,OR,INV)    _DMA_DMGCR_FAOI(3,##Field,AND,OR,INV)
  #define _DMA_DMGCR3_CFG(Val)                  _DMA_DMGCR_CFG(3,Val)

  #define _DMA_DMGCR4_GET()                     _DMA_DMGCR_GET(4)
  #define _DMA_DMGCR4_SET(Val)                  _DMA_DMGCR_SET(4,Val)
  #define _DMA_DMGCR4_AOI(AND,OR,INV)           _DMA_DMGCR_AOI(4,AND,OR,INV)
  #define _DMA_DMGCR4_FGET(Field)               _DMA_DMGCR_FGET(4,##Field)
  #define _DMA_DMGCR4_FSETS(Field,Sym)          _DMA_DMGCR_FSETS(4,##Field,Sym)
  #define _DMA_DMGCR4_FSET(Field,Val)           _DMA_DMGCR_FSET(4,##Field,Val)
  #define _DMA_DMGCR4_FAOI(Field,AND,OR,INV)    _DMA_DMGCR_FAOI(4,##Field,AND,OR,INV)
  #define _DMA_DMGCR4_CFG(Val)                  _DMA_DMGCR_CFG(4,Val)

  #define _DMA_DMGCR5_GET()                     _DMA_DMGCR_GET(5)
  #define _DMA_DMGCR5_SET(Val)                  _DMA_DMGCR_SET(5,Val)
  #define _DMA_DMGCR5_AOI(AND,OR,INV)           _DMA_DMGCR_AOI(5,AND,OR,INV)
  #define _DMA_DMGCR5_FGET(Field)               _DMA_DMGCR_FGET(5,##Field)
  #define _DMA_DMGCR5_FSET(Field,Val)           _DMA_DMGCR_FSET(5,##Field,Val)
  #define _DMA_DMGCR5_FSETS(Field,Sym)          _DMA_DMGCR_FSETS(5,##Field,Sym)
  #define _DMA_DMGCR5_FAOI(Field,AND,OR,INV)    _DMA_DMGCR_FAOI(5,##Field,AND,OR,INV)
  #define _DMA_DMGCR5_CFG(Val)                  _DMA_DMGCR_CFG(5,Val)

#else

  #define _DMA_DMGCR_GET()\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR)

  #define _DMA_DMGCR_SET(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR, Val)

  #define _DMA_DMGCR_AOI(AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR, AND, OR, INV)

  #define _DMA_DMGCR_FGET(Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR,\
    _DMA_DMGCR_##Field)

  #define _DMA_DMGCR_FSET(Field,Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR,\
    _DMA_DMGCR_##Field, Val)

  #define _DMA_DMGCR_FSETS(Field,Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR,\
    _DMA_DMGCR_##Field, DMA_DMGCR_##Field##_##Sym)

  #define _DMA_DMGCR_FAOI(Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR,\
    _DMA_DMGCR_##Field, AND, OR, INV)

#define _DMA_DMGCR_CFG(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGCR_ADDR, Val)

#endif
/*******************************************************************************\
* _DMA_DMGFR Global Frame Count Register (autoinit)
* 
* Fields:
*  _DMA_DMGFR_FRAMECNT
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMGFR_FRAMECNT: Global Frame Count Register
\*----------------------------------------------------------------------------*/
#define _DMA_DMGFR_FRAMECNT_SHIFT           (0x0000u)
#define _DMA_DMGFR_FRAMECNT_MK(n)           (((Uint16)(n) & 0xffffu)<< _DMA_DMGFR_FRAMECNT_SHIFT)
#define _DMA_DMGFR_FRAMECNT_MASK            (_DMA_DMGFR_FRAMECNT_MK(0xffffu))
#define _DMA_DMGFR_FRAMECNT_CLR             (~(_DMA_DMGFR_FRAMECNT_MASK))

#if (_DMA_CH_RLDR_SUPPORT)
  
  #define _DMA_DMGFR_GET(Chan)\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan))

  #define _DMA_DMGFR_SET(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan), Val)

  #define _DMA_DMGFR_AOI(Chan, AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan), AND, OR, INV)

  #define _DMA_DMGFR_FGET(Chan, Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan),\
    _DMA_DMGFR_##Field)

  #define _DMA_DMGFR_FSET(Chan, Field, Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan),\
    _DMA_DMGFR_##Field, Val)

  #define _DMA_DMGFR_FSETS(Chan, Field, Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan),\
    _DMA_DMGFR_##Field, DMA_DMGFR_##Field##_##Sym)

  #define _DMA_DMGFR_FAOI(Chan, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan),\
    _DMA_DMGFR_##Field, AND, OR, INV)

  #define _DMA_DMGFR_CFG(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMGFR(Chan), Val)
 
  #define _DMA_DMGFR0_GET()                     _DMA_DMGFR_GET(0)
  #define _DMA_DMGFR0_SET(Val)                  _DMA_DMGFR_SET(0,Val)
  #define _DMA_DMGFR0_GETI()                    _DMA_DMGFR_GETI(0)
  #define _DMA_DMGFR0_SETI(Val)                 _DMA_DMGFR_SETI(0,Val)
  #define _DMA_DMGFR0_AOI(AND,OR,INV)           _DMA_DMGFR_AOI(0,AND,OR,INV)
  #define _DMA_DMGFR0_FGET(Field)               _DMA_DMGFR_FGET(0,##Field)
  #define _DMA_DMGFR0_FSET(Field,Val)           _DMA_DMGFR_FSET(0,##Field,Val)
  #define _DMA_DMGFR0_FSETS(Field,Sym)          _DMA_DMGFR_FSETS(0,##Field,Sym)
  #define _DMA_DMGFR0_FAOI(Field,AND,OR,INV)    _DMA_DMGFR_FSET(0,##Field,AND,OR,INV)
  #define _DMA_DMGFR0_CFG(Val)                  _DMA_DMGFR_CFG(0,Val)

  #define _DMA_DMGFR1_GET()                     _DMA_DMGFR_GET(1)
  #define _DMA_DMGFR1_SET(Val)                  _DMA_DMGFR_SET(1,Val)
  #define _DMA_DMGFR1_AOI(AND,OR,INV)           _DMA_DMGFR_AOI(1,AND,OR,INV)
  #define _DMA_DMGFR1_FGET(Field)               _DMA_DMGFR_FGET(1,##Field)
  #define _DMA_DMGFR1_FSET(Field,Val)           _DMA_DMGFR_FSET(1,##Field,Val)
  #define _DMA_DMGFR1_FSETS(Field,Sym)          _DMA_DMGFR_FSETS(1,##Field,Sym)
  #define _DMA_DMGFR1_FAOI(Field,AND,OR,INV)    _DMA_DMGFR_FAOI(1,##Field,AND,OR,INV)
  #define _DMA_DMGFR1_CFG(Val)                  _DMA_DMGFR_CFG(1,Val)

  #define _DMA_DMGFR2_GET()                     _DMA_DMGFR_GET(2)
  #define _DMA_DMGFR2_SET(Val)                  _DMA_DMGFR_SET(2,Val)
  #define _DMA_DMGFR2_AOI(AND,OR,INV)           _DMA_DMGFR_AOI(2,AND,OR,INV)
  #define _DMA_DMGFR2_FGET(Field)               _DMA_DMGFR_FGET(2,##Field)
  #define _DMA_DMGFR2_FSET(Field,Val)           _DMA_DMGFR_FSET(2,##Field,Val)
  #define _DMA_DMGFR2_FSETS(Field,Sym)          _DMA_DMGFR_FSETS(2,##Field,Sym)
  #define _DMA_DMGFR2_FAOI(Field,AND,OR,INV)    _DMA_DMGFR_FSET(2,##Field,AND,OR,INV)
  #define _DMA_DMGFR2_CFG(Val)                  _DMA_DMGFR_CFG(2,Val)

  #define _DMA_DMGFR3_GET()                     _DMA_DMGFR_GET(3)
  #define _DMA_DMGFR3_SET(Val)                  _DMA_DMGFR_SET(3,Val)
  #define _DMA_DMGFR3_AOI(AND,OR,INV)           _DMA_DMGFR_AOI(3,AND,OR,INV)
  #define _DMA_DMGFR3_FGET(Field)               _DMA_DMGFR_FGET(3,##Field)
  #define _DMA_DMGFR3_FSET(Field,Val)           _DMA_DMGFR_FSET(3,##Field,Val)
  #define _DMA_DMGFR3_FSETS(Field,Sym)          _DMA_DMGFR_FSETS(3,##Field,Sym)
  #define _DMA_DMGFR3_FAOI(Field,AND,OR,INV)    _DMA_DMGFR_FAOI(3,##Field,AND,OR,INV)
  #define _DMA_DMGFR3_CFG(Val)                  _DMA_DMGFR_CFG(3,Val)

  #define _DMA_DMGFR4_GET()                     _DMA_DMGFR_GET(4)
  #define _DMA_DMGFR4_SET(Val)                  _DMA_DMGFR_SET(4,Val)
  #define _DMA_DMGFR4_AOI(AND,OR,INV)           _DMA_DMGFR_AOI(4,AND,OR,INV)
  #define _DMA_DMGFR4_FGET(Field)               _DMA_DMGFR_FGET(4,##Field)
  #define _DMA_DMGFR4_FSET(Field,Val)           _DMA_DMGFR_FSET(4,##Field,Val)
  #define _DMA_DMGFR4_FSETS(Field,Sym)          _DMA_DMGFR_FSETS(4,##Field,Sym)
  #define _DMA_DMGFR4_FAOI(Field,AND,OR,INV)    _DMA_DMGFR_FAOI(4,##Field,AND,OR,INV)
  #define _DMA_DMGFR4_CFG(Val)                  _DMA_DMGFR_CFG(4,Val)

  #define _DMA_DMGFR5_GET()                     _DMA_DMGFR_GET(5)
  #define _DMA_DMGFR5_SET(Val)                  _DMA_DMGFR_SET(5,Val)
  #define _DMA_DMGFR5_AOI(AND,OR,INV)           _DMA_DMGFR_AOI(5,AND,OR,INV)
  #define _DMA_DMGFR5_FGET(Field)               _DMA_DMGFR_FGET(5,##Field)
  #define _DMA_DMGFR5_FSET(Field,Val)           _DMA_DMGFR_FSET(5,##Field,Val)
  #define _DMA_DMGFR5_FSETS(Field,Sym)          _DMA_DMGFR_FSETS(5,##Field,Sym)
  #define _DMA_DMGFR5_FAOI(Field,AND,OR,INV)    _DMA_DMGFR_FAOI(5,##Field,AND,OR,INV)
  #define _DMA_DMGFR5_CFG(Val)                  _DMA_DMGFR_CFG(5,Val)

#else

  #define _DMA_DMGFR_GET()\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR)

  #define _DMA_DMGFR_SET(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR, Val)

  #define _DMA_DMGFR_AOI(AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR, AND, OR, INV)

  #define _DMA_DMGFR_FGET(Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR,\
    _DMA_DMGFR_##Field)

  #define _DMA_DMGFR_FSET(Field,Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR,\
    _DMA_DMGFR_##Field, Val)

  #define _DMA_DMGFR_FSETS(Field,Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR,\
    _DMA_DMGFR_##Field, DMA_DMGFR_##Field##_##Sym)

  #define _DMA_DMGFR_FAOI(Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR,\
    _DMA_DMGFR_##Field, AND, OR, INV)

#define _DMA_DMGFR_CFG(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMGFR_ADDR, Val)

#endif

#if (_DMA_EXT_DATA_SUPPORT)
/*******************************************************************************\
* _DMA_DMSRCDP Extended Data Memory Source Data Page Register
* 
* Fields:
*  _DMA_DMSRCDP_DMSRCDP
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMSRCDP_DMSRCDP: Extended Program Memory Source Data Page
\*----------------------------------------------------------------------------*/
#define _DMA_DMSRCDP_DMSRCDP_SHIFT        (0x0000u)
#define _DMA_DMSRCDP_DMSRCDP_MK(n)        (((Uint16)(n) & 0x003fu)<< _DMA_DMSRCDP_DMSRCDP_SHIFT)
#define _DMA_DMSRCDP_DMSRCDP_MASK         (_DMA_DMSRCDP_DMSRCDP_MK(0x003fu))
#define _DMA_DMSRCDP_DMSRCDP_CLR          (~(_DMA_DMSRCDP_DMSRCDP_MASK))

#if (_DMA_CH_XDP_SUPPORT)
  #define _DMA_DMSRCDP_GET(Chan)\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan))

  #define _DMA_DMSRCDP_SET(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan), Val)

  #define _DMA_DMSRCDP_SETI(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDI_ADDR, __DMSRCDP(Chan), Val)

  #define _DMA_DMSRCDP_AOI(Chan, AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan), AND, OR, INV)

  #define _DMA_DMSRCDP_FGET(Chan, Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan),\
    _DMA_DMSRCDP_##Field)

  #define _DMA_DMSRCDP_FSET(Chan, Field, Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan),\
    _DMA_DMSRCDP_##Field, Val)

  #define _DMA_DMSRCDP_FSETS(Chan, Field, Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan),\
    _DMA_DMSRCDP_##Field, DMA_DMSRCDP_##Field##_##Sym)

  #define _DMA_DMSRCDP_FAOI(Chan, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan),\
    _DMA_DMSRCDP_##Field, AND, OR, INV)

  #define _DMA_DMSRCDP_CFG(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMSRCDP(Chan), Val)
 
  #define _DMA_DMSRCDP0_GET()                     _DMA_DMSRCDP_GET(0)
  #define _DMA_DMSRCDP0_SET(Val)                  _DMA_DMSRCDP_SET(0,Val)
  #define _DMA_DMSRCDP0_AOI(AND,OR,INV)           _DMA_DMSRCDP_AOI(0,AND,OR,INV)
  #define _DMA_DMSRCDP0_FGET(Field)               _DMA_DMSRCDP_FGET(0,##Field)
  #define _DMA_DMSRCDP0_FSET(Field,Val)           _DMA_DMSRCDP_FSET(0,##Field,Val)
  #define _DMA_DMSRCDP0_FSETS(Field,Sym)          _DMA_DMSRCDP_FSETS(0,##Field,Sym)
  #define _DMA_DMSRCDP0_FAOI(Field,AND,OR,INV)    _DMA_DMSRCDP_FAOI(0,##Field,AND,OR,INV)
  #define _DMA_DMSRCDP0_CFG(Val)                  _DMA_DMSRCDP_CFG(0,Val)

  #define _DMA_DMSRCDP1_GET()                     _DMA_DMSRCDP_GET(1)
  #define _DMA_DMSRCDP1_SET(Val)                  _DMA_DMSRCDP_SET(1,Val)
  #define _DMA_DMSRCDP1_AOI(AND,OR,INV)           _DMA_DMSRCDP_AOI(1,AND,OR,INV)
  #define _DMA_DMSRCDP1_FGET(Field)               _DMA_DMSRCDP_FGET(1,##Field)
  #define _DMA_DMSRCDP1_FSET(Field,Val)           _DMA_DMSRCDP_FSET(1,##Field,Val)
  #define _DMA_DMSRCDP1_FSETS(Field,Sym)          _DMA_DMSRCDP_FSETS(1,##Field,Sym)
  #define _DMA_DMSRCDP1_FAOI(Field,AND,OR,INV)    _DMA_DMSRCDP_FAOI(1,##Field,AND,OR,INV)
  #define _DMA_DMSRCDP1_CFG(Val)                  _DMA_DMSRCDP_CFG(1,Val)

  #define _DMA_DMSRCDP2_GET()                     _DMA_DMSRCDP_GET(2)
  #define _DMA_DMSRCDP2_SET(Val)                  _DMA_DMSRCDP_SET(2,Val)
  #define _DMA_DMSRCDP2_AOI(AND,OR,INV)           _DMA_DMSRCDP_AOI(2,AND,OR,INV)
  #define _DMA_DMSRCDP2_FGET(Field)               _DMA_DMSRCDP_FGET(2,##Field)
  #define _DMA_DMSRCDP2_FSET(Field,Val)           _DMA_DMSRCDP_FSET(2,##Field,Val)
  #define _DMA_DMSRCDP2_FSETS(Field,Sym)          _DMA_DMSRCDP_FSETS(2,##Field,Sym)
  #define _DMA_DMSRCDP2_FAOI(Field,AND,OR,INV)    _DMA_DMSRCDP_FAOI(2,##Field,AND,OR,INV)
  #define _DMA_DMSRCDP2_CFG(Val)                  _DMA_DMSRCDP_CFG(2,Val)

  #define _DMA_DMSRCDP3_GET()                     _DMA_DMSRCDP_GET(3)
  #define _DMA_DMSRCDP3_SET(Val)                  _DMA_DMSRCDP_SET(3,Val)
  #define _DMA_DMSRCDP3_AOI(AND,OR,INV)           _DMA_DMSRCDP_AOI(3,AND,OR,INV)
  #define _DMA_DMSRCDP3_FGET(Field)               _DMA_DMSRCDP_FGET(3,##Field)
  #define _DMA_DMSRCDP3_FSET(Field,Val)           _DMA_DMSRCDP_FSET(3,##Field,Val)
  #define _DMA_DMSRCDP3_FSETS(Field,Sym)          _DMA_DMSRCDP_FSETS(3,##Field,Sym)
  #define _DMA_DMSRCDP3_FAOI(Field,AND,OR,INV)    _DMA_DMSRCDP_FAOI(3,##Field,AND,OR,INV)
  #define _DMA_DMSRCDP3_CFG(Val)                  _DMA_DMSRCDP_CFG(3,Val)

  #define _DMA_DMSRCDP4_GET()                     _DMA_DMSRCDP_GET(4)
  #define _DMA_DMSRCDP4_SET(Val)                  _DMA_DMSRCDP_SET(4,Val)
  #define _DMA_DMSRCDP4_AOI(AND,OR,INV)           _DMA_DMSRCDP_AOI(4,AND,OR,INV)
  #define _DMA_DMSRCDP4_FGET(Field)               _DMA_DMSRCDP_FGET(4,##Field)
  #define _DMA_DMSRCDP4_FSET(Field,Val)           _DMA_DMSRCDP_FSET(4,##Field,Val)
  #define _DMA_DMSRCDP4_FSETS(Field,Sym)          _DMA_DMSRCDP_FSETS(4,##Field,Sym)
  #define _DMA_DMSRCDP4_FAOI(Field,AND,OR,INV)    _DMA_DMSRCDP_FAOI(4,##Field,AND,OR,INV)
  #define _DMA_DMSRCDP4_CFG(Val)                  _DMA_DMSRCDP_CFG(4,Val)

  #define _DMA_DMSRCDP5_GET()                     _DMA_DMSRCDP_GET(5)
  #define _DMA_DMSRCDP5_SET(Val)                  _DMA_DMSRCDP_SET(5,Val)
  #define _DMA_DMSRCDP5_AOI(AND,OR,INV)           _DMA_DMSRCDP_AOI(5,AND,OR,INV)
  #define _DMA_DMSRCDP5_FGET(Field)               _DMA_DMSRCDP_FGET(5,##Field)
  #define _DMA_DMSRCDP5_FSETS(Field,Sym)          _DMA_DMSRCDP_FSETS(5,##Field,Sym)
  #define _DMA_DMSRCDP5_FSET(Field,Val)           _DMA_DMSRCDP_FSET(5,##Field,Val)
  #define _DMA_DMSRCDP5_FAOI(Field,AND,OR,INV)    _DMA_DMSRCDP_FAOI(5,##Field,AND,OR,INV)
  #define _DMA_DMSRCDP5_CFG(Val)                  _DMA_DMSRCDP_CFG(5,Val)

#else

  #define _DMA_DMSRCDP_GET()\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR)

  #define _DMA_DMSRCDP_SET(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR, Val)

  #define _DMA_DMSRCDP_AOI(AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR, AND, OR, INV)

  #define _DMA_DMSRCDP_FGET(Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR,\
    _DMA_DMSRCDP_##Field)

  #define _DMA_DMSRCDP_FSET(Field,Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR,\
    _DMA_DMSRCDP_##Field, Val)

  #define _DMA_DMSRCDP_FSETS(Field,Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR,\
    _DMA_DMSRCDP_##Field, DMA_DMSRCDP_##Field##_##Sym)

  #define _DMA_DMSRCDP_FAOI(Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR,\
    _DMA_DMSRCDP_##Field, AND, OR, INV)

  #define _DMA_DMSRCDP_CFG(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMSRCDP_ADDR, Val)

#endif
/*******************************************************************************\
* _DMA_DMDSTDP Extended Progrma Memory Destination Data Page Register
* 
* Fields:
*  _DMA_DMDSTDP_DMDSTDP
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* _DMA_DMDSTDP_DMDSTDP: Extended Data Memory Destination Data Page
\*----------------------------------------------------------------------------*/
#define _DMA_DMDSTDP_DMDSTDP_SHIFT           (0x0000u)
#define _DMA_DMDSTDP_DMDSTDP_MK(n)           (((Uint16)(n) & 0x003fu)<< _DMA_DMDSTDP_DMDSTDP_SHIFT)
#define _DMA_DMDSTDP_DMDSTDP_MASK            (_DMA_DMDSTDP_DMDSTDP_MK(0x003fu))
#define _DMA_DMDSTDP_DMDSTDP_CLR             (~(_DMA_DMDSTDP_DMDSTDP_MASK))

#if (_DMA_CH_XDP_SUPPORT)
  #define _DMA_DMDSTDP_GET(Chan)\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan))

  #define _DMA_DMDSTDP_SET(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan), Val)

  #define _DMA_DMDSTDP_AOI(Chan, AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan), AND, OR, INV)

  #define _DMA_DMDSTDP_FGET(Chan, Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan),\
    _DMA_DMDSTDP_##Field)

  #define _DMA_DMDSTDP_FSET(Chan, Field, Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan),\
    _DMA_DMDSTDP_##Field, Val)

  #define _DMA_DMDSTDP_FSETS(Chan, Field, Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan),\
    _DMA_DMDSTDP_##Field, DMA_DMDSTDP_##Field##_##Sym)

  #define _DMA_DMDSTDP_FAOI(Chan, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan),\
    _DMA_DMDSTDP_##Field, AND, OR, INV)

  #define _DMA_DMDSTDP_CFG(Chan, Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, __DMDSTDP(Chan), Val)
 
  #define _DMA_DMDSTDP0_GET()                     _DMA_DMDSTDP_GET(0)
  #define _DMA_DMDSTDP0_SET(Val)                  _DMA_DMDSTDP_SET(0,Val)
  #define _DMA_DMDSTDP0_AOI(AND,OR,INV)           _DMA_DMDSTDP_AOI(0,AND,OR,INV)
  #define _DMA_DMDSTDP0_FGET(Field)               _DMA_DMDSTDP_FGET(0,##Field)
  #define _DMA_DMDSTDP0_FSET(Field,Val)           _DMA_DMDSTDP_FSET(0,##Field,Val)
  #define _DMA_DMDSTDP0_FSETS(Field,Sym)          _DMA_DMDSTDP_FSETS(0,##Field,Sym)
  #define _DMA_DMDSTDP0_FAOI(Field,AND,OR,INV)    _DMA_DMDSTDP_FAOI(0,##Field,AND,OR,INV)
  #define _DMA_DMDSTDP0_CFG(Val)                  _DMA_DMDSTDP_CFG(0,Val)

  #define _DMA_DMDSTDP1_GET()                     _DMA_DMDSTDP_GET(1)
  #define _DMA_DMDSTDP1_SET(Val)                  _DMA_DMDSTDP_SET(1,Val)
  #define _DMA_DMDSTDP1_AOI(AND,OR,INV)           _DMA_DMDSTDP_AOI(1,AND,OR,INV)
  #define _DMA_DMDSTDP1_FGET(Field)               _DMA_DMDSTDP_FGET(1,##Field)
  #define _DMA_DMDSTDP1_FSET(Field,Val)           _DMA_DMDSTDP_FSET(1,##Field,Val)
  #define _DMA_DMDSTDP1_FSETS(Field,Sym)          _DMA_DMDSTDP_FSETS(1,##Field,Sym)
  #define _DMA_DMDSTDP1_FAOI(Field,AND,OR,INV)    _DMA_DMDSTDP_FAOI(1,##Field,AND,OR,INV)
  #define _DMA_DMDSTDP1_CFG(Val)                  _DMA_DMDSTDP_CFG(1,Val)

  #define _DMA_DMDSTDP2_GET()                     _DMA_DMDSTDP_GET(2)
  #define _DMA_DMDSTDP2_SET(Val)                  _DMA_DMDSTDP_SET(2,Val)
  #define _DMA_DMDSTDP2_AOI(AND,OR,INV)           _DMA_DMDSTDP_AOI(2,AND,OR,INV)
  #define _DMA_DMDSTDP2_FGET(Field)               _DMA_DMDSTDP_FGET(2,##Field)
  #define _DMA_DMDSTDP2_FSET(Field,Val)           _DMA_DMDSTDP_FSET(2,##Field,Val)
  #define _DMA_DMDSTDP2_FSETS(Field,Sym)          _DMA_DMDSTDP_FSETS(2,##Field,Sym)
  #define _DMA_DMDSTDP2_FAOI(Field,AND,OR,INV)    _DMA_DMDSTDP_FAOI(2,##Field,AND,OR,INV)
  #define _DMA_DMDSTDP2_CFG(Val)                  _DMA_DMDSTDP_CFG(2,Val)

  #define _DMA_DMDSTDP3_GET()                     _DMA_DMDSTDP_GET(3)
  #define _DMA_DMDSTDP3_SET(Val)                  _DMA_DMDSTDP_SET(3,Val)
  #define _DMA_DMDSTDP3_AOI(AND,OR,INV)           _DMA_DMDSTDP_AOI(3,AND,OR,INV)
  #define _DMA_DMDSTDP3_FGET(Field)               _DMA_DMDSTDP_FGET(3,##Field)
  #define _DMA_DMDSTDP3_FSET(Field,Val)           _DMA_DMDSTDP_FSET(3,##Field,Val)
  #define _DMA_DMDSTDP3_FSETS(Field,Sym)          _DMA_DMDSTDP_FSETS(3,##Field,Sym)
  #define _DMA_DMDSTDP3_FAOI(Field,AND,OR,INV)    _DMA_DMDSTDP_FAOI(3,##Field,AND,OR,INV)
  #define _DMA_DMDSTDP3_CFG(Val)                  _DMA_DMDSTDP_CFG(3,Val)

  #define _DMA_DMDSTDP4_GET()                     _DMA_DMDSTDP_GET(4)
  #define _DMA_DMDSTDP4_SET(Val)                  _DMA_DMDSTDP_SET(4,Val)
  #define _DMA_DMDSTDP4_AOI(AND,OR,INV)           _DMA_DMDSTDP_AOI(4,AND,OR,INV)
  #define _DMA_DMDSTDP4_FGET(Field)               _DMA_DMDSTDP_FGET(4,##Field)
  #define _DMA_DMDSTDP4_FSET(Field,Val)           _DMA_DMDSTDP_FSET(4,##Field,Val)
  #define _DMA_DMDSTDP4_FSETS(Field,Sym)          _DMA_DMDSTDP_FSETS(4,##Field,Sym)
  #define _DMA_DMDSTDP4_FAOI(Field,AND,OR,INV)    _DMA_DMDSTDP_FAOI(4,##Field,AND,OR,INV)
  #define _DMA_DMDSTDP4_CFG(Val)                  _DMA_DMDSTDP_CFG(4,Val)

  #define _DMA_DMDSTDP5_GET()                     _DMA_DMDSTDP_GET(5)
  #define _DMA_DMDSTDP5_SET(Val)                  _DMA_DMDSTDP_SET(5,Val)
  #define _DMA_DMDSTDP5_AOI(AND,OR,INV)           _DMA_DMDSTDP_AOI(5,AND,OR,INV)
  #define _DMA_DMDSTDP5_FGET(Field)               _DMA_DMDSTDP_FGET(5,##Field)
  #define _DMA_DMDSTDP5_FSET(Field,Val)           _DMA_DMDSTDP_FSET(5,##Field,Val)
  #define _DMA_DMDSTDP5_FSETS(Field,Sym)          _DMA_DMDSTDP_FSETS(5,##Field,Sym)
  #define _DMA_DMDSTDP5_FAOI(Field,AND,OR,INV)    _DMA_DMDSTDP_FAOI(5,##Field,AND,OR,INV)
  #define _DMA_DMDSTDP5_CFG(Val)                  _DMA_DMDSTDP_CFG(5,Val)

#else

  #define _DMA_DMDSTDP_GET()\
    _SUBREG_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR)

  #define _DMA_DMDSTDP_SET(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR, Val)

  #define _DMA_DMDSTDP_AOI(OP, AND, OR, INV)\
    _SUBREG_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR, AND, OR, INV)

  #define _DMA_DMDSTDP_FGET(Field)\
    _SUBFIELD_GET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR,\
    _DMA_DMDSTDP_##Field)

  #define _DMA_DMDSTDP_FSET(Field,Val)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR,\
    _DMA_DMDSTDP_##Field, Val)

  #define _DMA_DMDSTDP_FSETS(Field,Sym)\
    _SUBFIELD_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR,\
    _DMA_DMDSTDP_##Field, DMA_DMDSTDP_##Field##_##Sym)

  #define _DMA_DMDSTDP_FAOI(Field, AND, OR, INV)\
    _SUBFIELD_AOI(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR,\
    _DMA_DMDSTDP_##Field, AND, OR, INV)

#define _DMA_DMDSTDP_CFG(Val)\
    _SUBREG_SET(_DMA_DMSA_ADDR, _DMA_DMSDN_ADDR, _DMA_DMDSTDP_ADDR, Val)

#endif

#endif /* _DMA_EXT_DATA_SUPPORT */


#else
  #ifndef __DMA_MOD_  // _DMA_SUPPORT
    #error DMA HAL Module Not Supported on Specified Target
  #endif
#endif
#endif   // __DMAHAL_
/******************************************************************************\
* End of csl_dmahal.h
\******************************************************************************/
