/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... EBUS
* FILENAME...... ebus.h
* DATE CREATED.. Wed 09/01/1999 
* PROJECT....... MCRTE - multichannel runtime environment
* COMPONENT..... CSL service layer
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   12/01/1999 (KSB) created
*   02/22/2000 (FSCA) C54x Romability .
*------------------------------------------------------------------------------
* DESCRIPTION:  (service layer interface file for the EBUS module)
*
*
*
\******************************************************************************/
#ifndef _EBUS_H_
#define _EBUS_H_

#include <_csl.h>
   
#if (_EBUS_SUPPORT)

#include <csl_ebushal.h>   

/****************************************\
* EBUS scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _EBUS_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* EBUS global typedefs
\****************************************/ 
#if (!((CHIP_5440) | (CHIP_5441)))
 typedef struct {
 Uint16 swwsr;
 Uint16 bscr;
 Uint16 swcr;
 } EBUS_Config;
#else
 typedef struct {
 Uint16 bscr;
 } EBUS_Config;
#endif

/*---------------------------------------*\
* Maros to GET/SET individual registers  
* or bit fields
\*---------------------------------------*/


#if (!(CHIP_5440 | CHIP_5441))
/* SWWSR Macro register */
#define EBUS_SWWSR_RMK(xpa,io,datahi,datalo,proghi,proglo)\
  ((Uint16)( \
    EBUS_FMK(SWWSR,XPA,xpa)|\
    EBUS_FMK(SWWSR,IO,io)|\
    EBUS_FMK(SWWSR,DATAHI,datahi)|\
    EBUS_FMK(SWWSR,DATALO,datalo)|\
    EBUS_FMK(SWWSR,PROGHI,proghi)|\
    EBUS_FMK(SWWSR,PROGLO,proglo) \
  )\
) 

#define EBUS_SWWSR_RMKS(xpa_sym,io_sym,datahi_sym,datalo_sym,\
   proghi_sym,proglo_sym)\
  ((Uint16)( \
    (EBUS_FMKS(SWWSR,XPA,xpa_sym))|\
    (EBUS_FMKS(SWWSR,IO,io_sym))|\
    (EBUS_FMKS(SWWSR,DATAHI,datahi_sym))|\
    (EBUS_FMKS(SWWSR,DATALO,datalo_sym))|\
    (EBUS_FMKS(SWWSR,PROGHI,proghi_sym))|\
    (EBUS_FMKS(SWWSR,PROGLO,proglo_sym)) \
  )\
)                                  
                                 
                   
/* SWCR Macro register */                   
#define EBUS_SWCR_RMK(swsm)\
  ((Uint16)( \
    EBUS_FMK(SWCR,SWSM,swsm)\
  )\
)      
#endif
  
/* BSCR Macro register */    
#if (CHIP_5401 | CHIP_5402 | CHIP_5409 | CHIP_5409A | CHIP_5471)
#define EBUS_BSCR_RMK(bnkcmp,psds,hbh,bh,exio)\
  ((Uint16)( \
    EBUS_FMK(BSCR,BNKCMP,bnkcmp)|\
    EBUS_FMK(BSCR,PSDS,psds)|\
    EBUS_FMK(BSCR,HBH,hbh)|\
    EBUS_FMK(BSCR,BH,bh)|\
    EBUS_FMK(BSCR,EXIO,exio)\
  )\
)
#define EBUS_BSCR_RMKS(bnkcmp_sym,psds_sym,hbh_sym,bh_sym,exio_sym)\
  ((Uint16)( \
    (EBUS_FMKS(BSCR,BNKCMP,bnkcmp_sym))|\
    (EBUS_FMKS(BSCR,PSDS,psds_sym))|\
    (EBUS_FMKS(BSCR,HBH,hbh_sym))|\
    (EBUS_FMKS(BSCR,BH,bh_sym))|\
    (EBUS_FMKS(BSCR,EXIO,exio_sym))\
  )\
)  
  
#define  EBUS_BSCR_DEFAULT              (0xF800u)
#endif  
                                                          
#if (CHIP_5404 | CHIP_5407 | CHIP_5416 | CHIP_5410 | CHIP_5410A)
#define EBUS_BSCR_RMK(consec,divfct,iack,hbh,bh)\
  ((Uint16)( \
    EBUS_FMK(BSCR,CONSEC,consec)|\
    EBUS_FMK(BSCR,DIVFCT,divfct)|\
    EBUS_FMK(BSCR,IACK,iack)|\
    EBUS_FMK(BSCR,HBH,hbh)|\
    EBUS_FMK(BSCR,BH,bh) \
  )\
) 
#define EBUS_BSCR_RMKS(consec_sym,divfct_sym,iack_sym,hbh_sym,bh_sym)\
  ((Uint16)( \
    (EBUS_FMKS(BSCR,CONSEC,consec_sym))|\
    (EBUS_FMKS(BSCR,DIVFCT,divfct_sym))|\
    (EBUS_FMKS(BSCR,IACK,iack_sym))|\
    (EBUS_FMKS(BSCR,HBH,hbh_sym))|\
    (EBUS_FMKS(BSCR,BH,bh_sym)) \
  )\
) 

#define  EBUS_BSCR_DEFAULT              (0xF000u)
#endif

#if (CHIP_54CST | CHIP_5403 | CHIP_5406)
#define EBUS_BSCR_RMK(consec,divfct,iack,daarst,daaclkdv,hbh,bh)\
  ((Uint16)( \
    EBUS_FMK(BSCR,CONSEC,consec)|\
    EBUS_FMK(BSCR,DIVFCT,divfct)|\
    EBUS_FMK(BSCR,IACK,iack)|\
    EBUS_FMK(BSCR,DAARST,daarst)|\
    EBUS_FMK(BSCR,DAACLKDV,daaclkdv)|\
    EBUS_FMK(BSCR,HBH,hbh)|\
    EBUS_FMK(BSCR,BH,bh) \
  )\
) 
#define EBUS_BSCR_RMKS(consec_sym,divfct_sym,iack_sym,daarst_sym,\
                       daaclkdv_sym,hbh_sym,bh_sym)\
  ((Uint16)( \
    (EBUS_FMKS(BSCR,CONSEC,consec_sym))|\
    (EBUS_FMKS(BSCR,DIVFCT,divfct_sym))|\
    (EBUS_FMKS(BSCR,IACK,iack_sym))|\
    (EBUS_FMKS(BSCR,DAARST,daarst_sym))|\
    (EBUS_FMKS(BSCR,DAACLKDV,daaclkdv_sym))|\
    (EBUS_FMKS(BSCR,HBH,hbh_sym))|\
    (EBUS_FMKS(BSCR,BH,bh_sym)) \
  )\
) 

#define  EBUS_BSCR_DEFAULT              (0xF000u)
#endif
                                                      
#if (CHIP_5420 | CHIP_5421)
#define EBUS_BSCR_RMK(bnkcmp,psds,ipirq,bh,exio)\
  ((Uint16)( \
    EBUS_FMK(BSCR,BNKCMP,bnkcmp)|\
    EBUS_FMK(BSCR,PSDS,psds)|\
    EBUS_FMK(BSCR,IPIRQ,ipirq)|\
    EBUS_FMK(BSCR,BH,bh)|\
    EBUS_FMK(BSCR,EXIO,exio)\
  )\
)   
#define EBUS_BSCR_RMKS(bnkcmp_sym,psds_sym,ipirq_sym,bh_sym,exio_sym)\
  ((Uint16)( \
    (EBUS_FMKS(BSCR,BNKCMP,bnkcmp_sym))|\
    (EBUS_FMKS(BSCR,PSDS,psds_sym))|\
    (EBUS_FMKS(BSCR,IPIRQ,ipirq_sym))|\
    (EBUS_FMKS(BSCR,BH,bh_sym))|\
    (EBUS_FMKS(BSCR,EXIO,exio_sym))\
  )\
)   
#define  EBUS_BSCR_DEFAULT               (0xF800u)
#endif

#if (CHIP_5440 | CHIP_5441)
#define EBUS_BSCR_RMK(bhd,bha)\
  ((Uint16) (\
   EBUS_FMK(BSCR,BHD,bhd)|\
   EBUS_FMK(BSCR,BHA,bha)\
   )\
)
#define EBUS_BSCR_RMKS(bhd_sym,bha_sym)\
  ((Uint16) (\
   (EBUS_FMKS(BSCR,BHD,bhd_sym))|\
   (EBUS_FMKS(BSCR,BHA,bha_sym))\
   )\
)

#define  EBUS_BSCR_DEFAULT               (0x0000u)
#endif                                                      
     
/* Default Values for SWWSR and SWCR */     
#define  EBUS_SWWSR_DEFAULT              (0x7FFFu)
#define  EBUS_SWCR_DEFAULT               (0x0000u) 

/* SWWSR field values */
#define    EBUS_SWWSR_XPA_DEFAULT        (0x0000u)
#define    EBUS_SWWSR_XPA_ADDREXT        (0x0001u)     
#define    EBUS_SWWSR_XPA_ADDRLO         (0x0000u)

#define    EBUS_SWWSR_IO_DEFAULT         (0x0007u)
#define    EBUS_SWWSR_IO_OF(x)           ((Uint16)(x))

#define    EBUS_SWWSR_DATAHI_DEFAULT     (0x0007u)
#define    EBUS_SWWSR_DATAHI_OF(x)       ((Uint16)(x))

#define    EBUS_SWWSR_DATALO_DEFAULT     (0x0007u)
#define    EBUS_SWWSR_DATALO_OF(x)       ((Uint16)(x))

#define    EBUS_SWWSR_PROGHI_DEFAULT     (0x0007u)
#define    EBUS_SWWSR_PROGHI_OF(x)       ((Uint16)(x))

#define    EBUS_SWWSR_PROGLO_DEFAULT     (0x0007u)
#define    EBUS_SWWSR_PROGLO_OF(x)       ((Uint16)(x))     

/* BSCR field values  */
/* For 5402 5409 5420 5416 */ 

#define    EBUS_BSCR_BH_DEFAULT          (0x0000u)
#define    EBUS_BSCR_BH_ENABLE           (0x0001u)
#define    EBUS_BSCR_BH_DISABLE          (0x0000u)   

/* For 5402 5409 5420 only*/ 
#define    EBUS_BSCR_BNKCMP_DEFAULT      (0x000Fu)
#define    EBUS_BSCR_BNKCMP_64K          (0x0000u)
#define    EBUS_BSCR_BNKCMP_32K          (0x0008u)                 
#define    EBUS_BSCR_BNKCMP_16K          (0x000Cu) 
#define    EBUS_BSCR_BNKCMP_4K           (0x000Fu) 

#define    EBUS_BSCR_PSDS_DEFAULT        (0x0001u)
#define    EBUS_BSCR_PSDS_NOEXCY         (0x0000u)
#define    EBUS_BSCR_PSDS_INSCY          (0x0001u)

#define    EBUS_BSCR_EXIO_DEFAULT        (0x0000u)
#define    EBUS_BSCR_EXIO_DEFAULT        (0x0000u)
#define    EBUS_BSCR_EXIO_INACTIF        (0x0001u)
#define    EBUS_BSCR_EXIO_NORMAL         (0x0000u)

/*For 5402 5409 5416 only */
#define    EBUS_BSCR_HBH_DEFAULT         (0x0000u)
#define    EBUS_BSCR_HBH_ENABLE          (0x0001u)
#define    EBUS_BSCR_HBH_DISABLE         (0x0000u)

/* For 5420  only */                                          
#define    EBUS_BSCR_IPIRQ_INTR          (0x0001u) 
#define    EBUS_BSCR_IPIRQ_CLR           (0x0000u)   

/* For 5416, 5410, 5410A only */
#define    EBUS_NSCR_CONSEC_DEFAULT      (0x0001u)
#define    EBUS_BSCR_CONSEC_32KFASTREAD  (0x0000u)
#define    EBUS_BSCR_CONSEC_EXTMEM       (0x0001u)

#define    EBUS_BSCR_DIVFCT_DEFAULT      (0x0003u)
#define    EBUS_BSCR_DIVFCT_ZERO         (0x0000u)
#define    EBUS_BSCR_DIVFCT_CLKBYTWO     (0x0001u)
#define    EBUS_BSCR_DIVFCT_CLKBYTHREE   (0x0002u)
#define    EBUS_BSCR_DIVFCT_CLKBYFOUR    (0x0003u)

#define    EBUS_BSCR_IACK_DEFAULT        (0x0000u) 
#define    EBUS_BSCR_IACK_ON             (0x0000u) 
#define    EBUS_BSCR_IACK_OFF            (0x0001u) 


/* For 54CST, 5403, 5406 */

#define EBUS_BSCR_DAARST_RESET           (0x0000u)
#define EBUS_BSCR_DAARST_ENABLE          (0x0001u)
#define EBUS_BSCR_DAARST_DEFAULT         EBUS_BSCR_DAARST_RESET

#define EBUS_BSCR_DAACLKDV_CPURATE       (0x0000u)
#define EBUS_BSCR_DAACLKDV_HALFCPU       (0x0001u)
#define EBUS_BSCR_DAACLKDV_DEFAULT       EBUS_BSCR_DAACLKDV_CPURATE

/* For 5440, 5441 only */
#define EBUS_BSCR_BHA_DEFAULT            (0x0000u)
#define EBUS_BSCR_BHA_ENABLE             (0x0001u)
#define EBUS_BSCR_BHA_DISABLE            (0x0000u)

#define EBUS_BSCR_BHD_DEFAULT            (0x0000u)
#define EBUS_BSCR_BHD_ENABLE             (0x0001u)
#define EBUS_BSCR_BHD_DISABLE            (0x0000u)

/* SWCR field value */
#define    EBUS_SWCR_SWSM_DEFAULT        (0x0000u)
#define    EBUS_SWCR_SWSM_MULTBY2        (0x0001u)
#define    EBUS_SWCR_SWSM_NOMULT         (0x0000u)

/*******************************************\
* EBUS global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area by ebusdata.h */

/* Data definition */
#define Ebus_Initialized           EBUS_SYM(0)
  
/****************************************\ 

* EBUS global typedef declarations
\****************************************/
/* device configuration structure */ 

 
/****************************************\
* EBUS global variable declarations
\****************************************/

/****************************************\
* EBUS global function declarations
\****************************************/

/****************************************\
* EBUS inline function declarations
\****************************************/
IDECL void EBUS_init();        
IDECL void EBUS_config(EBUS_Config *Config);

#if (CHIP_5540)
  IDECL void EBUS_configArgs(Uint16 bscr);
#else
  IDECL void EBUS_configArgs(Uint16 swwsr, Uint16 bscr, Uint16 swcr);
#endif

IDECL void EBUS_getConfig(EBUS_Config *Config);
IDECL void EBUS_reset();      


#ifdef USEDEFS 
/*----------------------------------------------------------------------------*/
IDEF void EBUS_config(EBUS_Config *Config) {

#if (CHIP_5440 | CHIP_5441)
  EBUS_RSET(BSCR, Config->bscr);
#else
  EBUS_RSET(SWWSR,Config->swwsr);
  EBUS_RSET(BSCR,Config->bscr);
  EBUS_RSET(SWCR,Config->swcr);
#endif
}
/*----------------------------------------------------------------------------*/
#if (CHIP_5540)
  IDEF void EBUS_configArgs(Uint16 bscr) 
  {
    EBUS_RSET(BSCR,bscr);
  } 
#else
  IDEF void EBUS_configArgs(Uint16 swwsr, Uint16 bscr , Uint16 swcr) 
  {
    EBUS_RSET(SWWSR,swwsr);
    EBUS_RSET(BSCR,bscr);
    EBUS_RSET(SWCR,swcr);
  } 
#endif
/*----------------------------------------------------------------------------*/
IDEF void EBUS_reset() {  
#if ((CHIP_5440)|(CHIP_5441))
  EBUS_RSET(BSCR,EBUS_BSCR_DEFAULT);
#else    
  EBUS_RSET(SWWSR,EBUS_SWWSR_DEFAULT);
  EBUS_RSET(BSCR,EBUS_BSCR_DEFAULT);
  EBUS_RSET(SWCR,EBUS_SWCR_DEFAULT);
#endif     
  }
/*----------------------------------------------------------------------------*/
IDEF void EBUS_getConfig(EBUS_Config *Config) {
#if ((CHIP_5440) | (CHIP_5441))
  Config->bscr = EBUS_RGET(BSCR);
#else
  Config->swwsr = EBUS_RGET(SWWSR);
  Config->bscr = EBUS_RGET(BSCR);
  Config->swcr = EBUS_RGET(SWCR);
#endif
}
/*----------------------------------------------------------------------------*/
         
#endif /* USEDEFS */

#else
  #ifndef _EBUS_MOD_ /* EBUS_SUPPORT */
    #error EBUS Module Not Supported on Specified Target
  #endif
#endif /* EBUS_SUPPORT */
#endif /* _EBUS_H_ */
/******************************************************************************\
* End of ebus.h
\******************************************************************************/

