/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... EBUS - HAL External Bus Control and Wait State Interface module
* FILENAME...... ebushal.h
* DATE CREATED.. Fri 05/19/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. csl_stdinc.h, csl_chiphal.h
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:        12/1/1999
*   LAST MODIFIED:  06/19/2000
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the External Bus and Wait State control module)
*            
* Registers:
*   SWWSR - software wait state register
*   BSCR  - bank switch control register
*   SWCR  - software wait state control register
*
\******************************************************************************/
#ifndef _CSL_EBUSHAL_H_
#define _CSL_EBUSHAL_H_

#include <csl_chiphal.h>
 
#if (_EBUS_SUPPORT)

/********************************************************\
* EBUS Memory Mapped Addresses
\********************************************************/

#define _EBUS_BASE_ADDR             (_CHIP_PERBASE_ADDR+0x0028u)

#if (!(CHIP_5440 | CHIP_5441))
  #define _EBUS_SWWSR_ADDR          (_EBUS_BASE_ADDR+0x0000u)
  #define _EBUS_SWCR_ADDR           (_EBUS_BASE_ADDR+0x0003u)
#endif

#define _EBUS_BSCR_ADDR             (_EBUS_BASE_ADDR+0x0001u)


/********************************************************\
* HBUS Memory Mapped Registers
\********************************************************/
#if (!(CHIP_5440 | CHIP_5441))
  #define _EBUS_SWWSR               REG16(_EBUS_SWWSR_ADDR)
  #define _EBUS_SWCR			REG16(_EBUS_SWCR_ADDR)
#endif

#define _EBUS_BSCR			REG16(_EBUS_BCSR_ADDR)

#if (!(CHIP_5440) | (CHIP_5441))
  #define _SWWSR                    _EBUS_SWWSR
  #define _SWCR                     _EBUS_SWCR
#endif

#define _BSCR                        _EBUS_BSCR

/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/
#define EBUS_ADDR(Reg)                  _EBUS_##Reg##_ADDR
#define EBUS_RGET(Reg)                  _EBUS_##Reg##_GET()
#define EBUS_RSET(Reg,Val)              _EBUS_##Reg##_SET(Val)
#define EBUS_RAOI(Reg,AND,OR,INV)       _EBUS_##Reg##_AOI(AND,OR,INV)
#define EBUS_FGET(Reg,Field)            _EBUS_##Reg##_##FGET(##Field)
#define EBUS_FSET(Reg,Field,Val)        _EBUS_##Reg##_##FSET(##Field,Val)
#define EBUS_FSETS(Reg,Field,Sym)       _EBUS_FSET(##Reg,##Field,EBUS_##Reg##_##Field##_##Sym)
#define EBUS_FMK(Reg,Field,Val)         _EBUS_##Reg##_##Field##_MK(Val)
#define EBUS_FMKS(Reg,Field,Sym)        _EBUS_FMK(##Reg,##Field,EBUS_##Reg##_##Field##_##Sym)
#define EBUS_FAOI(Reg,Field,AND,OR,INV) _EBUS_##Reg##_##Field##_AOI(AND,OR,INV)

#define _EBUS_BSCR_GET()                _REG_GET(_EBUS_BSCR_ADDR)
#define _EBUS_BSCR_SET(Val)             _REG_SET(_EBUS_BSCR_ADDR,Val)
#define _EBUS_BSCR_RAOI(AND,OR,INV)     _REG_AOI(_EBUS_BSCR_ADDR,AND,OR,INV)
#define _EBUS_BSCR_FGET(Field)          _FIELD_GET(_EBUS_BSCR_ADDR,_EBUS_BSCR_##Field)
#define _EBUS_BSCR_FSET(Field,Val)      _FIELD_SET(_EBUS_BSCR_ADDR,_EBUS_BSCR_##Field,Val)
#define _EBUS_BSCR_FMK(Field,Val)       _EBUS_BSCR_##Field##_MK(Val)
#define _EBUS_BSCR_FMKS(Field,Sym)      _EBUS_BSCR_FMK(##Field,EBUS_BSCR_##Field##_#Sym)
#define _EBUS_BSCR_FAOI(Field,AND,OR,INV)\
  _FIELD_FAOI(_EBUS_BSCR_ADDR,EBUS_BSCR_##Field,AND,OR,INV)			 

#if (!(CHIP_5440 | CHIP_5441))
  #define _EBUS_SWWSR_GET()               _REG_GET(_EBUS_SWWSR_ADDR)
  #define _EBUS_SWWSR_SET(Val)            _REG_SET(_EBUS_SWWSR_ADDR,Val)
  #define _EBUS_SWWSR_AOI(AND,OR,INV)     _REG_AOI(_EBUS_SWWSR_ADDR,AND,OR,INV)
  #define _EBUS_SWWSR_FGET(Field)         _FIELD_GET(_EBUS_SWWSR_ADDR, _EBUS_SWWSR_##Field)
  #define _EBUS_SWWSR_FSET(Field,Val)     _FIELD_SET(_EBUS_SWWSR_ADDR, _EBUS_SWWSR_##Field, Val)
  #define _EBUS_SWWSR_FMK(Field,Val)      _EBUS_SWWSR_##Field##_MK(Val)
  #define _EBUS_SWWSR_FMKS(Field,Sym)     _EBUS_SWWSR_FMK(Field,EBUS_SWWSR_##Field##_#Sym)
  #define _EBUS_SWWSR_FAOI(Field,AND,OR,INV)\
    _FIELD_FAOI(_EBUS_SWWSR_ADDR,_EBUS_SWWSR_##Field,AND,OR,INV)

  #define _EBUS_SWCR_GET()           _REG_GET(_EBUS_SWCR_ADDR)
  #define _EBUS_SWCR_SET(Val)        _REG_SET(_EBUS_SWCR_ADDR,Val)
  #define _EBUS_SWCR_AOI(AND,OR,INV) _REG_AOI(_EBUS_SWCR_ADDR,AND,OR,INV)
  #define _EBUS_SWCR_CFG(swsm)       _REG_SET(_EBUS_SWCR_ADDR, _EBUS_SWCR_SWSM_MK(swsm))
  #define _EBUS_SWCR_FGET(Field)     _FIELD_GET(_EBUS_SWCR_ADDR,_EBUS_SWCR_##Field)
  #define _EBUS_SWCR_FSET(Field,Val) _FIELD_SET(_EBUS_SWCR_ADDR,_EBUS_SWCR_##Field,Val)
  #define _EBUS_SWCR_FMK(Field,Val)  _EBUS_SWCR_##Field##_MK(Val)
  #define _EBUS_SWCR_FMKS(Field,Sym) _EBUS_SWCR_FMK(##Field,EBUS_SWCR_##Field##_#Sym)
  #define _EBUS_SWCR_FAOI(Field,AND,OR,INV)\
    _FIELD_FAOI(_EBUS_SWCR_ADDR,EBUS_SWCR_##Field,AND,OR,INV)			 
#endif

#if (!(CHIP_5440 | CHIP_5441))
/******************************************************************************\
* _EBUS_SWWSR - EBUS software wait state register
*
* Fields:
*  (RW) _EBUS_SWWSR_XPA
*  (RW) _EBUS_SWWSR_IO
*  (RW) _EBUS_SWWSR_DATAHI
*  (RW) _EBUS_SWWSR_DATALO
*  (RW) _EBUS_SWWSR_PROGHI
*  (RW) _EBUS_SWWSR_PROGLO
*
\******************************************************************************/

#define _EBUS_SWWSR_CFG(proglo, proghi, datalo, datahi, io, xpa)\
  _REG_SET(_EBUS_SWWSR_ADDR,\
           (_EBUS_SWWSR_PROGLO_MK(proglo)   |\
            _EBUS_SWWSR_PROGHI_MK(proghi)   |\
            _EBUS_SWWSR_DATALO_MK(datalo)   |\
            _EBUS_SWWSR_DATAHI_MK(datahi)   |\
            _EBUS_SWWSR_IO_MK(io)           |\
            _EBUS_SWWSR_XPA_MK(xpa)         |\
           )\
  )

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWWSR_XPA: Extended program address control bit
\*----------------------------------------------------------------------------*/
#define _EBUS_SWWSR_XPA_SHIFT       (0x000fu)
#define _EBUS_SWWSR_XPA_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_SWWSR_XPA_SHIFT)
#define _EBUS_SWWSR_XPA_MASK         (_EBUS_SWWSR_XPA_MK(1))
#define _EBUS_SWWSR_XPA_CLR         (~(_EBUS_SWWSR_XPA_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWWSR_IO: I/O address space base wait state value
\*----------------------------------------------------------------------------*/
#define _EBUS_SWWSR_IO_SHIFT        (0x000cu)
#define _EBUS_SWWSR_IO_MK(n)        (((Uint16)(n) & 0x0007u)<< _EBUS_SWWSR_IO_SHIFT)
#define _EBUS_SWWSR_IO_MASK         (_EBUS_SWWSR_IO_MK(7))
#define _EBUS_SWWSR_IO_CLR          (~(_EBUS_SWWSR_IO_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWWSR_DATAHI: Base wait state value for DATA address 0x8000-0xffff
\*----------------------------------------------------------------------------*/
#define _EBUS_SWWSR_DATAHI_SHIFT     (0x0009u)
#define _EBUS_SWWSR_DATAHI_MK(n)     (((Uint16)(n) & 0x0007u)<< _EBUS_SWWSR_DATAHI_SHIFT)
#define _EBUS_SWWSR_DATAHI_MASK      (_EBUS_SWWSR_DATAHI_MK(7))
#define _EBUS_SWWSR_DATAHI_CLR       (~(_EBUS_SWWSR_DATAHI_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWWSR_DATALO: Base wait state value for DATA address 0x0000-0x7fff
\*----------------------------------------------------------------------------*/
#define _EBUS_SWWSR_DATALO_SHIFT     (0x0006u)
#define _EBUS_SWWSR_DATALO_MK(n)     (((Uint16)(n) & 0x0007u)<< _EBUS_SWWSR_DATALO_SHIFT)
#define _EBUS_SWWSR_DATALO_MASK      (_EBUS_SWWSR_DATALO_MK(7))
#define _EBUS_SWWSR_DATALO_CLR       (~(_EBUS_SWWSR_DATALO_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWWSR_PROGHI: Base wait state value for PROGRAM address 0x8000-0xffff
\*----------------------------------------------------------------------------*/
#define _EBUS_SWWSR_PROGHI_SHIFT     (0x0003u)
#define _EBUS_SWWSR_PROGHI_MK(n)     (((Uint16)(n) & 0x0007u)<< _EBUS_SWWSR_PROGHI_SHIFT)
#define _EBUS_SWWSR_PROGHI_MASK      (_EBUS_SWWSR_PROGHI_MK(7))
#define _EBUS_SWWSR_PROGHI_CLR       (~(_EBUS_SWWSR_PROGHI_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWWSR_PROGLO: Base wait state value for DATA address 0x0000-0x7fff
\*----------------------------------------------------------------------------*/
#define _EBUS_SWWSR_PROGLO_SHIFT     (0x0000u)
#define _EBUS_SWWSR_PROGLO_MK(n)     (((Uint16)(n) & 0x0007u)<< _EBUS_SWWSR_PROGLO_SHIFT)
#define _EBUS_SWWSR_PROGLO_MASK      (_EBUS_SWWSR_PROGLO_MK(7))
#define _EBUS_SWWSR_PROGLO_CLR       (~(_EBUS_SWWSR_PROGLO_MASK))


/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWWSR
\*----------------------------------------------------------------------------*/   
#endif /* (!(CHIP_5440) | (CHIP_5441)) */	 

#if (CHIP_5401 | CHIP_5402 | CHIP_5409 | CHIP_5471 | CHIP_5472)
/******************************************************************************\
* _EBUS_BSCR - Bank switching control register
*
* Fields:
*  (RW) _EBUS_BSCR_BNKCMP
*  (RW) _EBUS_BSCR_PSDS
*  (RW) _EBUS_BSCR_HBH
*  (RW) _EBUS_BSCR_BH
*  (RW) _EBUS_BSCR_EXIO
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_BNKCMP: Bank compare - determines external memory bank size
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_BNKCMP_SHIFT       (0x000cu)
#define _EBUS_BSCR_BNKCMP_MK(n)     (((Uint16)(n) & 0x000fu)<< _EBUS_BSCR_BNKCMP_SHIFT)
#define _EBUS_BSCR_BNKCMP_MASK         (_EBUS_BSCR_BNKCMP_MK(0x000fu))
#define _EBUS_BSCR_BNKCMP_CLR         (~(_EBUS_BSCR_BNKCMP_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_PSDS: Insert cycles between program access and data access
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_PSDS_SHIFT       (0x000bu)
#define _EBUS_BSCR_PSDS_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_PSDS_SHIFT)
#define _EBUS_BSCR_PSDS_MASK         (_EBUS_BSCR_PSDS_MK(1))
#define _EBUS_BSCR_PSDS_CLR         (~(_EBUS_BSCR_PSDS_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_HBH: HPI Bus Holder
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_HBH_SHIFT       (0x0002u)
#define _EBUS_BSCR_HBH_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_HBH_SHIFT)
#define _EBUS_BSCR_HBH_MASK         (_EBUS_BSCR_HBH_MK(1))
#define _EBUS_BSCR_HBH_CLR         (~(_EBUS_BSCR_HBH_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_BH: Bus Holder
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_BH_SHIFT       (0x0001u)
#define _EBUS_BSCR_BH_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_BH_SHIFT)
#define _EBUS_BSCR_BH_MASK         (_EBUS_BSCR_BH_MK(1))
#define _EBUS_BSCR_BH_CLR         (~(_EBUS_BSCR_BH_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_EXIO: Enable/disable external bus
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_EXIO_SHIFT       (0x0000u)
#define _EBUS_BSCR_EXIO_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_EXIO_SHIFT)
#define _EBUS_BSCR_EXIO_MASK         (_EBUS_BSCR_EXIO_MK(1))
#define _EBUS_BSCR_EXIO_CLR         (~(_EBUS_BSCR_EXIO_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR: Register GET/SET & CFG Macros
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_CFG(exio, bh, hbh, psds, bnkcmp) |\
   _REG_SET(_EBUS_BSCR_ADDR, |\
            (_EBUS_BSCR_EXIO_MK(exio)     |\
             _EBUS_BSCR_BH_MK(bh)         |\
             _EBUS_BSCR_HBH_MK(hbh)       |\
             _EBUS_BSCR_PSDS_MK(psds)     |\
             _EBUS_BSCR_BNKCMP_MK(bnkcmp) |\
            )\
           )

#endif /* CHIP_5402 | CHIP_5409 | CHIP_5472 */

#if (CHIP_5410 | CHIP_5416 | CHIP_54CST | CHIP_5406 | CHIP_5403 | CHIP_5404 | CHIP_5407)
/******************************************************************************\
* _EBUS_BSCR - Bank switching control register
*
* Fields:
*  (RW) _EBUS_BSCR_CONSEC
*  (RW) _EBUS_BSCR_DIVFCT
*  (RW) _EBUS_BSCR_IACK
*  (RW) _EBUS_BSCR_HBH
*  (RW) _EBUS_BSCR_BH
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_CONSEC: Enable/disable consecutive bank switching
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_CONSEC_SHIFT       (0x000fu)
#define _EBUS_BSCR_CONSEC_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_CONSEC_SHIFT)
#define _EBUS_BSCR_CONSEC_MASK         (_EBUS_BSCR_CONSEC_MK(1))
#define _EBUS_BSCR_CONSEC_CLR         (~(_EBUS_BSCR_CONSEC_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_DIVFCT: Clkout divide down factor
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_DIVFCT_SHIFT       (0x000du)
#define _EBUS_BSCR_DIVFCT_MK(n)     (((Uint16)(n) & 0x0003u)<< _EBUS_BSCR_DIVFCT_SHIFT)
#define _EBUS_BSCR_DIVFCT_MASK         (_EBUS_BSCR_DIVFCT_MK(3))
#define _EBUS_BSCR_DIVFCT_CLR         (~(_EBUS_BSCR_DIVFCT_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_IACK: Enable/disable IACK signal
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_IACK_SHIFT       (0x000cu)
#define _EBUS_BSCR_IACK_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_IACK_SHIFT)
#define _EBUS_BSCR_IACK_MASK         (_EBUS_BSCR_IACK_MK(1))
#define _EBUS_BSCR_IACK_CLR         (~(_EBUS_BSCR_IACK_MASK))

#if (CHIP_54CST | CHIP_5403 | CHIP_5406)
/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_DAARST: DAA Reset
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_DAARST_SHIFT       (0x0004u)
#define _EBUS_BSCR_DAARST_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_DAARST_SHIFT)
#define _EBUS_BSCR_DAARST_MASK         (_EBUS_BSCR_DAARST_MK(1))
#define _EBUS_BSCR_DAARST_CLR         (~(_EBUS_BSCR_DAARST_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_DAACLKDV: DAA Clock Divide
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_DAACLKDV_SHIFT       (0x0003u)
#define _EBUS_BSCR_DAACLKDV_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_DAACLKDV_SHIFT)
#define _EBUS_BSCR_DAACLKDV_MASK         (_EBUS_BSCR_DAACLKDV_MK(1))
#define _EBUS_BSCR_DAACLKDV_CLR         (~(_EBUS_BSCR_DAACLKDV_MASK))

#endif

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_HBH: HPI Bus Holder
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_HBH_SHIFT       (0x0002u)
#define _EBUS_BSCR_HBH_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_HBH_SHIFT)
#define _EBUS_BSCR_HBH_MASK         (_EBUS_BSCR_HBH_MK(1))
#define _EBUS_BSCR_HBH_CLR         (~(_EBUS_BSCR_HBH_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_BH: Bus Holder
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_BH_SHIFT       (0x0001u)
#define _EBUS_BSCR_BH_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_BH_SHIFT)
#define _EBUS_BSCR_BH_MASK         (_EBUS_BSCR_BH_MK(1))
#define _EBUS_BSCR_BH_CLR         (~(_EBUS_BSCR_BH_MASK))


/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR: Register GET/SET & CFG Macros
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_CFG(bh, hbh, iack, divfct, consec) |\
   _REG_SET(_EBUS_BSCR_ADDR, |\
            (_EBUS_BSCR_BH_MK(bh)            |\
             _EBUS_BSCR_HBH_MK(hbh)          |\
             _EBUS_BSCR_IACK_MK(iack)  |\
             _EBUS_BSCR_DIVFCT_MK(divfct)    |\
             _EBUS_BSCR_CONSEC_MK(consec)    |\
            )\
           )

#endif /* CHIP_5410 | CHIP_5416 */

#if (CHIP_5420) | (CHIP_5421)
/******************************************************************************\
* _EBUS_BSCR - Bank switching control register
*
* Fields:
*  (RW) _EBUS_BSCR_BNKCMP
*  (RW) _EBUS_BSCR_PSDS
*  (RW) _EBUS_BNKCMP_IPIRQ
*  (RW) _EBUS_BSCR_HBH
*  (RW) _EBUS_BSCR_BH
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_BNKCMP: Bank compare - determines external memory bank size
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_BNKCMP_SHIFT      (0x000cu)
#define _EBUS_BSCR_BNKCMP_MK(n)      (((Uint16)(n) & 0x000fu)<< _EBUS_BSCR_BNKCMP_SHIFT)
#define _EBUS_BSCR_BNKCMP_MASK       (_EBUS_BSCR_BNKCMP_MK(0x000fu))
#define _EBUS_BSCR_BNKCMP_CLR        (~(_EBUS_BSCR_BNKCMP_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_PSDS: Insert cycles between program access and data access
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_PSDS_SHIFT        (0x000bu)
#define _EBUS_BSCR_PSDS_MK(n)        (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_PSDS_SHIFT)
#define _EBUS_BSCR_PSDS_MASK         (_EBUS_BSCR_PSDS_MK(1))
#define _EBUS_BSCR_PSDS_CLR          (~(_EBUS_BSCR_PSDS_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_IPIRQ: Assert interprocessor interrupt
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_IPIRQ_SHIFT       (0x0008u)
#define _EBUS_BSCR_IPIRQ_MK(n)       (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_IPIRQ_SHIFT)
#define _EBUS_BSCR_IPIRQ_MASK        (_EBUS_BSCR_IPIRQ_MK(1))
#define _EBUS_BSCR_IPIRQ_CLR         (~(_EBUS_BSCR_IPIRQ_MASK))


/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_HBH: HPI Bus Holder
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_HBH_SHIFT         (0x0002u)
#define _EBUS_BSCR_HBH_MK(n)         (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_HBH_SHIFT)
#define _EBUS_BSCR_HBH_MASK          (_EBUS_BSCR_HBH_MK(1))
#define _EBUS_BSCR_HBH_CLR           (~(_EBUS_BSCR_HBH_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_BH: Bus Holder
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_BH_SHIFT          (0x0001u)
#define _EBUS_BSCR_BH_MK(n)          (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_BH_SHIFT)
#define _EBUS_BSCR_BH_MASK           (_EBUS_BSCR_BH_MK(1))
#define _EBUS_BSCR_BH_CLR            (~(_EBUS_BSCR_BH_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_EXIO: Enable/disable external bus
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_EXIO_SHIFT       (0x0000u)
#define _EBUS_BSCR_EXIO_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_EXIO_SHIFT)
#define _EBUS_BSCR_EXIO_MASK         (_EBUS_BSCR_EXIO_MK(1))
#define _EBUS_BSCR_EXIO_CLR         (~(_EBUS_BSCR_EXIO_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR: Register GET/SET & CFG Macros
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_CFG(bh, hbh, ipirq, psds, bnkcmp, exio) |\
   _REG_SET(_EBUS_BSCR_ADDR, |\
            (_EBUS_BSCR_BH_MK(bh)         |\
             _EBUS_BSCR_HBH_MK(hbh)       |\
             _EBUS_BSCR_IPIRQ_MK(ipirq)   |\
             _EBUS_BSCR_PSDS_MK(psds)     |\
             _EBUS_BSCR_BNKCMP_MK(bnkcmp) |\
             _EBUS_BSCR_EXIO_MK(exio)\
            )\
           )

#endif /* CHIP_5420 */ 

#if ((CHIP_5440) | (CHIP_5441))
/******************************************************************************\
* _EBUS_BSCR - Bank switching control register
*
* Fields:
*  (RW) _EBUS_BSCR_BHD
*  (RW) _EBUS_BSCR_BHA
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_BHD: HPI Data Bus Hold
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_BHD_SHIFT            (0x0002u)
#define _EBUS_BSCR_BHD_MK(n)            (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_BHD_SHIFT)
#define _EBUS_BSCR_BHD_MASK             (_EBUS_BSCR_BHD_MK(0x0001u))
#define _EBUS_BSCR_BHD_CLR              (~(_EBUS_BSCR_BHD_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _EBUS_BSCR_BHA: HPI Address Bus Hold
\*----------------------------------------------------------------------------*/
#define _EBUS_BSCR_BHA_SHIFT            (0x0001u)
#define _EBUS_BSCR_BHA_MK(n)            (((Uint16)(n) & 0x0001u)<< _EBUS_BSCR_BHA_SHIFT)
#define _EBUS_BSCR_BHA_MASK             (_EBUS_BSCR_BHA_MK(0x0001u))
#define _EBUS_BSCR_BHA_CLR              (~(_EBUS_BSCR_BHA_MASK))

#endif /* CHIP_5440 */

#if (!(CHIP_5440 | CHIP_5441))
/******************************************************************************\
* _EBUS_SWCR - EBUS software wait state register
*
* Fields:
*  (RW) _EBUS_SWCR_SWSM
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWCR_SWSM: Software wait state multiplier
\*----------------------------------------------------------------------------*/
#define _EBUS_SWCR_SWSM_SHIFT       (0x0000u)
#define _EBUS_SWCR_SWSM_MK(n)     (((Uint16)(n) & 0x0001u)<< _EBUS_SWCR_SWSM_SHIFT)
#define _EBUS_SWCR_SWSM_MASK         (_EBUS_SWCR_SWSM_MK(1))
#define _EBUS_SWCR_SWSM_CLR         (~(_EBUS_SWCR_SWSM_MASK))

#define _EBUS_SWCR_SWSM_GET(RegAddr)\
  _FIELD_GET(RegAddr, _EBUS_SWCR_SWSM)

#define _EBUS_SWCR_SWSM_SET(RegAddr, Val)\
  _FIELD_SET(RegAddr, _EBUS_SWCR_SWSM, Val)
                                 
/*----------------------------------------------------------------------------*\
* (RW) _EBUS_SWCR
\*----------------------------------------------------------------------------*/   
#endif /* (!CHIP_5440) */
                                 
#else
  #ifndef _EBUS_MOD_  /* EBUS_SUPPORT */
    #error EBUS HAL Module Not Supported on Specified Target
  #endif
#endif  /* EBUS_SUPPORT */

#endif  /* _CSL_EBUSHAL_H */
/******************************************************************************\
* End of csl_ebushal.h
\******************************************************************************/
