/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... ERR
* FILENAME...... err.h
* DATE CREATED.. Tue 06/22/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... 
* PREREQUISITS.. csl_stdinc.h, csl_chiphal.h, csl.h
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:        06/22/1999  Created
*   MODIFIED:       02/12/2000  C54x romability
*   MODIFIED:       06/19/2000
*   LAST MODIFIED:  06/10/2001 Modified for new initialization model  
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the ERR module)
*
*
*
\******************************************************************************/
#ifndef _CSL_ERR_H_
#define _CSL_ERR_H_

#include <csl_chiphal.h>

#if (_ERR_SUPPORT)

#include <_csl.h>

/****************************************\
* ERR scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _ERR_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS 
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/****************************************\
* ERR global macro declarations
\****************************************/   

#define ERR_BASE_DAT   0x00000001
#define ERR_BASE_DMA   0x00000002
#define ERR_BASE_EDMA  0x00000003
#define ERR_BASE_MCBSP 0x00000004
#define ERR_BASE_TIMER 0x00000005 
#define ERR_BASE_PWR   0x00000006
#define ERR_BASE_GPIO  0x00000007
#define ERR_BASE_PLL   0x00000008
#define ERR_BASE_WDTIM 0x00000009

#define ERR_BASE_USER  0x80000000

/****************************************\
* ERR global typedef declarations
\****************************************/

/*******************************************\
* ERR global macro definition : ROMABILITY
\*******************************************/ 
/* Reserved ROM Area for Err Data */

/* ErrFunc is " type" : 32bit Address */
/****************************************\
* ERR global variable declarations
\****************************************/

/****************************************\
* ERR global function declarations
\****************************************/
IDECL  void   ERR_defaultHandler(Uint32 Major, Uint32 Minor);
IDECL  void   ERR_installHandler(ERR_Handler Handler);
IDECL  void   ERR_submit(Uint32 Major, Uint32 Minor);
IDECL  Uint16 ERR_getCount();
IDECL  void   ERR_init();

/****************************************\
* ERR inline function declarations
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
IDEF void ERR_defaultHandler(Uint32 Major, Uint32 Minor) {
  UNREFERENCED_PARAMETER(Major);
  UNREFERENCED_PARAMETER(Minor);
}
/*----------------------------------------------------------------------------*/
IDEF void ERR_init() {
 CSL_ERR_DATA.ErrCnt=0;  
 CSL_ERR_DATA.ErrFuncPtr = (Uint32)ERR_defaultHandler;    
}
/*----------------------------------------------------------------------------*/
 IDEF Uint16 ERR_getCount() {
  return CSL_ERR_DATA.ErrCnt;
}
/*----------------------------------------------------------------------------*/
/* ErrFunc ponts the user's ErrHandler function */
IDEF void ERR_installHandler(ERR_Handler Handler) {
   CSL_ERR_DATA.ErrFuncPtr = (Uint32)Handler;
}
/*----------------------------------------------------------------------------*/
IDEF void ERR_submit(Uint32 Major, Uint32 Minor) {
   ++(CSL_ERR_DATA.ErrCnt);
  (*(ERR_Handler)(CSL_ERR_DATA.ErrFuncPtr))(Major,Minor); 
}

#endif /* USEDEFS */
/****************************************\
* ERR inline function definitions
\****************************************/

#else
  #ifndef _ERR_MOD_ /* ERR_SUPPORT */
    #error ERR Module Not Supported on Specified Target
  #endif
#endif /* ERR_SUPPORT */

#endif /* _CSL_ERR_H_ */
/******************************************************************************\
* End of csl_err.h
\******************************************************************************/

