/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... GPIO
* FILENAME...... csl_gpiohal.h
* DATE CREATED.. Sun 06/20/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. csl_stdinc.h, csl_stdinch.h, csl_chiphal.h
* VERSION....... 1.00 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:  06/20/1999 
*   MODIFIED: 01/26/2000 modified for TMS320C54xx
*   MODIFIED: 06/19/2000
*   MODIFIED: 08/2001    fixed shift vale for DAT fields
*   MODIFIED: 02/12/2002 fixed RSET/RGET address problems added missing
*                        XXF/XBIO and CLKOUT1/CLKOUT2 fields
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the GPIO module)
*
* Registers Covered:
*   (RW) _GPIO_GPIO - General purpose I/O control and data register
*
\******************************************************************************/
#ifndef _CSL_GPIOHAL_H_
#define _CSL_GPIOHAL_H_

#include <csl_chiphal.h>


#if (_GPIO_SUPPORT)

    /******************************************************************************\
    * _GPIO_GPIO - General purpose I/O status register (Currently 5440/5441 Only)
    *
    * Fields:
    *   (RW) _GPIO_GPIO_TOUT
    *   (RW) _GPIO_GPIO_DIR0 
    *   (RW) _GPIO_GPIO_DIR1        
    *   (RW) _GPIO_GPIO_DIR2        
    *   (RW) _GPIO_GPIO_DIR3               
    *   (RW) _GPIO_GPIO_DAT0
    *   (RW) _GPIO_GPIO_DAT1
    *   (RW) _GPIO_GPIO_DAT2
    *   (RW) _GPIO_GPIO_DAT3
    \******************************************************************************/
    #define _GPIO_GPIO_ADDR          (0x003Cu)
    #define _GPIO_GPIO               (REG16(_GPIO_GPIO_ADDR))
    #define _GPIO                     _GPIO_GPIO

    #define GPIO_ADDR(Reg)                  _GPIO_##Reg##_ADDR
    #define GPIO_RGET(Reg)                  _REG_GET(_GPIO_##Reg##_ADDR)
    #define GPIO_RSET(Reg,Val)              _REG_SET(_GPIO_##Reg##_ADDR, Val)
    #define GPIO_RAOI(Reg,AND,OR,INV)       _REG_AOI(_GPIO_##Reg##_ADDR,AND,OR,INV)
    #define GPIO_FGET(Reg,Field)            _FIELD_GET(_GPIO_##Reg##_ADDR,_GPIO_##Reg##_##Field)
    #define GPIO_FSET(Reg,Field,Val)        _FIELD_SET(_GPIO_##Reg##_ADDR,_GPIO_##Reg##_##Field,Val)
    #define GPIO_FSETS(Reg,Field,Sym)       GPIO_FSET(##Reg,##Field,GPIO_##Reg##_##Field##_##Sym)
    #define GPIO_FAOI(Reg,Field,AND,OR,INV)\
      _FIELD_FAOI(_GPIO_##Reg##_ADDR, _GPIO_##Reg##_##Field, AND, OR, INV)
    #define GPIO_FMK(Reg,Field,Val)         _GPIO_##Reg##_##Field##_MK(Val)
    #define GPIO_FMKS(Reg,Field,Sym)        GPIO_FMK(##Reg,##Field,GPIO_##Reg##_##Field##_##Sym)

    #define _GPIO_GPIO_GET()            _REG_GET(_GPIO_GPIO_ADDR)   
    #define _GPIO_GPIO_SET(Val)         _REG_SET(_GPIO_GPIO_ADDR,Val)
    #define _GPIO_GPIO_AOI(AND,OR,INV)  _REG_AOI(_GPIO_GPIO_ADDR,AND,OR,INV)
    #define _GPIO_GPIO_FGET(Field)      _FIELD_GET(_GPIO_GPIO_ADDR,_GPIO_GPIO_##Field)
    #define _GPIO_GPIO_FSET(Field,Val)  _FIELD_SET(_GPIO_GPIO_ADDR,_GPIO_GPIO_##Field,Val)
    #define _GPIO_GPIO_FSETS(Field,Val) _GPIO_GPIO_FSET(##Field,GPIO_GPIO_#Field##_##Sym)
    #define _GPIO_GPIO_FAOI(Field,AND,OR,INV)\
       _FIELD_FAOI(_GPIO_GPIO_ADDR,_GPIO_GPIO_##Field,AND,OR,INV)

    #define _GPIO_GPIO_CFG(tout, dir3, dir2, dir1, dir0)\
     _REG_SET(_GPIO_GPIO_ADDR,\
              (_GPIO_GPIO_TOUT_MK(tout)   |\
               _GPIO_GPIO_DIR3_MK(dir3)   |\
               _GPIO_GPIO_DIR2_MK(dir2)   |\
               _GPIO_GPIO_DIR1_MK(dir1)   |\
               _GPIO_GPIO_DIR0_MK(dir0)\
              )\
     )

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_TOUT: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_TOUT_SHIFT            (0x000Fu)
    #define _GPIO_GPIO_TOUT_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_TOUT_SHIFT)
    #define _GPIO_GPIO_TOUT_MASK             (_GPIO_GPIO_TOUT_MK(0x0001u))
    #define _GPIO_GPIO_TOUT_CLR              (~(_GPIO_GPIO_TOUT_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_XBIO: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_XBIO_SHIFT            (0x000Du)
    #define _GPIO_GPIO_XBIO_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_XBIO_SHIFT)
    #define _GPIO_GPIO_XBIO_MASK             (_GPIO_GPIO_XBIO_MK(0x0001u))
    #define _GPIO_GPIO_XBIO_CLR              (~(_GPIO_GPIO_XBIO_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_XXF: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_XXF_SHIFT            (0x000Cu)
    #define _GPIO_GPIO_XXF_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_XXF_SHIFT)
    #define _GPIO_GPIO_XXF_MASK             (_GPIO_GPIO_XXF_MK(0x0001u))
    #define _GPIO_GPIO_XXF_CLR              (~(_GPIO_GPIO_XXF_MASK))


    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DIR3: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DIR3_SHIFT            (0x000Bu)
    #define _GPIO_GPIO_DIR3_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DIR3_SHIFT)
    #define _GPIO_GPIO_DIR3_MASK             (_GPIO_GPIO_DIR3_MK(0x0001u))
    #define _GPIO_GPIO_DIR3_CLR              (~(_GPIO_GPIO_DIR3_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DIR2: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DIR2_SHIFT            (0x000Au)
    #define _GPIO_GPIO_DIR2_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DIR2_SHIFT)
    #define _GPIO_GPIO_DIR2_MASK             (_GPIO_GPIO_DIR2_MK(0x0001u))
    #define _GPIO_GPIO_DIR2_CLR              (~(_GPIO_GPIO_DIR2_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DIR1: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DIR1_SHIFT            (0x0009u)
    #define _GPIO_GPIO_DIR1_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DIR1_SHIFT)
    #define _GPIO_GPIO_DIR1_MASK             (_GPIO_GPIO_DIR1_MK(0x0001u))
    #define _GPIO_GPIO_DIR1_CLR              (~(_GPIO_GPIO_DIR1_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_CLKOUT1: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_CLKOUT1_SHIFT            (0x0007u)
    #define _GPIO_GPIO_CLKOUT1_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_CLKOUT1_SHIFT)
    #define _GPIO_GPIO_CLKOUT1_MASK             (_GPIO_GPIO_CLKOUT1_MK(0x0001u))
    #define _GPIO_GPIO_CLKOUT1_CLR              (~(_GPIO_GPIO_CLKOUT1_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_CLKOUT2: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_CLKOUT2_SHIFT            (0x0006u)
    #define _GPIO_GPIO_CLKOUT2_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_CLKOUT2_SHIFT)
    #define _GPIO_GPIO_CLKOUT2_MASK             (_GPIO_GPIO_CLKOUT2_MK(0x0001u))
    #define _GPIO_GPIO_CLKOUT2_CLR              (~(_GPIO_GPIO_CLKOUT2_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DIR0: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DIR0_SHIFT            (0x0008u)
    #define _GPIO_GPIO_DIR0_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DIR0_SHIFT)
    #define _GPIO_GPIO_DIR0_MASK             (_GPIO_GPIO_DIR0_MK(0x0001u))
    #define _GPIO_GPIO_DIR0_CLR              (~(_GPIO_GPIO_DIR0_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DAT3: Writes/Reads from dat3
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DAT3_SHIFT            (0x0003u)
    #define _GPIO_GPIO_DAT3_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DAT3_SHIFT)
    #define _GPIO_GPIO_DAT3_MASK             (_GPIO_GPIO_DAT3_MK(0x0001u))
    #define _GPIO_GPIO_DAT3_CLR              (~(_GPIO_GPIO_DAT3_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DAT2: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DAT2_SHIFT            (0x0002u)
    #define _GPIO_GPIO_DAT2_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DAT2_SHIFT)
    #define _GPIO_GPIO_DAT2_MASK             (_GPIO_GPIO_DAT2_MK(0x0001u))
    #define _GPIO_GPIO_DAT2_CLR              (~(_GPIO_GPIO_DAT2_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DAT1: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DAT1_SHIFT            (0x0001u)
    #define _GPIO_GPIO_DAT1_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DAT1_SHIFT)
    #define _GPIO_GPIO_DAT1_MASK             (_GPIO_GPIO_DAT1_MK(0x0001u))
    #define _GPIO_GPIO_DAT1_CLR              (~(_GPIO_GPIO_DAT1_MASK))

    /*----------------------------------------------------------------------------*\
    * (RW) _GPIO_GPIO_DAT0: Configures standard timer T0 as output
    \*----------------------------------------------------------------------------*/
    #define _GPIO_GPIO_DAT0_SHIFT            (0x0000u)
    #define _GPIO_GPIO_DAT0_MK(n)            (((Uint16)(n) & 0x0001u) << _GPIO_GPIO_DAT0_SHIFT)
    #define _GPIO_GPIO_DAT0_MASK             (_GPIO_GPIO_DAT0_MK(0x0001u))
    #define _GPIO_GPIO_DAT0_CLR              (~(_GPIO_GPIO_DAT0_MASK))
#else
  #ifndef _GPIO_MOD_ /* GPIO_SUPPORT */
    #error GPIO HAL Module Not Supported on Specified Target
  #endif
#endif /* GPIO_SUPPORT */

#endif /* _CSL_GPIOHAL_H_ */
/******************************************************************************\
* End of csl_gpiohal.h
\******************************************************************************/

