/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... HPI
* FILENAME...... hpi.h
* DATE CREATED.. Wed 09/01/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... CSL service layer
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CRETAED:        09/01/1999 
*   MODIFIED:       12/01/1999 modified for TMS302C54xx
*   MODIFIED:       12/15/1999 Added GIO_init()
*   LAST MODIFIED:  06/19/2000 made file names and #ifdefs consistent, cpluplus compatability
*------------------------------------------------------------------------------
* DESCRIPTION:  (service layer interface file for the HPI module)
\******************************************************************************/
#ifndef _CSL_HPI_H_
#define _CSL_HPI_H_    

#include <csl_chiphal.h>

#if (_HPI_SUPPORT)

#include <_csl.h>
#include <csl_hpihal.h> 

/****************************************\
* HPI scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CSL_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/****************************************\
* HPI global macro declarations
\****************************************/

#define HPI_GPIOSR_IO7_MASK                  ((Uint16)(0x0080)
#define HPI_GPIOSR_IO6_MASK                  ((Uint16)(0x0040)
#define HPI_GPIOSR_IO5_MASK                  ((Uint16)(0x0020)
#define HPI_GPIOSR_IO4_MASK                  ((Uint16)(0x0010)
#define HPI_GPIOSR_IO3_MASK                  ((Uint16)(0x0008)
#define HPI_GPIOSR_IO2_MASK                  ((Uint16)(0x0004)
#define HPI_GPIOSR_IO1_MASK                  ((Uint16)(0x0002)
#define HPI_GPIOSR_IO0_MASK                  ((Uint16)(0x0001)

#if ((CHIP_5402) | (CHIP_5401))
#define HPI_GPIOCR_TOUT1_MASK                ((Uint16)(0x8000)
#endif

#define HPI_GPIOCR_DIR7_MASK                 ((Uint16)(0x0080)
#define HPI_GPIOCR_DIR6_MASK                 ((Uint16)(0x0040)
#define HPI_GPIOCR_DIR5_MASK                 ((Uint16)(0x0020)
#define HPI_GPIOCR_DIR4_MASK                 ((Uint16)(0x0010)
#define HPI_GPIOCR_DIR3_MASK                 ((Uint16)(0x0008)
#define HPI_GPIOCR_DIR2_MASK                 ((Uint16)(0x0004)
#define HPI_GPIOCR_DIR1_MASK                 ((Uint16)(0x0002)
#define HPI_GPIOCR_DIR0_MASK                 ((Uint16)(0x0001)

#define GPIO_GPIOCR_DIR7_I                   (0x0000u)
#define GPIO_GPIOCR_DIR6_I                   (0x0000u)
#define GPIO_GPIOCR_DIR5_I                   (0x0000u)
#define GPIO_GPIOCR_DIR4_I                   (0x0000u)
#define GPIO_GPIOCR_DIR3_I                   (0x0000u)
#define GPIO_GPIOCR_DIR2_I                   (0x0000u)
#define GPIO_GPIOCR_DIR1_I                   (0x0000u)
#define GPIO_GPIOCR_DIR0_I                   (0x0000u)


#define GPIO_GPIOCR_DIR7_O                   (0x0001u)
#define GPIO_GPIOCR_DIR6_O                   (0x0001u)
#define GPIO_GPIOCR_DIR5_O                   (0x0001u)
#define GPIO_GPIOCR_DIR4_O                   (0x0001u)
#define GPIO_GPIOCR_DIR3_O                   (0x0001u)
#define GPIO_GPIOCR_DIR2_O                   (0x0001u)
#define GPIO_GPIOCR_DIR1_O                   (0x0001u)
#define GPIO_GPIOCR_DIR0_O                   (0x0001u)

#define GPIO_GPIOSR_IO7_HI                   (0x0001u)
#define GPIO_GPIOSR_IO6_HI                   (0x0001u)
#define GPIO_GPIOSR_IO5_HI                   (0x0001u)
#define GPIO_GPIOSR_IO4_HI                   (0x0001u)
#define GPIO_GPIOSR_IO3_HI                   (0x0001u)
#define GPIO_GPIOSR_IO2_HI                   (0x0001u)
#define GPIO_GPIOSR_IO1_HI                   (0x0001u)
#define GPIO_GPIOSR_IO0_HI                   (0x0001u)

#define GPIO_GPIOSR_IO7_LO                   (0x0000u)
#define GPIO_GPIOSR_IO6_LO                   (0x0000u)
#define GPIO_GPIOSR_IO5_LO                   (0x0000u)
#define GPIO_GPIOSR_IO4_LO                   (0x0000u)
#define GPIO_GPIOSR_IO3_LO                   (0x0000u)
#define GPIO_GPIOSR_IO2_LO                   (0x0000u)
#define GPIO_GPIOSR_IO1_LO                   (0x0000u)
#define GPIO_GPIOSR_IO0_LO                   (0x0000u)


/*------------------------------------------*\
* Macros to GET/SET register and bit field
* values
\*------------------------------------------*/

#define GPIO_GPIOCR_RMK(dir7, dir6, dir5, dir4, dir3, dir2, dir1, dir0)\
 (Uint16)((HPI_FMK(GPIOCR,DIR7,dir7) |\
          (HPI_FMK(GPIOCR,DIR7,dir6) |\
          (HPI_FMK(GPIOCR,DIR7,dir5) |\
          (HPI_FMK(GPIOCR,DIR7,dir4) |\
          (HPI_FMK(GPIOCR,DIR7,dir3) |\
          (HPI_FMK(GPIOCR,DIR7,dir2) |\
          (HPI_FMK(GPIOCR,DIR7,dir1) |\
          (HPI_FMK(GPIOCR,DIR7,dir0) |\
 )

#define GPIO_GPIOCR_RMKS(dir7, dir6, dir5, dir4, dir3, dir2, dir1, dir0)\
 (Uint16)((HPI_FMKS(GPIOCR,DIR7,dir7) |\
          (HPI_FMKS(GPIOCR,DIR6,dir6) |\
          (HPI_FMKS(GPIOCR,DIR5,dir5) |\
          (HPI_FMKS(GPIOCR,DIR4,dir4) |\
          (HPI_FMKS(GPIOCR,DIR3,dir3) |\
          (HPI_FMKS(GPIOCR,DIR2,dir2) |\
          (HPI_FMKS(GPIOCR,DIR1,dir1) |\
          (HPI_FMKS(GPIOCR,DIR0,dir0) |\
 )

#define GPIO_GPIOSR_RMK(io7, io6, io5, io4, io3, io2, io1, io0)\
 (Uint16)((HPI_FMK(GPIOSR,IO7,io7) |\
          (HPI_FMK(GPIOSR,IO6,io6) |\
          (HPI_FMK(GPIOSR,IO5,io5) |\
          (HPI_FMK(GPIOSR,IO4,io4) |\
          (HPI_FMK(GPIOSR,IO3,io3) |\
          (HPI_FMK(GPIOSR,IO2,io2) |\
          (HPI_FMK(GPIOSR,IO1,io1) |\
          (HPI_FMK(GPIOSR,IO0,io0) |\
 )

#define GPIO_GPIOSR_RMKS(io7, io6, io5, io4, io3, io2, io1, io0)\
 (Uint16)((HPI_FMKS(GPIOSR,IO7,io7) |\
          (HPI_FMKS(GPIOSR,IO6,io6) |\
          (HPI_FMKS(GPIOSR,IO5,io5) |\
          (HPI_FMKS(GPIOSR,IO4,io4) |\
          (HPI_FMKS(GPIOSR,IO3,io3) |\
          (HPI_FMKS(GPIOSR,IO2,io2) |\
          (HPI_FMKS(GPIOSR,IO1,io1) |\
          (HPI_FMKS(GPIOSR,IO0,io0) |\
 )

/*******************************************\
* HPI global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area by hpidata.h */

#define Hpi_Initialized           HPI_SYM(0)

/****************************************\
* HPI global variable declarations
\****************************************/

/****************************************\
* HPI global function declarations
\****************************************/

/****************************************\
* HPI inline function declarations
\****************************************/

/****************************************\
* HPI inline function definitions
\****************************************/
#ifdef USEDEFS
#endif /* USEDEFS */

#else
  #ifndef _HPI_MOD_ /* HPI_SUPPORT */
    #error HPI Module Not Supported on SPecified Target
  #endif
#endif /* HPI_SUPPORT */

#endif /* _CSL_HPI_H_ */
/******************************************************************************\
* End of csl_hpi.h
\******************************************************************************/

