/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... HPI
* FILENAME...... hpihal.h
* DATE CREATED.. Sun 06/20/1999 
* PROJECT....... CSL - Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   06/20/1999 (BWC) Created
*   11/29/1999 (KSB) Modified for TMS320C54xx
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the HPI module)
*
* Registers Covered:
*   (RW) _HPI_HPIC - HPI control register
*   (RW) _HPI_GPIOCR - General purpose I/O control register
*   (RW) _HPI_GPIOSR - General purpose I/O status register
*
\******************************************************************************/
#ifndef _HPIHAL_H_
#define _HPIHAL_H_ 

#include <csl_chiphal.h> 

#if (_HPI_SUPPORT)

#define _HPI_BASE_ADDR       (_CHIP_PERBASE_ADDR+0x02cu)
#define _HPI_HPIC_ADDR       (_HPI_BASE_ADDR+0x0000)
#define _HPI_HPIC            REG16(_HPI_HPIC_ADDR)
#define _HPIC                _HPI_HPIC


/*-----------------------------------------------------------------------------*\
* Register Macros:
\*-----------------------------------------------------------------------------*/
#define HPI_ADDR(Reg)                    _HPI_##Reg##_ADDR
#define HPI_RGET(Reg)                    _HPI_##Reg##_GET()
#define HPI_RSET(Reg,Val)                _HPI_##Reg##_SET(Val)
#define HPI_RAOI(Reg,AND,OR,INV)         _HPI_##Reg##_AOI(AND,OR,INV)
#define HPI_FGET(Reg,Field)              _HPI_##Reg##_FGET(##Field)
#define HPI_FSET(Reg,Field,Val)          _HPI_##Reg##_FSET(##Field,Val)
#define HPI_FAOI(Reg,Fied,AND,OR,INV)    _HPI_##Reg##_FAOI(##Field,AND,OR,INV)
#define HPI_FMK(Reg,Field,Val)           _HPI_##Reg##_##Field##_MK(Val) 
#define HPI_FMKS(Reg,Field,Sym)          _HPI_FMK(##Reg,##Field,HPI_##Reg##_##Field##_##Sym)

/*----------------------------------------------------------------------------*\
* Register Macros
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_GET()                  _REG_GET(_HPI_HPIC_ADDR)
#define _HPI_HPIC_SET(Val)               _REG_SET(_HPI_HPIC_ADDR, Val)
#define _HPI_HPIC_AOI(AND,OR,INV)        _REG_AOI(_HPI_HPIC_ADDR,AND,OR,INV)

#define _HPI_HPIC_FGET(Field)\
  _FIELD_GET(_HPI_HPIC_ADDR, _HPI_HPIC_##Field)

#define _HPI_HPIC_FSET(Field, Val)\
  _FIELD_SET(_HPI_HPIC_ADDR, _HPI_HPIC_##Field, Val)

#define _HPI_HPIC_FAOI(Field, AND, OR, INV)\
  _FIELD_AOI(_HPI_HPIC_ADDR, _HPI_HPIC_##Field, AND, OR, INV)


#if (CHIP_5401 | CHIP_5402 | CHIP_5409 | CHIP_5410 | CHIP_54CST | CHIP_5403 | CHIP_5406 | CHIP_5404 | CHIP_5407) 
/******************************************************************************\
* _HPI_HPIC - HPI control register
*
* Fields:
*   (TR)       _HPI_HPIC_HPIENA
*   (HRW, TR)  _HPI_HPIC_XHPIA
*   (HRW, TRW) _HPI_HPIC_HINT
*   (HW, TR)   _HPI_HPIC_DSPINT
*   (HW)       _HPI_HPIC_BOB
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (HRW, TR) _HPI_HPIC_HPIENA: Host port enabled status pin
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_HPIENA_SHIFT                (0x0007u)
#define _HPI_HPIC_HPIENA_MK(n)              (((Uint16)(n) & 0x0001u) << _HPI_HPIC_HPIENA_SHIFT)
#define _HPI_HPIC_HPIENA_MASK                  (_HPI_HPIC_HPIENA_MK(1))
#define _HPI_HPIC_HPIENA_CLR                  (~(_HPI_HPIC_HPIENA_MASK))

#if (!(CHIP_54CST | CHIP_5406 | CHIP_5403 | CHIP_5404 | CHIP_5407))
/*----------------------------------------------------------------------------*\
* (HRW, TR) _HPI_HPIC_XHPIA : Extended address enable bit
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_XHPIA_SHIFT           (0x0004u)
#define _HPI_HPIC_XHPIA_MK(n)           (((Uint16)(n) & 0x0001u) << _HPI_HPIC_XHPIA_SHIFT)
#define _HPI_HPIC_XHPIA_MASK            (_HPI_HPIC_XHPIA_MK(1))
#define _HPI_HPIC_XHPIA_CLR             (~(_HPI_HPIC_XHPIA_MASK))

#endif
/*----------------------------------------------------------------------------*\
* (HRW, TR) _HPI_HPIC_HINT : Target-to-host interrupt
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_HINT_SHIFT            (0x0003u)
#define _HPI_HPIC_HINT_MK(n)            (((Uint16)(n) & 0x0001u) << _HPI_HPIC_HINT_SHIFT)
#define _HPI_HPIC_HINT_MASK             (_HPI_HPIC_HINT_MK(1))
#define _HPI_HPIC_HINT_CLR              (~(_HPI_HPIC_HINT_MASK))

/*----------------------------------------------------------------------------*\
* (HW, TR) _HPI_HPIC_DSPINT: Host-to-Target interrupt
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_DSPINT_SHIFT           (0x0002u)
#define _HPI_HPIC_DSPINT_MK(n)           (((Uint16)(n) & 0x0001u) << _HPI_HPIC_DSPINT_SHIFT)
#define _HPI_HPIC_DSPINT_MASK            (_HPI_HPIC_DSPINT_MK(1))
#define _HPI_HPIC_DSPINT_CLR                (~(_HPI_HPIC_DSPINT_MASK))

/*----------------------------------------------------------------------------*\
* (HW, TR) _HPI_HPIC_BOB: Hi byte/lo byte tansfer order bit
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_BOB_SHIFT              (0x0000u)
#define _HPI_HPIC_BOB_MK(n)              (((Uint16)(n) & 0x0001u) << _HPI_HPIC_BOB_SHIFT)
#define _HPI_HPIC_BOB_MASK               (_HPI_HPIC_BOB_MK(1))
#define _HPI_HPIC_BOB_CLR                (~(_HPI_HPIC_BOB_MASK))

#endif  /* CHIP_5402 | CHIP_5409 | CHIP_5410*/

#if (CHIP_5416 | CHIP_5420 | CHIP_5421 | CHIP_5440 | CHIP_5441)
/******************************************************************************\
* _HPI_HPIC - HPI control register
*
* Fields:
*   (HRW, TR)  _HPI_HPIC_XHPIA
*   (HW)       _HPI_HPIC_FETCH
*   (HR, TR)   _HPI_HPIC_HRDY
*   (HRW, TRW) _HPI_HPIC_HINT
*   (HW)       _HPI_HPIC_DSPINT       
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (HRW, TR) _HPI_HPIC_XHPIA : Extended address enable bit
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_XHPIA_SHIFT            (0x0005u)
#define _HPI_HPIC_XHPIA_MK(n)            (((Uint16)(n) & 0x0001u) << _HPI_HPIC_XHPIA_SHIFT)
#define _HPI_HPIC_XHPIA_MASK             (_HPI_HPIC_XHPIA_MK(1))
#define _HPI_HPIC_XHPIA_CLR              (~(_HPI_HPIC_XHPIA_MASK))

/*----------------------------------------------------------------------------*\
* (HRW, TR) _HPI_HPIC_FETCH : Host data fetch request
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_FETCH_SHIFT            (0x0004u)
#define _HPI_HPIC_FETCH_MK(n)            (((Uint16)(n) & 0x0001u) << _HPI_HPIC_FETCH_SHIFT)
#define _HPI_HPIC_FETCH_MASK             (_HPI_HPIC_FETCH_MK(1))
#define _HPI_HPIC_FETCH_CLR              (~(_HPI_HPIC_FETCH_MASK))

/*----------------------------------------------------------------------------*\
* (HRW, TR) _HPI_HPIC_HRDY : Data transfer status bit
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_HRDY_SHIFT              (0x0003u)
#define _HPI_HPIC_HRDY_MK(n)              (((Uint16)(n) & 0x0001u) << _HPI_HPIC_HRDY_SHIFT)
#define _HPI_HPIC_HRDY_MASK               (_HPI_HPIC_HRDY_MK(1))
#define _HPI_HPIC_HRDY_CLR                (~(_HPI_HPIC_HRDY_MASK))

/*----------------------------------------------------------------------------*\
* (HRW, TR) _HPI_HPIC_HINT : Target-to-host interrupt
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_HINT_SHIFT              (0x0002u)
#define _HPI_HPIC_HINT_MK(n)              (((Uint16)(n) & 0x0001u) << _HPI_HPIC_HINT_SHIFT)
#define _HPI_HPIC_HINT_MASK               (_HPI_HPIC_HINT_MK(1))
#define _HPI_HPIC_HINT_CLR                (~(_HPI_HPIC_HINT_MASK))

/*----------------------------------------------------------------------------*\
* (HW, TR) _HPI_HPIC_DSPINT: Host-to-Target interrupt
\*----------------------------------------------------------------------------*/
#define _HPI_HPIC_DSPINT_SHIFT            (0x0001u)
#define _HPI_HPIC_DSPINT_MK(n)            (((Uint16)(n) & 0x0001u) << _HPI_HPIC_DSPINT_SHIFT)
#define _HPI_HPIC_DSPINT_MASK             (_HPI_HPIC_DSPINT_MK(1))
#define _HPI_HPIC_DSPINT_CLR              (~(_HPI_HPIC_DSPINT_MASK))

#endif /* (CHIP_5416 | CHIP_5420) */
    
#if (_HPI_GPIO_SUPPORT)
/******************************************************************************\
* _HPI_GPIOCR - General purpose I/O control register, when HPIENA is disabled
*               the HPI can be used for general purpose I/O. This register is
*               used to control the configuration of the 8 data bits.
*
* Fields:
*   (RW)  _HPI_GPIOCR_TOUT1      - available only on 5402
*   (RW)  _HPI_GPIOCR_DIR        - 8 bit field that determines direction i/o
*                                  for each of the HPI data pins.
\******************************************************************************/
#define _HPI_GPIOCR_ADDR            (_HPI_BASE_ADDR+0x0010u)
#define _HPI_GPIOCR                 REG16(_HPI_GPIOCR_ADDR)

#define _HPI_GPIOCR_GET()           _REG_GET(_HPI_GPIOCR_ADDR)
#define _HPI_GPIOCR_SET(Val)        _REG_SET(_HPI_GPIOCR_ADDR,Val)
#define _HPI_GPIOCR_AOI(AND,OR,INV) _REG_AOI(_HPI_GPIOCR_ADDR,AND,OR,INV)
#define _HPI_GPIOCR_FGET(Field)     _FIELD_GET(_HPI_GPIOCR_ADDR,_HPI_GPIOCR_##Field)
#define _HPI_GPIOCR_FSET(Field,Val)\
  _FIELD_SET(_HPI_GPIOCR_ADDR, _HPI_GPIOCR_##Field, Val)

#define _HPI_GPIOCR_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_HPI_GPIOCR_ADDR, _HPI_GPIOCR_##Field, AND, OR, INV)

#if (CHIP_5402) | (CHIP_5401)
  /*----------------------------------------------------------------------------*\
  * (RW) _HPI_GPIOCR_TOUT1: Timer 1 output enable bit (5402|5401 only)
  \*----------------------------------------------------------------------------*/
  #define _HPI_GPIOCR_TOUT1_SHIFT            (0x000Fu)
  #define _HPI_GPIOCR_TOUT1_MK(n)            (((Uint16)(n) & 0x0001u) << _HPI_GPIOCR_TOUT1_SHIFT)
  #define _HPI_GPIOCR_TOUT1_MASK             (_HPI_GPIOCR_TOUT1_MK(1))
  #define _HPI_GPIOCR_TOUT1_CLR              (~(_HPI_GPIOCR_TOUT1_MASK))

#endif  /* CHIP_5402 | CHIP_5401 */

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR_SHIFT              (0x0000u)
#define _HPI_GPIOCR_DIR_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR_SHIFT)
#define _HPI_GPIOCR_DIR_MASK               (_HPI_GPIOCR_DIR_MK(0x00ffu))
#define _HPI_GPIOCR_DIR_CLR                (~(_HPI_GPIOCR_DIR_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR0: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR0_SHIFT              (0x0000u)
#define _HPI_GPIOCR_DIR0_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR0_SHIFT)
#define _HPI_GPIOCR_DIR0_MASK               (_HPI_GPIOCR_DIR0_MK(0x00ffu))
#define _HPI_GPIOCR_DIR0_CLR                (~(_HPI_GPIOCR_DIR0_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR1: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR1_SHIFT              (0x0001u)
#define _HPI_GPIOCR_DIR1_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR1_SHIFT)
#define _HPI_GPIOCR_DIR1_MASK               (_HPI_GPIOCR_DIR1_MK(0x00ffu))
#define _HPI_GPIOCR_DIR1_CLR                (~(_HPI_GPIOCR_DIR1_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR2: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR2_SHIFT              (0x0002u)
#define _HPI_GPIOCR_DIR2_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR2_SHIFT)
#define _HPI_GPIOCR_DIR2_MASK               (_HPI_GPIOCR_DIR2_MK(0x00ffu))
#define _HPI_GPIOCR_DIR2_CLR                (~(_HPI_GPIOCR_DIR2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR3: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR3_SHIFT              (0x0003u)
#define _HPI_GPIOCR_DIR3_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR3_SHIFT)
#define _HPI_GPIOCR_DIR3_MASK               (_HPI_GPIOCR_DIR3_MK(0x00ffu))
#define _HPI_GPIOCR_DIR3_CLR                (~(_HPI_GPIOCR_DIR3_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR4: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR4_SHIFT              (0x0004u)
#define _HPI_GPIOCR_DIR4_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR4_SHIFT)
#define _HPI_GPIOCR_DIR4_MASK               (_HPI_GPIOCR_DIR4_MK(0x00ffu))
#define _HPI_GPIOCR_DIR4_CLR                (~(_HPI_GPIOCR_DIR4_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR5: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR5_SHIFT              (0x0005u)
#define _HPI_GPIOCR_DIR5_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR5_SHIFT)
#define _HPI_GPIOCR_DIR5_MASK               (_HPI_GPIOCR_DIR5_MK(0x00ffu))
#define _HPI_GPIOCR_DIR5_CLR                (~(_HPI_GPIOCR_DIR5_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR6: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR6_SHIFT              (0x0006u)
#define _HPI_GPIOCR_DIR6_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR6_SHIFT)
#define _HPI_GPIOCR_DIR6_MASK               (_HPI_GPIOCR_DIR6_MK(0x00ffu))
#define _HPI_GPIOCR_DIR6_CLR                (~(_HPI_GPIOCR_DIR6_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOCR_DIR7: Determines direction i/o of each data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOCR_DIR7_SHIFT              (0x0007u)
#define _HPI_GPIOCR_DIR7_MK(n)              (((Uint16)(n) & 0x00ffu) << _HPI_GPIOCR_DIR7_SHIFT)
#define _HPI_GPIOCR_DIR7_MASK               (_HPI_GPIOCR_DIR7_MK(0x00ffu))
#define _HPI_GPIOCR_DIR7_CLR                (~(_HPI_GPIOCR_DIR7_MASK))

/******************************************************************************\
* _HPI_GPIOSR - General purpose I/O status register
*
* Fields:
*   (RW)  _HPI_GPIOSR_IO        - 8 bit field that determines status of each 
*                                 of the 8 HPI data pins.
\******************************************************************************/
#define _HPI_GPIOSR_ADDR            (_HPI_BASE_ADDR+0x0011u)
#define _HPI_GPIOSR                 REG16(_HPI_GPIOSR_ADDR)

#define _HPI_GPIOSR_GET()           _REG_GET(_HPI_GPIOSR_ADDR)
#define _HPI_GPIOSR_SET(Val)        _REG_SET(_HPI_GPIOSR_ADDR,Val)
#define _HPI_GPIOSR_AOI(AND,OR,INV) _REG_AOI(_HPI_GPIOSR_ADDR,AND,OR,INV)
#define _HPI_GPIOSR_FGET(Field)     _FIELD_GET(_HPI_GPIOSR_ADDR,_HPI_GPIOSR_##Field)
#define _HPI_GPIOSR_FSET(Field,Val)\
  _FIELD_SET(_HPI_GPIOSR_ADDR, _HPI_GPIOSR_##Field, Val)

#define _HPI_GPIOSR_FAOI(Field,AND,OR,INV)\
  _FIELD_AOI(_HPI_GPIOSR_ADDR, _HPI_GPIOSR_##Field, AND, OR, INV)

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO_SHIFT            (0x0000u)
#define _HPI_GPIOSR_IO_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO_SHIFT)
#define _HPI_GPIOSR_IO_MASK             (_HPI_GPIOSR_IO_MK(0x00ffu))
#define _HPI_GPIOSR_IO_CLR              (~(_HPI_GPIOSR_IO_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO0: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO0_SHIFT            (0x0000u)
#define _HPI_GPIOSR_IO0_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO0_SHIFT)
#define _HPI_GPIOSR_IO0_MASK             (_HPI_GPIOSR_IO0_MK(0x00ffu))
#define _HPI_GPIOSR_IO0_CLR              (~(_HPI_GPIOSR_IO0_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO1_SHIFT            (0x0001u)
#define _HPI_GPIOSR_IO1_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO1_SHIFT)
#define _HPI_GPIOSR_IO1_MASK             (_HPI_GPIOSR_IO1_MK(0x00ffu))
#define _HPI_GPIOSR_IO1_CLR              (~(_HPI_GPIOSR_IO1_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO2_SHIFT            (0x0002u)
#define _HPI_GPIOSR_IO2_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO2_SHIFT)
#define _HPI_GPIOSR_IO2_MASK             (_HPI_GPIOSR_IO2_MK(0x00ffu))
#define _HPI_GPIOSR_IO2_CLR              (~(_HPI_GPIOSR_IO2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO3_SHIFT            (0x0003u)
#define _HPI_GPIOSR_IO3_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO3_SHIFT)
#define _HPI_GPIOSR_IO3_MASK             (_HPI_GPIOSR_IO3_MK(0x00ffu))
#define _HPI_GPIOSR_IO3_CLR              (~(_HPI_GPIOSR_IO3_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO4_SHIFT            (0x0004u)
#define _HPI_GPIOSR_IO4_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO4_SHIFT)
#define _HPI_GPIOSR_IO4_MASK             (_HPI_GPIOSR_IO4_MK(0x00ffu))
#define _HPI_GPIOSR_IO4_CLR              (~(_HPI_GPIOSR_IO4_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO5_SHIFT            (0x0005u)
#define _HPI_GPIOSR_IO5_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO5_SHIFT)
#define _HPI_GPIOSR_IO5_MASK             (_HPI_GPIOSR_IO5_MK(0x00ffu))
#define _HPI_GPIOSR_IO5_CLR              (~(_HPI_GPIOSR_IO5_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO6_SHIFT            (0x0006u)
#define _HPI_GPIOSR_IO6_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO6_SHIFT)
#define _HPI_GPIOSR_IO6_MASK             (_HPI_GPIOSR_IO6_MK(0x00ffu))
#define _HPI_GPIOSR_IO6_CLR              (~(_HPI_GPIOSR_IO6_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _HPI_GPIOSR_IO: Determines status of each HPI data pin
\*----------------------------------------------------------------------------*/
#define _HPI_GPIOSR_IO7_SHIFT            (0x0007u)
#define _HPI_GPIOSR_IO7_MK(n)            (((Uint16)(n) & 0x00ffu) << _HPI_GPIOSR_IO7_SHIFT)
#define _HPI_GPIOSR_IO7_MASK             (_HPI_GPIOSR_IO7_MK(0x00ffu))
#define _HPI_GPIOSR_IO7_CLR              (~(_HPI_GPIOSR_IO7_MASK))


#endif /* HPI_GPIO_SUPPORT */

#if (CHIP_5401 | CHIP_5402 | CHIP_5409 |CHIP_5410)
  #define _HPI_HPIC_CFG(xhpia,hint,dspint,bob)\
  REG16(_HPI_HPIC_ADDR) = (\
    _FIELD_SHIFT(_HPI_HPIC_XHPIA, xhpia)|\
    _FIELD_SHIFT(_HPI_HPIC_DSPINT, dspint)|\
    _FIELD_SHIFT(_HPI_HPIC_HINT, hint)|\
    _FIELD_SHIFT(_HPI_HPIC_BOB, bob)\
  )
#endif

#if (CHIP_5416 | CHIP_5420 | CHIP_5421)
  #define _HPI_HPIC_CFG(dspint, hint)\
  REG16(_HPI_HPIC_ADDR) = (\
    _FIELD_SHIFT(_HPI_HPIC_HPINT, dspint)|\
    _FIELD_SHIFT(_HPI_HPIC_HINT, hint)\
  )
#endif 

/*----------------------------------------------------------------------------*/

#else
  #ifndef _HPI_MOD_ /* HPI_SUPPORT */
    #error HPI HAL Not Supported on Specified Target
  #endif
#endif /* HPI_SUPPORT */

#endif /* _HPIHAL_H_ */
/******************************************************************************\
* End of hpihal.h
\******************************************************************************/

