/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999-2000 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* FILENAME...... csl_irq.h
* DATE CREATED.. 06/09/1999 
*      MODIFIED. 03/08/2000
*      MODIFIED. 07/20/2000
*      LAST MODIFIED: 04/18/2001 updated typedef to avoid conflict with BIOS types
*
\******************************************************************************/
#ifndef _CSL_IRQ_H_
#define _CSL_IRQ_H_


#include <csl_chiphal.h>



#if (_IRQ_SUPPORT)

#include <csl_err.h>
#include <csl_irqhal.h>

/****************************************\
* IRQ scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif 

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _IRQ_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* IRQ global macro declarations
\****************************************/
/* misc global settings */

#define IRQ_GIEROUTINES_IN_ASSEMBLY 0
#define IRQ_EVENT_NOT_MAPPED_ERROR  0x00001u

/*Software Interrupts */
  #define IRQ_EVT_RS         (0 )
  #define IRQ_EVT_SINTR	     (0 ) 
  #define IRQ_EVT_NMI        (1 )
  #define IRQ_EVT_SINT16     (1 ) 
  #define IRQ_EVT_SINT17     (2 )
  #define IRQ_EVT_SINT18     (3 )
  #define IRQ_EVT_SINT19     (4 )
  #define IRQ_EVT_SINT20     (5 )
  #define IRQ_EVT_SINT21     (6 ) 
  #define IRQ_EVT_SINT22     (7 )
  #define IRQ_EVT_SINT23     (8 )
  #define IRQ_EVT_SINT24     (9 )
  #define IRQ_EVT_SINT25     (10)
  #define IRQ_EVT_SINT26     (11)
  #define IRQ_EVT_SINT27     (12)
  #define IRQ_EVT_SINT28     (13)
  #define IRQ_EVT_SINT29     (14)
  #define IRQ_EVT_SINT30     (15) 
  #define IRQ_EVT_SINT0      (16) 
  #define IRQ_EVT_SINT1      (17)  
  #define IRQ_EVT_SINT2      (18)
  #define IRQ_EVT_SINT3      (19)  
  #define IRQ_EVT_SINT5      (21)
  #define IRQ_EVT_SINT4      (20) 
  #define IRQ_EVT_SINT6      (22)  
  #define IRQ_EVT_SINT7      (23)
  #define IRQ_EVT_SINT8      (24) 
  #define IRQ_EVT_SINT9      (25)
  #define IRQ_EVT_SINT10     (26)
  #define IRQ_EVT_SINT11     (27)
  #define IRQ_EVT_SINT12     (28)
  #define IRQ_EVT_SINT13     (29) 
  
  #define IRQ_EVT_INT0       (16)  
  #define IRQ_EVT_INT1       (17) 
  #define IRQ_EVT_INT2       (18)  
  #define IRQ_EVT_INT3       (24)
  
  #define IRQ_EVT_TINT0      (19) 
  #define IRQ_EVT_HINT       (25) 
 
  #define IRQ_EVT_DMAC0      (22) 
  #define IRQ_EVT_DMAC1      (23) 
  #define IRQ_EVT_DMAC2      (26) 
  #define IRQ_EVT_DMAC3      (27)
  #define IRQ_EVT_DMAC4      (28)
  #define IRQ_EVT_DMAC5      (29)  

/* For (CHIP_54CST | CHIP_5403 | CHIP_5406) */
  #define IRQ_EVT_UART       (30)  
  #define IRQ_EVT_DAARCV     (22)  
  #define IRQ_EVT_DAAXMT     (23)

   
/* for  (CHIP_5402 | CHIP_5409 | CHIP_5420) */
   
  #define IRQ_EVT_RINT0     (20)
  #define IRQ_EVT_XINT0     (21) 
  #define IRQ_EVT_RINT2     (22)  
  #define IRQ_EVT_XINT2     (23)

#if (CHIP_5402)
  #define IRQ_EVT_TINT1     (23)
#else
  #define IRQ_EVT_TINT1     (24)
#endif
  
  #define IRQ_EVT_HPINT     (25)   
  #define IRQ_EVT_RINT1     (26) 
  #define IRQ_EVT_XINT1     (27)

/* for  (CHIP_5416 | CHIP_5410 )   */
  #define IRQ_EVT_RINT0      (20)
  #define IRQ_EVT_XINT0      (21)
  #define IRQ_EVT_RINT2      (22)
  #define IRQ_EVT_XINT2      (23)   
  #define IRQ_EVT_RINT1      (26)  
  #define IRQ_EVT_XINT1      (27) 

#if (CHIP_5420) 
  #define IRQ_EVT_IPINT      (30)  
  #define IRQ_EVT_SINT14     (30)
#endif
  
#if (CHIP_5440)
  #define IRQ_EVT_WDTINT     (33)
#endif

  
/* Mask for IMR and IFR */
#define IRQ_MASK_NA (0x0000)
#define IRQ_MASK_00 (0x0001)
#define IRQ_MASK_01 (0x0002)
#define IRQ_MASK_02 (0x0004)
#define IRQ_MASK_03 (0x0008)
#define IRQ_MASK_04 (0x0010)
#define IRQ_MASK_05 (0x0020)
#define IRQ_MASK_06 (0x0040)
#define IRQ_MASK_07 (0x0080)
#define IRQ_MASK_08 (0x0100)
#define IRQ_MASK_09 (0x0200)
#define IRQ_MASK_10 (0x0400)
#define IRQ_MASK_11 (0x0800)
#define IRQ_MASK_12 (0x1000)
#define IRQ_MASK_13 (0x2000)
#define IRQ_MASK_14 (0x4000)
#define IRQ_MASK_15 (0x8000) 

/* Mask For IerMask in Dispatch Config */

#define IRQ_IEMASK_ALL		(0x0000FFFFu)
#define IRQ_IEMASK_SELF       (0x80000000u)
#define IRQ_IEMASK_DEFAULT    IRQ_IEMASK_SELF 

/* Allows to mask the bit "x"*/
/* of IFR or IMR registers */ 
#define IRQ_MASK(x)  (0x1u<<(x))     

#define _IRQ_DISPATCHTBL_CNT   (IRQ_EVENT_CNT+1)
#define _IRQ_EVENT2INTTBL_CNT  (IRQ_EVENT_CNT+1)
#define _IRQ_INT2EVENTTBL_CNT  (IRQ_INT_CNT)

#define IRQ_USER_INT_OFFSET     0x0040u
/****************************************\
* IRQ global typedef declarations
\****************************************/
typedef  void (*IRQ_IsrPtr)(void);

/****************************************\
* IRQ global typedef declarations
\****************************************/
typedef struct {
  IRQ_IsrPtr funcAddr;
  Uint16 funcArg;
  Uint32 ierMask;
} IRQ_Config;

typedef struct {
  Uint16 IsrContent[4];
} IRQ_VecObj;



/****************************************\
* IRQ global variable declarations
\****************************************/

/****************************************\
* IRQ global function declarations
\****************************************/
CSLAPI void _IRQ_dat2Prg(IRQ_IsrPtr PlgArg, Uint16 PlugAddr);
CSLAPI void _IRQ_putVec(Uint32 VecLoc, IRQ_VecObj *vecObj);
CSLAPI void _IRQ_getVec(Uint32 VecLoc, IRQ_VecObj *vecObj);

/****************************************\
* IRQ inline function declarations
\****************************************/
IDECL void    IRQ_clear(Uint16 EventId);
IDECL void    IRQ_config(Uint16 EventId, IRQ_Config *Config);
IDECL void    IRQ_configArgs(Uint16 EventId, IRQ_IsrPtr funcAddr, Uint16 funcArg, Uint32 ierMask);
IDECL int     IRQ_disable(Uint16 EventId);
IDECL int     IRQ_enable(Uint16 EventId);
IDECL void    IRQ_restore(Uint16 EventId, Uint16 val);
IDECL Uint32  IRQ_getArg(Uint16 EventId);
IDECL void    IRQ_getConfig(Uint16 EventId, IRQ_Config *Config);
CSLAPI int    IRQ_globalDisable(void);
CSLAPI int    IRQ_globalEnable(void);
CSLAPI void   IRQ_globalRestore(int gie);
IDECL void    _IRQ_init(Uint16 biosPresent, _IRQ_Dispatch  *dispatch_table);
IDECL void    IRQ_init(void);
IDECL int     IRQ_setVecs(Uint16 iptr);

IDECL void     IRQ_plug(Uint16 EventId, IRQ_IsrPtr funcAddr);
IDECL void     IRQ_getVec(Uint16 EventId, IRQ_VecObj *vecObj);
IDECL void     IRQ_putVec(Uint16 EventId, IRQ_VecObj *vecObj);

IDECL void    IRQ_map(Uint16 EventId);
IDECL void    IRQ_setArg(Uint16 EventId, Uint32 Val);
IDECL CSLBool    IRQ_test(Uint16 EventId);

/****************************************\
* IRQ inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
IDEF void IRQ_plug(Uint16 EventId, IRQ_IsrPtr funcAddr) {   
  Uint16 bit = (EventId-16);
  Uint16 iptr = CHIP_FGET(PMST,IPTR);
  Uint16 VecLoc = ((iptr<<7) | (bit<<2)) + IRQ_USER_INT_OFFSET;  
  Uint16 old_intm;

    old_intm = IRQ_globalDisable();

    _IRQ_dat2Prg(funcAddr, VecLoc);
    _IFR = IRQ_MASK(bit);

    IRQ_globalRestore(old_intm);

}     
/*----------------------------------------------------------------------------*/
  IDEF int IRQ_enable(Uint16 EventId) {
   Uint16 bit;
   int old_flag, old_intm;

   bit=(EventId-16);
   old_flag = (_IMR | (1u << bit)) >> bit; 
   old_intm = IRQ_globalDisable();
   _IMR = _IMR | IRQ_MASK(bit);
   IRQ_globalRestore(old_intm);
   return old_flag;
} 
/*----------------------------------------------------------------------------*/
 IDEF int IRQ_disable(Uint16 EventId) { 
  Uint16 bit;
  int old_flag, old_intm;

  bit=(EventId-16);
  old_intm = IRQ_globalDisable();
  old_flag = (_IMR | (1u << bit)) >> bit;
  _IMR = _IMR & (~(IRQ_MASK(bit))); 
  IRQ_globalRestore(old_intm);
  return old_flag;
} 
/*----------------------------------------------------------------------------*/
  IDEF void IRQ_restore(Uint16 EventId, Uint16 val) {
   Uint16 bit;
   int old_flag, old_intm;

   bit=(EventId-16);
   old_flag = (val << bit); 
   old_intm = IRQ_globalDisable();
   _IMR = _IMR | old_flag;
   IRQ_globalRestore(old_intm);
} 
                                
/*----------------------------------------------------------------------------*/
 IDEF void IRQ_clear(Uint16 EventId) {   
  Uint16 bit, old_intm;

  bit=(EventId-16);
  old_intm = IRQ_globalDisable();
  _IFR = IRQ_MASK(bit);
  IRQ_globalRestore(old_intm);
}     
/*----------------------------------------------------------------------------*/
IDEF CSLBool IRQ_test(Uint16 EventId) {
  Uint16 bit, old_intm;

  bit=(EventId-16); 
  old_intm = IRQ_globalDisable();
  bit = ((_IFR & IRQ_MASK(bit)) != 0);
  IRQ_globalRestore(old_intm);
  return (CSLBool) bit;
}
/*----------------------------------------------------------------------------*/
 IDEF void IRQ_config(Uint16 EventId, IRQ_Config *Config) {
 Uint16 event = (EventId <= 15) ? EventId - 16 : EventId;
 Uint32 iemask;
 int old_intm;

 iemask = Config->ierMask;
 if (iemask == IRQ_IEMASK_SELF)
    iemask = (1u << event);

 old_intm = IRQ_globalDisable();
    CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcAddr = (Uint32)(Config->funcAddr);
    CSL_IRQ_DATA.IrqDispatchTblPtr[event].ierMask = (Uint16)(iemask & 0x0000FFFFu);
    CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcArg = Config->funcArg;
 IRQ_globalRestore(old_intm);
  
}
/*----------------------------------------------------------------------------*/
IDEF void IRQ_configArgs(Uint16 EventId, IRQ_IsrPtr funcAddr, Uint16 funcArg, Uint32 ierMask) {
 Uint16 event = (EventId <= 15) ? EventId - 16 : EventId;
 int old_intm;

    old_intm = IRQ_globalDisable();
    CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcAddr = (Uint32)funcAddr;
    CSL_IRQ_DATA.IrqDispatchTblPtr[event].ierMask = (ierMask == IRQ_IEMASK_SELF) ? (1u << event) :
                                         (Uint16)(ierMask & 0x0000FFFFu);
    CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcArg = funcArg;
   IRQ_globalRestore(old_intm);
  
}
/*----------------------------------------------------------------------------*/
IDEF Uint32 IRQ_getArg(Uint16 EventId){
 Uint16 event = (EventId <= 15) ? EventId - 16 : EventId;
 return CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcArg;
}
/*----------------------------------------------------------------------------*/
IDEF void IRQ_setArg(Uint16 EventId, Uint32 val){
 Uint16 event = (EventId <= 15) ? EventId - 16 : EventId;
 CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcArg = val;
}
/*----------------------------------------------------------------------------*/
IDEF void IRQ_map(Uint16 EventId){
  CSL_IRQ_DATA.IrqIntTable[EventId] = IRQ_MASK(EventId - 16);
}
/*----------------------------------------------------------------------------*/
IDEF void IRQ_getConfig(Uint16 EventId, IRQ_Config *Config) {
 Uint16 event = (EventId <= 15) ? EventId - 16 : EventId;
 int old_intm;
    old_intm = IRQ_globalDisable();
    Config->funcAddr = (IRQ_IsrPtr)CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcAddr;
    Config->ierMask =  CSL_IRQ_DATA.IrqDispatchTblPtr[event].ierMask;
    Config->funcArg =  CSL_IRQ_DATA.IrqDispatchTblPtr[event].funcArg; 
    IRQ_globalRestore(old_intm);
}
/*----------------------------------------------------------------------------*/
 IDEF void _IRQ_init(Uint16 biosPresent, _IRQ_Dispatch  *dispatchTable){
   CSLBool Initialized= CSL_IRQ_DATA.IrqInitialized;  
   Uint16 i; 
  
  if (!Initialized) {
   if (dispatchTable != INV) {
      CSL_IRQ_DATA.IrqDispatchTblPtr = dispatchTable;
   }

   for (i=0; i<=15; i++)
    CSL_IRQ_DATA.IrqIntTable[i] = i;
   
   for(i=0; i<= IRQ_EVENT_CNT-1; i++)
    CSL_IRQ_DATA.IrqEventTable[i] = IRQ_MASK(i & 0xfu);

    CSL_IRQ_DATA.IrqBiosPresent = biosPresent;

    CSL_IRQ_DATA.IrqInitialized = TRUE;

  }
}
/*----------------------------------------------------------------------------*/
IDEF int IRQ_setVecs(Uint16 iptr){
   int old_iptr, old_intm;

   old_intm = IRQ_globalDisable();
   old_iptr = CHIP_FGET(PMST,IPTR);
   CHIP_FSET(PMST,IPTR,iptr);
   IRQ_globalRestore(old_intm);
   return old_iptr;
}
/*----------------------------------------------------------------------------*/
 IDEF void IRQ_getVec(Uint16 EventId, IRQ_VecObj *vecObj) {   
  Uint16 bit = (EventId-16);
  Uint16 iptr = CHIP_FGET(PMST,IPTR);
  Uint16 VecLoc = ((iptr<<7) | (bit<<2)) + IRQ_USER_INT_OFFSET;  
  Uint16 old_intm;
  
    
    old_intm = IRQ_globalDisable();

    _IRQ_getVec(VecLoc, vecObj);
    _IFR  = IRQ_MASK(bit);

    IRQ_globalRestore(old_intm);
}    
/*----------------------------------------------------------------------------*/
IDEF void IRQ_putVec(Uint16 EventId, IRQ_VecObj *vecObj) {   
  Uint16 bit = (EventId-16);
  Uint16 iptr = CHIP_FGET(PMST,IPTR);
  Uint16 VecLoc = ((iptr<<7) | (bit<<2)) + IRQ_USER_INT_OFFSET;  
  Uint16 old_intm;
  
    
    old_intm = IRQ_globalDisable();

    _IRQ_putVec(VecLoc, vecObj);
    _IFR  = IRQ_MASK(bit);

    IRQ_globalRestore(old_intm);
}     



/*----------------------------------------------------------------------------*/
IDEF void IRQ_init(void) {}

#endif /* USEDEFS */

#endif /* IRQ_SUPPORT */
#endif /* _CSL_IRQ_H_ */
/******************************************************************************\
* End of csl_irq.h
\******************************************************************************/

