/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... MCBSP
* FILENAME...... csl_mcbsp.h
* DATE CREATED.. Fri 06/11/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... 
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CRETAED:  06/11/1999 
*   MODIFIED: 11/18/1999 Modified for TMS320C54xx
*   MODIFIED: 02/15/2000 C54x Romability .
*   MODIFIED: 06/19/2000
*   MODIFIED: 04/18/2001 updated typedef to avoid BIOS type conflict
*   MODIFIED: 05/31/2001 updated for new initialization model
*   MODIFIED: 02/22/2002 fixed MCBSP_read/write read16/write16 backward
*                        compatability problem
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the MCBSP module)
*
*
*
\******************************************************************************/
#ifndef _CSL_MCBSP_H_
#define _CSL_MCBSP_H_

#include <csl_chiphal.h>
  
#if (_MCBSP_SUPPORT)

#include <_csl.h>
#include <csl_mcbsphal.h> 

/****************************************\
* MCBSP scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _MCBSP_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* MCBSP global macro declarations
\****************************************/

#define MCBSP_PORT_CNT             _MCBSP_PORT_CNT

/* MCBSP_Open() flags */
#define MCBSP_OPEN_RESET          (0x0001)


/* error codes */
#define MCBSP_ERR_MAJOR            (0x00000004)
#define MCBSP_ERR_ALLOC            (0x00000000)
#define MCBSP_ERR_INVALID_HANDLE   (0x00000001)
                                              
/* device identifiers for MCBSP_Open() */
#define MCBSP_PORT0    (0)
#define MCBSP_PORT1    (1) 
#if (MCBSP_PORT_CNT == 3)
  #define MCBSP_PORT2  (2)
#endif
 
/*******************************************\
* MCBSP global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area by Mcbspdata.h */

/* Data definition */
#define Mcbsp_Initialized            MCBSP_SYM(0)
#define Mcbsp_DeviceTable            MCBSP_SYM(1)

/* Predefined Device Handlers */
#define _MCBSP_PORT0    ((MCBSP_Handle)(&(CSL_MCBSP_DATA.Mcbsp[0]))) 
#define _MCBSP_PORT1    ((MCBSP_Handle)(&(CSL_MCBSP_DATA.Mcbsp[1]))) 
#define _MCBSP_PORT2    ((MCBSP_Handle)(&(CSL_MCBSP_DATA.Mcbsp[2]))) 

#define MCBSP_PORT_ANY            (0xFFFFu)
 
/*******************************************/
/* Define a debuging assertion macro */ 
/* for validating device handles */

#ifdef _MCRTE_DEBUG
  #define MCBSP_ASSERT_HANDLE(hMcbsp,RetExp) \
    if (hMcbsp == INV) { \
      ERR_submit(MCBSP_ERR_MAJOR, MCBSP_ERR_INVALID_HANDLE); \
      RetExp; \
    } 
#else
  #define MCBSP_ASSERT_HANDLE(hMcbsp,RetExp) 
#endif
/*-----------------------------------------------------------------------*/
/* Special macros to set some register values                            */
/*-----------------------------------------------------------------------*/

#define MCBSP_channelEnable(_Mcbsp,Reg,Channels)\
  MCBSP_RSETH(_Mcbsp,Reg,Channels)

#define MCBSP_channelDisable(_Mcbsp,Reg,Channels)\
  MCBSP_RAOIH(_Mcbsp,Reg,~(Channels),0,0) 

#define MCBSP_channelStatus(hMcbsp,Reg,Channel)\
  ((Uint16) ((MCBSP_RGETH(hMcbsp,Reg)) & Channel))
                               

/*-----------------------------------------------------------------------*/
/* The following macros are used to construct peripheral register        */
/* values based on symbolic constants. They will be useful to initialize */
/* the MCBSP_Config structure in a readable way.                         */
/*-----------------------------------------------------------------------*/

/*--------------------*/
/* SPCR register      */
/*--------------------*/
/* make SPCR register value based on symbolic constants */
#if (_MCBSP_ABIS_SUPPORT)
#define MCBSP_SPCR1_RMK(dlb,rjust,clkstp, dxena, abis, rintm, rrst)\
    ((Uint16)( \
    (MCBSP_FMK(SPCR1,RRST,rrst))| \
    (MCBSP_FMK(SPCR1,RINTM,rintm))| \
    (MCBSP_FMK(SPCR1,ABIS,abis))| \
    (MCBSP_FMK(SPCR1,DXENA,dxena))| \
    (MCBSP_FMK(SPCR1,CLKSTP,clkstp))| \
    (MCBSP_FMK(SPCR1,RJUST,rjust))| \
    (MCBSP_FMK(SPCR1,DLB,dlb)) \
  ) \
)
#define MCBSP_SPCR1_RMKS(dlb_sym,rjust_sym,clkstp_sym, dxena_sym, abis_sym, rintm_sym, rrst_sym)\
    ((Uint16)( \
    (MCBSP_FMKS(SPCR1,RRST,rrst_sym))| \
    (MCBSP_FMKS(SPCR1,RINTM,rintm_sym))| \
    (MCBSP_FMKS(SPCR1,ABIS,abis_sym))| \
    (MCBSP_FMKS(SPCR1,DXENA,dxena_sym))| \
    (MCBSP_FMKS(SPCR1,CLKSTP,clkstp_sym))| \
    (MCBSP_FMKS(SPCR1,RJUST,rjust_sym))| \
    (MCBSP_FMKS(SPCR1,DLB,dlb_sym)) \
  ) \
)
#else
#define MCBSP_SPCR1_RMK(dlb,rjust,clkstp, dxena, rintm, rrst)\
    ((Uint16)( \
    (MCBSP_FMK(SPCR1,RRST,rrst))| \
    (MCBSP_FMK(SPCR1,RINTM,rintm))| \
    (MCBSP_FMK(SPCR1,DXENA,dxena))| \
    (MCBSP_FMK(SPCR1,CLKSTP,clkstp))| \
    (MCBSP_FMK(SPCR1,RJUST,rjust))| \
    (MCBSP_FMK(SPCR1,DLB,dlb)) \
  ) \
)

#define MCBSP_SPCR1_RMKS(dlb_sym,rjust_sym,clkstp_sym, dxena_sym, rintm_sym, rrst_sym)\
    ((Uint16)( \
    (MCBSP_FMKS(SPCR1,RRST,rrst_sym))| \
    (MCBSP_FMKS(SPCR1,RINTM,rintm_sym))| \
    (MCBSP_FMKS(SPCR1,DXENA,dxena_sym))| \
    (MCBSP_FMKS(SPCR1,CLKSTP,clkstp_sym))| \
    (MCBSP_FMKS(SPCR1,RJUST,rjust_sym))| \
    (MCBSP_FMKS(SPCR1,DLB,dlb_sym)) \
  ) \
)

#endif

#define MCBSP_SPCR2_RMK(free,soft,frst,grst,xintm,xrst)\
    ((Uint16)( \
    (MCBSP_FMK(SPCR2,XRST,xrst))|\
    (MCBSP_FMK(SPCR2,XINTM,xintm))|\
    (MCBSP_FMK(SPCR2,GRST,grst))|\
    (MCBSP_FMK(SPCR2,FRST,frst))|\
    (MCBSP_FMK(SPCR2,SOFT,soft))|\
    (MCBSP_FMK(SPCR2,FREE,free))\
  ) \
)

#define MCBSP_SPCR2_RMKS(free_sym,soft_sym,frst_sym,grst_sym,xintm_sym,xrst_sym)\
    ((Uint16)( \
    (MCBSP_FMKS(SPCR2,XRST,xrst_sym))|\
    (MCBSP_FMKS(SPCR2,XINTM,xintm_sym))|\
    (MCBSP_FMKS(SPCR2,GRST,grst_sym))|\
    (MCBSP_FMKS(SPCR2,FRST,frst_sym))|\
    (MCBSP_FMKS(SPCR2,SOFT,soft_sym))|\
    (MCBSP_FMKS(SPCR2,FREE,free_sym))\
  ) \
)

#define MCBSP_RCR1_RMK(rfrlen1,rwdlen1)\
  ((Uint16)(\
    (MCBSP_FMK(RCR1,RWDLEN1,rwdlen1))|\
    (MCBSP_FMK(RCR1,RFRLEN1,rfrlen1))\
  ) \
)

#define MCBSP_RCR1_RMKS(rfrlen1_sym,rwdlen1_sym)\
  ((Uint16)(\
    (MCBSP_FMKS(RCR1,RWDLEN1,rwdlen1_sym))|\
    (MCBSP_FMKS(RCR1,RFRLEN1,rfrlen1_sym))\
  ) \
)

#define MCBSP_RCR2_RMK(rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)\
   ((Uint16)(\
    (MCBSP_FMK(RCR2,RDATDLY,rdatdly))   |\
    (MCBSP_FMK(RCR2,RFIG,rfig))         |\
    (MCBSP_FMK(RCR2,RCOMPAND,rcompand)) |\
    (MCBSP_FMK(RCR2,RWDLEN2,rwdlen2))   |\
    (MCBSP_FMK(RCR2,RFRLEN2,rfrlen2))   |\
    (MCBSP_FMK(RCR2,RPHASE,rphase))      \
  ) \
)

#define MCBSP_RCR2_RMKS(rphase_sym,rfrlen2_sym,rwdlen2_sym,rcompand_sym,rfig_sym,rdatdly_sym)\
   ((Uint16)(\
    (MCBSP_FMKS(RCR2,RDATDLY,rdatdly_sym))   |\
    (MCBSP_FMKS(RCR2,RFIG,rfig_sym))         |\
    (MCBSP_FMKS(RCR2,RCOMPAND,rcompand_sym)) |\
    (MCBSP_FMKS(RCR2,RWDLEN2,rwdlen2_sym))   |\
    (MCBSP_FMKS(RCR2,RFRLEN2,rfrlen2_sym))   |\
    (MCBSP_FMKS(RCR2,RPHASE,rphase_sym))      \
  ) \
)

#define MCBSP_XCR1_RMK(xfrlen1,xwdlen1)\
  ((Uint16)(\
    (MCBSP_FMK(XCR1,XWDLEN1,xwdlen1))|\
    (MCBSP_FMK(XCR1,XFRLEN1,xfrlen1))\
  ) \
)

#define MCBSP_XCR1_RMKS(xfrlen1_sym,xwdlen1_sym)\
  ((Uint16)(\
    (MCBSP_FMKS(XCR1,XWDLEN1,xwdlen1_sym))|\
    (MCBSP_FMKS(XCR1,XFRLEN1,xfrlen1_sym))\
  ) \
)

#define MCBSP_XCR2_RMK(xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)\
   ((Uint16)(\
    (MCBSP_FMK(XCR2,XDATDLY,xdatdly))|\
    (MCBSP_FMK(XCR2,XFIG,xfig))|\
    (MCBSP_FMK(XCR2,XCOMPAND,xcompand))|\
    (MCBSP_FMK(XCR2,XWDLEN2,xwdlen2))|\
    (MCBSP_FMK(XCR2,XFRLEN2,xfrlen2))|\
    (MCBSP_FMK(XCR2,XPHASE,xphase))\
  ) \
)

#define MCBSP_XCR2_RMKS(xphase_sym,xfrlen2_sym,xwdlen2_sym,xcompand_sym,\
   xfig_sym,xdatdly_sym)\
   ((Uint16)(\
    (MCBSP_FMKS(XCR2,XDATDLY,xdatdly_sym))|\
    (MCBSP_FMKS(XCR2,XFIG,xfig_sym))|\
    (MCBSP_FMKS(XCR2,XCOMPAND,xcompand_sym))|\
    (MCBSP_FMKS(XCR2,XWDLEN2,xwdlen2_sym))|\
    (MCBSP_FMKS(XCR2,XFRLEN2,xfrlen2_sym))|\
    (MCBSP_FMKS(XCR2,XPHASE,xphase_sym))\
  ) \
)

#define MCBSP_SRGR1_RMK(fwid,clkgdv) (\
  (Uint16)(\
    (MCBSP_FMK(SRGR1,CLKGDV,clkgdv))|\
    (MCBSP_FMK(SRGR1,FWID,fwid))\
  )\
)

#define MCBSP_SRGR1_RMKS(fwid_sym,clkgdv_sym) (\
  (Uint16)(\
    (MCBSP_FMKS(SRGR1,CLKGDV,clkgdv_sym))|\
    (MCBSP_FMKS(SRGR1,FWID,fwid_sym))\
  )\
)

#define MCBSP_SRGR2_RMK(gsync,clksp,clksm,fsgm,fper)(\
  (Uint16)(\
    (MCBSP_FMK(SRGR2,FPER,fper))|\
    (MCBSP_FMK(SRGR2,FSGM,fsgm))|\
    (MCBSP_FMK(SRGR2,CLKSM,clksm))|\
    (MCBSP_FMK(SRGR2,CLKSP,clksp))|\
    (MCBSP_FMK(SRGR2,GSYNC,gsync))\
  )\
)

#define MCBSP_SRGR2_RMKS(gsync_sym,clksp_sym,clksm_sym,\
  fsgm_sym,fper_sym)(\
  (Uint16)(\
    (MCBSP_FMKS(SRGR2,FPER,fper_sym))|\
    (MCBSP_FMKS(SRGR2,FSGM,fsgm_sym))|\
    (MCBSP_FMKS(SRGR2,CLKSM,clksm_sym))|\
    (MCBSP_FMKS(SRGR2,CLKSP,clksp_sym))|\
    (MCBSP_FMKS(SRGR2,GSYNC,gsync_sym))\
  )\
)

#if(_MCBSP_128_CH_ENABLE_SUPPORT)
    #define MCBSP_MCR1_RMK(rmcme,rpbblk, rpablk, rmcm)\
  ((Uint16)(\
     (MCBSP_FMK(MCR1,RMCM,rmcm))|\
     (MCBSP_FMK(MCR1,RPABLK,rpablk))|\
     (MCBSP_FMK(MCR1,RPBBLK,rpbblk))|\
     (MCBSP_FMK(MCR1,RMCME,rmcme))\
    )\
  ) 

    #define MCBSP_MCR1_RMKS(rmcme_sym,rpbblk_sym,\
       rpablk_sym, rmcm_sym)\
  ((Uint16)(\
     (MCBSP_FMKS(MCR1,RMCM,rmcm_sym))|\
     (MCBSP_FMKS(MCR1,RPABLK,rpablk_sym))|\
     (MCBSP_FMKS(MCR1,RPBBLK,rpbblk_sym))|\
     (MCBSP_FMKS(MCR1,RMCME,rmcme_sym))\
    )\
  ) 

#else  
  #define MCBSP_MCR1_RMK(rpbblk, rpablk, rmcm)\
  ((Uint16)(\
     (MCBSP_FMK(MCR1,RMCM,rmcm))|\
     (MCBSP_FMK(MCR1,RPABLK,rpablk))|\
     (MCBSP_FMK(MCR1,RPBBLK,rpbblk))\
    )\
  )

  #define MCBSP_MCR1_RMKS(rpbblk_sym, rpablk_sym, rmcm_sym)\
  ((Uint16)(\
     (MCBSP_FMKS(MCR1,RMCM,rmcm_sym))|\
     (MCBSP_FMKS(MCR1,RPABLK,rpablk_sym))|\
     (MCBSP_FMKS(MCR1,RPBBLK,rpbblk_sym))\
    )\
  )
#endif 
#if(_MCBSP_128_CH_ENABLE_SUPPORT)
   #define MCBSP_MCR2_RMK(xmcme,xpbblk,xpablk,xmcm)\
  ( (Uint16)(\
      (MCBSP_FMK(MCR2,XMCM,xmcm))|\
      (MCBSP_FMK(MCR2,XPABLK,xpablk))|\
      (MCBSP_FMK(MCR2,XPBBLK,xpbblk))|\
      (MCBSP_FMK(MCR2,XMCME,xmcme))\
     )\
   )

   #define MCBSP_MCR2_RMKS(xmcme_sym,xpbblk_sym,xpablk_sym,xmcm_sym)\
  ( (Uint16)(\
      (MCBSP_FMKS(MCR2,XMCM,xmcm_sym))|\
      (MCBSP_FMKS(MCR2,XPABLK,xpablk_sym))|\
      (MCBSP_FMKS(MCR2,XPBBLK,xpbblk_sym))|\
      (MCBSP_FMKS(MCR2,XMCME,xmcme_sym))\
     )\
   )
#else
 #define MCBSP_MCR2_RMK(xpbblk,xpablk,xmcm)\
  ((Uint16)(\
    (MCBSP_FMK(MCR2,XMCM,xmcm))|\
    (MCBSP_FMK(MCR2,XPABLK,xpablk))|\
    (MCBSP_FMK(MCR2,XPBBLK,xpbblk))\
  )\
)
 #define MCBSP_MCR2_RMKS(xpbblk_sym,xpablk_sym,xmcm_sym)\
  ((Uint16)(\
    (MCBSP_FMKS(MCR2,XMCM,xmcm_sym))|\
    (MCBSP_FMKS(MCR2,XPABLK,xpablk_sym))|\
    (MCBSP_FMKS(MCR2,XPBBLK,xpbblk_sym))\
  )\
)
#endif  

#define MCBSP_RCERA_RMK(rcea)((Uint16)(\
    (((Uint16)(rcea))&0xFFFFu)\
  )\
)\

#define MCBSP_RCERB_RMK(rceb) ((Uint16)(\
    (((Uint16)(rceb))&0xFFFFu)\
  )\
)

#if (_MCBSP_SCLKME_SUPPORT)
   #define MCBSP_PCR_RMK(xioen, rioen, fsxm, fsrm, sclkme ,clkxm, clkrm, fsxp, fsrp, clkxp, clkrp)\
      ((Uint16)(\
       (MCBSP_FMK(PCR,CLKRP,clkrp))|\
       (MCBSP_FMK(PCR,CLKXP,clkxp))|\
       (MCBSP_FMK(PCR,FSRP,fsrp))|\
       (MCBSP_FMK(PCR,FSXP,fsxp))|\
       (MCBSP_FMK(PCR,CLKRM,clkrm))|\
       (MCBSP_FMK(PCR,CLKXM,clkxm))|\
       (MCBSP_FMK(PCR,SCLKME,sclkme))|\
       (MCBSP_FMK(PCR,FSRM,fsrm))|\
       (MCBSP_FMK(PCR,FSXM,fsxm))|\
       (MCBSP_FMK(PCR,RIOEN,rioen))|\
       (MCBSP_FMK(PCR,XIOEN,xioen))\
     )\
   )

   #define MCBSP_PCR_RMKS(xioen_sym, rioen_sym, fsxm_sym, fsrm_sym, sclkme_sym\
      ,clkxm_sym, clkrm_sym, fsxp_sym, fsrp_sym, clkxp_sym, clkrp_sym)\
      ((Uint16)(\
       (MCBSP_FMKS(PCR,CLKRP,clkrp_sym))|\
       (MCBSP_FMKS(PCR,CLKXP,clkxp_sym))|\
       (MCBSP_FMKS(PCR,FSRP,fsrp_sym))|\
       (MCBSP_FMKS(PCR,FSXP,fsxp_sym))|\
       (MCBSP_FMKS(PCR,CLKRM,clkrm_sym))|\
       (MCBSP_FMKS(PCR,CLKXM,clkxm_sym))|\
       (MCBSP_FMKS(PCR,SCLKME,sclkme_sym))|\
       (MCBSP_FMKS(PCR,FSRM,fsrm_sym))|\
       (MCBSP_FMKS(PCR,FSXM,fsxm_sym))|\
       (MCBSP_FMKS(PCR,RIOEN,rioen_sym))|\
       (MCBSP_FMKS(PCR,XIOEN,xioen_sym))\
     )\
   )

#else
   #define MCBSP_PCR_RMK(xioen, rioen, fsxm, fsrm, clkxm, clkrm, fsxp, fsrp, clkxp, clkrp)\
      ((Uint16)(\
       (MCBSP_FMK(PCR,CLKRP,clkrp))|\
       (MCBSP_FMK(PCR,CLKXP,clkxp))|\
       (MCBSP_FMK(PCR,FSRP,fsrp))|\
       (MCBSP_FMK(PCR,FSXP,fsxp))|\
       (MCBSP_FMK(PCR,CLKRM,clkrm))|\
       (MCBSP_FMK(PCR,CLKXM,clkxm))|\
       (MCBSP_FMK(PCR,FSRM,fsrm))|\
       (MCBSP_FMK(PCR,FSXM,fsxm))|\
       (MCBSP_FMK(PCR,RIOEN,rioen))|\
       (MCBSP_FMK(PCR,XIOEN,xioen))\
     )\
   )

   #define MCBSP_PCR_RMKS(xioen_sym, rioen_sym, fsxm_sym, fsrm_sym, clkxm_sym,\
      clkrm_sym, fsxp_sym, fsrp_sym, clkxp_sym, clkrp_sym)\
      ((Uint16)(\
       (MCBSP_FMKS(PCR,CLKRP,clkrp_sym))|\
       (MCBSP_FMKS(PCR,CLKXP,clkxp_sym))|\
       (MCBSP_FMKS(PCR,FSRP,fsrp_sym))|\
       (MCBSP_FMKS(PCR,FSXP,fsxp_sym))|\
       (MCBSP_FMKS(PCR,CLKRM,clkrm_sym))|\
       (MCBSP_FMKS(PCR,CLKXM,clkxm_sym))|\
       (MCBSP_FMKS(PCR,FSRM,fsrm_sym))|\
       (MCBSP_FMKS(PCR,FSXM,fsxm_sym))|\
       (MCBSP_FMKS(PCR,RIOEN,rioen_sym))|\
       (MCBSP_FMKS(PCR,XIOEN,xioen_sym))\
     )\
   )

#endif /* _MCBSP_128_CH_ENABLE_SUPPORT */

/* make XCER register value based on symbolic constants */
#define MCBSP_XCERA_RMK(xcea) ((Uint16)(\
    (((Uint16)(xcea))&0xFFFFu)\
  )\
)

#define MCBSP_XCERB_RMK(xceb) ((Uint16)(\
    (((Uint16)(xceb))&0xFFFFu)\
  )\
)

#define MCBSP_RCER_RMK(rc15,rc14,rc13,rc12,rc11,rc10,rc9,\
         rc8,rc7,rc6,rc5,rc4,rc3,rc2,rc1,rc0)\
((Uint16) ( (MCBSP_FMK(RCER,RCE15,rc15)) |\
           (MCBSP_FMK(RCER,RCE14,rc14)) |\
           (MCBSP_FMK(RCER,RCE13,rc13)) |\
           (MCBSP_FMK(RCER,RCE12,rc12)) |\
           (MCBSP_FMK(RCER,RCE11,rc11)) |\
           (MCBSP_FMK(RCER,RCE10,rc10)) |\
           (MCBSP_FMK(RCER,RCE9,rc9)) |\
           (MCBSP_FMK(RCER,RCE8,rc8)) |\
           (MCBSP_FMK(RCER,RCE7,rc7)) |\
           (MCBSP_FMK(RCER,RCE6,rc6)) |\
           (MCBSP_FMK(RCER,RCE5,rc5)) |\
           (MCBSP_FMK(RCER,RCE4,rc4)) |\
           (MCBSP_FMK(RCER,RCE3,rc3)) |\
           (MCBSP_FMK(RCER,RCE2,rc2)) |\
           (MCBSP_FMK(RCER,RCE1,rc1)) |\
           (MCBSP_FMK(RCER,RCE0,rc0)) \
         )\
)

#define MCBSP_XCER_RMK(xc15,xc14,xc13,xc12,xc11,xc10,xc9,\
         xc8,xc7,xc6,xc5,xc4,xc3,xc2,xc1,xc0)\
((Uint16) ( (MCBSP_FMK(XCER,XCE15,xc15)) |\
           (MCBSP_FMK(XCER,XCE14,xc14)) |\
           (MCBSP_FMK(XCER,XCE13,xc13)) |\
           (MCBSP_FMK(XCER,XCE12,xc12)) |\
           (MCBSP_FMK(XCER,XCE11,xc11)) |\
           (MCBSP_FMK(XCER,XCE10,xc10)) |\
           (MCBSP_FMK(XCER,XCE9,xc9)) |\
           (MCBSP_FMK(XCER,XCE8,xc8)) |\
           (MCBSP_FMK(XCER,XCE7,xc7)) |\
           (MCBSP_FMK(XCER,XCE6,xc6)) |\
           (MCBSP_FMK(XCER,XCE5,xc5)) |\
           (MCBSP_FMK(XCER,XCE4,xc4)) |\
           (MCBSP_FMK(XCER,XCE3,xc3)) |\
           (MCBSP_FMK(XCER,XCE2,xc2)) |\
           (MCBSP_FMK(XCER,XCE1,xc1)) |\
           (MCBSP_FMK(XCER,XCE0,xc0)) \
         )\
)

/* default SPCR register value */
#define MCBSP_SPCR1_DEFAULT                (0x0000u)
#define MCBSP_SPCR2_DEFAULT                (0x0000u)

/* SPCR field values */
#define MCBSP_SPCR1_RRST_DEFAULT           (0x0000u)
#define MCBSP_SPCR1_RRST_DISABLE           (0x0000u)
#define MCBSP_SPCR1_RRST_ENABLE            (0x0001u)

#define MCBSP_SPCR1_RRDY_DEFAULT           (0x0000u)
#define MCBSP_SPCR1_RRDY_NO                (0x0000u)
#define MCBSP_SPCR1_RRDY_YES               (0x0001u)

#define MCBSP_SPCR1_RFULL_DEFAULT          (0x0000u)
#define MCBSP_SPCR1_RFULL_NO               (0x0000u)
#define MCBSP_SPCR1_RFULL_YES              (0x0001u)

#define MCBSP_SPCR1_RSYNCERR_DEFAULT       (0x0000u)
#define MCBSP_SPCR1_RSYNCERR_NO            (0x0000u)
#define MCBSP_SPCR1_RSYNCERR_YES           (0x0001u)

#define MCBSP_SPCR1_RINTM_DEFAULT          (0x0000u)
#define MCBSP_SPCR1_RINTM_RRDY             (0x0000u)
#define MCBSP_SPCR1_RINTM_EOS              (0x0001u)
#define MCBSP_SPCR1_RINTM_FRM              (0x0002u)
#define MCBSP_SPCR1_RINTM_RSYNCERR         (0x0003u)

#define MCBSP_SPCR1_ABIS_DEFAULT           (0x0000u)
#define MCBSP_SPCR1_ABIS_DISABLE           (0x0000u)
#define MCBSP_SPCR1_ABIS_ENABLE            (0x0001u)


#define MCBSP_SPCR1_DXENA_DEFAULT          (0x0000u)
#define MCBSP_SPCR1_DXENA_NA               (0x0000u)
#define MCBSP_SPCR1_DXENA_OFF              (0x0000u)
#define MCBSP_SPCR1_DXENA_ON               (0x0001u)

#define MCBSP_SPCR1_CLKSTP_DEFAULT         (0x0000u)
#define MCBSP_SPCR1_CLKSTP_DISABLE         (0x0000u)
#define MCBSP_SPCR1_CLKSTP_NODELAY         (0x0002u)
#define MCBSP_SPCR1_CLKSTP_DELAY           (0x0003u)

#define MCBSP_SPCR1_RJUST_DEFAULT          (0x0000u)
#define MCBSP_SPCR1_RJUST_RZF              (0x0000u)
#define MCBSP_SPCR1_RJUST_RSE              (0x0001u)
#define MCBSP_SPCR1_RJUST_LZF              (0x0002u)

#define MCBSP_SPCR1_DLB_DEFAULT            (0x0000u)
#define MCBSP_SPCR1_DLB_OFF                (0x0000u)
#define MCBSP_SPCR1_DLB_ON                 (0x0001u)

#define MCBSP_SPCR2_XRST_DEFAULT           (0x0000u)
#define MCBSP_SPCR2_XRST_DEFAULT           (0x0000u)
#define MCBSP_SPCR2_XRST_DISABLE           (0x0000u)
#define MCBSP_SPCR2_XRST_ENABLE            (0x0001u)

#define MCBSP_SPCR2_XRDY_DEFAULT           (0x0000u)
#define MCBSP_SPCR2_XRDY_NO                (0x0000u)
#define MCBSP_SPCR2_XRDY_YES               (0x0001u)

#define MCBSP_SPCR2_XEMPTY_DEFAULT         (0x0000u)
#define MCBSP_SPCR2_XEMPTY_YES             (0x0000u)
#define MCBSP_SPCR2_XEMPTY_NO              (0x0001u)

#define MCBSP_SPCR2_XSYNCERR_DEFAULT       (0x0000u)
#define MCBSP_SPCR2_XSYNCERR_NO            (0x0000u)
#define MCBSP_SPCR2_XSYNCERR_YES           (0x0001u)

#define MCBSP_SPCR2_XINTM_DEFAULT          (0x0000u)
#define MCBSP_SPCR2_XINTM_XRDY             (0x0000u)
#define MCBSP_SPCR2_XINTM_EOS              (0x0001u)
#define MCBSP_SPCR2_XINTM_FRM              (0x0002u)
#define MCBSP_SPCR2_XINTM_XSYNCERR         (0x0003u)

#define MCBSP_SPCR2_GRST_DEFAULT           (0x0000u)
#define MCBSP_SPCR2_GRST_RESET             (0x0000u)
#define MCBSP_SPCR2_GRST_CLKG              (0x0001u)

#define MCBSP_SPCR2_FRST_DEFAULT           (0x0000u)
#define MCBSP_SPCR2_FRST_RESET             (0x0000u)
#define MCBSP_SPCR2_FRST_FSG               (0x0001u)

#define MCBSP_SPCR2_SOFT_DEFAULT           (0x0000u)
#define MCBSP_SPCR2_SOFT_NO                (0x0000u)
#define MCBSP_SPCR2_SOFT_YES               (0x0001u)

#define MCBSP_SPCR2_FREE_DEFAULT           (0x0000u)
#define MCBSP_SPCR2_FREE_NO                (0x0000u)
#define MCBSP_SPCR2_FREE_YES               (0x0001u)

/*--------------------*/
/* RCR register       */
/*--------------------*/
/* make RCR register value based on symbolic constants */
/* make RCR register value based on symbolic constants */



/* default RCR register value */
#define MCBSP_RCR1_DEFAULT                 (0x0000u)
#define MCBSP_RCR2_DEFAULT                 (0x0000u)

/* RCR field values */
#define MCBSP_RCR1_RWDLEN1_DEFAULT         (0x0000u)
#define MCBSP_RCR1_RWDLEN1_8BIT            (0x0000u)
#define MCBSP_RCR1_RWDLEN1_12BIT           (0x0001u)
#define MCBSP_RCR1_RWDLEN1_16BIT           (0x0002u)
#define MCBSP_RCR1_RWDLEN1_20BIT           (0x0003u)
#define MCBSP_RCR1_RWDLEN1_24BIT           (0x0004u)
#define MCBSP_RCR1_RWDLEN1_32BIT           (0x0005u)

#define MCBSP_RCR1_RFRLEN1_DEFAULT         (0x0000u)
#define MCBSP_RCR1_RFRLEN1_OF(x)           ((Uint16)(x))

#define MCBSP_RCR2_RDATDLY_DEFAULT         (0x0000u)
#define MCBSP_RCR2_RDATDLY_0BIT            (0x0000u)
#define MCBSP_RCR2_RDATDLY_1BIT            (0x0001u)
#define MCBSP_RCR2_RDATDLY_2BIT            (0x0002u)

#define MCBSP_RCR2_RFIG_DEFAULT            (0x0000u)
#define MCBSP_RCR2_RFIG_YES                (0x0000u)
#define MCBSP_RCR2_RFIG_NO                 (0x0001u)

#define MCBSP_RCR2_RCOMPAND_DEFAULT        (0x0000u)
#define MCBSP_RCR2_RCOMPAND_MSB            (0x0000u)
#define MCBSP_RCR2_RCOMPAND_8BITLSB        (0x0001u)
#define MCBSP_RCR2_RCOMPAND_ULAW           (0x0002u)
#define MCBSP_RCR2_RCOMPAND_ALAW           (0x0003u)

#define MCBSP_RCR2_RWDLEN2_DEFAULT         (0x0000u)
#define MCBSP_RCR2_RWDLEN2_8BIT            (0x0000u)
#define MCBSP_RCR2_RWDLEN2_12BIT           (0x0001u)
#define MCBSP_RCR2_RWDLEN2_16BIT           (0x0002u)
#define MCBSP_RCR2_RWDLEN2_20BIT           (0x0003u)
#define MCBSP_RCR2_RWDLEN2_24BIT           (0x0004u)
#define MCBSP_RCR2_RWDLEN2_32BIT           (0x0005u)

#define MCBSP_RCR2_RFRLEN2_DEFAULT         (0x0000u)
#define MCBSP_RCR2_RFRLEN2_OF(x)           ((Uint16)(x))

#define MCBSP_RCR2_RPHASE_DEFAULT          (0x0000u)
#define MCBSP_RCR2_RPHASE_SINGLE           (0x0000u)
#define MCBSP_RCR2_RPHASE_DUAL             (0x0001u)


/*--------------------*/
/* XCR register       */
/*--------------------*/
/* make XCR register value based on symbolic constants */
/* default XCR register value */
#define MCBSP_XCR1_DEFAULT                (0x0000u)
#define MCBSP_XCR2_DEFAULT                (0x0000u)

/* XCR field values */
#define MCBSP_XCR1_XWDLEN1_DEFAULT         (0x0000u)
#define MCBSP_XCR1_XWDLEN1_8BIT            (0x0000u)
#define MCBSP_XCR1_XWDLEN1_12BIT           (0x0001u)
#define MCBSP_XCR1_XWDLEN1_16BIT           (0x0002u)
#define MCBSP_XCR1_XWDLEN1_20BIT           (0x0003u)
#define MCBSP_XCR1_XWDLEN1_24BIT           (0x0004u)
#define MCBSP_XCR1_XWDLEN1_32BIT           (0x0005u)

#define MCBSP_XCR1_XFRLEN1_DEFAULT         (0x0000u)
#define MCBSP_XCR1_XFRLEN1_OF(x)           ((Uint16)(x))

#define MCBSP_XCR2_XDATDLY_DEFAULT         (0x0000u)
#define MCBSP_XCR2_XDATDLY_0BIT            (0x0000u)
#define MCBSP_XCR2_XDATDLY_1BIT            (0x0001u)
#define MCBSP_XCR2_XDATDLY_2BIT            (0x0002u)

#define MCBSP_XCR2_XFIG_DEFAULT            (0x0000u)
#define MCBSP_XCR2_XFIG_YES                (0x0000u)
#define MCBSP_XCR2_XFIG_NO                 (0x0001u)

#define MCBSP_XCR2_XCOMPAND_DEFAULT        (0x0000u)
#define MCBSP_XCR2_XCOMPAND_MSB            (0x0000u)
#define MCBSP_XCR2_XCOMPAND_8BITLSB        (0x0001u)
#define MCBSP_XCR2_XCOMPAND_ULAW           (0x0002u)
#define MCBSP_XCR2_XCOMPAND_ALAW           (0x0003u)

#define MCBSP_XCR2_XWDLEN2_DEFAULT         (0x0000u)
#define MCBSP_XCR2_XWDLEN2_8BIT            (0x0000u)
#define MCBSP_XCR2_XWDLEN2_12BIT           (0x0001u)
#define MCBSP_XCR2_XWDLEN2_16BIT           (0x0002u)
#define MCBSP_XCR2_XWDLEN2_20BIT           (0x0003u)
#define MCBSP_XCR2_XWDLEN2_24BIT           (0x0004u)
#define MCBSP_XCR2_XWDLEN2_32BIT           (0x0005u)
#define MCBSP_XCR2_XFRLEN2_OF(x)           ((Uint16)(x))

#define MCBSP_XCR2_XPHASE_DEFAULT          (0x0000u)
#define MCBSP_XCR2_XPHASE_SINGLE           (0x0000u)
#define MCBSP_XCR2_XPHASE_DUAL             (0x0001u)


#define MCBSP_RCV_START                    (0x0001u)
#define MCBSP_XMIT_START                   (0x0002u)
#define MCBSP_SRGR_START                   (0x0004u)
#define MCBSP_SRGR_FRAMESYNC               (0x0008u)

#define MCBSP_XMIT_RESET                   MCBSP_FMK(SPCR2,XRST,1)
#define MCBSP_RCV_RESET                    MCBSP_FMK(SPCR1,RRST,1)
#define MCBSP_SRGR_RESET                   MCBSP_FMK(SPCR2,GRST,1)
#define MCBSP_FSG_RESET                    MCBSP_FMK(SPCR2,FRST,1)

#define MCBSP_SAMPLE_RATE_DELAY_DEFAULT    (0xFFFFu)

/*--------------------*/
/* SRGR register      */
/*--------------------*/
/* make SRGR register value based on symbolic constants */
/* default SRGR register value */
#define MCBSP_SRGR1_DEFAULT                (0x0001u)
#define MCBSP_SRGR2_DEFAULT                (0x2000u)

/* SRGR field values */

#define MCBSP_SRGR1_CLKGDV_DEFAULT         (0x0000u)
#define MCBSP_SRGR1_CLKGDV_OF(x)           ((Uint16)(x))

#define MCBSP_SRGR1_FWID_DEFAULT           (0x0000u)
#define MCBSP_SRGR1_FWID_OF(x)             ((Uint16)(x))

#define MCBSP_SRGR2_FPER_DEFAULT           (0x0000u)
#define MCBSP_SRGR2_FPER_OF(x)             ((Uint16)(x))

#define MCBSP_SRGR2_FSGM_DEFAULT           (0x0000u)
#define MCBSP_SRGR2_FSGM_DXR2XSR           (0x0000u)
#define MCBSP_SRGR2_FSGM_FSG               (0x0001u)

#define MCBSP_SRGR2_CLKSM_DEFAULT          (0x0000u)
#define MCBSP_SRGR2_CLKSM_0                (0x0000u)
#define MCBSP_SRGR2_CLKSM_1                (0x0001u)
#define MCBSP_SRGR2_CLKSM_CLKS             MCBSP_SRGR2_CLKSM_0                
#define MCBSP_SRGR2_CLKSM_INTERNAL         MCBSP_SRGR2_CLKSM_1                

#define MCBSP_SRGR2_CLKSP_DEFAULT          (0x0000u)
#define MCBSP_SRGR2_CLKSP_RISING           (0x0000u)
#define MCBSP_SRGR2_CLKSP_FALLING          (0x0001u)

#define MCBSP_SRGR2_GSYNC_DEFAULT          (0x0000u)
#define MCBSP_SRGR2_GSYNC_FREE             (0x0000u)
#define MCBSP_SRGR2_GSYNC_SYNC             (0x0001u)


/*--------------------*/
/* MCR regsiter       */
/*--------------------*/
/* make MCR register value based on symbolic constants */

/* default MCR register value */
#define MCBSP_MCR1_DEFAULT                 (0x0000u)
#define MCBSP_MCR2_DEFAULT                 (0x0000u)

/* MCR field values */

#define MCBSP_MCR1_RMCM_DEFAULT            (0x0000u)
#define MCBSP_MCR1_RMCM_CHENABLE           (0x0000u)
#define MCBSP_MCR1_RMCM_ELDISABLE          (0x0001u)

#define MCBSP_MCR1_RCBLK_DEFAULT           (0x0000u)
#define MCBSP_MCR1_RCBLK_SF0               (0x0000u)
#define MCBSP_MCR1_RCBLK_SF1               (0x0001u)
#define MCBSP_MCR1_RCBLK_SF2               (0x0002u)
#define MCBSP_MCR1_RCBLK_SF3               (0x0003u)
#define MCBSP_MCR1_RCBLK_SF4               (0x0004u)
#define MCBSP_MCR1_RCBLK_SF5               (0x0005u)
#define MCBSP_MCR1_RCBLK_SF6               (0x0006u)
#define MCBSP_MCR1_RCBLK_SF7               (0x0007u)

#define MCBSP_MCR1_RPABLK_DEFAULT          (0x0000u)
#define MCBSP_MCR1_RPABLK_SF0              (0x0000u)
#define MCBSP_MCR1_RPABLK_SF2              (0x0001u)
#define MCBSP_MCR1_RPABLK_SF4              (0x0002u)
#define MCBSP_MCR1_RPABLK_SF6              (0x0003u)

#define MCBSP_MCR1_RPBBLK_DEFAULT          (0x0000u)
#define MCBSP_MCR1_RPBBLK_SF1              (0x0000u)
#define MCBSP_MCR1_RPBBLK_SF3              (0x0001u)
#define MCBSP_MCR1_RPBBLK_SF5              (0x0002u)
#define MCBSP_MCR1_RPBBLK_SF7              (0x0003u)

#define MCBSP_MCR1_RMCME_DEFAULT           (0x0000u) 
#define MCBSP_MCR1_RMCME_NO                (0x0000u)
#define MCBSP_MCR1_RMCME_ATOH              (0x0001u)

#define MCBSP_MCR2_XMCM_DEFAULT            (0x0000u)
#define MCBSP_MCR2_XMCM_ENNOMASK           (0x0000u)
#define MCBSP_MCR2_XMCM_DISXP              (0x0001u)
#define MCBSP_MCR2_XMCM_ENMASK             (0x0002u)
#define MCBSP_MCR2_XMCM_DISRP              (0x0003u)

#define MCBSP_MCR2_XCBLK_DEFAULT           (0x0000u)
#define MCBSP_MCR2_XCBLK_SF0               (0x0000u)
#define MCBSP_MCR2_XCBLK_SF1               (0x0001u)
#define MCBSP_MCR2_XCBLK_SF2               (0x0002u)
#define MCBSP_MCR2_XCBLK_SF3               (0x0003u)
#define MCBSP_MCR2_XCBLK_SF4               (0x0004u)
#define MCBSP_MCR2_XCBLK_SF5               (0x0005u)
#define MCBSP_MCR2_XCBLK_SF6               (0x0006u)
#define MCBSP_MCR2_XCBLK_SF7               (0x0007u)

#define MCBSP_MCR2_XPABLK_DEFAULT          (0x0000u)
#define MCBSP_MCR2_XPABLK_SF0              (0x0000u)
#define MCBSP_MCR2_XPABLK_SF2              (0x0001u)
#define MCBSP_MCR2_XPABLK_SF4              (0x0002u)
#define MCBSP_MCR2_XPABLK_SF6              (0x0003u)

#define MCBSP_NCR2_XPBBLK_DEFAULT          (0x0000u)
#define MCBSP_MCR2_XPBBLK_SF1              (0x0000u)
#define MCBSP_MCR2_XPBBLK_SF3              (0x0001u)
#define MCBSP_MCR2_XPBBLK_SF5              (0x0002u)
#define MCBSP_MCR2_XPBBLK_SF7              (0x0003u)

#define MCBSP_MCR2_XMCME_DEFAULT           (0x0000u)
#define MCBSP_MCR2_XMCME_NO                (0x0000u)
#define MCBSP_MCR2_XMCME_ATOH              (0x0001u)

/*--------------------*/
/* RCER register      */
/*--------------------*/
/* make RCER register value based on symbolic constants */

/* default RCER register value */
#define MCBSP_RCERA_DEFAULT                (0x0000u)
#define MCBSP_RCERB_DEFAULT                (0x0000u)

/* RCER field values */
#define MCBSP_RCERA_RCEA_OF(x)             ((Uint16)(x))
#define MCBSP_RCERB_RCEB_OF(x)             ((Uint16)(x))

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define MCBSP_RCERC_DEFAULT                (0x0000u)
  #define MCBSP_RCERD_DEFAULT                (0x0000u)
  #define MCBSP_RCERE_DEFAULT                (0x0000u)
  #define MCBSP_RCERF_DEFAULT                (0x0000u)
  #define MCBSP_RCERG_DEFAULT                (0x0000u)
  #define MCBSP_RCERH_DEFAULT                (0x0000u)

  #define MCBSP_RCERC_RCEC_OF(x)             ((Uint16)(x))
  #define MCBSP_RCERD_RCED_OF(x)             ((Uint16)(x)) 
  #define MCBSP_RCERE_RCEE_OF(x)             ((Uint16)(x))
  #define MCBSP_RCERF_RCEF_OF(x)             ((Uint16)(x)) 
  #define MCBSP_RCERG_RCEG_OF(x)             ((Uint16)(x))
  #define MCBSP_RCERH_RCEH_OF(x)             ((Uint16)(x))
#endif
/*--------------------*/
/* XCER register      */
/*--------------------*/

/* default XCER register value */
#define MCBSP_XCERA_DEFAULT                (0x0000u)
#define MCBSP_XCERB_DEFAULT                (0x0000u)

/* XCER field values */
#define MCBSP_XCERA_XCEA_OF(x)             ((Uint16)(x))
#define MCBSP_XCERB_XCEB_OF(x)             ((Uint16)(x))

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define MCBSP_XCERC_DEFAULT                (0x0000u)
  #define MCBSP_XCERD_DEFAULT                (0x0000u)
  #define MCBSP_XCERE_DEFAULT                (0x0000u)
  #define MCBSP_XCERF_DEFAULT                (0x0000u)
  #define MCBSP_XCERG_DEFAULT                (0x0000u)
  #define MCBSP_XCERH_DEFAULT                (0x0000u)

  #define MCBSP_XCERC_XCEC_OF(x)             ((Uint16)(x))
  #define MCBSP_XCERD_XCED_OF(x)             ((Uint16)(x)) 
  #define MCBSP_XCERE_XCEE_OF(x)             ((Uint16)(x))
  #define MCBSP_XCERF_XCEF_OF(x)             ((Uint16)(x)) 
  #define MCBSP_XCERG_XCEG_OF(x)             ((Uint16)(x))
  #define MCBSP_XCERH_XCEH_OF(x)             ((Uint16)(x))
#endif

/*--------------------*/
/* PCR register       */
/*--------------------*/
/* make PCR register value based on symbolic constants */

/* default PCR register value */
#define MCBSP_PCR_DEFAULT                 (0x0000u)

/* PCR field values */

#define MCBSP_PCR_CLKRP_DEFAULT           (0x0000u)
#define MCBSP_PCR_CLKRP_FALLING           (0x0000u)
#define MCBSP_PCR_CLKRP_RISING            (0x0001u)

#define MCBSP_PCR_CLKXP_DEFAULT           (0x0000u)
#define MCBSP_PCR_CLKXP_RISING            (0x0000u)
#define MCBSP_PCR_CLKXP_FALLING           (0x0001u)

#define MCBSP_PCR_FSRP_DEFAULT            (0x0000u)
#define MCBSP_PCR_FSRP_ACTIVEHIGH         (0x0000u)
#define MCBSP_PCR_FSRP_ACTIVELOW          (0x0001u)

#define MCBSP_PCR_FSXP_DEFAULT            (0x0000u)
#define MCBSP_PCR_FSXP_ACTIVEHIGH         (0x0000u)
#define MCBSP_PCR_FSXP_ACTIVELOW          (0x0001u)

#define MCBSP_PCR_DRSTAT_DEFAULT          (0x0000u)
#define MCBSP_PCR_DRSTAT_0                (0x0000u)
#define MCBSP_PCR_DRSTAT_1                (0x0001u)
#define MCBSP_PCR_DXSTAT_0                (0x0000u)

#define MCBSP_PCR_DXSTAT_DEFAULT          (0x0000u)
#define MCBSP_PCR_DXSTAT_1                (0x0001u)

#define MCBSP_PCR_CLKSSTAT_DEFAULT        (0x0000u)
#define MCBSP_PCR_CLKSSTAT_0              (0x0000u)
#define MCBSP_PCR_CLKSSTAT_1              (0x0001u) 

#define MCBSP_PCR_SCLKME_DEFAULT          (0x0000u)
#define MCBSP_PCR_SCLKME_1                (0x0001u)
#define MCBSP_PCR_SCLKME_0                (0x0000u)
#define MCBSP_PCR_SCLKME_BCLK             MCBSP_PCR_SCLKME_1
#define MCBSP_PCR_SCLKME_NO               MCBSP_PCR_SCLKME_0

#define MCBSP_PCR_CLKRM_DEFAULT           (0x0000u)
#define MCBSP_PCR_CLKRM_INPUT             (0x0000u)
#define MCBSP_PCR_CLKRM_OUTPUT            (0x0001u)

#define MCBSP_PCR_CLKXM_DEFAULT           (0x0000u)
#define MCBSP_PCR_CLKXM_INPUT             (0x0000u)
#define MCBSP_PCR_CLKXM_OUTPUT            (0x0001u)

#define MCBSP_PCR_FSRM_DEFAULT            (0x0000u)
#define MCBSP_PCR_FSRM_EXTERNAL           (0x0000u)
#define MCBSP_PCR_FSRM_INTERNAL           (0x0001u)

#define MCBSP_PCR_FSXM_DEFAULT            (0x0000u)
#define MCBSP_PCR_FSXM_EXTERNAL           (0x0000u)
#define MCBSP_PCR_FSXM_INTERNAL           (0x0001u)

#define MCBSP_PCR_RIOEN_DEFAULT           (0x0000u)
#define MCBSP_PCR_RIOEN_SP                (0x0000u)
#define MCBSP_PCR_RIOEN_GPIO              (0x0001u)

#define MCBSP_PCR_XIOEN_DEFAULT           (0x0000u)
#define MCBSP_PCR_XIOEN_SP                (0x0000u)
#define MCBSP_PCR_XIOEN_GPIO              (0x0001u)

/*-------------------------------------------------*\
* Register macros
\*-------------------------------------------------*/

/* Map-register definition */
#define DRR1(hMcbsp)  REG16(((MCBSP_PrivateObj*)hMcbsp)->Drr1Addr)
#define DRR2(hMcbsp)  REG16(((MCBSP_PrivateObj*)hMcbsp)->Drr2Addr)
#define DXR1(hMcbsp)  REG16(((MCBSP_PrivateObj*)hMcbsp)->Dxr1Addr)
#define DXR2(hMcbsp)  REG16(((MCBSP_PrivateObj*)hMcbsp)->Dxr2Addr)
#define SPSA(hMcbsp)  REG16(((MCBSP_PrivateObj*)hMcbsp)->SpsaAddr)
#define SPSD(hMcbsp)  REG16(((MCBSP_PrivateObj*)hMcbsp)->SpsdAddr)
#define XMTEVENT(hMcbsp) (((MCBSP_PrivateObj*)hMcbsp)->XmtEvent)
#define RCVEVENT(hMcbsp) (((MCBSP_PrivateObj*)hMcbsp)->RcvEvent)
#define ALLOCATED(hMcbsp)(((MCBSP_PrivateObj*)hMcbsp)->Allocated)

/* define SubRegisters: Global write/read functions -Shorter definition*/


/****************************************\
* MCBSP global typedef declarations
\****************************************/

/* device handle type */
typedef struct {
  Uint32 Private;
} *MCBSP_Handle;


/* device configuration structure */
typedef struct {
  Uint16 spcr1;
  Uint16 spcr2;
  Uint16 rcr1;
  Uint16 rcr2;
  Uint16 xcr1;
  Uint16 xcr2;
  Uint16 srgr1;
  Uint16 srgr2;
  Uint16 mcr1;
  Uint16 mcr2;
  Uint16 pcr;
#if (!_MCBSP_128_CH_ENABLE_SUPPORT)
  Uint16 rcera;
  Uint16 rcerb;
  Uint16 xcera;
  Uint16 xcerb;
#else
  Uint16 rcera;
  Uint16 rcerb;
  Uint16 rcerc;
  Uint16 rcerd;
  Uint16 rcere;
  Uint16 rcerf;
  Uint16 rcerg;
  Uint16 rcerh;
  Uint16 xcera;
  Uint16 xcerb;
  Uint16 xcerc;
  Uint16 xcerd;
  Uint16 xcere;
  Uint16 xcerf;
  Uint16 xcerg;
  Uint16 xcerh;
#endif
  
} MCBSP_Config;


/****************************************\
* Mcbsp Auxiliary Macros
\****************************************/

/****************************************\
* MCBSP global variable declarations
\****************************************/

/****************************************\
* MCBSP global function declarations
\****************************************/
CSLAPI void MCBSP_init();
CSLAPI void MCBSP_reset(MCBSP_Handle hMcbsp);

CSLAPI MCBSP_Handle MCBSP_open(int DevNum, Uint32 Flags);
CSLAPI void MCBSP_close(MCBSP_Handle hMcbsp);


/****************************************\
* MCBSP inline function declarations
\****************************************/
IDECL void MCBSP_config(MCBSP_Handle hMcbsp, MCBSP_Config *Config);
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
IDECL void MCBSP_configArgs(MCBSP_Handle hMcbsp, 
                        Uint16 spcr1, Uint16 spcr2, Uint16 rcr1,  Uint16 rcr2, 
                        Uint16 xcr1,  Uint16 xcr2, Uint16 srgr1, Uint16 srgr2,
                        Uint16 mcr1,  Uint16 mcr2,  Uint16 pcr,
                        Uint16 rcera, Uint16 rcerb, Uint16 rcerc, Uint16 rcerd,
                        Uint16 rcere, Uint16 rcerf, Uint16 rcerg, Uint16 rcerh, 
                        Uint16 xcera, Uint16 xcerb, Uint16 xcerc, Uint16 xcerd,
                        Uint16 xcere, Uint16 xcerf, Uint16 xcerg, Uint16 xcerh 
                        );  
#else
IDECL void MCBSP_configArgs(MCBSP_Handle hMcbsp, 
                        Uint16 spcr1, Uint16 spcr2, Uint16 rcr1,  Uint16 rcr2, 
                        Uint16 xcr1,  Uint16 xcr2, Uint16 srgr1, Uint16 srgr2, 
                        Uint16 mcr1,  Uint16 mcr2, Uint16 pcr,
                        Uint16 rcera, Uint16 rcerb, 
                        Uint16 xcera, Uint16 xcerb 
                        );  
#endif  

/* Rename MCBSP_read and write functions to maintain */
/* backward compatability with older library versions */

/* Get IRQ_EventNumber listed into the IRQ.h file */ 
IDECL Uint16 MCBSP_getXmtEventId(MCBSP_Handle hMcbsp);
IDECL Uint16 MCBSP_getRcvEventId(MCBSP_Handle hMcbsp);
IDECL Uint16 MCBSP_getPort(MCBSP_Handle hMcbsp);
IDECL Uint16 MCBSP_read(MCBSP_Handle hMcbsp);
IDECL Uint16 MCBSP_read16(MCBSP_Handle hMcbsp);
IDECL Uint32 MCBSP_read32(MCBSP_Handle hMcbsp);
IDECL void   MCBSP_write16(MCBSP_Handle hMcbsp, Uint16 Val);
IDECL void   MCBSP_write(MCBSP_Handle hMcbsp, Uint16 Val);
IDECL void   MCBSP_write32(MCBSP_Handle hMcbsp, Uint32 Val);
IDECL CSLBool   MCBSP_start(MCBSP_Handle hMcbsp, Uint16 StartMask, Uint32 SampleRateDelay);
IDECL CSLBool   MCBSP_xrdy(MCBSP_Handle hMcbsp);
IDECL CSLBool   MCBSP_rrdy(MCBSP_Handle hMcbsp);
IDECL CSLBool   MCBSP_xempty(MCBSP_Handle hMcbsp);
IDECL CSLBool   MCBSP_rfull(MCBSP_Handle hMcbsp);
IDECL void   MCBSP_getConfig(MCBSP_Handle hMcbsp, MCBSP_Config *Config);

/****************************************\
* MCBSP inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
IDEF Uint16 MCBSP_getXmtEventId(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return 0xFFFF);
  return (((MCBSP_PrivateObj*)hMcbsp)->XmtEvent);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 MCBSP_getRcvEventId(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return 0xFFFF);
  return (((MCBSP_PrivateObj*)hMcbsp)->RcvEvent);
}
/*----------------------------------------------------------------------------*/
IDEF Uint16 MCBSP_read(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return 0xFFFF);
  return (MCBSP_RGETH(hMcbsp,DRR1));
} 
/*----------------------------------------------------------------------------*/
IDEF Uint16 MCBSP_read16(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return 0xFFFF);
  return (MCBSP_RGETH(hMcbsp,DRR1));
} 
/*----------------------------------------------------------------------------*/
IDEF Uint16 MCBSP_getPort(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return 0xFFFF);
  return (((MCBSP_PrivateObj*)hMcbsp)->Port);
}
/*----------------------------------------------------------------------------*/
 IDEF Uint32 MCBSP_read32(MCBSP_Handle hMcbsp) {
  Uint32 Drr1Drr2,Drr2,Drr1; 
  
  MCBSP_ASSERT_HANDLE(hMcbsp,return 0xFFFFFFFF);
  Drr2=MCBSP_RGETH(hMcbsp,DRR2);
  while(!MCBSP_rrdy(hMcbsp));
  Drr1=MCBSP_RGETH(hMcbsp,DRR1);
  Drr1Drr2=((Drr2<<16)&0xFFFF0000 | (Drr1&0x0000FFFF));
  return Drr1Drr2;
}

/*----------------------------------------------------------------------------*/
IDEF void MCBSP_write16(MCBSP_Handle hMcbsp,Uint16 Val) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return);
  MCBSP_RSETH(hMcbsp,DXR1,Val);
} 
/*----------------------------------------------------------------------------*/
IDEF void MCBSP_write(MCBSP_Handle hMcbsp,Uint16 Val) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return);
  MCBSP_RSETH(hMcbsp,DXR1,Val);
}   
/*----------------------------------------------------------------------------*/
 IDEF void MCBSP_write32(MCBSP_Handle hMcbsp, Uint32 Val) {
  Uint16 Valcut;
  MCBSP_ASSERT_HANDLE(hMcbsp,return);  
  Valcut=Val>>16;
  MCBSP_RSETH(hMcbsp,DXR2,(Valcut));  
  while(!(MCBSP_xrdy(hMcbsp)));
  MCBSP_RSETH(hMcbsp,DXR1, (Val & 0x0000FFFFu)); 
}

/*----------------------------------------------------------------------------*/
IDEF CSLBool MCBSP_xrdy(MCBSP_Handle hMcbsp) {
 Uint16 spsa = ((MCBSP_PrivateObj*)(hMcbsp))->SpsaAddr;
 Uint16 spsd = ((MCBSP_PrivateObj*)(hMcbsp))->SpsdAddr;

  MCBSP_ASSERT_HANDLE(hMcbsp,return FALSE);
  return (CSLBool)(_SUBFIELD_GET(spsa,spsd,_MCBSP_SPCR2_ADDR,_MCBSP_SPCR2_XRDY));
}
/*----------------------------------------------------------------------------*/
IDEF CSLBool MCBSP_rrdy(MCBSP_Handle hMcbsp) {
 Uint16 spsa = ((MCBSP_PrivateObj*)(hMcbsp))->SpsaAddr;
 Uint16 spsd = ((MCBSP_PrivateObj*)(hMcbsp))->SpsdAddr;

  MCBSP_ASSERT_HANDLE(hMcbsp,return FALSE);
  return (CSLBool)(_SUBFIELD_GET(spsa,spsd,_MCBSP_SPCR1_ADDR,_MCBSP_SPCR1_RRDY));
}
/*----------------------------------------------------------------------------*/
IDEF CSLBool MCBSP_xempty(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return FALSE);
  return (CSLBool)(MCBSP_FGETH(hMcbsp,SPCR2,XEMPTY)==0);
}
/*----------------------------------------------------------------------------*/
IDEF CSLBool MCBSP_rfull(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return FALSE);
  return (CSLBool)MCBSP_FGETH(hMcbsp,SPCR1,RFULL);
}
/*----------------------------------------------------------------------------*/
IDEF CSLBool MCBSP_start(MCBSP_Handle hMcbsp, Uint16 StartMask, Uint32 SampleRateDelay) {
 
  MCBSP_ASSERT_HANDLE(hMcbsp,return FALSE);

  if (StartMask & (MCBSP_SRGR_START | MCBSP_SRGR_FRAMESYNC)) {
    _SUBFIELD_SET(((MCBSP_PrivateObj*)hMcbsp)->SpsaAddr,
    ((MCBSP_PrivateObj*)hMcbsp)->SpsdAddr, _MCBSP_SPCR2_ADDR, _MCBSP_SPCR2_GRST, 1);
    _SUBFIELD_SET(((MCBSP_PrivateObj*)hMcbsp)->SpsaAddr,
    ((MCBSP_PrivateObj*)hMcbsp)->SpsdAddr, _MCBSP_SPCR2_ADDR, _MCBSP_SPCR2_FRST, 1);
    while(SampleRateDelay > 0) --SampleRateDelay;
  }

  if (StartMask & MCBSP_RCV_START) {
    _SUBFIELD_SET(((MCBSP_PrivateObj*)hMcbsp)->SpsaAddr,
    ((MCBSP_PrivateObj*)hMcbsp)->SpsdAddr, _MCBSP_SPCR1_ADDR, _MCBSP_SPCR1_RRST, 1);
  }
  if (StartMask & MCBSP_XMIT_START) {
    _SUBFIELD_SET(((MCBSP_PrivateObj*)hMcbsp)->SpsaAddr,
    ((MCBSP_PrivateObj*)hMcbsp)->SpsdAddr, _MCBSP_SPCR2_ADDR, _MCBSP_SPCR2_XRST, 1);
  }
 return TRUE;
}

/*----------------------------------------------------------------------------*/
IDEF void MCBSP_enableFsync(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return);
  MCBSP_FSETH(hMcbsp,SPCR2,FRST,1);
}
/*----------------------------------------------------------------------------*/
IDEF void MCBSP_enableSrgr(MCBSP_Handle hMcbsp) {
  MCBSP_ASSERT_HANDLE(hMcbsp,return);
  MCBSP_FSETH(hMcbsp,SPCR2,GRST, 1);
}     
/*----------------------------------------------------------------------------*/
IDEF void MCBSP_config(MCBSP_Handle hMcbsp, MCBSP_Config *Config) {

  Uint16 spsa = ((MCBSP_PrivateObj*)(hMcbsp))->SpsaAddr;
  Uint16 spsd = ((MCBSP_PrivateObj*)(hMcbsp))->SpsdAddr;
                      
  int old_intm;
                             
  MCBSP_ASSERT_HANDLE(hMcbsp,return);
  
  old_intm = IRQ_globalDisable();    
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(PCR),Config->pcr);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERB),Config->xcerb);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERA),Config->xcera);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERB),Config->rcerb);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERA),Config->rcera);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(MCR2),Config->mcr2);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(MCR1),Config->mcr1);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SRGR2),Config->srgr2);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SRGR1),Config->srgr1);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCR2),Config->xcr2);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCR1),Config->xcr1);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCR2),Config->rcr2); 
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCR1),Config->rcr1);  
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SPCR2),
          Config->spcr2 & (~(MCBSP_XMIT_RESET | MCBSP_SRGR_RESET | MCBSP_FSG_RESET)));
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SPCR1),Config->spcr1 & (~(MCBSP_RCV_RESET)));

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERC),Config->rcerc);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERD),Config->rcerd);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERE),Config->rcere);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERF),Config->rcerf);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERG),Config->rcerg);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERH),Config->rcerh);

  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERC),Config->xcerc);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERD),Config->xcerd);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERE),Config->xcere);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERF),Config->xcerf);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERG),Config->xcerg);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERH),Config->xcerh);
#endif
 
     
  IRQ_globalRestore(old_intm);
  return;
}
/*----------------------------------------------------------------------------*/
IDEF void MCBSP_getConfig(MCBSP_Handle hMcbsp, MCBSP_Config *Config) {
  int old_intm;

  MCBSP_ASSERT_HANDLE(hMcbsp,return);
  
  old_intm = IRQ_globalDisable();    
  Config->pcr   = MCBSP_RGETH(hMcbsp,PCR);
  Config->xcerb = MCBSP_RGETH(hMcbsp,XCERB);
  Config->xcera = MCBSP_RGETH(hMcbsp,XCERA);
  Config->rcerb = MCBSP_RGETH(hMcbsp,RCERB);
  Config->rcera = MCBSP_RGETH(hMcbsp,RCERA);
  Config->mcr2  = MCBSP_RGETH(hMcbsp,MCR2);
  Config->mcr1  = MCBSP_RGETH(hMcbsp,MCR1);
  Config->srgr2 = MCBSP_RGETH(hMcbsp,SRGR2);
  Config->srgr1 = MCBSP_RGETH(hMcbsp,SRGR1);
  Config->xcr2  = MCBSP_RGETH(hMcbsp,XCR2);
  Config->xcr1  = MCBSP_RGETH(hMcbsp,XCR1);
  Config->rcr2  = MCBSP_RGETH(hMcbsp,RCR2); 
  Config->rcr1  = MCBSP_RGETH(hMcbsp,RCR1);  
  Config->spcr2 = MCBSP_RGETH(hMcbsp,SPCR2);
  Config->spcr1 = MCBSP_RGETH(hMcbsp,SPCR1);
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  Config->rcerc = MCBSP_RGETH(hMcbsp,RCERC); 
  Config->rcerd = MCBSP_RGETH(hMcbsp,RCERD); 
  Config->rcere = MCBSP_RGETH(hMcbsp,RCERE); 
  Config->rcerf = MCBSP_RGETH(hMcbsp,RCERF); 
  Config->rcerg = MCBSP_RGETH(hMcbsp,RCERG); 
  Config->rcerh = MCBSP_RGETH(hMcbsp,RCERH); 
  Config->xcerc = MCBSP_RGETH(hMcbsp,XCERC); 
  Config->xcerd = MCBSP_RGETH(hMcbsp,XCERD); 
  Config->xcere = MCBSP_RGETH(hMcbsp,XCERE); 
  Config->xcerf = MCBSP_RGETH(hMcbsp,XCERF); 
  Config->xcerg = MCBSP_RGETH(hMcbsp,XCERG); 
  Config->xcerh = MCBSP_RGETH(hMcbsp,XCERH); 
#endif
  IRQ_globalRestore(old_intm);
  return;
}

/*----------------------------------------------------------------------------*/
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
 IDEF void MCBSP_configArgs(MCBSP_Handle hMcbsp, 
                       Uint16 spcr1, Uint16 spcr2, Uint16 rcr1,  Uint16 rcr2, 
                       Uint16 xcr1,  Uint16 xcr2, Uint16 srgr1, Uint16 srgr2, 
                       Uint16 mcr1,  Uint16 mcr2, Uint16 pcr,
                       Uint16 rcera, Uint16 rcerb, Uint16 rcerc, Uint16 rcerd,
                       Uint16 rcere, Uint16 rcerf, Uint16 rcerg, Uint16 rcerh,
                       Uint16 xcera, Uint16 xcerb, Uint16 xcerc, Uint16 xcerd,
                       Uint16 xcere, Uint16 xcerf, Uint16 xcerg, Uint16 xcerh) {    
#else
 IDEF void MCBSP_configArgs(MCBSP_Handle hMcbsp, 
                       Uint16 spcr1, Uint16 spcr2, Uint16 rcr1,  Uint16 rcr2, 
                       Uint16 xcr1,  Uint16 xcr2, Uint16 srgr1, Uint16 srgr2, 
                       Uint16 mcr1,  Uint16 mcr2, Uint16 pcr,
                       Uint16 rcera, Uint16 rcerb, Uint16 xcera, Uint16 xcerb) {  
#endif  
  int old_intm;
  Uint16 spsa = ((MCBSP_PrivateObj*)(hMcbsp))->SpsaAddr;
  Uint16 spsd = ((MCBSP_PrivateObj*)(hMcbsp))->SpsdAddr;
  
  MCBSP_ASSERT_HANDLE(hMcbsp,return);

  old_intm = IRQ_globalDisable();
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(PCR),pcr);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERB),xcerb);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERA),xcera);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERB),rcerb);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERA),rcera);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(MCR2),mcr2);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(MCR1),mcr1);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SRGR2),srgr2);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SRGR1),srgr1);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCR2),xcr2);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCR1),xcr1);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCR2),rcr2); 
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCR1),rcr1); 
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SPCR2),spcr2 & (~(MCBSP_XMIT_RESET)));
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(SPCR1),spcr1 & (~(MCBSP_RCV_RESET)));  

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERC),rcerc);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERD),rcerd);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERE),rcere);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERF),rcerf);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERG),rcerg);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(RCERH),rcerh);

  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERC),xcerc);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERD),xcerd);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERE),xcere);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERF),xcerf);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERG),xcerg);
  _SUBREG_SET(spsa, spsd, MCBSP_ADDR(XCERH),xcerh);
#endif

  IRQ_globalRestore(old_intm);
  return;
}      
 
/*----------------------------------------------------------------------------*/




/*----------------------------------------------------------------------------*/
#endif /* USEDEFS */

#else
  #ifndef _MCBSP_MOD_ /* MCBSP_SUPPORT */
    #error MCBSP Module Not Supported on Specified Target
  #endif
#endif /* MCBSP_SUPPORT */

#endif /* _CSL_MCBSP_H_ */
/******************************************************************************\
* End of csl_mcbsp.h
\******************************************************************************/

