/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... PLL
* FILENAME...... csl_pll.h
* DATE CREATED.. Sun 06/20/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... service layer
* PREREQUISITS.. csl_chiphal.h, csl.h, csl_pllhal.h
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:        06/20/1999   
*   MODIFIED:       12/06/2000 Modification for C54x.
*   MODIFIED:       02/18/2000 C54x Romability .
*   LAST MODIFIED:  06/19/2000 make #ifdefs consistent with new csl_ header names,
*                              cplusplus naming compatability
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the PLL module)
*
*
*
\******************************************************************************/
#ifndef _CSL_PLL_H_
#define _CSL_PLL_H_

#include <csl_chiphal.h>

#if (_PLL_SUPPORT)

#include <_csl.h>
#include <csl_pllhal.h>

/****************************************\
* PLL scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _PLL_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* PLL global macro declarations
\****************************************/ 
#define PLL_DEVICE_CNT           _PLL_DEVICE_CNT

/* error codes */
#define PLL_ERR_MAJOR            (ERR_BASE_PLL) 
#define PLL_ERR_ALLOC            (0x00000000)
#define PLL_ERR_INVALID_HANDLE   (0x00000001)


/*----------------------------------------------------------------------------*/
#define PLL_RESET()   CLKMD = 0


/*******************************************\
* PLL global macro definition : ROMABILITY
\*******************************************/ 
/* Reserved ROM Area for pllData.h */
/* Data definition */   
#define PLL_Initialized            PLL_SYM(0)
#define PLL_InUse                  PLL_SYM(1)


/* make CLKMD register value based on symbolic constants */

#define PLL_CLKMD_RMK(pllmul, plldiv, pllcount, pllonoff, pllndiv)\
  ((Uint16) (   PLL_FMK(CLKMD,PLLNDIV,pllndiv)   |\
                PLL_FMK(CLKMD,PLLONOFF,pllonoff) |\
                PLL_FMK(CLKMD,PLLCOUNT,pllcount) |\
                PLL_FMK(CLKMD,PLLDIV,plldiv)     |\
                PLL_FMK(CLKMD,PLLMUL,pllmul)      \
           )\
  )

#define PLL_CLKMD_RMKS(pllmul_sym,plldiv_sym,pllcount_sym, pllonoff_sym, pllndiv_sym)\
  ((Uint16) (   PLL_FMKS(CLKMD,PLLNDIV,pllndiv_sym)   |\
                PLL_FMKS(CLKMD,PLLONOFF,pllonoff_sym) |\
                PLL_FMKS(CLKMD,PLLCOUNT,pllcount_sym) |\
                PLL_FMKS(CLKMD,PLLDIV,plldiv_sym)     |\
                PLL_FMKS(CLKMD,PLLMUL,pllmul_sym)      \
           )\
  )


/* Default CLKMD register values                         */

#define PLL_CLKMD_DEFAULT               (0x0000u)

#define PLL_CLKMD_PLLNDIV_OFF           (0x0000u)
#define PLL_CLKMD_PLLNDIV_ON            (0x0001u)

#define PLL_CLKMD_PLLONOFF_OFF          (0x0000u)
#define PLL_CLKMD_PLLONOFF_ON           (0x0001u)

#define PLL_CLKMD_PLLCOUNT_OF(x)        ((Uint16)x)

#define PLL_CLKMD_PLLDIV_OFF            (0x0000u)
#define PLL_CLKMD_PLLDIV_ON             (0x0001u)

#define PLL_CLKMD_PLLMUL_OF(x)          ((Uint16)x)

#define PLL_MODE_DIV				1
#define PLL_MODE_MUL				2

/****************************************\
* PLL global typedef declarations
\****************************************/

/* device configuration structure */
typedef struct {
  Uint16 pllmode;
  Uint16 pllcount;
  Uint16 pllmul;
#if (CHIP_5410 | CHIP_5416)
  Uint16 divfct;
#endif
} PLL_Config;


/****************************************\
* PLL global function declarations
\****************************************/

/****************************************\
* PLL inline function declarations
\****************************************/

IDECL void PLL_config( PLL_Config *Config);
#if (CHIP_5410 | CHIP_5416)
IDECL void PLL_configArgs(Uint16 pllmode, Uint16 pmul, Uint16 pcnt, Uint16 divfct);
#else
IDECL void PLL_configArgs(Uint16 pllmode, Uint16 pmul, Uint16 pcnt);
#endif
IDECL int PLL_setFreq (Uint16 mul,Uint16 div);

/****************************************\
* PLL inline function definitions
\****************************************/
#ifdef USEDEFS

/*----------------------------------------------------------------------------*/
IDEF void PLL_config(PLL_Config *pcfg) {
  Uint16  lockUp = (pcfg->pllmode) & PLL_MODE_DIV;
  Uint16  pllndiv = lockUp;
  Uint16  plldiv = lockUp ? 0:1;
  Uint16  pcnt = pcfg->pllcount;
  Uint16  pmul = pcfg->pllmul;
  

  #if (CHIP_5410 | CHIP_5416)
    EBUS_FSET(BSCR,DIVFCT,pcfg->divfct);
  #endif

  PLL_FSET(CLKMD,PLLDIV,1);
  
  while (PLL_FGET(CLKMD,PLLSTATUS));
  
  PLL_RSET(CLKMD, PLL_CLKMD_RMK(pmul, plldiv, pcnt, 1, pllndiv));

  while(PLL_FGET(CLKMD,PLLSTATUS)!=lockUp);
}   
/*----------------------------------------------------------------------------*/
#if (CHIP_5410 | CHIP_5416)
IDEF void PLL_configArgs(Uint16 pllmode, Uint16 pmul, Uint16 pcnt, Uint16 divfct) {
#else
IDEF void PLL_configArgs(Uint16 pllmode, Uint16 pmul, Uint16 pcnt) {
#endif
  Uint16 lockUp = (pllmode & PLL_MODE_DIV)? 0:1;
  Uint16  pllndiv = lockUp;
  Uint16  plldiv = lockUp ? 0:1;

  
  #if (CHIP_5410 | CHIP_5416)
    EBUS_FSET(BSCR,DIVFCT,divfct);
  #endif

  PLL_FSET(CLKMD,PLLDIV,1);
  while (PLL_FGET(CLKMD,PLLSTATUS));
  PLL_RSET(CLKMD,PLL_CLKMD_RMK(pmul, plldiv, pcnt, 1, pllndiv));
  while(PLL_FGET(CLKMD,PLLSTATUS)!=lockUp);
}
   
/*----------------------------------------------------------------------------*/
#endif /*USEDEFS */
#else
  #ifndef _PLL_MOD_ /*PLL_SUPPORT */
    #error PLL Module Not Supported on Specified Target
  #endif
#endif /*PLL_SUPPORT */

#endif /* _CSL_PLL_H_ */                
/******************************************************************************\
* End of csl_pll.h
\******************************************************************************/

