/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... PLL
* FILENAME...... pllhal.h
* DATE CREATED.. Sun 05/07/2000
* PROJECT....... MCRTE - multichannel runtime environment
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
* 05/07/2000 created by (KSB) for TMS320C54xx
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the PLL module)
*
* Registers Covered:
*   (RW) _PLL_CLKMD
\******************************************************************************/
#ifndef _PLLHAL_H_
#define _PLLHAL_H_

#include <csl_chiphal.h>

#if (_PLL_SUPPORT)

/****************************************\
* _PLL scope and inline control macros
\****************************************/
#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#define IDECL static inline
#define USEDEFS
#define IDEF  static inline

/*============================================================================*\
* misc declarations
\*============================================================================*/
#define _PLL_DEVICE_CNT 1

/*============================================================================*\
 * Register Address Macros
\*============================================================================*/

#define _PLL_CLKMD_ADDR           (0x0058u)
#define _PLL_CLKMD                REG16(_PLL_CLKMD_ADDR)
#define _CLKMD                    REG16(_PLL_CLKMD_ADDR)

#define PLL_ADDR(Reg)                  _PLL_##Reg##_ADDR
#define PLL_RGET(Reg)                  _PLL_##Reg##_GET()
#define PLL_RSET(Reg,Val)              _PLL_##Reg##_SET(Val)
#define PLL_RAOI(Reg,AND,OR,INV)       _PLL_##Reg##_AOI(AND,OR,INV)
#define PLL_FGET(Reg,Field)            _PLL_##Reg##_FGET(##Field)
#define PLL_FSET(Reg,Field,Val)        _PLL_##Reg##_FSET(##Field,Val)
#define PLL_FSETS(Reg,Field,Sym)       PLL_FSET(Reg,Field,PLL_##Reg##_##Field##_##Sym)
#define PLL_FMK(Reg,Field,Val)         _PLL_##Reg##_##Field##_MK(Val)
#define PLL_FMKS(Reg,Field,Sym)        PLL_FMK(Reg,Field,PLL_##Reg##_##Field##_##Sym)
#define PLL_FAOI(Reg,Field,AND,OR,INV) _PLL_##Reg##_FAOI(Field,AND,OR,INV)

#define _PLL_CLKMD_GET()               _REG_GET(_PLL_CLKMD_ADDR)
#define _PLL_CLKMD_SET(Val)            _REG_SET(_PLL_CLKMD_ADDR,Val)
#define _PLL_CLKMD_AOI(AND,OR,INV)     _REG_AOI(_PLL_CLKMD_ADDR,AND,OR,INV)
#define _PLL_CLKMD_FGET(Field)         _FIELD_GET(_PLL_CLKMD_ADDR,_PLL_CLKMD_##Field)
#define _PLL_CLKMD_FSET(Field,Val)     _FIELD_SET(_PLL_CLKMD_ADDR,_PLL_CLKMD_##Field,Val)
#define _PLL_CLKMD_FAOI(Field,AND,OR,INV)\
   _FIELD_AOI(_PLL_CLKMD_ADDR,_PLL_CLKMD_##Field,AND,OR,INV)

#define _PLL_CLKMD_CFG(pllmul, plldiv, pllcount, pllonoff, pllndiv)\
  HREG_SET(_PLL_CLKMD_ADDR,\
  (Uint16) (   _PLL_CLKMD_PLLNDIV_MK(pllndiv)    |\
               _PLL_CLKMD_PLLONOFF_MK(pllonoff)  |\
               _PLL_CLKMD_PLLCOUNT_MK(pllcount)  |\
               _PLL_CLKMD_PLLDIV_MK(plldiv)      |\
               _PLL_CLKMD_PLLMUL_MK(pllmul)\
           )\
   )

/******************************************************************************\
* _PLL_CLKMD - clock mode register
*
* Fields:
*   (RW) _PLL_CLKMD_PLLMUL
*   (RW) _PLL_CLKMD_PLLDIV
*   (RW) _PLL_CLKMD_PLLCOUNT
*   (RW) _PLL_CLKMD_PLLONOFF
*   (RW) _PLL_CLKMD_PLLNDIV
*   (R)  _PLL_CLKMD_PLLSTATUS
*
\******************************************************************************/

/*----------------------------------------------------------------------------*\
* Clock Mode Register (CLKMD) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) PLL_CLKMD_PLLMUL: PLL multiplier
\*----------------------------------------------------------------------------*/
#define _PLL_CLKMD_PLLMUL_SHIFT     (0x000cu)
#define _PLL_CLKMD_PLLMUL_MK(n)     (((Uint16)(n) & 0x000Fu)<< _PLL_CLKMD_PLLMUL_SHIFT)
#define _PLL_CLKMD_PLLMUL_MASK      (_PLL_CLKMD_PLLMUL_MK(0xFu))
#define _PLL_CLKMD_PLLMUL_CLR       (~(_PLL_CLKMD_PLLMUL_MASK))

/*----------------------------------------------------------------------------*\
* (RW) PLL_CLKMD_PLLDIV: PLL divider
\*----------------------------------------------------------------------------*/
#define _PLL_CLKMD_PLLDIV_SHIFT     (0x000bu)
#define _PLL_CLKMD_PLLDIV_MK(n)     (((Uint16)(n) & 0x0001u)<< _PLL_CLKMD_PLLDIV_SHIFT)
#define _PLL_CLKMD_PLLDIV_MASK      (_PLL_CLKMD_PLLDIV_MK(0x1u))
#define _PLL_CLKMD_PLLDIV_CLR       (~(_PLL_CLKMD_PLLDIV_MASK))

/*----------------------------------------------------------------------------*\
* (RW) PLL_CLKMD_PLLCOUNT: PLL divider
\*----------------------------------------------------------------------------*/
#define _PLL_CLKMD_PLLCOUNT_SHIFT   (0x0003u)
#define _PLL_CLKMD_PLLCOUNT_MK(n)   (((Uint16)(n) & 0x00FFu)<< _PLL_CLKMD_PLLCOUNT_SHIFT)
#define _PLL_CLKMD_PLLCOUNT_MASK    (_PLL_CLKMD_PLLCOUNT_MK(0xFFu))
#define _PLL_CLKMD_PLLCOUNT_CLR     (~(_PLL_CLKMD_PLLCOUNT_MASK))

/*----------------------------------------------------------------------------*\
* (RW) PLL_CLKMD_PLLONOFF: Enable/disable analog part of clock generator
\*----------------------------------------------------------------------------*/
#define _PLL_CLKMD_PLLONOFF_SHIFT   (0x0002u)
#define _PLL_CLKMD_PLLONOFF_MK(n)   (((Uint16)(n) & 0x0001u)<< _PLL_CLKMD_PLLONOFF_SHIFT)
#define _PLL_CLKMD_PLLONOFF_MASK    (_PLL_CLKMD_PLLONOFF_MK(0x1u))
#define _PLL_CLKMD_PLLONOFF_CLR     (~(_PLL_CLKMD_PLLONOFF_MASK))

/*----------------------------------------------------------------------------*\
* (RW) PLL_CLKMD_PLLNDIV: PLL clock generator select
\*----------------------------------------------------------------------------*/
#define _PLL_CLKMD_PLLNDIV_SHIFT    (0x0001u)
#define _PLL_CLKMD_PLLNDIV_MK(n)    (((Uint16)(n) & 0x0001u)<< _PLL_CLKMD_PLLNDIV_SHIFT)
#define _PLL_CLKMD_PLLNDIV_MASK     (_PLL_CLKMD_PLLNDIV_MK(0x1u))
#define _PLL_CLKMD_PLLNDIV_CLR      (~(_PLL_CLKMD_PLLNDIV_MASK))

/*----------------------------------------------------------------------------*\
* (R) PLL_CLKMD_PLLSTATUS: PLL status
\*----------------------------------------------------------------------------*/
#define _PLL_CLKMD_PLLSTATUS_SHIFT  (0x0000u)
#define _PLL_CLKMD_PLLSTATUS_MK(n)  (((Uint16)(n) & 0x0001u)<< _PLL_CLKMD_PLLSTATUS_SHIFT)
#define _PLL_CLKMD_PLLSTATUS_MASK   (_PLL_CLKMD_PLLSTATUS_MK(0x1u))
#define _PLL_CLKMD_PLLSTATUS_CLR    (~(_PLL_CLKMD_PLLSTATUS_MASK))

#else
  #ifndef __PLL_MOD_   /* PLL_SUPPORT */
    #error PLL HAL Module Not Supported on Specified Target
  #endif
#endif   /* PLL_SUPPORT */

#endif   /* _PLLHAL_H_ */
/******************************************************************************\
* End of pllhal.h
\******************************************************************************/
