/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... PWR
* FILENAME...... csl_pwr.h
* DATE CREATED.. Thu 11/11/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... CSL service layer
* PREREQUISITS..
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:       11/11/1999 
*   MODIFIED:      12/01/1999 Modified for TMS320C54xx
*   LAST MODIFIED: 06/19/2000 make #ifdefs consistent with new csl_ headers,
*                             cplusplus compatability
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (service layer interface file for the PLL module)
*
*
*
\******************************************************************************/
#ifndef _CSL_PWR_H_
#define _CSL_PWR_H_


#include <csl_chiphal.h>

#if (_PWR_SUPPORT)

#include <_csl.h>
#include <csl_pwrhal.h>      

/****************************************\
* PWR scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _PWR_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* PWR global macro declarations
\****************************************/
#define PWR_ERR_MAJOR         (ERR_BASE_PWR)
#define PWR_ERR_INVALID_MODE   (0x00000000)
  

#ifdef _MCRTE_DEBUG
  #define PWR_ASSERT_MODE(mode)\
   if((mode <1) || (mode >3)) {\
     ERR_submit(PWR_ERR_MAJOR, PWR_ERR_INVALID_MODE);\
     mode;\
   }
#else
  #define PWR_ASSERT_MODE(mode)
#endif
/*******************************************\
* PWR global macro definition : ROMABILITY
\*******************************************/  
/* Reserved ROM Area for PWR Data */
  
/****************************************\
* PWR global typedef declarations
\****************************************/
#define PWR_CPU_DOWN		(1u)
#define PWR_CPU_PER_DOWN	(2u)
#define PWR_CPU_PER_PLL_DOWN	(3u)

#define PWR_WAKEUP_MI		(1u)
#define PWR_WAKEUP_NMI		(0u)


/****************************************\
* PWR global variable declarations
\****************************************/

/****************************************\
* PWR global function declarations
\****************************************/

/****************************************\
* PWR inline function declarations
\****************************************/
IDECL void PWR_powerDown(Uint16 pwrDownMode, Uint16 wakeUpMode);

/****************************************\
* PWR inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*\
*wake up and continue intruction after IDLE instruction
\*----------------------------------------------------------------------------*/
IDEF void PWR_powerDown(Uint16 pwrDownMode, Uint16 wakeUpMode) {
 
 if (wakeUpMode) {
    IRQ_globalRestore(0);
  }

  switch(pwrDownMode) {
    case PWR_CPU_DOWN: 
		asm("  IDLE #1  ;*** Note: Automatic text generated by CSL");
		break;
    case PWR_CPU_PER_DOWN:
		asm("  IDLE #2  ;*** Note: Automatic text generated by CSL"); 
		break;
    case PWR_CPU_PER_PLL_DOWN:
		asm("  IDLE #3  ;*** Note: Automatic text generated by CSL"); 
		break;
    default: {} 
       /* ERR_submit(PWR_ERR_MAJOR, PWR_ERR_INVALID_MODE); */
  }
}
/*----------------------------------------------------------------------------*/
#endif /* USEDEFS */

#elif (!(_PWR_MOD_))
     #error PWR Module Not Supported on Specified Target 
#endif /* PWR_SUPPORT */
#endif /* _CSL_PWR_H_ */
/******************************************************************************\
* End of csl_pwr.h
\******************************************************************************/

