/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE.NAME... HCFG - HAL configuration module
* FILENAME...... stdinc.h
* DATE CREATED.. 03/11/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* IMPORTS....... 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:       03/11/1999 
*   MODIFIED:      05/04/1999 modified for c54x
*   MODIFIED:      06/19/2000
*   LAST MODIFIED: 04/18/2001 modified typedefs to avoid conflict with BIOS types
*------------------------------------------------------------------------------
* DESCRIPTION:  (CHIP memory mapped register definitions)
*
*
*
\******************************************************************************/


#ifndef _CSL_STDINC_H_
#define _CSL_STDINC_H_

/****************************************\
* STDINC macro declarations
\****************************************/

#ifndef TRUE
#define TRUE             ((CSLBool)(1))
#endif
#ifndef FALSE
#define FALSE            ((CSLBool)(0))
#endif
#define YES              ((CSLBool)(1))
#define NO               ((CSLBool)(0))
#ifndef AND_DEFAULT
#define AND_DEFAULT      ((Uint16)0xFFFFu)
#endif
#ifndef OR_DEFAULT
#define OR_DEFAULT       ((Uint16)0x0000u)
#endif
#ifndef INV_DEFAULT
#define INV_DEFAULT      ((Uint16)0x0000u)
#endif
/* invalid pointer */
#define INV    ((void*)(-1))

/* useful macros for declaring peripheral registers */

#define REG16(addr)		(*(volatile Uint16*)(addr))
#define SUB_ADDR(addr)		((Uint16)(addr))

/****************************************\
* STDINC macrso for enabling/disabling   
* interrupts
\****************************************/

#define ENABLE_INTERRUPTS\
 { asm("\t .newblock");\
   asm("\t  bd __STDINC_rsetINTM?");\
   asm("\t  rsbx INTM");\
   asm("\t  nop");\
   asm("__STDINC_rsetINTM?");\
   asm("\t  nop");\
 }
#define DISABLE_INTERRUPTS\
 { asm("\t .newblock");\
   asm("\t  bd __STDINC_setINTM?");\
   asm("\t  ssbx INTM");\
   asm("\t  nop");\
   asm("__STDINC_setINTM?");\
   asm("\t  nop");\
 }


/****************************************\
* STDINC typedef declarations
\****************************************/

typedef unsigned char	Uchar;
typedef unsigned short	Uint16;
typedef unsigned long 	Uint32;
typedef short		Int16;
typedef long		Int32;
typedef void *           Handle;

/*-------------------------------*\
* BIOS already defines these 
\*-------------------------------*/


typedef char		 CSLChar;
typedef unsigned short   CSLBool;


/*******************************************************************************\
* Setup (non Rom model) or retrieve (ROM model) address of global data
\*******************************************************************************/
/* ROM Area */
#define CSL_DATA_PTR     (0x007bu)

/****************************************\
* CSL Resource Management Masks
\****************************************/

 /*============================================================================*\
 * register bit manipulation macros
 \*============================================================================*/

  /* memory mapped register macros */
  #define _FIELD_GET(RegAddr,FIELD) (Uint16)( \
  (REG16(RegAddr)&##FIELD##_MASK)>>##FIELD##_SHIFT \
  ) 

  #define _FIELD_SET(RegAddr,FIELD,Val) REG16(RegAddr)=(Uint16)( \
  (REG16(RegAddr)&##FIELD##_CLR)|((Uint16)##FIELD##_MK(Val)) \
  )

  #define _FIELD_AOI(RegAddr,FIELD,AND,OR,INV) REG16(RegAddr)=(Uint16)( \
  ((((REG16(RegAddr)&##FIELD##_MASK) & AND) | OR) ^ INV)\
  )

  #define _FIELD_AND(RegAddr,FIELD,Val) REG16(RegAddr)=(Uint16)( \
  (REG16(RegAddr)&##FIELD##_CLR) | ((REG16(RegAddr)) & ((Uint16)##FIELD##_MK(Val))) \
  )

  #define _FIELD_OR(RegAddr,FIELD,Val) REG16(RegAddr)=(Uint16)( \
  (REG16(RegAddr)) | ((Uint16)##FIELD##_MK(Val)) \
  )

  #define _FIELD_XOR(RegAddr,FIELD,Val) REG16(RegAddr)=(Uint16)( \
  (REG16(RegAddr)&##FIELD##_CLR) | ((REG16(RegAddr)) ^ ((Uint16)##FIELD##_MK(Val))) \
  )

  #define _FIELD_SHIFT(FIELD,Val)   ((Uint16)##FIELD##_MK(Val))

  #define _REG32_GET(RegAddr)       (Uint32)Reg32(RegAddr)

  #define _REG_GET(RegAddr)         (Uint16)REG16(RegAddr)

  #define _REG32_SET(RegAddr,Val)    Reg32(RegAddr)=(Uint32)(Val)
  
  #define _REG_SET(RegAddr,Val)      REG16(RegAddr)=(Uint16)(Val)

  #define _REG_AOI(RegAddr,AND,OR,INV)\
     REG16(RegAddr) = (Uint16)(((REG16(RegAddr) & AND) | OR ) ^ INV)

  #define _REG_AND(RegAddr,Val)      REG16(RegAddr) &= (Uint16)(Val)

  #define _REG_OR(RegAddr,Val)       REG16(RegAddr) |= (Uint16)(Val)

  #define _REG_XOR(RegAddr,Val)      REG16(RegAddr) ^= (Uint16)(Val)


  #define HSSBX_SET(BIT)\
       asm( "\t.newblock ; <=== Begin CSL generated inline assembly");\
       asm( "\tbd __CHIP_set?    ; ");\
       asm( "\tSSBX\t" #BIT);\
       asm( "\tnop");\
       asm( "__CHIP_set? ");\
       asm( "\tnop       ; <=== End CSL generated inline assembly");

  #define HRSBX_SET(BIT)\
       asm( "\t.newblock ; <=== Begin CSL generated inline assembly");\
       asm( "\tbd __CHIP_rset?    ; ");\
       asm( "\tRSBX\t" #BIT);\
       asm( "\tnop");\
       asm( "__CHIP_rset? ");\
       asm( "\tnop       ; <=== End CSL generated inline assembly");
  /*============================================================================*\
   * Set fields in status registers that may only be set via RSBX and SSBX
  \*============================================================================*/

 #define HSBX_SET(BIT, val)\
    { if (val){ HSSBX_SET(BIT) } else { HRSBX_SET(BIT) }}

  /*============================================================================*\
  * Sub register bit manipulation macros
  \*============================================================================*/

  #define _SUBFIELD_SET(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankAddr, FIELD, Val) \
    { REG16(SubBankAddrRegAddr) = (Uint16)(SubBankAddr);\
      REG16(SubBankDataRegAddr)=(Uint16)( \
     (REG16(SubBankDataRegAddr)&##FIELD##_CLR)| \
     ((Uint16)##FIELD##_MK(Val)) \
     );\
    }

  #define _SUBFIELD_GET(SubBankAddrRegAddr,SubBankDataRegAddr, SubBankAddr, FIELD) ((Uint16)( \
     REG16(SubBankAddrRegAddr) = (Uint16)(SubBankAddr),\
     ((REG16(SubBankDataRegAddr)&##FIELD##_MASK)>>##FIELD##_SHIFT)\
     )\
   )  
  /*============================================================================*\
  * Sub register read/write macros
  \*============================================================================*/
  #define _SUBREG_SET(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr, Val)\
    {REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr);\
     REG16(SubBankDataRegAddr) = (Uint16)Val;\
    }

  #define _SUBREG_AOI(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr, AND, OR, INV)\
    {REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr);\
     REG16(SubBankDataRegAddr) = (Uint16)(((REG16(SubBankDataRegAddr) & AND) | OR) ^ INV);\
    }
 

  #define _SUBREG_AND(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr, Val)\
    {REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr);\
     REG16(SubBankDataRegAddr) &= (Uint16)Val;\
    }

  #define _SUBREG_OR(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr, Val)\
    {REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr);\
     REG16(SubBankDataRegAddr) |= (Uint16)Val;\
    }

  #define _SUBREG_XOR(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr, Val)\
    {REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr);\
     REG16(SubBankDataRegAddr) ^= (Uint16)Val;\
    }

  #define _SUBREG_GET(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr) ((Uint16) (\
     REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr),\
     REG16(SubBankDataRegAddr)\
     )\
   )

  #define _SUBREG_SETI(SubBankDataRegAddr, Val)\
  {REG16(SubBankDataRegAddr) = (Uint16)Val;}

  #define _SUBREG_GETI(SubBankDataRegAddr)\
  (Uint16) REG16(SubBankDataRegAddr)

  #define _SUBREG_SETN(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr, Val)\
  {REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr);\
   REG16(SubBankDataRegAddr) = (Uint16)Val;\
  }

  #define _SUBREG_GETN(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankRegAddr) ((Uint16) (\
   REG16(SubBankAddrRegAddr) = (Uint16)(SubBankRegAddr),\
   REG16(SubBankDataRegAddr)\
   )\
  )

  #define _SUBFIELD_SETN(SubBankAddrRegAddr, SubBankDataRegAddr, SubBankAddr, FIELD, Val) \
    { REG16(SubBankAddrRegAddr) = (Uint16)(SubBankAddr);\
      REG16(SubBankDataRegAddr)=(Uint16)( \
     (REG16(SubBankDataRegAddr)&##FIELD##_CLR)| \
     ((Uint16)##FIELD##_MK(Val)) \
     );\
    }


  #define _SUBFIELD_GETN(SubBankAddrRegAddr,SubBankDataRegAddr, SubBankAddr, FIELD) ((Uint16)( \
     REG16(SubBankAddrRegAddr) = (Uint16)(SubBankAddr),\
     ((REG16(SubBankDataRegAddr)&##FIELD##_MASK)>>##FIELD##_SHIFT)\
     )\
   )  

  #define _SUBFIELD_SETI(SubBankDataRegAddr, SubBankAddr, FIELD, Val) \
    {REG16(SubBankDataRegAddr)=(Uint16)( \
     (REG16(SubBankDataRegAddr)&##FIELD##_CLR)| \
     ((Uint16)##FIELD##_MK(Val)) \
     );\
    }

  #define _SUBFIELD_GETI(SubBankDataRegAddr, SubBankAddr, FIELD) ((Uint16)( \
     ((REG16(SubBankDataRegAddr)&##FIELD##_MASK)>>##FIELD##_SHIFT)\
     )\
   )  

 /*===========================================================================*\
 * control register macros 
 \*===========================================================================*/

  #define _CRFIELD_GET(RegAddr,FIELD) (Uint16)( \
    (REG16(RegAddr)&##FIELD##_MASK)>>##FIELD##_SHIFT \
  )  

  #define _CRFIELD_SET(RegAddr,FIELD,Val) REG16(RegAddr)=(Uint16)( \
  (REG16(RegAddr)& ##FIELD##_CLR)| \
  (((Uint16) ##FIELD##_MK(Val)) \
  ) 

/****************************************\
* STDINC variable declarations
\****************************************/

/****************************************\
* STDINC function declarations
\****************************************/

#endif
/******************************************************************************\
* End of csl_stdinc.h
\******************************************************************************/

