/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... TIMER
* FILENAME...... csl_timer.h
* DATE CREATED.. Sun 06/20/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... service layer
* PREREQUISITS.. csl.h
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:       06/20/1999 (BWC) Created for C6x.  
*   MODIFIED:      12/06/2000 (FSCA) Modification for C54x.
*   MODIFIED:      02/18/2000 (FSCA) C54x Romability .
*   MODIFIED:      06/19/2000 make #ifdefs consistent with new csl_ header names,
*                            c++ compatability
*   LAST MODIFIED: 05/31/2001 Updated for new initialization model
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the TIMER module)
*
*
*
\******************************************************************************/
#ifndef _CSL_TIMER_H_
#define _CSL_TIMER_H_

#include <csl_chiphal.h>


#if (_TIMER_SUPPORT)

#include <_csl.h>
#include <csl_timerhal.h>

/****************************************\
* TIMER scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _TIMER_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* TIMER global macro declarations
\****************************************/ 
#define TIMER_DEVICE_CNT           _TIMER_DEVICE_CNT

/* TIMER_Open() flags */
#define TIMER_OPEN_RESET           (0x0001)

/* error codes */
#define TIMER_ERR_MAJOR            (ERR_BASE_TIMER) 
#define TIMER_ERR_ALLOC            (0x00000000)
#define TIMER_ERR_INVALID_HANDLE   (0x00000001)

/* device identifiers for TIMER_Open() */
#define TIMER_DEV_ANY  (-1)
#define TIMER_DEV0    (0)
#define TIMER_DEV1    (1)  

/*******************************************\
* TIMER global macro definition : ROMABILITY
\*******************************************/ 
/* Reserved ROM Area for timerData.h */
/* Data definition */   
#define Timer_Initialized            TIMER_SYM(0)
#define Timer_DeviceTable            TIMER_SYM(1)

/* Predefined Device Handlers */
#define TIMER_hDev0   ((TIMER_Handle)&(CSL_TIMER_DATA.Timer[0])) 
#define TIMER_hDev1   ((TIMER_Handle)&(CSL_TIMER_DATA.Timer[1])) 

/*-------------------------------------------*\
* Macros to GET/SET control register and bit
* field values                  
\*-------------------------------------------*/


/*******************************************/
/* Define a debuging assertion macro */ 
/* for validating device handles */
#ifdef _MCRTE_DEBUG
  #define TIMER_ASSERT_HANDLE(hTimer,RetExp) \
    if (hTimer == INV) { \
      ERR_submit(TIMER_ERR_MAJOR, TIMER_ERR_INVALID_HANDLE); \
      RetExp; \
    }
#else
  #define TIMER_ASSERT_HANDLE(hTimer,RetExp)
#endif

/*-----------------------------------------------------------------------*/
/* The following macros are used to construct peripheral register        */
/* values based on symbolic constants. They will be useful to initialize */
/* the TIMER_Config structure in a readable way.                         */
/*-----------------------------------------------------------------------*/

/* make TCR register value based on symbolic constants */

#define TIMER_TCR_RMK(soft,free,trb,tss,tddr) \
 ((Uint16) ( \
  ( TIMER_FMK(TCR,SOFT,soft))|\
  ( TIMER_FMK(TCR,FREE,free))|\
  ( TIMER_FMK(TCR,TRB,trb))|\
  ( TIMER_FMK(TCR,TSS,tss))|\
  ( TIMER_FMK(TCR,TDDR,tddr))\
  )\
)  

#define TIMER_TCR_RMKS(soft_sym,free_sym,trb_sym,tss_sym,tddr_sym) \
 ((Uint16) ( \
  ( TIMER_FMKS(TCR,SOFT,soft_sym))|\
  ( TIMER_FMKS(TCR,FREE,free_sym))|\
  ( TIMER_FMKS(TCR,TRB,trb_sym))|\
  ( TIMER_FMKS(TCR,TSS,tss_sym))|\
  ( TIMER_FMKS(TCR,TDDR,tddr_sym))\
  )\
)  

#define TIMER_PRD_MK(prd)\
  (Uint16)(TIMER_FMK(PRD,PRD,prd))
  
/* default TCR register value */
#define TIMER_TCR_DEFAULT                 (0x0000)

/* TCR field values */
#define TIMER_TCR_SOFT_BRKPTNOW           (0x0000)
#define TIMER_TCR_SOFT_WAITZERO           (0x0001)
#define TIMER_TCR_FREE_WITHSOFT           (0x0000)
#define TIMER_TCR_FREE_NOSOFT             (0x0001)
#define TIMER_TCR_TRB_NORESET             (0x0000)
#define TIMER_TCR_TRB_RESET               (0x0001)
#define TIMER_TCR_TSS_START               (0x0000)
#define TIMER_TCR_TSS_STOP                (0x0001)

#define TIMER_TCR_TDDR_OF(x)              (x)

/* TSCR field values */
#define TIMER_TSCR_PREMD_DIRECT           (0x0000)
#define TIMER_TSCR_PREMD_INDIRECT         (0x0001)

#define TIMER_PRD_DEFAULT                 (0xFFFF)
#define TIMER_TIM_DEFAULT                 (0xFFFF)

/* make CLKMD register value based on symbolic constants */

/****************************************\
* TIMER global typedef declarations
\****************************************/
/* device handle type */

typedef struct {
  Uint16 Private;
} *TIMER_Handle;

/* private object, not to be used by application code */

/* device configuration structure */
typedef struct {
  Uint16 tcr;
#if (_TIMER_PRSC_MODE_SUPPORT)
  Uint16 tscr;
#endif
  Uint16 prd;
} TIMER_Config;

/****************************************\
* TIMER global variable declarations
\****************************************/ 


/****************************************\
* TIMER global function declarations
\****************************************/
CSLAPI void TIMER_init();
CSLAPI void TIMER_reset(TIMER_Handle hTimer);

CSLAPI TIMER_Handle TIMER_open(int DevNum, Uint16 Flags);
CSLAPI void TIMER_close(TIMER_Handle hTimer);


/****************************************\
* TIMER inline function declarations
\****************************************/
IDECL Uint16 TIMER_getEventId(TIMER_Handle hTimer);

/* TSS stop & start status  **/

IDECL void TIMER_start(TIMER_Handle hTimer);
IDECL void TIMER_stop(TIMER_Handle hTimer); 
IDECL void TIMER_reload(TIMER_Handle hTimer);
IDECL void TIMER_config(TIMER_Handle hTimer, TIMER_Config *Config);
IDECL void TIMER_getConfig(TIMER_Handle hTimer, TIMER_Config *Config);

#if (_TIMER_PRSC_MODE_SUPPORT)
  IDECL void TIMER_configArgs(TIMER_Handle hTimer, Uint16 tcr, Uint16 tscr, Uint16 prd);
#else
  IDECL void TIMER_configArgs(TIMER_Handle hTimer, Uint16 tcr, Uint16 prd);
#endif

/****************************************\
* TIMER inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
IDEF Uint16 TIMER_getEventId(TIMER_Handle hTimer) {
  return (Uint16)(((TIMER_PrivateObj*)hTimer)->EventId);
}
/*----------------------------------------------------------------------------*/
IDEF void TIMER_start(TIMER_Handle hTimer) {
  TIMER_FSETH(hTimer,TCR,TSS,0);
}
/*----------------------------------------------------------------------------*/
IDEF void TIMER_stop(TIMER_Handle hTimer) {
  TIMER_FSETH(hTimer,TCR,TSS,1);
} 
/*----------------------------------------------------------------------------*/
IDEF void TIMER_reload(TIMER_Handle hTimer) {
  TIMER_FSETH(hTimer,TCR,TRB,1);
}

/*----------------------------------------------------------------------------*/
IDEF void TIMER_config(TIMER_Handle hTimer, TIMER_Config *Config) {
  int old_intm;
  TIMER_ASSERT_HANDLE(hTimer,return);
  old_intm = IRQ_globalDisable();  
  TIMER_RSETH(hTimer,TCR,0x0010u);
#if (_TIMER_PRSC_MODE_SUPPORT)
  TIMER_FSETH(hTimer,TSCR,PREMD,Config->tscr);
#endif
  TIMER_RSETH(hTimer,PRD,Config->prd);
  TIMER_RAOIH(hTimer,TCR,AND_DEFAULT,0x0010u,INV_DEFAULT);   
  IRQ_globalRestore(old_intm);   
}
/*----------------------------------------------------------------------------*/
IDEF void TIMER_getConfig(TIMER_Handle hTimer, TIMER_Config *Config) {
  int old_intm, old_tcr;
  TIMER_ASSERT_HANDLE(hTimer,return);
  old_intm = IRQ_globalDisable();  
  old_tcr =  TIMER_RGETH(hTimer,TCR);
  TIMER_FSETH(hTimer,TCR,TSS,1);
#if (_TIMER_PRSC_MODE_SUPPORT)
  Config->tscr = TIMER_RGETH(hTimer,TSCR);
#endif
  Config->prd = TIMER_RGETH(hTimer,PRD);
  Config->tcr = TIMER_RGETH(hTimer,TCR); 
  TIMER_RSETH(hTimer,TCR,old_tcr);   
  IRQ_globalRestore(old_intm);   
}

/*----------------------------------------------------------------------------*/
#if (_TIMER_PRSC_MODE_SUPPORT)
IDEF void TIMER_configArgs(TIMER_Handle hTimer, Uint16 tcr, Uint16 tscr, Uint16 prd) {
#else 
IDEF void TIMER_configArgs(TIMER_Handle hTimer, Uint16 tcr, Uint16 prd) {
#endif 
  int old_intm;

  TIMER_ASSERT_HANDLE(hTimer,return);
   old_intm = IRQ_globalDisable(); 
    
   TIMER_RSETH(hTimer,TCR,0x0010);
#if (_TIMER_PRSC_MODE_SUPPORT)
   TIMER_RSETH(hTimer,TSCR,tscr);
#endif
   TIMER_RSETH(hTimer,PRD,prd);
   TIMER_RSETH(hTimer,TCR, tcr | 0x0010);   
  
  IRQ_globalRestore(old_intm);   
}
/*----------------------------------------------------------------------------*/
#endif /*USEDEFS */
#else
  #ifndef _TIMER_MOD_ /*TIMER_SUPPORT */
    #error TIMER Module Not Supported on Specified Target
  #endif
#endif /*TIMER_SUPPORT */

#endif /* _CSL_TIMER_H_ */                
/******************************************************************************\
* End of csl_timer.h
\******************************************************************************/

