/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... TIMER
* FILENAME...... csl_timerhal.h
* DATE CREATED.. Tues 10/26/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:          06/20/1999 
*   MODIFIED:         10/26/1999 Modified for TMS320C54xx  
*   MODIFIED:         12/01/1999 Modification of Registern Names: TIM,TCR.
*                                Correction of Register ADDR.
*   LAST MODIFIED:    06/19/2000 make #ifdefs consistent with new csl_ header names,
*                                cplusplus comptability
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the TIMER module)
*
* Registers Covered:
*   (RW) _TIMER_TCR0 - timer 0 control register
*   (RW) _TIMER_TCR1 - timer 1 control register
*   (RW) _TIMER_TSCR0 - timer 0 secondary control register (5472 & 5440 only)
*   (RW) _TIMER_PRD0 - timer 0 period register
*   (RW) _TIMER_PRD1 - timer 1 perid register
*   (RW) _TIMER_TIM0 - timer 0 count register
*   (RW) _TIMER_TIM1 - timer 1 count register
*
\******************************************************************************/
#ifndef _CSL_TIMERHAL_H_
#define _CSL_TIMERHAL_H_


#include <csl_chiphal.h>

#if (_TIMER_SUPPORT)

/****************************************\
* TIMER scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _TIMER_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/*----------------------------------------------------------------------------*\
* Address Macros:
\*----------------------------------------------------------------------------*/
#if (CHIP_5402 | CHIP_5401 | CHIP_54CST | CHIP_5403 | CHIP_5404 | CHIP_5406 | CHIP_5407)
   #define _TIMER_DEVICE_CNT        2
#else
   #define _TIMER_DEVICE_CNT        1
#endif

#if (CHIP_5402 | CHIP_5401 | CHIP_54CST | CHIP_5403 | CHIP_5404 | CHIP_5406 | CHIP_5407)
  #define _TIMER_TCR1_ADDR          (0x0032u)
  #define _TIMER_TCR1               REG16(_TIMER_TCR1_ADDR)
  #define TCR1                      _TIMER_TCR1
  #define _TIMER_PRD1_ADDR          (0x0031u)
  #define _TIMER_PRD1               REG16(_TIMER_PRD1_ADDR)
  #define PRD1                      REG16(_TIMER_PRD1_ADDR)
  #define _TIMER_TIM1_ADDR          (0x0030u)
  #define _TIMER_TIM1               REG16(_TIMER_TIM1_ADDR)
  #define TIM1                      REG16(_TIMER_TIM1_ADDR)
#endif

#define _TIMER_TIM0_ADDR           (0x0024u)
#define _TIMER_TIM0                REG16(_TIMER_TIM0_ADDR)
#define TIM0                       REG16(_TIMER_TIM0_ADDR)

#define _TIMER_PRD0_ADDR           (0x0025u)
#define _TIMER_PRD0                REG16(_TIMER_PRD0_ADDR)
#define PRD0                       REG16(_TIMER_PRD0_ADDR)

#define _TIMER_TCR0_ADDR           (0x0026u)
#define _TIMER_TCR0                REG16(_TIMER_TCR0_ADDR)
#define TCR0                       _TIMER_TCR0

#if (_TIMER_PRSC_MODE_SUPPORT)
  #define _TIMER_TSCR0_ADDR        (0x0027u)
  #define _TIMER_TSCR0             REG16(_TIMER_TSCR0_ADDR)
  #define TSCR0                    _TIMER_TSCR0
#endif

#define _TIMER_BASE                (0x0024u)
#define _TIMER_TIM_BASE            (_TIMER_BASE + 0)
#define _TIMER_PRD_BASE            (_TIMER_BASE + 1)
#define _TIMER_TCR_BASE            (_TIMER_BASE + 2)
#if (_TIMER_PRSC_MODE_SUPPORT)
  #define _TIMER_TSCR_BASE         (_TIMER_BASE + 3)
#endif

#define _TIMER_TCR_ADDR(n)          (_TIMER_TCR0_ADDR + (n * 0x000cu))
#define _TIMER_PRD_ADDR(n)          (_TIMER_PRD0_ADDR + (n * 0x000cu))
#define _TIMER_TIM_ADDR(n)          (_TIMER_TIM0_ADDR + (n * 0x000cu)) 

#define _TIMER_TCR(n)               REG16(_TIMER_TCR_ADDR(n))
#define _TIMER_PRD(n)               REG16(_TIMER_PRD_ADDR(n))
#define _TIMER_TIM(n)               REG16(_TIMER_TIM_ADDR(n))
 

#define _TIMER_TCR_ADDRH(Timer)      ((Timer*0x000Cu) + _TIMER_TCR_BASE)
#define _TIMER_PRD_ADDRH(Timer)      ((Timer*0x000Cu) + _TIMER_PRD_BASE)
#define _TIMER_TIM_ADDRH(Timer)      ((Timer*0x000Cu) + _TIMER_TIM_BASE)
#if (_TIMER_PRSC_MODE_SUPPORT)
  #define _TIMER_TSCR_ADDRH(Timer)   ((Timer*0x000Cu) + _TIMER_TSCR_BASE)
  #define _TIMER_TSCR_ADDR(Timer)     ((Timer*0x000Cu) + _TIMER_TSCR_BASE)
#endif

/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/
#define TIMER_RGET(Reg)                     _TIMER_##Reg##_GET()
#define TIMER_ADDR(Reg)                     _TIMER_##Reg##_ADDR
#define TIMER_RSET(Reg,Val)                 _TIMER_##Reg##_SET(Val)
#define TIMER_RAOI(Reg,AND,OR,INV)          _TIMER_##Reg##_AOI(AND,OR,INV)
#define TIMER_FGET(Reg,Field)               _TIMER_##Reg##_FGET(##Field)
#define TIMER_FSET(Reg,Field,Val)           _TIMER_##Reg##_FSET(##Field,Val)
#define TIMER_FAOI(Reg,Field,AND,OR,INV)    _TIMER_##Reg##_FAOI(##Field,AND,OR,INV)
#define TIMER_FMK(Reg,Field,Val)            _TIMER_##Reg##_##Field##_MK(Val)
#define TIMER_FMKS(Reg,Field,Sym)           TIMER_FMK(##Reg,TIMER_##Reg##_##Field##_##Sym)

#define TIMER_RGETH(Handle,Reg)            _TIMER_##Reg##_GET(((TIMER_PrivateObj*)(Handle))->Timer)
#define TIMER_ADDRH(Handle,Reg)            _TIMER_##Reg##_ADDRH(((TIMER_PrivateObj*)(Handle))->Timer)         
#define TIMER_RSETH(Handle,Reg,Val)        _TIMER_##Reg##_SET((((TIMER_PrivateObj*)(Handle))->Timer),Val)
#define TIMER_RAOIH(Handle,Reg,AND,OR,INV) _TIMER_##Reg##_AOI((((TIMER_PrivateObj*)(Handle))->Timer),AND,OR,INV)
#define TIMER_FGETH(Handle,Reg,Field)      _TIMER_##Reg##_FGET((((TIMER_PrivateObj*)(Handle))->Timer),##Field)
#define TIMER_FSETH(Handle,Reg,Field,Val)  _TIMER_##Reg##_FSET((((TIMER_PrivateObj*)(Handle))->Timer),##Field,Val)
#define TIMER_FSETSH(Handle,Reg,Field,Sym)\
  TIMER_FSETH(Handle,##Reg,##Field,TIMER_##Reg##_##Field##_##Sym)
#define TIMER_FAOIH(Handle,Reg,Field,AND,OR,INV)\
   _TIMER_##Reg##_FAOI((((TIMER_PrivateObj*)(Handle))->Timer),##Field,AND,OR,INV)    
#define TIMER_FMKH(Handle,Reg,Field,Val)   _TIMER_##Reg##_##Field##_MK(Val)
#define TIMER_FMKSH(Handle,Reg,Field,Sym)  TIMER_FMK(Reg,TIMER_##Reg##_##Field##_##Sym)

#define TIMER_RGET_H(Handle,Reg)            _TIMER_##Reg##_GET(((TIMER_PrivateObj*)(Handle))->Timer)
#define TIMER_ADDR_H(Handle,Reg)            _TIMER_##Reg##_ADDRH(((TIMER_PrivateObj*)(Handle))->Timer)         
#define TIMER_RSET_H(Handle,Reg,Val)        _TIMER_##Reg##_SET((((TIMER_PrivateObj*)(Handle))->Timer),Val)
#define TIMER_RAOI_H(Handle,Reg,AND,OR,INV) _TIMER_##Reg##_AOI((((TIMER_PrivateObj*)(Handle))->Timer),AND,OR,INV)
#define TIMER_FGET_H(Handle,Reg,Field)      _TIMER_##Reg##_FGET((((TIMER_PrivateObj*)(Handle))->Timer),##Field)
#define TIMER_FSET_H(Handle,Reg,Field,Val)  _TIMER_##Reg##_FSET((((TIMER_PrivateObj*)(Handle))->Timer),##Field,Val)
#define TIMER_FSETS_H(Handle,Reg,Field,Sym)\
  TIMER_FSETH(Handle,##Reg,##Field,TIMER_##Reg##_##Field##_##Sym)
#define TIMER_FAOI_H(Handle,Reg,Field,AND,OR,INV)\
   _TIMER_##Reg##_FAOI((((TIMER_PrivateObj*)(Handle))->Timer),##Field,AND,OR,INV)    
#define TIMER_FMK_H(Handle,Reg,Field,Val)   _TIMER_##Reg##_##Field##_MK(Val)
#define TIMER_FMKS_H(Handle,Reg,Field,Sym)  TIMER_FMK(Reg,TIMER_##Reg##_##Field##_##Sym)


#if (_TIMER_PRSC_MODE_SUPPORT)
  #define _TIMER_TSCR_GET(Timer)              _REG_GET(_TIMER_TSCR_ADDR(Timer))
  #define _TIMER_TSCR_SET(Timer,Val)          _REG_SET(_TIMER_TSCR_ADDR(Timer), Val)
  #define _TIMER_TSCR_AOI(Timer,AND,OR,INV)   _REG_AOI(_TIMER_TSCR_ADDR(Timer),AND,OR,INV)
  #define _TIMER_TSCR_FGET(Timer,Field)       _FIELD_GET(_TIMER_TSCR_ADDR(Timer), _TIMER_TSCR_##Field)
  #define _TIMER_TSCR_FSET(Timer,Field,Val)   _FIELD_SET(_TIMER_TSCR_ADDR(Timer), _TIMER_TSCR_##Field, Val)
  #define _TIMER_TSCR_FAOI(Timer,Field,AND,OR,INV)\
     _FIELD_AOI(_TIMER_TSCR_ADDR(Timer),_TIMER_TSCR_##Field,AND,OR,INV)

  #define _TIMER_TSCR0_GET()                  _REG_GET(_TIMER_TSCR_ADDR(0))
  #define _TIMER_TSCR0_SET(Val)               _REG_SET(_TIMER_TSCR_ADDR(0), Val)
  #define _TIMER_TSCR0_AOI(AND,OR,INV)        _REG_AOI(_TIMER_TSCR_ADDR(0),AND,OR,INV)
  #define _TIMER_TSCR0_FGET(Field)            _FIELD_GET(_TIMER_TSCR_ADDR(0), _TIMER_TSCR_##Field)
  #define _TIMER_TSCR0_FSET(Field,Val)        _FIELD_SET(_TIMER_TSCR_ADDR(0), _TIMER_TSCR_##Field, Val)
  #define _TIMER_TSCR0_FAOI(Field,AND,OR,INV) _TIMER_TSCR_FAOI(0,##Field,AND,OR,INV)
#endif

  #define _TIMER_TCR_GET(Timer)              _REG_GET(_TIMER_TCR_ADDR(Timer))
  #define _TIMER_TCR_SET(Timer,Val)          _REG_SET(_TIMER_TCR_ADDR(Timer), Val)
  #define _TIMER_TCR_AOI(Timer,AND,OR,INV)   _REG_AOI(_TIMER_TCR_ADDR(Timer),AND,OR,INV)
  #define _TIMER_TCR_FGET(Timer,Field)       _FIELD_GET(_TIMER_TCR_ADDR(Timer), _TIMER_TCR_##Field)
  #define _TIMER_TCR_FSET(Timer,Field,Val)   _FIELD_SET(_TIMER_TCR_ADDR(Timer), _TIMER_TCR_##Field, Val)
  #define _TIMER_TCR_FAOI(Timer,Field,AND,OR,INV)\
     _FIELD_AOI(_TIMER_TCR_ADDR(Timer),_TIMER_TCR_##Field,AND,OR,INV)
  #define _TIMER_TCR_CFG(Timer,tddr, tss, trb, free, soft)\
     _REG_SET(_TIMER_TCR_ADDR(Timer), \
     (Uint16)( _TIMER_TCR_SOFT_MK(soft)     |\
               _TIMER_TCR_FREE_MK(free)     |\
               _TIMER_TCR_TRB_MK(trb)       |\
               _TIMER_TCR_TSS_MK(tss)       |\
               _TIMER_TCR_TDDR_MK(tddr)\
              )\
      )
 			 

  #define _TIMER_TCR0_GET()                  _REG_GET(_TIMER_TCR_ADDR(0))
  #define _TIMER_TCR0_SET(Val)               _REG_SET(_TIMER_TCR_ADDR(0), Val)
  #define _TIMER_TCR0_AOI(AND,OR,INV)        _REG_AOI(_TIMER_TCR_ADDR(0),AND,OR,INV)
  #define _TIMER_TCR0_FGET(Field)            _FIELD_GET(_TIMER_TCR_ADDR(0), _TIMER_TCR_##Field)
  #define _TIMER_TCR0_FSET(Field,Val)        _FIELD_SET(_TIMER_TCR_ADDR(0), _TIMER_TCR_##Field, Val)
  #define _TIMER_TCR0_FAOI(Field,AND,OR,INV)\
     _FIELD_AOI(_TIMER_TCR_ADDR(0),_TIMER_TCR_##Field,AND,OR,INV)
  #define _TIMER_TCR0_CFG(tddr, tss, trb, free, soft)\
      _TIMER_TCR_CFG(0,tddr, tss, trb, free, soft)

  #if (_TIMER_DEVICE_CNT == 2)
    #define _TIMER_TCR1_GET()                  _REG_GET(_TIMER_TCR_ADDR(1))
    #define _TIMER_TCR1_SET(Val)               _REG_SET(_TIMER_TCR_ADDR(1), Val)
    #define _TIMER_TCR1_AOI(AND,OR,INV)        _REG_AOI(_TIMER_TCR_ADDR(1),AND,OR,INV)
    #define _TIMER_TCR1_FGET(Field)            _FIELD_GET(_TIMER_TCR_ADDR(1), _TIMER_TCR_##Field)
    #define _TIMER_TCR1_FSET(Field,Val)        _FIELD_SET(_TIMER_TCR_ADDR(1), _TIMER_TCR_##Field, Val)
    #define _TIMER_TCR1_FAOI(Field,AND,OR,INV)\
       _FIELD_AOI(_TIMER_TCR_ADDR(1),_TIMER_TCR_##Field,AND,OR,INV)
    #define _TIMER_TCR1_CFG(tddr, tss, trb, free, soft)\
        _TIMER_TCR_CFG(1,tddr, tss, trb, free, soft)

  #endif

  #define _TIMER_PRD_GET(Timer)              _REG_GET(_TIMER_PRD_ADDR(Timer))
  #define _TIMER_PRD_SET(Timer,Val)          _REG_SET(_TIMER_PRD_ADDR(Timer), Val)
  #define _TIMER_PRD_AOI(Timer,AND,OR,INV)   _REG_AOI(_TIMER_PRD_ADDR(Timer),AND,OR,INV)
  #define _TIMER_PRD_FGET(Timer,Field)       _FIELD_GET(_TIMER_PRD_ADDR(Timer), _TIMER_PRD_##Field)
  #define _TIMER_PRD_FSET(Timer,Field,Val)   _FIELD_SET(_TIMER_PRD_ADDR(Timer), _TIMER_PRD_##Field, Val)
  #define _TIMER_PRD_FAOI(Timer,Field,AND,OR,INV)\
     _FIELD_AOI(_TIMER_PRD_ADDR(Timer),_TIMER_PRD_##Field,AND,OR,INV)

  #define _TIMER_PRD0_GET()                  _REG_GET(_TIMER_PRD_ADDR(0))
  #define _TIMER_PRD0_SET(Val)               _REG_SET(_TIMER_PRD_ADDR(0), Val)
  #define _TIMER_PRD0_AOI(AND,OR,INV)        _REG_AOI(_TIMER_PRD_ADDR(0),AND,OR,INV)
  #define _TIMER_PRD0_FGET(Field)            _FIELD_GET(_TIMER_PRD_ADDR(0), _TIMER_PRD_##Field)
  #define _TIMER_PRD0_FSET(Field,Val)        _FIELD_SET(_TIMER_PRD_ADDR(0), _TIMER_PRD_##Field, Val)
  #define _TIMER_PRD0_FAOI(Field,AND,OR,INV)\
     _FIELD_AOI(_TIMER_PRD_ADDR(0),_TIMER_PRD_##Field,AND,OR,INV)

  #if (_TIMER_DEVICE_CNT == 2)
    #define _TIMER_PRD1_GET()                  _REG_GET(_TIMER_PRD_ADDR(1))
    #define _TIMER_PRD1_SET(Val)               _REG_SET(_TIMER_PRD_ADDR(1), Val)
    #define _TIMER_PRD1_AOI(AND,OR,INV)        _REG_AOI(_TIMER_PRD_ADDR(1),AND,OR,INV)
    #define _TIMER_PRD1_FGET(Field)            _FIELD_GET(_TIMER_PRD_ADDR(1), _TIMER_PRD_##Field)
    #define _TIMER_PRD1_FSET(Field,Val)        _FIELD_SET(_TIMER_PRD_ADDR(1), _TIMER_PRD_##Field, Val)
    #define _TIMER_PRD1_FAOI(Field,AND,OR,INV)\
       _FIELD_AOI(_TIMER_PRD_ADDR(1),_TIMER_PRD_##Field,AND,OR,INV)
  #endif

  #define _TIMER_TIM_GET(Timer)              _REG_GET(_TIMER_TIM_ADDR(Timer))
  #define _TIMER_TIM_SET(Timer,Val)          _REG_SET(_TIMER_TIM_ADDR(Timer), Val)
  #define _TIMER_TIM_AOI(Timer,AND,OR,INV)   _REG_AOI(_TIMER_TIM_ADDR(Timer),AND,OR,INV)
  #define _TIMER_TIM_FGET(Timer,Field)       _FIELD_GET(_TIMER_TIM_ADDR(Timer), _TIMER_TIM_##Field)
  #define _TIMER_TIM_FSET(Timer,Field,Val)   _FIELD_SET(_TIMER_TIM_ADDR(Timer), _TIMER_TIM_##Field, Val)
  #define _TIMER_TIM_FAOI(Timer,Field,AND,OR,INV)\
     _FIELD_AOI(_TIMER_TIM_ADDR(Timer),_TIMER_TIM_##Field,AND,OR,INV)

  #define _TIMER_TIM0_GET()                  _REG_GET(_TIMER_TIM_ADDR(0))
  #define _TIMER_TIM0_SET(Val)               _REG_SET(_TIMER_TIM_ADDR(0), Val)
  #define _TIMER_TIM0_AOI(AND,OR,INV)        _REG_AOI(_TIMER_TIM_ADDR(0),AND,OR,INV)
  #define _TIMER_TIM0_FGET(Field)            _FIELD_GET(_TIMER_TIM_ADDR(0), _TIMER_TIM_##Field)
  #define _TIMER_TIM0_FSET(Field,Val)        _FIELD_SET(_TIMER_TIM_ADDR(0), _TIMER_TIM_##Field, Val)
  #define _TIMER_TIM0_FAOI(Field,AND,OR,INV)\
     _FIELD_AOI(_TIMER_TIM_ADDR(0),_TIMER_TIM_##Field,AND,OR,INV)

  #if (_TIMER_DEVICE_CNT == 2)
    #define _TIMER_TIM1_GET()                  _REG_GET(_TIMER_TIM_ADDR(1))
    #define _TIMER_TIM1_SET(Val)               _REG_SET(_TIMER_TIM_ADDR(1), Val)
    #define _TIMER_TIM1_AOI(AND,OR,INV)        _REG_AOI(_TIMER_TIM_ADDR(1),AND,OR,INV)
    #define _TIMER_TIM1_FGET(Field)            _FIELD_GET(_TIMER_TIM_ADDR(1), _TIMER_TIM_##Field)
    #define _TIMER_TIM1_FSET(Field,Val)        _FIELD_SET(_TIMER_TIM_ADDR(1), _TIMER_TIM_##Field, Val)
    #define _TIMER_TIM1_FAOI(Field,AND,OR,INV)\
       _FIELD_AOI(_TIMER_TIM_ADDR(1),_TIMER_TIM_##Field,AND,OR,INV)
  #endif



  

/******************************************************************************\
* _TIMER_TCR0 - timer 0 control register
* _TIMER_TCR1 - timer 1 control register
*
* Fields:
*   (RW) _TIMER_TCR_SOFT
*   (RW) _TIMER_TCR_FREE
*   (RW) _TIMER_TCR_PSC
*   (RW) _TIMER_TCR_TRB
*   (RW) _TIMER_TCR_TSS
*   (RW) _TIMER_TCR_TDR
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* Timer Control Register (TCR) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR_SOFT
\*----------------------------------------------------------------------------*/
#define _TIMER_TCR_SOFT_SHIFT       (0x000bu)
#define _TIMER_TCR_SOFT_MK(n)       (((Uint16)(n) & 0x0001u)<< _TIMER_TCR_SOFT_SHIFT)
#define _TIMER_TCR_SOFT_MASK        (_TIMER_TCR_SOFT_MK(1))
#define _TIMER_TCR_SOFT_CLR         (~(_TIMER_TCR_SOFT_MASK))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR_FREE
\*----------------------------------------------------------------------------*/
#define _TIMER_TCR_FREE_SHIFT       (0x000au)
#define _TIMER_TCR_FREE_MK(n)       (((Uint16)(n) &0x0001u) << _TIMER_TCR_FREE_SHIFT)
#define _TIMER_TCR_FREE_MASK        (_TIMER_TCR_FREE_MK(1))
#define _TIMER_TCR_FREE_CLR         (~(_TIMER_TCR_FREE_MASK))

/*----------------------------------------------------------------------------*\
* (R) TIMER_TCR_PSC
\*----------------------------------------------------------------------------*/
#define _TIMER_TCR_PSC_SHIFT        (0x0006u)
#define _TIMER_TCR_PSC_MK(n)     	(((Uint16)(n) & 0x000fu) << _TIMER_TCR_PSC_SHIFT)
#define _TIMER_TCR_PSC_MASK     	(_TIMER_TCR_PSC_MK(0x000fu))
#define _TIMER_TCR_PSC_CLR     	(~_TIMER_TCR_PSC_MK(0x000fu))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR_TRB
\*----------------------------------------------------------------------------*/
#define _TIMER_TCR_TRB_SHIFT        (0x0005u)
#define _TIMER_TCR_TRB_MK(n)        (((Uint16)(n) & 0x0001u)<< _TIMER_TCR_TRB_SHIFT)
#define _TIMER_TCR_TRB_MASK		(_TIMER_TCR_TRB_MK(1))
#define _TIMER_TCR_TRB_CLR		(~(_TIMER_TCR_TRB_MASK))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR_TSS
\*----------------------------------------------------------------------------*/
#define _TIMER_TCR_TSS_SHIFT        (0x0004u)
#define _TIMER_TCR_TSS_MK(n)      (((Uint16)(n) & 0x0001u)<< _TIMER_TCR_TSS_SHIFT)
#define _TIMER_TCR_TSS_MASK          (_TIMER_TCR_TSS_MK(1))
#define _TIMER_TCR_TSS_CLR          (~(_TIMER_TCR_TSS_MASK))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR_TDDR
\*----------------------------------------------------------------------------*/
#define _TIMER_TCR_TDDR_SHIFT       (0x0000u)
#define _TIMER_TCR_TDDR_MK(n)       (((Uint16)(n) & 0x000fu)<< _TIMER_TCR_TDDR_SHIFT)
#define _TIMER_TCR_TDDR_MASK		(_TIMER_TCR_TDDR_MK(0x000fu))
#define _TIMER_TCR_TDDR_CLR		(~(_TIMER_TCR_TDDR_MASK))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR
\*----------------------------------------------------------------------------*/
/******************************************************************************\
* _TIMER_PRD0 - timer 0 period register
* _TIMER_PRD1 - timer 1 period register
*
* Fields:
*   (RW) PRD
*
\******************************************************************************/

/*----------------------------------------------------------------------------*\
* (RW) TIMER_PRD_PRD
\*----------------------------------------------------------------------------*/
#define _TIMER_PRD_PRD_SHIFT      (0x0000u)
#define _TIMER_PRD_PRD_MK(n)      (((Uint16)(n) & 0xffffu)<< _TIMER_PRD_PRD_SHIFT)
#define _TIMER_PRD_PRD_MASK       (_TIMER_PRD_PRD_MK(0xffffu))
#define _TIMER_PRD_PRD_CLR        (~(_TIMER_PRD_PRD_MASK))


/******************************************************************************\
* _TIMER_TIM0 - timer 0  register
* _TIMER_TIM1 - timer 1  register
*
* Fields:
*   (RW) TIM
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) TIMER_TIM_TIM
\*----------------------------------------------------------------------------*/
#define _TIMER_TIM_TIM_SHIFT      (0x0000u)
#define _TIMER_TIM_TIM_MK(n)      (((Uint16)(n) & 0xffffu)<< _TIMER_TIM_TIM_SHIFT)
#define _TIMER_TIM_TIM_MASK       (_TIMER_TIM_TIM_MK(0xffffu))
#define _TIMER_TIM_TIM_CLR        (~(_TIMER_TIM_TIM_MASK))


#if (_TIMER_PRSC_MODE_SUPPORT)
/******************************************************************************\
* _TIMER_TSCR - Timer Pre-Scaler Control Register
*
* Fields:
*   (RW) TSCR_PREMD
*
\******************************************************************************/
#define _TIMER_TSCR_PREMD_SHIFT      (0x000cu)
#define _TIMER_TSCR_PREMD_MK(n)      (((Uint16)(n) & 0x1u)<< _TIMER_TSCR_PREMD_SHIFT)
#define _TIMER_TSCR_PREMD_MASK       (_TIMER_TSCR_PREMD_MK(0x1u))
#define _TIMER_TSCR_PREMD_CLR        (~(_TIMER_TSCR_PREMD_MASK))

#endif /* TIMER_PRSC_MODE_SUPPORT */

/*----------------------------------------------------------------------------*\
* Timer address macro declarations
\*----------------------------------------------------------------------------*/
#else
  #ifndef _TIMER_MOD_ /* _TIMERHAL_H_ */
    #error TIMER HAL Module Not Supported on Specified Target
  #endif
#endif  /* _CSL_TIMERHAL_H_ */
#endif
/******************************************************************************\
* End of csl_timerhal.h
\******************************************************************************/
