/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 2001 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... UART
* FILENAME...... csl_uart.h
* DATE CREATED.. Thur 02/01/2001 
* PROJECT....... Chip Support Library
* COMPONENT..... service layer
* PREREQUISITS.. cslhal.h
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:       02/01/2001 (BWC) Created for 5403/5406.  
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the UART module)
*
*
*
\******************************************************************************/
#ifndef _CSL_UART_H_
#define _CSL_UART_H_

#include <csl_stdinc.h>
#include <csl_stdinch.h>
#include <csl_chiphal.h>
#include <csl_csldat.h>
#include <csl_irq.h>
#include <csl_uarthal.h>

#ifdef __cplusplus
extern "C" {
#endif

#if (_UART_SUPPORT)
/****************************************\
* UART scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"
#else
#define CSLAPI extern
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _UART_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* Temp define info (should be included in other CSL module
\****************************************/

/****************************************\
* UART global typedef declarations
\****************************************/

/******************************************************************************\
* Register Field Values
\******************************************************************************/

/* LCR Register field values */
#define UART_URLCR_WLS_5bits               (0x0000u)         /* word length is 5 bits */
#define UART_URLCR_WLS_6bits               (0x0001u)         /* word length is 6 bits */
#define UART_URLCR_WLS_7bits               (0x0002u)         /* word length is 7 bits */
#define UART_URLCR_WLS_8bits               (0x0003u)         /* word length is 8 bits */

#define UART_URLCR_STB_ZERO                (0x0000u)         /* STB bit setup to 0 */
#define UART_URLCR_STB_ONE                 (0x0004u)         /* STB bit setup to 1 */

#define UART_URLCR_PEN_ENABLE              (0x0008u)         /* parity enabled */
#define UART_URLCR_PEN_DISABLE             (0x0000u)         /* parity disabled */

#define UART_URLCR_EPS_ENABLE              (0x0010u)         /* even parity check enabled */
#define UART_URLCR_EPS_DISABLE             (0x0000u)         /* even parity check disabled */

#define UART_URLCR_STPAR_ENABLE            (0x0020u)         /* stick parity check enabled */
#define UART_URLCR_STPAR_DISABLE           (0x0000u)         /* stick parity check disabled */

#define UART_URLCR_BC_ENABLE               (0x0040u)         /* break control enabled */
#define UART_URLCR_BC_DISABLE              (0x0000u)         /* break control disabled */

#define UART_URLCR_DLAB_ONE                (0x0080u)         /* DLAB set to 1 */
#define UART_URLCR_DLAB_ZERO               (0x0000u)         /* DLAB set to 0 */

#define UART_URLCR_RMK(wls, stb, pen, eps, stpar, bc, dlab)((Uint16)(\
    (UART_FMK(URLCR,WLS, wls))|\
    (UART_FMK(URLCR,STB, stb))|\
    (UART_FMK(URLCR,PEN, pen))|\
    (UART_FMK(URLCR,EPS, eps))|\
    (UART_FMK(URLCR,STPAR, stpar))|\
    (UART_FMK(URLCR,BC, bc))|\
    (UART_FMK(URLCR,DLAB, dlab))\
 )\
)

#define UART_URLCR_RMKS(wls_sym, stb_sym, pen_sym, eps_sym, stpar_sym, bc_sym, dlab_sym)((Uint16)(\
    (UART_FMKS(URLCR,WLS, wls_sym))|\
    (UART_FMKS(URLCR,STB, stb_sym))|\
    (UART_FMKS(URLCR,PEN, pen_sym))|\
    (UART_FMKS(URLCR,EPS, eps_sym))|\
    (UART_FMKS(URLCR,STPAR, stpar_sym))|\
    (UART_FMKS(URLCR,BC, bc_sym))|\
    (UART_FMKS(URLCR,DLAB, dlab_sym))\
 )\
)

/* URIER Register field values */
#define UART_URIER_ERBI_DISABLE            (0x0000u)         /* disable receive data availabe interrupt */
#define UART_URIER_ERBI_ENABLE             (0x0001u)         /* enable receive data availabe interrupt */

#define UART_URIER_ETBEI_DISABLE           (0x0000u)         /* disable transmitter holding register empty interrupt */
#define UART_URIER_ETBEI_ENABLE            (0x0002u)         /* enable transmitter holding register empty interrupt */

#define UART_URIER_ELSI_DISABLE            (0x0000u)         /* disable receive line status interrupt */
#define UART_URIER_ELSI_ENABLE             (0x0004u)         /* enable receive line status interrupt */

#define UART_URIER_RMK(erbi, etbei, elsi)((Uint16)(\
    (UART_FMK(URIER,ERBI, erbi))|\
    (UART_FMK(URIER,ETBEI, etbei))|\
    (UART_FMK(URIER,ELSI, elsi))\
 )\
)

#define UART_URIER_RMKS(erbi_sym, etbei_sym, elsi_sym)((Uint16)(\
    (UART_FMKS(URIER,ERBI, erbi_sym))|\
    (UART_FMKS(URIER,ETBEI, etbei_sym))|\
    (UART_FMKS(URIER,ELSI, elsi_sym))\
 )\
)

/* URFCR Register field values */
#define UART_URFCR_FIEN_DISABLE            (0x0000u)         /* FIFO disable */
#define UART_URFCR_FIEN_ENABLE             (0x0001u)         /* FIFO enable */
#define UART_URFCR_RFIRS_NORESET           (0x0000u)         /*  */
#define UART_URFCR_RFIRS_RESET             (0x0002u)         /* receive FIFO reset */
#define UART_URFCR_TFIRS_NORESET           (0x0000u)         /*  */
#define UART_URFCR_TFIRS_RESET             (0x0004u)         /* transmit FIFO reset */
#define UART_URFCR_RFITR_TRIG01            (0x0000u)         /* receive FIFO trigger level */
#define UART_URFCR_RFITR_TRIG04            (0x0040u)         /* receive FIFO trigger level */
#define UART_URFCR_RFITR_TRIG08            (0x0080u)         /* receive FIFO trigger level */
#define UART_URFCR_RFITR_TRIG014           (0x00C0u)         /* receive FIFO trigger level */


#define UART_URFCR_RMK(fien, rfirs, tfirs, rfitr)((Uint16)(\
    (UART_FMK(URFCR,FIEN, fien))|\
    (UART_FMK(URFCR,RFIRS, rfirs))|\
    (UART_FMK(URFCR,TFIRS, tfirs))|\
    (UART_FMK(URFCR,RFITR, rfitr))\
 )\
)

#define UART_URFCR_RMKS(fien_sym, rfirs_sym, tfirs_sym, rfitr_sym)((Uint16)(\
    (UART_FMKS(URFCR,FIEN, fien_sym))|\
    (UART_FMKS(URFCR,RFIRS, rfirs_sym))|\
    (UART_FMKS(URFCR,TFIRS, tfirs_sym))|\
    (UART_FMKS(URFCR,RFITR, rfitr_sym))\
 )\
)

/* URLSR Register field values */
#define UART_URLSR_DR_OFF                  (0x0000u)         /* data ready bit off */
#define UART_URLSR_DR_ON                   (0x0001u)         /* data ready bit on */
#define UART_URLSR_OE_OFF                  (0x0000u)         /* overrun error bit off */
#define UART_URLSR_OE_ON                   (0x0002u)         /* overrun bit on */
#define UART_URLSR_PE_OFF                  (0x0000u)         /* parity error bit off */
#define UART_URLSR_PE_ON                   (0x0004u)         /* parity error bit on */
#define UART_URLSR_FE_OFF                  (0x0000u)         /* frame error bit off */
#define UART_URLSR_FE_ON                   (0x0008u)         /* frame bit on */
#define UART_URLSR_BI_OFF                  (0x0000u)         /* break interrupt bit off */
#define UART_URLSR_BI_ON                   (0x0010u)         /* break interrupt bit on */
#define UART_URLSR_THRE_OFF                (0x0000u)         /* transmit holding register bit off */
#define UART_URLSR_THRE_ON                 (0x0020u)         /* transmit holding register bit bit on */
#define UART_URLSR_TEMT_OFF                (0x0000u)         /* transmitter empty bit off */
#define UART_URLSR_TEMT_ON                 (0x0040u)         /* transmitter empty bit on */
#define UART_URLSR_RFIER_OFF               (0x0000u)         /* error in RCVR FIFO bit off */
#define UART_URLSR_RFIER_ON                (0x0080u)         /* error in RCVR FIFO bit on */

#define UART_URLSR_RMK(dr, oe, pe, fe, bi, thre, temt, rfier)((Uint16)(\
    (UART_FMK(URLSR,DR, dr))|\
    (UART_FMK(URLSR,OE, oe))|\
    (UART_FMK(URLSR,PE, pe))|\
    (UART_FMK(URLSR,FE, fe))|\
    (UART_FMK(URLSR,BI, bi))|\
    (UART_FMK(URLSR,THRE, thre))|\
    (UART_FMK(URLSR,TEMT, temt))|\
    (UART_FMK(URLSR,RFIER, rfier))\
 )\
)

#define UART_URLSR_RMKS(dr_sym, oe_sym, pe_sym, fe_sym, bi_sym, thre_sym, temt_sym, rfier_sym)((Uint16)(\
    (UART_FMKS(URLSR,DR, dr_sym))|\
    (UART_FMKS(URLSR,OE, oe_sym))|\
    (UART_FMKS(URLSR,PE, pe_sym))|\
    (UART_FMKS(URLSR,FE, fe_sym))|\
    (UART_FMKS(URLSR,BI, bi_sym))|\
    (UART_FMKS(URLSR,THRE, thre_sym))|\
    (UART_FMKS(URLSR,TEMT, temt_sym))|\
    (UART_FMKS(URLSR,RFIER, rfier_sym))\
 )\
)

/* URIIR Register field values */
#define UART_URIIR_IP_ON                   (0x0001u)         /* interrupt pending bit on */
#define UART_URIIR_IP_OFF                  (0x0000u)         /* interrupt pending bit off */
#define UART_URIIR_IID_RCLINESTATUS        (0x0006u)         /* receive line status interrupt */
#define UART_URIIR_IID_RCDATA              (0x0004u)         /* receive line data interrupt */
#define UART_URIIR_IID_CHARTIMEOUT         (0x000Cu)         /* char time out interrupt */
#define UART_URIIR_IID_TXEMPTY             (0x0002u)         /* transmitter holding register empty interrupt */
#define UART_URIIR_FIENR_ON                (0x0080u)         /* FIFOs enabled bit on */
#define UART_URIIR_FIENR_OFF               (0x0000u)         /* FIFOs enabled bit off */


#define UART_URIIR_RMK(ip, iid, fienr)((Uint16)(\
    (UART_FMK(URIIR,IP, ip))|\
    (UART_FMK(URIIR,IID, iid))|\
    (UART_FMK(URIIR,FIENR, fienr))\
 )\
)

#define UART_URIIR_RMKS(ip_sym, iid_sym, fienr_sym)((Uint16)(\
    (UART_FMKS(URIIR,IP, ip_sym))|\
    (UART_FMKS(URIIR,IID, iid_sym))|\
    (UART_FMKS(URIIR,FIENR, fienr_sym))\
 )\
)

/* HPIGPIOSR Register field values */
#define UART_HPIGPIOSR_DTR_ON            (0x0001u)         /* DTR mapped in HPIGPIOSR register on */
#define UART_HPIGPIOSR_DTR_OFF           (0x0000u)         /* DTR mapped in HPIGPIOSR register off */
#define UART_HPIGPIOSR_RTS_ON            (0x0002u)         /* RTS mapped in HPIGPIOSR register on */
#define UART_HPIGPIOSR_RTS_OFF           (0x0000u)         /* RTS mapped in HPIGPIOSR register off */
#define UART_HPIGPIOSR_CTS_ON            (0x0004u)         /* CTS mapped in HPIGPIOSR register on */
#define UART_HPIGPIOSR_CTS_OFF           (0x0000u)         /* CTS mapped in HPIGPIOSR register off */
#define UART_HPIGPIOSR_DSR_ON            (0x0008u)         /* DSR mapped in HPIGPIOSR register on */
#define UART_HPIGPIOSR_DSR_OFF           (0x0000u)         /* DSR mapped in HPIGPIOSR register off */
#define UART_HPIGPIOSR_CD_ON             (0x0010u)         /* CD mapped in HPIGPIOSR register on */
#define UART_HPIGPIOSR_CD_OFF            (0x0000u)         /* CD mapped in HPIGPIOSR register off */
#define UART_HPIGPIOSR_RI_ON             (0x0020u)         /* RI mapped in HPIGPIOSR register on */
#define UART_HPIGPIOSR_RI_OFF            (0x0000u)         /* RI mapped in HPIGPIOSR register off */


#define UART_HPIGPIOSR_RMK(dtr, rts, cts, dsr, cd, ri)((Uint16)(\
    (UART_FMK(HPIGPIOSR,DTR, dtr))|\
    (UART_FMK(HPIGPIOSR,RTS, rts))|\
    (UART_FMK(HPIGPIOSR,CTS, cts))|\
    (UART_FMK(HPIGPIOSR,DSR, dsr))|\
    (UART_FMK(HPIGPIOSR,CD, cd))|\
    (UART_FMK(HPIGPIOSR,RI, ri))\
 )\
)

#define UART_HPIGPIOSR_RMKS(dtr_sym, rts_sym, cts_sym, dsr_sym, cd_sym, ri_sym)((Uint16)(\
    (UART_FMKS(HPIGPIOSR,DTR, dtr_sym))|\
    (UART_FMKS(HPIGPIOSR,RTS, rts_sym))|\
    (UART_FMKS(HPIGPIOSR,CTS, cts_sym))|\
    (UART_FMKS(HPIGPIOSR,DSR, dsr_sym))|\
    (UART_FMKS(HPIGPIOSR,CD, cd_sym))|\
    (UART_FMKS(HPIGPIOSR,RI, ri_sym))\
 )\
)

/* HPIGPIOCR Register field values */
#define UART_HPIGPIOCR_DTR_OUTPUT            (0x0001u)         /* DTR mapped in HPIGPIOSR register output */
#define UART_HPIGPIOCR_DTR_INPUT             (0x0000u)         /* DTR mapped in HPIGPIOSR register input */
#define UART_HPIGPIOCR_RTS_OUTPUT            (0x0002u)         /* RTS mapped in HPIGPIOSR register output */
#define UART_HPIGPIOCR_RTS_INPUT             (0x0000u)         /* RTS mapped in HPIGPIOSR register input */
#define UART_HPIGPIOCR_CTS_OUTPUT            (0x0004u)         /* CTS mapped in HPIGPIOSR register output */
#define UART_HPIGPIOCR_CTS_INPUT             (0x0000u)         /* CTS mapped in HPIGPIOSR register input */
#define UART_HPIGPIOCR_DSR_OUTPUT            (0x0008u)         /* DSR mapped in HPIGPIOSR register output */
#define UART_HPIGPIOCR_DSR_INPUT             (0x0000u)         /* DSR mapped in HPIGPIOSR register input */
#define UART_HPIGPIOCR_CD_OUTPUT             (0x0010u)         /* CD mapped in HPIGPIOSR register output */
#define UART_HPIGPIOCR_CD_INPUT              (0x0000u)         /* CD mapped in HPIGPIOSR register input */
#define UART_HPIGPIOCR_RI_OUTPUT             (0x0020u)         /* RI mapped in HPIGPIOSR register output */
#define UART_HPIGPIOCR_RI_INPUT              (0x0000u)         /* RI mapped in HPIGPIOSR register input */


#define UART_HPIGPIOCR_RMK(dtr, rts, cts, dsr, cd, ri)((Uint16)(\
    (UART_FMK(HPIGPIOCR,DTR, dtr))|\
    (UART_FMK(HPIGPIOCR,RTS, rts))|\
    (UART_FMK(HPIGPIOCR,CTS, cts))|\
    (UART_FMK(HPIGPIOCR,DSR, dsr))|\
    (UART_FMK(HPIGPIOCR,CD, cd))|\
    (UART_FMK(HPIGPIOCR,RI, ri))\
 )\
)

#define UART_HPIGPIOCR_RMKS(dtr_sym, rts_sym, cts_sym, dsr_sym, cd_sym, ri_sym)((Uint16)(\
    (UART_FMKS(HPIGPIOCR,DTR, dtr_sym))|\
    (UART_FMKS(HPIGPIOCR,RTS, rts_sym))|\
    (UART_FMKS(HPIGPIOCR,CTS, cts_sym))|\
    (UART_FMKS(HPIGPIOCR,DSR, dsr_sym))|\
    (UART_FMKS(HPIGPIOCR,CD, cd_sym))|\
    (UART_FMKS(HPIGPIOCR,RI, ri_sym))\
 )\
)

/*****************************************************************************/
/* typedefs & enums                                                          */
/*****************************************************************************/

// TL16C550C UART interrupts
#define   UART_NOINT          0x00             // Disable all interrupts
#define   UART_RINT           0x01             // Enable rx data available interrupt
#define   UART_TINT           0x02             // Enable tx hold register empty interrupt
#define   UART_LSINT          0x04             // Enable rx line status interrupt
#define   UART_MSINT          0x08             // Enable modem status interrupt
#define   UART_ALLINT         0x0f              // Enable all interrupts

// TL16C550C UART autoBaud
#define   UART_AUTOBAUD            0x01           
#define   UART_NO_AUTOBAUD         0x00

// TL16C550C UART clkInput
#define   UART_CLK_INPUT_58         0x01       // Input clock = 58.9824MHz    
#define   UART_CLK_INPUT_117        0x02       // Input clock = 117.9684MHz    

// TL16C550C UART serial character word length
#define   UART_WORD5            0x00           // 5-bit 
#define   UART_WORD6            0x01           // 6-bit
#define   UART_WORD7            0x02           // 7-bit
#define   UART_WORD8            0x03            // 8-bit

// TL16C550C UART stop bits
#define   UART_STOP1                0x0             // 1 stop bit
#define   UART_STOP1_PLUS_HALF      0x4             // 1 1/2 stop bits
#define   UART_STOP2                0x4             // 2 stop bits

// TL16C550C UART flow control
#define   UART_NO_LOOPBACK    0x0
#define   UART_LOOPBACK       0x10

// TL16C550C UART parity select
/*  LCR		bit5 	bit4	bit3
 *  x		x		0		- No parity
 *  0		0		1		- odd parity
 *  0		1		1		- even parity
 *  1		0		1		- mark parity
 *  1		1		1		- space parity
 */
 
#define   UART_DISABLE_PARITY   0x0      //disable parity checking
#define   UART_ODD_PARITY       0x08   //enable odd parity
#define   UART_EVEN_PARITY      0x18   //enable even parity
#define   UART_MARK_PARITY      0x28   //enable mark parity
#define   UART_SPACE_PARITY     0x38   //enable space parity

#define   UART_PARITY_MASK      0x38   
// TL16C550C UART stick parity select
//#define   UART_DISABLE_STICKPARITY   0x0      //disable stick parity 
//#define   UART_ENABLE_STICKPARITY    0x2      //enable stick parity 


// TL16C550C UART baud rates for clk = 58.9824MHz
#define   UART_BAUD_150         24576
#define   UART_BAUD_300         12288
#define   UART_BAUD_600         6144
#define   UART_BAUD_1200        3072
#define   UART_BAUD_1800        2048
#define   UART_BAUD_2000        1856
#define   UART_BAUD_2400        1536
#define   UART_BAUD_3600        1024
#define   UART_BAUD_4800        768
#define   UART_BAUD_7200        512
#define   UART_BAUD_9600        384
#define   UART_BAUD_19200       192
#define   UART_BAUD_38400       96
#define   UART_BAUD_57600       64
#define   UART_BAUD_115200      32

// TL16C550C UART baud rates for clk = 117.9684MHz
/*
#define   UART_BAUD_150         49152
#define   UART_BAUD_300         24576
#define   UART_BAUD_600         12288
#define   UART_BAUD_1200        6144
#define   UART_BAUD_1800        4096
#define   UART_BAUD_2000        3712
#define   UART_BAUD_2400        3072
#define   UART_BAUD_3600        2048
#define   UART_BAUD_4800        1536
#define   UART_BAUD_7200        1024
#define   UART_BAUD_9600        768
#define   UART_BAUD_19200       384
#define   UART_BAUD_38400       192
#define   UART_BAUD_57600       128
#define   UART_BAUD_115200      64
*/

// TL16C550C UART FIFO control
#define   UART_FIFO_DISABLE     0x00
#define   UART_FIFO_DMA0_TRIG01   0x07    //DMA mode0 and trigger level 01
#define   UART_FIFO_DMA0_TRIG04   0x47    //DMA mode0 and trigger level 01
#define   UART_FIFO_DMA0_TRIG08   0x87    //DMA mode0 and trigger level 01
#define   UART_FIFO_DMA0_TRIG14   0xC7    //DMA mode0 and trigger level 01


//TL16C550C UART interrupt information as indicated
//by b0-b3 of UART_IIR_REG
#define   UART_NO_INTERRUPTPENDING  -1   //no interrupt pending
#define   UART_LSR_INTR             0x6  //rx line status - overrun error, parity error,  
                                         //framing error, or break interrupt. Read line  
                                         //status register to determine exact interrupt 
                                         //source.
#define   UART_RXRDY_INTR           0x4  //rx data available
#define   UART_CHAR_TIMEOUT         0xc  //character timeout
#define   UART_TXRDY_INTR           0x2  //tx holding register empty
#define   UART_MSR_INTR             0x0  //modem status - clear to send, data set ready,
                                         //ring indicator, or data carrier detect.
                                         //Read modem status register to exact interrupt 
                                         //source.

typedef struct
{
   Uint16              clkInput;
   Uint16              baud;
   Uint16              wordLength;
   Uint16              stopBits;
   Uint16              parity;
   Uint16              fifoControl;
   Uint16              loopBackEnable;
} UART_Setup;

typedef struct
{
   Uint16              dll;
   Uint16              dlm;
   Uint16              lcr;
   Uint16              fcr;
   Uint16              mcr;                //only for loopback
} UART_Config;


typedef struct
{
   void (*lsiAddr)(void);          // Receiver line status
   void (*rbfiAddr)(void);         // received data available
   void (*tbeiAddr)(void);         // transmiter holding register empty
//   void (*dssiAddr)(void);         // modem status
   void (*ctoiAddr)(void);         // character time-out indication
} UART_IsrAddr;

#define    UART_EVT_LSI    0x03     // Receiver line status
#define    UART_EVT_RBFI   0x02     // received data available
#define    UART_EVT_CTOI   0x06     // character time-out indication
#define    UART_EVT_TBEI   0x01     // transmiter holding register empty
//#define    UART_EVT_DSSI   0x00     // modem status


/****************************************\
* UART global function declarations
\****************************************/
CSLAPI void UART_setup(UART_Setup *params);
CSLAPI void UART_config(UART_Config *Config);
CSLAPI void UART_getConfig(UART_Config *Config);
CSLAPI void UART_configArgs(Uint16 dll, Uint16 dlm, Uint16 lcr, 
                            Uint16 fcr, Uint16 mcr);
CSLAPI void UART_eventEnable(Uint16 ierMask);
CSLAPI void UART_eventDisable(Uint16 ierMask);
CSLAPI void UART_setCallback(UART_IsrAddr *isrAddr);
CSLAPI Uint16 UART_getEventId();
CSLAPI void UART_setupBaudRate(Uint16 clkInput, Uint16 baudRate);

CSLAPI CSLBool UART_read(char *pBuf, Uint16 length, Uint32 timeout);
CSLAPI CSLBool UART_write(char *pBuf, Uint16 length, Uint32 timeout);
CSLAPI CSLBool UART_fgetc(int *c, Uint32 timeout);
CSLAPI CSLBool UART_fgets(char* pBuf, int bufSize, Uint32);
CSLAPI CSLBool UART_fputc(const int c, Uint32 timeout);
CSLAPI CSLBool UART_fputs(const char* pBuf, Uint32 timeout);
/* private function */
interrupt void UART_intrDispatch(void);

/****************************************\
* UART global macro declarations
\****************************************/ 
#define UART_ctsOff            UART_HPIFSET(HPIGPIOSR,CTS,1)
#define UART_ctsOn             UART_HPIFSET(HPIGPIOSR, CTS,0)
#define UART_isRts             ( (UART_HPIFGET(HPIGPIOSR,RTS)) ? 0 : 1 )
#define UART_cdOff             UART_HPIFSET(HPIGPIOSR,CD,1)
#define UART_cdOn              UART_HPIFSET(HPIGPIOSR,CD,0)
#define UART_riOff             UART_HPIFSET(HPIGPIOSR,RI,1)
#define UART_riOn              UART_HPIFSET(HPIGPIOSR,RI,0)
#define UART_dsrOff            UART_HPIFSET(HPIGPIOSR,DSR,1)
#define UART_dsrOn             UART_HPIFSET(HPIGPIOSR,DSR,0)
#define UART_isDtr             ((UART_HPIFGET(HPIGPIOSR,DTR)) ? 0 : 1)
#define UART_flowCtrlInit      {UART_HPIRSET(HPIGPIOCR,0x003C); UART_HPIRSET(HPIGPIOSR,0x3C);}

#define UART_RGET(Reg)                      UartRegRead(_UART_##Reg##_ADDR)
#define UART_RSET(Reg,Val)                  UartRegWrite(_UART_##Reg##_ADDR,Val)
#define UART_RMKSET(Reg,Val)                UartRegMaskSet(_UART_##Reg##_ADDR,Val)
#define UART_RMKCLR(Reg,Val)                UartRegMaskClear(_UART_##Reg##_ADDR,Val)
#define UART_FGET(Reg,Field)      (( UartRegRead(_UART_##Reg##_ADDR)&_UART_##Reg##_##Field##_MASK ) >> _UART_##Reg##_##Field##_SHIFT)
#define UART_FSET(Reg,Field,Val)  Val? UartRegMaskSet(_UART_##Reg##_ADDR,_UART_##Reg##_##Field##_MASK): UartRegMaskClear(_UART_##Reg##_ADDR,_UART_##Reg##_##Field##_MASK)


/* private function */
extern Uint16 UartRegRead(Uint16 Reg);
extern void UartRegWrite(Uint16 Reg, Uint16 Value);
extern void UartRegMaskSet(Uint16 Reg, Uint16 MaskSet);
extern void UartRegMaskClear(Uint16 Reg, Uint16 MaskClear);


/****************************************\
* UART global variable declarations
\****************************************/ 

/*----------------------------------------------------------------------------*/

#ifdef __cplusplus
}
#endif /* extern "C" */
#else
  #ifndef _UART_MOD_ /* UART_SUPPORT */
    #error UART Module Not Supported on Specified Target
  #endif
#endif /* UART_SUPPORT */

#endif /* _CSL_UART_H_ */                
/******************************************************************************\
* End of CSL_uart.h
\******************************************************************************/

