/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 2001 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... UART
* FILENAME...... csl_uarthal.h
* DATE CREATED.. Tues 02/02/2001 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:          02/02/2000 
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the UART module)
*
* Registers Covered:
*   (RW) _TIMER_TCR0 - timer 0 control register
*
\******************************************************************************/
#ifndef _CSL_UARTHAL_H_
#define _CSL_UARTHAL_H_

#include <csl_stdinc.h>
#include <csl_stdinch.h>
#include <csl_hpihal.h>

#ifdef __cplusplus
extern "C" {
#endif

#if (_UART_SUPPORT)
/****************************************\
* TIMER scope and inline control macros
\****************************************/
#ifdef _UART_cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CSL_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif



#define UART_HIGHBYTE_MASK         (0x00FFu)
#define UART_HIGHBYTE_SHIFT        (0x0008u)

/*----------------------------------------------------------------------------*\
* Address Macros:
\*----------------------------------------------------------------------------*/
#define _UART_ADDR           			(0x0044u)
#define _UART_DATA           			(0x0045u)

#define UART_ADDR_REG_GET()              REG16(_UART_ADDR)
#define UART_ADDR_REG_SET(Val)           REG16(_UART_ADDR)=(Uint16)(Val)

#define UART_ADDR(Reg)                    _UART_##Reg##_ADDR
#define UART_FMK(Reg,Field,Val)           _UART_##Reg##_##Field##_MK(Val)
#define UART_FMKS(Reg,Field,Sym)          _UART_##Reg##_##Field##_MK(UART_##Reg##_##Field##_##Sym)


#define UART_HPIRGET(Reg)                _REG_GET(_UART_##Reg##_ADDR)
#define UART_HPIRSET(Reg,Val)            _REG_SET(_UART_##Reg##_ADDR, (Val & UART_HIGHBYTE_MASK))

#define UART_HPIFGET(Reg,Field)          _FIELD_GET(_UART_##Reg##_ADDR,_UART_##Reg##_##Field)
#define UART_HPIFSET(Reg,Field,Val)      _FIELD_SET(_UART_##Reg##_ADDR,_UART_##Reg##_##Field, (Val & UART_HIGHBYTE_MASK))


/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/

#define _UART_URRBR_ADDR                      (0x0u)
#define _UART_URTHR_ADDR                      (0x0u)
#define _UART_URIER_ADDR                      (0x1u)
#define _UART_URIIR_ADDR                      (0x2u)
#define _UART_URFCR_ADDR                      (0x2u)
#define _UART_URLCR_ADDR                      (0x3u)
#define _UART_URMCR_ADDR                      (0x4u)
#define _UART_URLSR_ADDR                      (0x5u)
#define _UART_URMSR_ADDR                      (0x6u)
#define _UART_URSCR_ADDR                      (0x7u)

#define _UART_URDLL_ADDR                      (0x0u)
#define _UART_URDLM_ADDR                      (0x1u)

#define HPIGPIOSR                  _UART_HPIGPIOSR_ADDR
#define HPIGPIOCR                  _UART_HPIGPIOCR_ADDR

#define DLAB_MASK                 _UART_URLCR_DLAB_MASK     
#define CTS_MASK                  _UART_HPIGPIOSR_CTS_MASK
#define RTS_MASK                  _UART_HPIGPIOSR_RTS_MASK



/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*\
* UART Register (URDLL) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) UART_URDLL_URDLL 
\*----------------------------------------------------------------------------*/
#define _UART_URDLL_URDLL_SHIFT      (0x0000u)
#define _UART_URDLL_URDLL_MK(n)      (((Uint16)(n) & 0x000Fu)<< _UART_URDLL_URDLL_SHIFT)
#define _UART_URDLL_URDLL_MASK       (_UART_URDLL_URDLL_MK(0xF))
#define _UART_URDLL_URDLL_CLR        (~(_UART_URDLL_URDLL_MASK))

/*----------------------------------------------------------------------------*\
* UART Register (URDLM) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) UART_URDLM_URDLM 
\*----------------------------------------------------------------------------*/
#define _UART_URDLM_URDLM_SHIFT      (0x0000u)
#define _UART_URDLM_URDLM_MK(n)      (((Uint16)(n) & 0x000Fu)<< _UART_URDLM_URDLM_SHIFT)
#define _UART_URDLM_URDLM_MASK       (_UART_URDLM_URDLM_MK(0xF))
#define _UART_URDLM_URDLM_CLR        (~(_UART_URDLM_URDLM_MASK))

/*----------------------------------------------------------------------------*\
* UART Register (URRBR) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (R) UART_URRBR_URRBR 
\*----------------------------------------------------------------------------*/
#define _UART_URRBR_URRBR_SHIFT      (0x0000u)
#define _UART_URRBR_URRBR_MK(n)      (((Uint16)(n) & 0x000Fu)<< _UART_URRBR_URRBR_SHIFT)
#define _UART_URRBR_URRBR_MASK       (_UART_URRBR_URRBR_MK(0xF))
#define _UART_URRBR_URRBR_CLR        (~(_UART_URRBR_URRBR_MASK))

/*----------------------------------------------------------------------------*\
* UART Register (URTHR) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (R) UART_URTHR_URTHR 
\*----------------------------------------------------------------------------*/
#define _UART_URTHR_URTHR_SHIFT      (0x0000u)
#define _UART_URTHR_URTHR_MK(n)      (((Uint16)(n) & 0x000Fu)<< _UART_URTHR_URTHR_SHIFT)
#define _UART_URTHR_URTHR_MASK       (_UART_URTHR_URTHR_MK(0xF))
#define _UART_URTHR_URTHR_CLR        (~(_UART_URTHR_URTHR_MASK))


/*----------------------------------------------------------------------------*\
* UART Register (URIER) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) UART_URIER_ERBI 
\*----------------------------------------------------------------------------*/
#define _UART_URIER_ERBI_SHIFT      (0x0000u)
#define _UART_URIER_ERBI_MK(n)      (((Uint16)(n) & 0x0001u)<< _UART_URIER_ERBI_SHIFT)
#define _UART_URIER_ERBI_MASK       (_UART_URIER_ERBI_MK(1))
#define _UART_URIER_ERBI_CLR        (~(_UART_URIER_ERBI_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URIER_ETBEI 
\*----------------------------------------------------------------------------*/
#define _UART_URIER_ETBEI_SHIFT      (0x0001u)
#define _UART_URIER_ETBEI_MK(n)      (((Uint16)(n) & 0x0001u)<< _UART_URIER_ETBEI_SHIFT)
#define _UART_URIER_ETBEI_MASK       (_UART_URIER_ETBEI_MK(1))
#define _UART_URIER_ETBEI_CLR        (~(_UART_URIER_ETBEI_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URIER_ELSI
\*----------------------------------------------------------------------------*/
#define _UART_URIER_ELSI_SHIFT      (0x0002u)
#define _UART_URIER_ELSI_MK(n)      (((Uint16)(n) & 0x0001u)<< _UART_URIER_ELSI_SHIFT)
#define _UART_URIER_ELSI_MASK       (_UART_URIER_ELSI_MK(1))
#define _UART_URIER_ELSI_CLR        (~(_UART_URIER_ELSI_MASK))

/*----------------------------------------------------------------------------*\
* UART Register (URLCR) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) UART_URLCR_WLS (WLS0 and WLS1 - 2 bits together)
\*----------------------------------------------------------------------------*/
#define _UART_URLCR_WLS_SHIFT      (0x0000u)
#define _UART_URLCR_WLS_MK(n)      (((Uint16)(n) & 0x0003u)<< _UART_URLCR_WLS_SHIFT)
#define _UART_URLCR_WLS_MASK       (_UART_URLCR_WLS_MK(3))
#define _UART_URLCR_WLS_CLR        (~(_UART_URLCR_WLS_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLCR_STB
\*----------------------------------------------------------------------------*/
#define _UART_URLCR_STB_SHIFT      (0x0002u)
#define _UART_URLCR_STB_MK(n)      (((Uint16)(n) & 0x0001u)<< _UART_URLCR_STB_SHIFT)
#define _UART_URLCR_STB_MASK       (_UART_URLCR_STB_MK(1))
#define _UART_URLCR_STB_CLR        (~(_UART_URLCR_STB_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLCR_PEN
\*----------------------------------------------------------------------------*/
#define _UART_URLCR_PEN_SHIFT      (0x0003u)
#define _UART_URLCR_PEN_MK(n)      (((Uint16)(n) & 0x0001u)<< _UART_URLCR_PEN_SHIFT)
#define _UART_URLCR_PEN_MASK       (_UART_URLCR_PEN_MK(1))
#define _UART_URLCR_PEN_CLR        (~(_UART_URLCR_PEN_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLCR_EPS
\*----------------------------------------------------------------------------*/
#define _UART_URLCR_EPS_SHIFT      (0x0004u)
#define _UART_URLCR_EPS_MK(n)      (((Uint16)(n) & 0x0001u)<< _UART_URLCR_EPS_SHIFT)
#define _UART_URLCR_EPS_MASK       (_UART_URLCR_EPS_MK(1))
#define _UART_URLCR_EPS_CLR        (~(_UART_URLCR_EPS_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLCR_STPAR
\*----------------------------------------------------------------------------*/
#define _UART_URLCR_STPAR_SHIFT      (0x0005u)
#define _UART_URLCR_STPAR_MK(n)      (((Uint16)(n) & 0x0001u)<< _UART_URLCR_STPAR_SHIFT)
#define _UART_URLCR_STPAR_MASK       (_UART_URLCR_STPAR_MK(1))
#define _UART_URLCR_STPAR_CLR        (~(_UART_URLCR_STPAR_MASK))

/*----------------------------------------------------------------------------*\
* (RW) UART_URLCR_BC
\*----------------------------------------------------------------------------*/
#define _UART_URLCR_BC_SHIFT         (0x0006u)
#define _UART_URLCR_BC_MK(n)         (((Uint16)(n) & 0x0001u)<< _UART_URLCR_BC_SHIFT)
#define _UART_URLCR_BC_MASK          (_UART_URLCR_BC_MK(1))
#define _UART_URLCR_BC_CLR           (~(_UART_URLCR_BC_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLCR_DLAB
\*----------------------------------------------------------------------------*/
#define _UART_URLCR_DLAB_SHIFT     (0x0007u)
#define _UART_URLCR_DLAB_MK(n)     (((Uint16)(n) & 0x0001u)<< _UART_URLCR_DLAB_SHIFT)
#define _UART_URLCR_DLAB_MASK      (_UART_URLCR_DLAB_MK(1))
#define _UART_URLCR_DLAB_CLR       (~(_UART_URLCR_DLAB_MASK))

/*----------------------------------------------------------------------------*\
* UART Register (URFCR) bit/field definitions - write only
\*----------------------------------------------------------------------------*/

#define _UART_URFCR_MASK           (0x00CFu)
/*----------------------------------------------------------------------------*\
* (W) UART_URFCR_FIEN 
\*----------------------------------------------------------------------------*/
#define _UART_URFCR_FIEN_SHIFT     (0x0000u)
#define _UART_URFCR_FIEN_MK(n)     (((Uint16)(n) & 0x0001u)<< _UART_URFCR_FIEN_SHIFT)
#define _UART_URFCR_FIEN_MASK      (_UART_URFCR_FIEN_MK(1))
#define _UART_URFCR_FIEN_CLR       (~(_UART_URFCR_FIEN_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_URFCR_RFIRS 
\*----------------------------------------------------------------------------*/
#define _UART_URFCR_RFIRS_SHIFT    (0x0001u)
#define _UART_URFCR_RFIRS_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_URFCR_RFIRS_SHIFT)
#define _UART_URFCR_RFIRS_MASK     (_UART_URFCR_RFIRS_MK(1))
#define _UART_URFCR_RFIRS_CLR      (~(_UART_URFCR_RFIRS_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_URFCR_TFIRS 
\*----------------------------------------------------------------------------*/
#define _UART_URFCR_TFIRS_SHIFT    (0x0002u)
#define _UART_URFCR_TFIRS_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_URFCR_TFIRS_SHIFT)
#define _UART_URFCR_TFIRS_MASK     (_UART_URFCR_TFIRS_MK(1))
#define _UART_URFCR_TFIRS_CLR      (~(_UART_URFCR_TFIRS_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_FCR_RFITR - (two bits: bit 6 and bit7) 
\*----------------------------------------------------------------------------*/
#define _UART_URFCR_RFITR_SHIFT    (0x0006u)
#define _UART_URFCR_RFITR_MK(n)    (((Uint16)(n) & 0x0003u)<< _UART_URFCR_RFITR_SHIFT)
#define _UART_URFCR_RFITR_MASK     (_UART_URFCR_RFITR_MK(3))
#define _UART_URFCR_RFITR_CLR      (~(_UART_URFCR_RFITR_MASK))

/*----------------------------------------------------------------------------*\
* UART Register (URMCR) bit/field definitions 
\*----------------------------------------------------------------------------*/
#define _UART_URMCR_MASK           (0x001Fu)
/*----------------------------------------------------------------------------*\
* (RW) UART_URMCR_LOOP 
\*-----------------------------  ---------------------------------------------*/
#define _UART_URMCR_LOOP_SHIFT     (0x0004u)
#define _UART_URMCR_LOOP_MK(n)     (((Uint16)(n) & 0x0001u)<< _UART_URMCR_LOOP_SHIFT)
#define _UART_URMCR_LOOP_MASK      (_UART_URMCR_LOOP_MK(1))
#define _UART_URMCR_LOOP_CLR       (~(_UART_URMCR_LOOP_MASK))

/*----------------------------------------------------------------------------*\
* UART Register (URLSR) bit/field definitions 
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_DR
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_DR_SHIFT        (0x0000u)
#define _UART_URLSR_DR_MK(n)        (((Uint16)(n) & 0x0001u)<< _UART_URLSR_DR_SHIFT)
#define _UART_URLSR_DR_MASK         (_UART_URLSR_DR_MK(1))
#define _UART_URLSR_DR_CLR          (~(_UART_URLSR_DR_MASK))

/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_OE
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_OE_SHIFT        (0x0001u)
#define _UART_URLSR_OE_MK(n)        (((Uint16)(n) & 0x0001u)<< _UART_URLSR_OE_SHIFT)
#define _UART_URLSR_OE_MASK         (_UART_URLSR_OE_MK(1))
#define _UART_URLSR_OE_CLR          (~(_UART_URLSR_OE_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_PE
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_PE_SHIFT        (0x0002u)
#define _UART_URLSR_PE_MK(n)        (((Uint16)(n) & 0x0001u)<< _UART_URLSR_PE_SHIFT)
#define _UART_URLSR_PE_MASK         (_UART_URLSR_PE_MK(1))
#define _UART_URLSR_PE_CLR          (~(_UART_URLSR_PE_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_FE
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_FE_SHIFT        (0x0003u)
#define _UART_URLSR_FE_MK(n)        (((Uint16)(n) & 0x0001u)<< _UART_URLSR_FE_SHIFT)
#define _UART_URLSR_FE_MASK         (_UART_URLSR_FE_MK(1))
#define _UART_URLSR_FE_CLR          (~(_UART_URLSR_FE_MASK))

/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_BI
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_BI_SHIFT        (0x0004u)
#define _UART_URLSR_BI_MK(n)        (((Uint16)(n) & 0x0001u)<< _UART_URLSR_BI_SHIFT)
#define _UART_URLSR_BI_MASK         (_UART_URLSR_BI_MK(1))
#define _UART_URLSR_BI_CLR          (~(_UART_URLSR_BI_MASK))

/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_THRE 
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_THRE_SHIFT       (0x0005u)
#define _UART_URLSR_THRE_MK(n)       (((Uint16)(n) & 0x0001u)<< _UART_URLSR_THRE_SHIFT)
#define _UART_URLSR_THRE_MASK        (_UART_URLSR_THRE_MK(1))
#define _UART_URLSR_THRE_CLR         (~(_UART_URLSR_THRE_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_TEMT 
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_TEMT_SHIFT       (0x0006u)
#define _UART_URLSR_TEMT_MK(n)       (((Uint16)(n) & 0x0001u)<< _UART_URLSR_TEMT_SHIFT)
#define _UART_URLSR_TEMT_MASK        (_UART_URLSR_TEMT_MK(1))
#define _UART_URLSR_TEMT_CLR         (~(_UART_URLSR_TEMT_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_URLSR_RFIER 
\*----------------------------------------------------------------------------*/
#define _UART_URLSR_RFIER_SHIFT       (0x0007u)
#define _UART_URLSR_RFIER_MK(n)       (((Uint16)(n) & 0x0001u)<< _UART_URLSR_RFIER_SHIFT)
#define _UART_URLSR_RFIER_MASK        (_UART_URLSR_RFIER_MK(1))
#define _UART_URLSR_RFIER_CLR         (~(_UART_URLSR_TEMT_MASK))


/*----------------------------------------------------------------------------*\
* UART Register (URIIR) bit/field definitions 
\*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*\
* (R) UART_URIIR_IP
\*----------------------------------------------------------------------------*/
#define _UART_URIIR_IP_SHIFT        (0x0000u)
#define _UART_URIIR_IP_MK(n)        (((Uint16)(n) & 0x0001u)<< _UART_URIIR_IP_SHIFT)
#define _UART_URIIR_IP_MASK         (_UART_URIIR_IP_MK(1))
#define _UART_URIIR_IP_CLR          (~(_UART_URIIR_IP_MASK))

/*----------------------------------------------------------------------------*\
* (R) UART_URIIR_IID (bit1,2,3)
\*----------------------------------------------------------------------------*/
#define _UART_URIIR_IID_SHIFT        (0x0001u)
#define _UART_URIIR_IID_MK(n)        (((Uint16)(n) & 0x0007u)<< _UART_URIIR_IID_SHIFT)
#define _UART_URIIR_IID_MASK         (_UART_URIIR_IID_MK(7))
#define _UART_URIIR_IID_CLR          (~(_UART_URIIR_IID_MASK))

/*----------------------------------------------------------------------------*\
* (R) UART_URIIR_FIENR
\*----------------------------------------------------------------------------*/
#define _UART_URIIR_FIENR_SHIFT        (0x0007u)
#define _UART_URIIR_FIENR_MK(n)        (((Uint16)(n) & 0x0001u)<< _UART_URIIR_FIENR_SHIFT)
#define _UART_URIIR_FIENR_MASK         (_UART_URIIR_FIENR_MK(1))
#define _UART_URIIR_FIENR_CLR          (~(_UART_URIIR_FIENR_MASK))

/*============================================================================*\
* (RW) UART HPI GPIOSR mapped register macros 
\*============================================================================*/
#define _UART_HPIGPIOSR_ADDR    _HPI_GPIOSR_ADDR


/*----------------------------------------------------------------------------*\
* UART HPI mapped signals bit/field definitions
* HD0 - DTR - Input
* HD1 - RTS - Input
* HD2 - CTS - Output
* HD3 - DSR - Output
* HD4 - CD - Output
* HD5 - RI - Output
\*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*\
* (R) UART_HPIGPIOSR_DTR 
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOSR_DTR_SHIFT    (0x0000u)
#define _UART_HPIGPIOSR_DTR_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOSR_DTR_SHIFT)
#define _UART_HPIGPIOSR_DTR_MASK     (_UART_HPIGPIOSR_DTR_MK(1))
#define _UART_HPIGPIOSR_DTR_CLR      (~(_UART_HPIGPIOSR_DTR_MASK))
/*----------------------------------------------------------------------------*\
* (R) UART_HPIGPIOSR_RTS
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOSR_RTS_SHIFT    (0x0001u)
#define _UART_HPIGPIOSR_RTS_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOSR_RTS_SHIFT)
#define _UART_HPIGPIOSR_RTS_MASK     (_UART_HPIGPIOSR_RTS_MK(1))
#define _UART_HPIGPIOSR_RTS_CLR      (~(_UART_HPIGPIOSR_RTS_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_HPIGPIOSR_CTS
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOSR_CTS_SHIFT    (0x0002u)
#define _UART_HPIGPIOSR_CTS_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOSR_CTS_SHIFT)
#define _UART_HPIGPIOSR_CTS_MASK     (_UART_HPIGPIOSR_CTS_MK(1))
#define _UART_HPIGPIOSR_CTS_CLR      (~(_UART_HPIGPIOSR_CTS_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_HPIGPIOSR_DSR
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOSR_DSR_SHIFT    (0x0003u)
#define _UART_HPIGPIOSR_DSR_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOSR_DSR_SHIFT)
#define _UART_HPIGPIOSR_DSR_MASK     (_UART_HPIGPIOSR_DSR_MK(1))
#define _UART_HPIGPIOSR_DSR_CLR      (~(_UART_HPIGPIOSR_DSR_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_HPIGPIOSR_CD
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOSR_CD_SHIFT    (0x0004u)
#define _UART_HPIGPIOSR_CD_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOSR_CD_SHIFT)
#define _UART_HPIGPIOSR_CD_MASK     (_UART_HPIGPIOSR_CD_MK(1))
#define _UART_HPIGPIOSR_CD_CLR      (~(_UART_HPIGPIOSR_CD_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_HPIGPIOSR_RI
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOSR_RI_SHIFT     (0x0005u)
#define _UART_HPIGPIOSR_RI_MK(n)     (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOSR_RI_SHIFT)
#define _UART_HPIGPIOSR_RI_MASK      (_UART_HPIGPIOSR_RI_MK(1))
#define _UART_HPIGPIOSR_RI_CLR       (~(_UART_HPIGPIOSR_RI_MASK))



/*============================================================================*\
* (RW) UART HPI GPIOCR mapped register macros 
\*============================================================================*/
#define _UART_HPIGPIOCR_ADDR    _HPI_GPIOCR_ADDR

/*----------------------------------------------------------------------------*\
* UART HPI mapped signals bit/field definitions
* HD0 - DTR - Input
* HD1 - RTS - Input
* HD2 - CTS - Output
* HD3 - DSR - Output
* HD4 - CD - Output
* HD5 - RI - Output
\*----------------------------------------------------------------------------*/
#define UART_HPIGPIOCR_SETUP    0x003C
/*----------------------------------------------------------------------------*\
* (RW) UART_HPIGPIOCR_DTR 
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOCR_DTR_SHIFT    (0x0000u)
#define _UART_HPIGPIOCR_DTR_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOCR_DTR_SHIFT)
#define _UART_HPIGPIOCR_DTR_MASK     (_UART_HPIGPIOCR_DTR_MK(1))
#define _UART_HPIGPIOCR_DTR_CLR      (~(_UART_HPIGPIOCR_DTR_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_HPIGPIOCR_RTS
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOCR_RTS_SHIFT    (0x0001u)
#define _UART_HPIGPIOCR_RTS_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOCR_RTS_SHIFT)
#define _UART_HPIGPIOCR_RTS_MASK     (_UART_HPIGPIOCR_RTS_MK(1))
#define _UART_HPIGPIOCR_RTS_CLR      (~(_UART_HPIGPIOCR_RTS_MASK))
/*----------------------------------------------------------------------------*\
* (RW) UART_HPIGPIOCR_CTS
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOCR_CTS_SHIFT    (0x0002u)
#define _UART_HPIGPIOCR_CTS_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOCR_CTS_SHIFT)
#define _UART_HPIGPIOCR_CTS_MASK     (_UART_HPIGPIOCR_CTS_MK(1))
#define _UART_HPIGPIOCR_CTS_CLR      (~(_UART_HPIGPIOCR_CTS_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_HPIGPIOCR_DSR
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOCR_DSR_SHIFT    (0x0003u)
#define _UART_HPIGPIOCR_DSR_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOCR_DSR_SHIFT)
#define _UART_HPIGPIOCR_DSR_MASK     (_UART_HPIGPIOCR_DSR_MK(1))
#define _UART_HPIGPIOCR_DSR_CLR      (~(_UART_HPIGPIOCR_DSR_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_HPIGPIOCR_CD
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOCR_CD_SHIFT    (0x0004u)
#define _UART_HPIGPIOCR_CD_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOCR_CD_SHIFT)
#define _UART_HPIGPIOCR_CD_MASK     (_UART_HPIGPIOCR_CD_MK(1))
#define _UART_HPIGPIOCR_CD_CLR      (~(_UART_HPIGPIOCR_CD_MASK))
/*----------------------------------------------------------------------------*\
* (W) UART_HPIGPIOCR_RI
\*----------------------------------------------------------------------------*/
#define _UART_HPIGPIOCR_RI_SHIFT     (0x0005u)
#define _UART_HPIGPIOCR_RI_MK(n)     (((Uint16)(n) & 0x0001u)<< _UART_HPIGPIOCR_RI_SHIFT)
#define _UART_HPIGPIOCR_RI_MASK      (_UART_HPIGPIOCR_RI_MK(1))
#define _UART_HPIGPIOCR_RI_CLR       (~(_UART_HPIGPIOCR_RI_MASK))





/*============================================================================*\
* (RW) UART HPI control mapped register macros 
\*============================================================================*/
#define _UART_HPIHPIC_ADDR    _HPI_HPIC_ADDR

#define _UART_HPIHPIC_FGET(Field) \
  _REG_FGET(_UART_HPIHPIC_ADDR,_UART_HPIHPIC_##Field)
/*----------------------------------------------------------------------------*\
* UART HPI HPIC mapped signals bit/field definitions
\*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*\
* (R) UART_HPIHPIC_HPIENA
\*----------------------------------------------------------------------------*/
#define _UART_HPIHPIC_HPIENA_SHIFT    (0x0007u)
#define _UART_HPIHPIC_HPIENA_MK(n)    (((Uint16)(n) & 0x0001u)<< _UART_HPIHPIC_HPIENA_SHIFT)
#define _UART_HPIHPIC_HPIENA_MASK     (_UART_HPIHPIC_HPIENA_MK(1))
#define _UART_HPIHPIC_HPIENA_CLR      (~(_UART_HPIHPIC_HPIENA_MASK))

#ifdef __cplusplus
}
#endif /* extern "C" */
#else
  #ifndef _UART_MOD_ /* UART_SUPPORT */
    #error UART Module Not Supported on Specified Target
  #endif
#endif /* UART_SUPPORT */

#endif /* _UARTHAL_H_ */
/******************************************************************************\
* End of csl_timerhal.h
\******************************************************************************/
