/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... WATCHDOG TIMER
* FILENAME...... csl_wdtim.h
* DATE CREATED.. Sun 06/20/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... service layer
* PREREQUISITS.. cslhal.h
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:       06/20/1999 (BWC) Created for C6x.  
*   MODIFIED:      12/06/2000 (FSCA) Modification for C54x.
*   MODIFIED:      02/18/2000 (FSCA) C54x Romability .
*   MODIFIED: 	 06/19/2000 make #ifdefs consistent with new csl_ header names,
*                            cpluplus compatability
*   LAST MODIFIED: 01/04/2001 (IM) Took handles out
*
*------------------------------------------------------------------------------
* DESCRIPTION:  (interface file for the TIMER module)
*
*
*
\******************************************************************************/
#ifndef _CSL_WDTIM_H_
#define _CSL_WDTIM_H_


#include <csl_chiphal.h>

#if (_WDTIM_SUPPORT)

#include <_csl.h>
#include <csl_wdtimhal.h>

/****************************************\
* WDTIMER scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _WDTIM_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* WDTIM global macro declarations
\****************************************/ 
#define WDTIM_DEVICE_CNT           _WDTIM_DEVICE_CNT

/* error codes */
#define WDTIM_ERR_MAJOR            (ERR_BASE_WDTIM) 
#define WDTIM_ERR_ALLOC            (0x00000000)
#define WDTIM_ERR_INVALID_HANDLE   (0x00000001)


/*-----------------------------------------------------------------------*/
/* The following macros are used to construct peripheral register        */
/* values based on symbolic constants. They will be useful to initialize */
/* the TIMER_Config structure in a readable way.                         */
/*-----------------------------------------------------------------------*/

/* make TCR register value based on symbolic constants */

#define WDTIM_WDTCR_RMK(soft,free,tddr) \
 ((Uint16) ( \
  ( WDTIM_FMK(WDTCR,SOFT,soft))|\
  ( WDTIM_FMK(WDTCR,FREE,free))|\
  ( WDTIM_FMK(WDTCR,TDDR,tddr))\
  )\
)  

#define WDTIM_WDTCR_RMKS(soft_sym,free_sym,tddr_sym) \
 ((Uint16) ( \
  ( WDTIM_FMKS(WDTCR,SOFT,soft_sym))|\
  ( WDTIM_FMKS(WDTCR,FREE,free_sym))|\
  ( WDTIM_FMKS(WDTCR,TDDR,tddr_sym))\
  )\
)  


  
/* default TCR register value */
#define WDTIM_WDTCR_DEFAULT                 (0x0000)

/* TCR field values */
#define WDTIM_WDTCR_SOFT_BRKPTNOW           (0x0000)
#define WDTIM_WDTCR_SOFT_WAITZERO           (0x0001)
#define WDTIM_WDTCR_SOFT_DEFAULT            WDTIM_WDTCR_SOFT_BRKPTNOW

#define WDTIM_WDTCR_FREE_WITHSOFT           (0x0000)
#define WDTIM_WDTCR_FREE_NOSOFT             (0x0001)
#define WDTIM_WDTCR_FREE_DEFAULT            WDTIM_WDTCR_FREE_WITHSOFT

#define WDTIM_WDTCR_TDDR_OF(x)              ((Uint16)x)

#define WDTIM_WDTSCR_RMK(wdflag,wden,premd,wdkey) \
 ((Uint16) ( \
  ( WDTIM_FMK(WDTSCR,WDFLAG,wdflag))|\
  ( WDTIM_FMK(WDTSCR,WDEN,wden))|\
  ( WDTIM_FMK(WDTSCR,PREMD,premd))|\
  ( WDTIM_FMK(WDTSCR,WDKEY,wdkey))\
  )\
)  

#define WDTIM_WDTSCR_RMKS(wdflag_s,wden_s,premd_s,wdkey_s) \
 ((Uint16) ( \
  ( WDTIM_FMKS(WDTSCR,WDFLAG,wdflag_s))|\
  ( WDTIM_FMKS(WDTSCR,WDEN,wden_s))|\
  ( WDTIM_FMKS(WDTSCR,PREMD,premd_s))|\
  ( WDTIM_FMKS(WDTSCR,WDKEY,wdkey_s))\
  )\
)  

#define WDTIM_WDPRD_RMK(prd) \
 ((Uint16)(WDTIM_FMK(WDPRD,PRD,prd)))  

#define WDTIM_WDPRD_RMKS(prd_s) \
 ((Uint16)(WDTIM_FMK(WDPRD,PRD,prd_s)))  

#define WDTIM_WDTIM_RMK(tim) \
 ((Uint16)(WDTIM_FMK(WDTIM,TIM,tim)))  

#define WDTIM_WDTIM_RMKS(tim_s) \
 ((Uint16)(WDTIM_FMK(WDTIM,PRD,tim_s)))  


/* TSCR field values */

#define WDTIM_WDTSCR_WDFLAG_TIMEOUT         (0x0001u)
#define WDTIM_WDTSCR_WDFLAG_NOTIMEOUT       (0x0000u)
#define WDTIM_WDTSCR_WDFLAG_DEFAULT         WDTIM_WDTSCR_WDFLAG_NOTIMEOUT

#define WDTIM_WDTSCR_WDEN_ENABLE            (0x0001u)
#define WDTIM_WDTSCR_WDEN_DISABLE           (0x0000u)
#define WDTIM_WDTSCR_WDEN_DEFAULT           WDTIM_WDTSCR_WDEN_DISABLE

#define WDTIM_WDTSCR_PREMD_DIRECT           (0x0000u)
#define WDTIM_WDTSCR_PREMD_INDIRECT         (0x0001u)
#define WDTIM_WDTSCR_PREMD_DEFAULT          WDTIM_WDTSCR_PREMD_DIRECT

#define WDTIM_WDTSCR_WDKEY_PREACTIVE        (0x05C6u)
#define WDTIM_WDTSCR_WDKEY_ACTIVE           (0x0A7Eu)
#define WDTIM_WDTSCR_WDKEY_DEFAULT          (0x0000u)

#define WDTIM_WDPRD_PRD_OF(x)               ((Uint16)(x))
#define WDTIM_WDPRD_DEFAULT                 (0xFFFFu)

#define WDTIM_WDTIM_TIM_OF(x)               ((Uint16)(x))
#define WDTIM_WDTIM_DEFAULT                 (0xFFFFu)

/* make CLKMD register value based on symbolic constants */

/****************************************\
* WDTIMER global typedef declarations
\****************************************/

/* device configuration structure */
typedef struct {
  Uint16 wdtcr;
  Uint16 wdtscr;
  Uint16 wdprd;
} WDTIM_Config;

/****************************************\
* WDTIMER global variable declarations
\****************************************/ 


/****************************************\
* WDTIMER global function declarations
\****************************************/

/****************************************\
* WDTIMER inline function declarations
\****************************************/

IDECL void WDTIM_config(WDTIM_Config *Config);
IDECL void WDTIM_getConfig(WDTIM_Config *Config);
IDECL void WDTIM_configArgs(Uint16 wdtcr, Uint16 wdtscr, Uint16 wdprd);
IDECL void WDTIM_service();
IDECL void WDTIM_start();

/****************************************\
* WDTIMER inline function definitions
\****************************************/
#ifdef USEDEFS
/*----------------------------------------------------------------------------*/
IDEF void WDTIM_config(WDTIM_Config *Config) {
  int old_intm;
  Uint16 tscr_val = Config->wdtscr & (_WDTIM_WDTSCR_WDKEY_CLR & _WDTIM_WDTSCR_WDEN_CLR);

  old_intm = IRQ_globalDisable();  
  WDTIM_RSET(WDTCR,Config->wdtcr);
  WDTIM_RSET(WDPRD,Config->wdprd);
  WDTIM_RSET(WDTSCR,tscr_val);
  IRQ_globalRestore(old_intm);   

}
/*----------------------------------------------------------------------------*/
IDEF void WDTIM_getConfig(WDTIM_Config *Config) {
  int old_intm;

  old_intm = IRQ_globalDisable();  
  Config->wdtscr = WDTIM_RGET(WDTSCR);
  Config->wdprd = WDTIM_RGET(WDPRD);
  Config->wdtcr = WDTIM_RGET(WDTCR);
  Config->wdtim = WDTIM_RGET(WDTIM);   
  IRQ_globalRestore(old_intm);   
}
/*----------------------------------------------------------------------------*/
IDEF void WDTIM_configArgs(Uint16 wdtcr, Uint16 wdtscr, Uint16 wdprd) {
  int old_intm;
  Uint16 tscr_val = wdtscr & (_WDTIM_WDTSCR_WDEN_CLR & _WDTIM_WDTSCR_WDKEY_CLR);

   old_intm = IRQ_globalDisable(); 
    
   WDTIM_RSET(WDPRD,wdprd);
   WDTIM_RSET(WDTCR,wdtcr); 
   WDTIM_RSET(WDTSCR,tscr_val);
  
  IRQ_globalRestore(old_intm);   
}
/*----------------------------------------------------------------------------*/
IDEF void WDTIM_service() {
 Uint16 old_wdtscr;
 int old_intm;

  old_intm = IRQ_globalDisable();

  old_wdtscr = WDTIM_RGET(WDTSCR);

  WDTIM_FSETS(WDTSCR,WDKEY,PREACTIVE);
  WDTIM_RSET(WDTSCR,(old_wdtscr & _WDTIM_WDTSCR_WDKEY_CLR) 
    | WDTIM_WDTSCR_WDEN_ENABLE | WDTIM_WDTSCR_WDKEY_ACTIVE);

  IRQ_globalRestore(old_intm);
}

/*----------------------------------------------------------------------------*/
IDEF void WDTIM_start() {
 
 Uint16 old_wdtscr;
 int old_intm;

  old_intm = IRQ_globalDisable();

  old_wdtscr = WDTIM_RGET(WDTSCR);

  WDTIM_FSETS(WDTSCR,WDKEY,PREACTIVE);
  WDTIM_RSET(WDTSCR, 
    ((old_wdtscr & _WDTIM_WDTSCR_WDKEY_CLR) | WDTIM_WDTSCR_WDEN_ENABLE | WDTIM_WDTSCR_WDKEY_ACTIVE));

  IRQ_globalRestore(old_intm);
}

#endif /*USEDEFS */
#else
  #ifndef _WDTIM_MOD_ /*TIMER_SUPPORT */
    #error Watchdog Timer Module Not Supported on Specified Target
  #endif
#endif /*WDTIM_SUPPORT */

#endif /* _CSL_WDTIM_H_ */                
/******************************************************************************\
* End of csl_wdtim.h
\******************************************************************************/

