/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... WATCHDOG TIMER
* FILENAME...... csl_wdtimhal.h
* DATE CREATED.. Tues 10/26/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:		07/28/2000 
*   LAST MODIFIED:	(IM) 01/04/2001	Took out handles
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the Watch Dog TIMER module)
*
* Registers Covered:
*   (RW) _WDTIM_WDTCR - watchdog timer control register
*   (RW) _WDTIM_WDTSCR - watchdog timer control register 2
*   (RW) _WDTIM_WDPRD - watchdog timer period register
*   (RW) _WDTIM_WDTIM - watchdog timer count register
*
\******************************************************************************/
#ifndef _CSL_WDTIMHAL_H_
#define _CSL_WDTIMHAL_H_


#include <csl_chiphal.h>

#if (_WDTIM_SUPPORT)

/****************************************\
* TIMER scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _WDTIM_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/******************************************************************************\
* _WDTIM_TCR 
*
* Fields:
*   (RW) _WDTIM_WDTCR_SOFT
*   (RW) _WDTIM_WDTCR_FREE
*   (RW) _WDTIM_WDTCR_PSC
*   (RW) _WDTIM_WDTCR_TDR
*
\******************************************************************************/

#define _WDTIM_DEVICE_CNT        1


#define _WDTIM_WDTCR_ADDR             (0x004Eu)
#define _WDTIM_WDTCR                  REG16(_WDTIM_WDTCR_ADDR)
#define _WDTCR                         _WDTIM_WDTCR

#define _WDTIM_WDTSCR_ADDR            (0x004Fu)
#define _WDTIM_WDTSCR                 REG16(_WDTIM_WDTSCR_ADDR)
#define _WDTSCR                        _WDTIM_WDTSCR

#define _WDTIM_WDPRD_ADDR             (0x004Du)
#define _WDTIM_WDPRD                  REG16(_WDTIM_WDPRD_ADDR)
#define _WDPRD                         _WDTIM_WDPRD

#define _WDTIM_WDTIM_ADDR             (0x004Cu)
#define _WDTIM_WDTIM                  REG16(_WDTIM_WDTIM_ADDR)
#define _WDTIM                         _WDTIM_WDTIM


/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/
#define WDTIM_ADDR(Reg)               _WDTIM_##Reg##_ADDR
#define WDTIM_RGET(Reg)               _WDTIM_##Reg##_GET
#define WDTIM_RSET(Reg,Val)           _WDTIM_##Reg##_SET(Val)
#define WDTIM_RAOI(Reg,AND,OR,INV)    _WDTIM_##Reg##_AOI(AND,OR,INV)
#define WDTIM_FGET(Reg,Field)         _WDTIM_##Reg##_FGET(##Field)
#define WDTIM_FSET(Reg,Field,Val)     _WDTIM_##Reg##_FSET(##Field,Val)
#define WDTIM_FSETS(Reg,Field,Sym)    WDTIM_FSET(Reg,Field,WDTIM_##Reg##_##Field##_##Sym)
#define WDTIM_FAOI(Reg,Field,AND,OR,INV)\
  _WDTIM_##Reg##_FAOI(Field,AND,OR,INV)
#define WDTIM_FMK(Reg,Field,Val)      _WDTIM_##Reg##_##Field##_MK(Val)
#define WDTIM_FMKS(Reg,Field,Sym)     WDTIM_FMK(##Reg,##Field,WDTIM_##Reg##_##Field##_##Sym)

#define _WDTIM_WDTCR_SET(Val)         _REG_SET(_WDTIM_WDTCR_ADDR,Val)
#define _WDTIM_WDTCR_GET              _REG_GET(_WDTIM_WDTCR_ADDR)
#define _WDTIM_WDTCR_AOI(AND,OR,INV)  _REG_AOI(_WDTIM_WDTCR_ADDR,AND,OR,INV)
#define _WDTIM_WDTCR_FGET(Field)      _FIELD_GET(_WDTIM_WDTCR_ADDR,_WDTIM_WDTCR_##Field)
#define _WDTIM_WDTCR_FSET(Field,Val)  _FIELD_SET(_WDTIM_WDTCR_ADDR,_WDTIM_WDTCR_##Field,Val)
#define _WDTIM_WDTCR_FSETS(Field,Sym) _WDTIM_WDTCR_FSETS(##Field,WDTIM_WDTCR_##Field##_##Sym)
#define _WDTIM_WDTCR_FAOI(Field,AND,OR,INV)\
   _FIELD_FAOI(_WDTIM_WDTCR_ADDR,_WDTIM_WDTCR_##Field,AND,OR,INV)

#define _WDTIM_WDTSCR_GET              _REG_GET(_WDTIM_WDTSCR_ADDR)
#define _WDTIM_WDTSCR_SET(Val)         _REG_SET(_WDTIM_WDTSCR_ADDR,Val)
#define _WDTIM_WDTSCR_AOI(AND,OR,INV)  _REG_AOI(_WDTIM_WDTSCR_ADDR,AND,OR,INV)
#define _WDTIM_WDTSCR_FGET(Field)      _FIELD_GET(_WDTIM_WDTSCR_ADDR,_WDTIM_WDTSCR_##Field)
#define _WDTIM_WDTSCR_FSET(Field,Val)  _FIELD_SET(_WDTIM_WDTSCR_ADDR,_WDTIM_WDTSCR_##Field,Val)
#define _WDTIM_WDTSCR_FSETS(Field,Sym) _WDTIM_WDTSCR_FSET(##Field,WDTIM_WDTSCR_##Field##_##Sym)
#define _WDTIM_WDTSCR_FAOI(Field,AND,OR,INV)\
   _FIELD_FAOI(_WDTIM_WDTSCR_ADDR,_WDTIM_WDTSCR_##Field,AND,OR,INV)

#define _WDTIM_WDPRD_GET              _REG_GET(_WDTIM_WDPRD_ADDR)
#define _WDTIM_WDPRD_SET(Val)         _REG_SET(_WDTIM_WDPRD_ADDR,Val)
#define _WDTIM_WDPRD_AOI(AND,OR,INV)  _REG_AOI(_WDTIM_WDPRD_ADDR,AND,OR,INV)
#define _WDTIM_WDPRD_FGET(Field)      _FIELD_GET(_WDTIM_WDPRD_ADDR,_WDTIM_WDPRD_##Field)
#define _WDTIM_WDPRD_FSET(Field,Val)  _FIELD_SET(_WDTIM_WDPRD_ADDR,_WDTIM_WDPRD_##Field,Val)
#define _WDTIM_WDPRD_FSETS(Field,Sym) _WDTIM_WDPRD_FSET(##Field,WDTIM_WDPRD_##Field##_##Sym)
#define _WDTIM_WDPRD_FAOI(Field,AND,OR,INV)\
   _FIELD_FAOI(_WDTIM_WDPRD_ADDR,_WDTIM_WDPRD_##Field,AND,OR,INV)

#define _WDTIM_WDTIM_GET              _REG_GET(_WDTIM_WDTIM_ADDR)
#define _WDTIM_WDTIM_SET(Val)         _REG_SET(_WDTIM_WDTIM_ADDR,Val)
#define _WDTIM_WDTIM_AOI(AND,OR,INV)  _REG_AOI(_WDTIM_WDTIM_ADDR,AND,OR,INV)
#define _WDTIM_WDTIM_FGET(Field)      _FIELD_GET(_WDTIM_WDTIM_ADDR,_WDTIM_WDTIM_##Field)
#define _WDTIM_WDTIM_FSET(Field,Val)  _FIELD_SET(_WDTIM_WDTIM_ADDR,_WDTIM_WDTIM_##Field,Val)
#define _WDTIM_WDTIM_FSETS(Field,Sym) _WDTIM_WDPRD_FSET(##Field,WDTIM_WDTIM_##Field##_##Sym)
#define _WDTIM_WDTIM_FAOI(Field,AND,OR,INV)\
   _FIELD_FAOI(_WDTIM_WDPRD_ADDR,_WDTIM_WDPRD_##Field,AND,OR,INV)


/*----------------------------------------------------------------------------*\
* Watch Dog Timer Control Register (WDTCR) bit/field definitions
\*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*\
* (RW) WDTIMER_WDTCR_SOFT
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTCR_SOFT_SHIFT       (0x000bu)
#define _WDTIM_WDTCR_SOFT_MK(n)       (((Uint16)(n) & 0x0001u)<< _WDTIM_WDTCR_SOFT_SHIFT)
#define _WDTIM_WDTCR_SOFT_MASK        (_WDTIM_WDTCR_SOFT_MK(1))
#define _WDTIM_WDTCR_SOFT_CLR         (~(_WDTIM_WDTCR_SOFT_MASK))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR_FREE
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTCR_FREE_SHIFT       (0x000au)
#define _WDTIM_WDTCR_FREE_MK(n)       (((Uint16)(n) &0x0001u) << _WDTIM_WDTCR_FREE_SHIFT)
#define _WDTIM_WDTCR_FREE_MASK        (_WDTIM_WDTCR_FREE_MK(1))
#define _WDTIM_WDTCR_FREE_CLR         (~(_WDTIM_WDTCR_FREE_MASK))

/*----------------------------------------------------------------------------*\
* (R) TIMER_TCR_PSC
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTCR_PSC_SHIFT        (0x0006u)
#define _WDTIM_WDTCR_PSC_MK(n)     	(((Uint16)(n) & 0x000fu) << 6)
#define _WDTIM_WDTCR_PSC_MASK     	(_WDTIM_WDTCR_PSC_MK(0x000fu))
#define _WDTIM_WDTCR_PSC_CLR     	(~_WDTIM_WDTCR_PSC_MK(0x000fu))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR_TDDR
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTCR_TDDR_SHIFT       (0x0000u)
#define _WDTIM_WDTCR_TDDR_MK(n)       (((Uint16)(n) & 0x000fu)<< _WDTIM_WDTCR_TDDR_SHIFT)
#define _WDTIM_WDTCR_TDDR_MASK	  (_WDTIM_WDTCR_TDDR_MK(0x000fu))
#define _WDTIM_WDTCR_TDDR_CLR	 	  (~(_WDTIM_WDTCR_TDDR_MASK))

/*----------------------------------------------------------------------------*\
* (RW) TIMER_TCR
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTCR_CFG(RegAddr, soft, free, tddr)\
   _REG_SET(RegAddr, \
   (Uint16)( _WDTIM_WDTCR_SOFT_MK(soft)     |\
             _WDTIM_WDTCR_FREE_MK(free)     |\
             _WDTIM_WDTCR_TDDR_MK(tddr)\
            )\
    )
 			 
/******************************************************************************\
* _WDTIM_WDPRD - Watch Dog Timer Period Register
*
* Fields:
*   (RW) PRD
*
\******************************************************************************/

/*----------------------------------------------------------------------------*\
* (RW) TIMER_PRD_PRD
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDPRD_PRD_SHIFT       (0x0000u)
#define _WDTIM_WDPRD_PRD_MK(n)       (((Uint16)(n) & 0xffffu)<< _WDTIM_WDPRD_PRD_SHIFT)
#define _WDTIM_WDPRD_PRD_MASK        (_WDTIM_WDPRD_PRD_MK(0xffffu))
#define _WDTIM_WDPRD_PRD_CLR         (~(_WDTIM_WDPRD_PRD_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _WDTIM_WDPRD
\*----------------------------------------------------------------------------*/
 			 


/******************************************************************************\
* _WDTIM_WDTIM - Watch Dog Timer Timer/Count register
*
* Fields:
*   (RW) TIM
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) _WDTIM_TIM_TIM
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTIM_TIM_SHIFT       (0x0000u)
#define _WDTIM_WDTIM_TIM_MK(n)       (((Uint16)(n) & 0xffffu)<< _WDTIM_WDTIM_TIM_SHIFT)
#define _WDTIM_WDTIM_TIM_MASK        (_WDTIM_WDTIM_TIM_MK(0xffffu))
#define _WDTIM_WDTIM_TIM_CLR         (~(_WDTIM_WDTIM_TIM_MASK))

/******************************************************************************\
* _WDTIM_WDTSCR - Watch Dog Timer Secondary Control Register
*
* Fields:
*   (RW) WDTSCR_WDFLAG
*   (RW) WDTSCR_WDEN
*   (RW) WDTSCR_PREMD
*   (RW) WDTSCR_WDKEY
*
\******************************************************************************/
/*----------------------------------------------------------------------------*\
* (RW) HWDTSCR_WDFLAG - Watch Dog Timeout flag
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTSCR_WDFLAG_SHIFT      (0x000Fu)
#define _WDTIM_WDTSCR_WDFLAG_MK(n)      (((Uint16)(n) & 0x1u)<< _WDTIM_WDTSCR_WDFLAG_SHIFT)
#define _WDTIM_WDTSCR_WDFLAG_MASK       (_WDTIM_WDTSCR_WDFLAG_MK(0x1u))
#define _WDTIM_WDTSCR_WDFLAG_CLR        (~(_WDTIM_WDTSCR_WDFLAG_MASK))

/*----------------------------------------------------------------------------*\
* (RW) HWDTSCR_WDEN - Watch Dog Timer Enable Bit
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTSCR_WDEN_SHIFT       (0x000Eu)
#define _WDTIM_WDTSCR_WDEN_MK(n)       (((Uint16)(n) & 0x1u)<< _WDTIM_WDTSCR_WDEN_SHIFT)
#define _WDTIM_WDTSCR_WDEN_MASK        (_WDTIM_WDTSCR_WDEN_MK(0x1u))
#define _WDTIM_WDTSCR_WDEN_CLR         (~(_WDTIM_WDTSCR_WDEN_MASK))

/*----------------------------------------------------------------------------*\
* (RW) HWDTSCR_PREMD - Watch Dog Timer Pre-scaler Mode Bit
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTSCR_PREMD_SHIFT      (0x000cu)
#define _WDTIM_WDTSCR_PREMD_MK(n)      (((Uint16)(n) & 0x1u)<< _WDTIM_WDTSCR_PREMD_SHIFT)
#define _WDTIM_WDTSCR_PREMD_MASK       (_WDTIM_WDTSCR_PREMD_MK(0x1u))
#define _WDTIM_WDTSCR_PREMD_CLR        (~(_WDTIM_WDTSCR_PREMD_MASK))

/*----------------------------------------------------------------------------*\
* (RW) HWDTSCR_WDKEY - Watch Dog Timer Pre-scaler Mode Bit
\*----------------------------------------------------------------------------*/
#define _WDTIM_WDTSCR_WDKEY_SHIFT      (0x0000u)
#define _WDTIM_WDTSCR_WDKEY_MK(n)      (((Uint16)(n) & 0xFFFu)<< _WDTIM_WDTSCR_WDKEY_SHIFT)
#define _WDTIM_WDTSCR_WDKEY_MASK       (_WDTIM_WDTSCR_WDKEY_MK(0xFFFu))
#define _WDTIM_WDTSCR_WDKEY_CLR        (~(_WDTIM_WDTSCR_WDKEY_MASK))

#else
  #ifndef _WDTIM_MOD_ /* _WDTIMHAL_H_ */
     #error WatchDog Timer HAL Module Not Supported on Specified Target
  #endif
#endif  /* _CSL_WDTIMHAL_H_ */
#endif
/******************************************************************************\
* End of csl_wdtimhal.h
\******************************************************************************/
