/******************************************************************/
/* bus.h - v0.00                                                  */
/* Copyright (c) 2000 Texas Instruments Incorporated              */
/******************************************************************/
/******************************************************************/
/* This header files defines the data structures and macros to    */
/* access the Software Wait State and Bank Switch Control Regs    */
/* and their bits/fields.                                         */
/******************************************************************/

#include "regs.h"

/******************************************************************/
/* BNKCMP_MASK(val) - creates mask to set bank size of ext mem    */
/*  val   - bank size of external memory (4,8,32,64)              */
/******************************************************************/
#define BNKCMP_MASK(val)\
       (0x0010u - (val/0x4u))

/******************************************************************/
/* BSCR_MASK(bnkcmp, psds, bh, exio) - set bank switch ctrl reg   */
/*  bnkcmp  - size of external memory banks (4 - 64)              */
/*  psds    - flag, equal 1 if extra cycle for back-to-back       */
/*            program-data or data-program memory reads           */
/*  bh      - flag, equal 1 if data bus holder is active , holds  */
/*            data bus , D(15-0) at previous logic level          */
/*  exio    - flag, equal 1 if external-bus-off function is       */
/*            enabled. (normally set to 0)                        */
/******************************************************************/
#define BSCR_MASK(bnkcmp, psds, bh, exio)\
	((MASK_FIELD(BNKCMP,BNKCMP_MASK(bnkcmp), BNKCMP_SZ)) &\
	 (psds ? (MASK_BIT(PSDS) | MASK_TARGET_WORD) : ~MASK_BIT(PSDS)) &\
	 (bh   ? (MASK_BIT(BH)   | MASK_TARGET_WORD) : ~MASK_BIT(BH))   &\
	 (exio))

/******************************************************************/
/* CLEAR_WAIT_STATES - clears all software wait states            */
/*   addr - address of software wait state register               */
/******************************************************************/
#define CLEAR_WAIT_STATES\
	SWWSR &= ~MASK_TARGET_WORD

/******************************************************************/
/* SET_WAIT_STATES(ctrl) - set software wait states               */
/*	addr  - address of software wait state register           */
/*      ctrl  - mask to use in setting wait state register        */
/******************************************************************/
#define SET_WAIT_STATES(ctrl)\
	SWWSR |= ctrl

/******************************************************************/
/* SET_BUS_CTRL(ctrl) - sets bus control register                 */
/*	ctrl - mask to use in setting register value              */
/******************************************************************/
#define SET_BUS_CTRL(ctrl)\
	BSCR |= ctrl
