#ifndef _DSPLIB
#define _DSPLIB

#include "tms320.h"

/* fft */

short cfft8 (DATA *x);
short cfft16 (DATA *x);
short cfft32 (DATA *x);
short cfft64 (DATA *x);
short cfft128 (DATA *x);
short cfft256 (DATA *x);
short cfft512 (DATA *x);
short cfft1024 (DATA *x);

short rfft16 (DATA *x);
short rfft32 (DATA *x);
short rfft64 (DATA *x);
short rfft128 (DATA *x);
short rfft256 (DATA *x);
short rfft512 (DATA *x);
short rfft1024 (DATA *x);

short cbrev (DATA *x, DATA *y, ushort n);

/* correlations */

short acorr_raw (DATA *x, DATA *r, ushort nx, ushort nr);
short acorr_bias(DATA *x, DATA *r, ushort nx, ushort nr);
short acorr_unbias(DATA *x, DATA *r, ushort nx, ushort nr);

short corr_raw	(DATA *x, DATA *y, DATA *r, ushort nx, ushort ny);
short corr_bias  (DATA *x, DATA *y, DATA *r, ushort nx, ushort ny);
short corr_unbias  (DATA *x, DATA *y, DATA *r, ushort nx, ushort ny);

/* filtering and convolution */

short convol (DATA *x, DATA *y, DATA *r, ushort ny, ushort nr);
short fir(DATA *x, DATA *h, DATA *r,DATA **d, ushort nh, ushort nx);
short firs(DATA *x, DATA *r,DATA **d, ushort nh, ushort nx);
short firs2(DATA *x, DATA *h, DATA *r,DATA **d, ushort nh, ushort nx);
short cfir(DATA *x, DATA *h, DATA *r,DATA **d, ushort nh, ushort nx);

short iircas4(DATA *x,DATA *h,DATA *r,DATA **d, ushort nbiq, ushort nx);
short iircas5(DATA *x,DATA *h,DATA *r,DATA **d, ushort nbiq, ushort nx);
short iircas51(DATA *x,DATA *h,DATA *r,DATA **d, ushort nbiq, ushort nx);
short iir32(DATA *x,LDATA *h,DATA *r,LDATA **d, ushort nbiq, ushort nx);

short firdec(DATA *x, DATA *h, DATA *r,DATA **d, ushort nh, ushort nx, ushort D);
short firinterp(DATA *x,DATA *h,DATA *r,DATA **db,ushort nh,ushort nx,ushort I);

short latfor (DATA *x, DATA *h, DATA *r, DATA *d, ushort nx, ushort nh);

/* adaptive filtering */

short dlms(DATA *x,DATA *h,DATA *r, DATA **d, DATA *des, DATA step, ushort nh, ushort nx);
short nblms (DATA *x,DATA *h,DATA *r, DATA **d, DATA *des, ushort nh, ushort nx, ushort nb, DATA *norm_e, int l_tau, int cutoff, int gain);
short ndlms (DATA *x, DATA *h, DATA *r, DATA **d, DATA *des, ushort nh, ushort nx, int l_tau, int cutoff, int gain, DATA *norm_d);


/* math */

short add (DATA *x, DATA *y, DATA *r, ushort nx, short scale);
short sub(DATA *x, DATA *y,  DATA *r, ushort nx, ushort scale);
short neg(DATA *x, DATA *r, ushort nx);

short ldiv16(LDATA *x, DATA *y, DATA *z, DATA *exp, unsigned short nx);
void recip16 (DATA *x, DATA *z, DATA *zexp, ushort n);


short expn(DATA *x, DATA *r, ushort nx);
short logn(DATA *x, LDATA *r, ushort nx);
short log_2(DATA *x, LDATA *r, ushort nx);
short log_16(DATA *x, LDATA *r, ushort nx);

short sqrt_16(DATA *x, DATA *y, short nx);

short maxidx (DATA *x, ushort nx);
short maxval (DATA *x, ushort nx);
short minidx (DATA *x, ushort nx);
short minval (DATA *x, ushort nx);

short rand16(DATA *r, ushort nr);
void rand16init(void);

short mul32(LDATA *x, LDATA *y,  LDATA *r, ushort nx);
short neg32(LDATA *x, LDATA *r, ushort nx);
short power(DATA *x, LDATA *r, ushort nx);

/* matrix */

short mmul(DATA *x1,short row1,short col1,DATA *x2,short row2,short col2,DATA *r);
short mtrans(DATA *x, short row, short col, DATA *r);

/* trigonometric */

short sine (DATA *x, DATA *r, ushort nx);

/* miscellaneous */

short fltoq15(float *x, DATA *r, ushort nx);
short  q15tofl (DATA *x, float *r, ushort nx);


/* macro definition */

#define acorr(n1, n2, n3, n4, type) acorr_##type(n1, n2, n3, n4)
#define corr(n1, n2, n3, n4, n5, type) corr_##type(n1, n2, n3, n4, n5)
#define dummy(x,n)	cfft##n(x)	// macro for generic FFT look
#define cfft(x,n)	dummy(x,n)

#define dummy2(x,n)	 rfft##n(x)	// macro for generic FFT look
#define rfft(x,n)	dummy2(x,n)

#endif
