************************************************************************
* - RTDX Include file - interface to 'C54x ASM.                        *
************************************************************************
      .width  80
      .length 55
      .title      "RTDX interface to 'C54x ASM"

************************ Channel Structures Info ***********************
_RTDX_OUTPUT_CHANNEL            .struct
_enabled                        .int
_RTDX_OUTPUT_CHANNEL_LEN        .endstruct
                                .stag   _RTDX_OUTPUT_CHANNEL, 16
                                .member _enabled, 0, 14, 8, 16
                                .eos

_RTDX_INPUT_CHANNEL             .struct
_enabled                        .int
_count                          .int
_busy                           .int
_RTDX_INPUT_CHANNEL_LEN         .endstruct
                                .stag   _RTDX_INPUT_CHANNEL, 48
                                .member _enabled, 0, 14, 8, 16
                                .member _count, 16, 14, 8, 16
                                .member _busy, 32, 4, 8, 16
                                .eos


***************************** Error Checking ****************************
Error_Check                     .macro param,level

SYMCHECK1    .set   1
SYMCHECK2    .set   2
SYMCHECK3    .set   3

      ; Check for level 1 testing
      .asg       level,SYMPARAM
      .if        SYMPARAM >= SYMCHECK1
      .if        ($symlen(param) == 0)        ; ensure parameter given
      .emsg      "ERROR -- Missing parameter
      .endif
      .endif

      ; Check for level 1 & 2 testing
      .if        SYMPARAM >= SYMCHECK2
      .if        ($isname(param) == 0)        ; ensure parameter is a
                                              ;     valid symbol name
      .emsg      "ERROR -- Invalid symbol name given as argument"
      .endif
      .endif

      ; Check for level 1,2 & 3 testing
      .if        SYMPARAM >= SYMCHECK3
      .if        ($isdefed(param) == 0)       ; ensure parameter is
                                              ;     a defined symbol
      .emsg      "ERROR -- Undefined Symbol given as argument"
      .endif
      .endif
      .endm

****************************** Data Macros ******************************

RTDX_CreateOutputChannel        .macro ochan
      Error_Check ochan,2
      .sect       ".cinit"
      .align      1
      .field      1,16
      .field      ochan+0,16
      .field      0,16
      .sect       ".text"
      .global     ochan
      .bss        ochan,1,0,0
      .sym        ochan,ochan, 8, 2, 16, _RTDX_OUTPUT_CHANNEL
      .endm


RTDX_CreateInputChannel         .macro ichan
      Error_Check ichan,2
      .sect       ".cinit"
      .align      1
      .field      3,16
      .field      ichan+0,16
      .field      0,16
      .field      0,16
      .field      0,16
      .sect       ".text"
      .global     ichan
      .bss        ichan,3,0,0
      .sym        ichan,ichan, 8, 2, 48, _RTDX_INPUT_CHANNEL
      .endm

RTDX_event                      .macro event,class
      Error_Check event,2
      Error_Check class,1
      
      .sect       ".cinit"
      .align      1
      .field      1,16
      .field      event+0,16
      .field      class,16
      .sect       ".text"
      .global     event
      .bss        event,1,0,0
      .endm

RTDX_e_class_set        .macro eclass
      Error_Check eclass,2
      
      .def        eclass
      .bss        eclass,1,0,0
      .endm

**************************** Function Macros ****************************

RTDX_enableOutput	        .macro ochan
      Error_Check ochan,3
      
      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_enableOutput
      LD          #ochan,A
      .if         __far_mode
      FCALL       #_RTDX_enableOutput
      .else
      CALL        #_RTDX_enableOutput
      .endif
      .endm

RTDX_disableOutput              .macro ochan
      Error_Check ochan,3

      SSBX        CPL                           ; set the CPL bit      
      .ref        _RTDX_disableOutput
      LD          #ochan,A
      .if         __far_mode
      FCALL       #_RTDX_disableOutput
      .else
      CALL        #_RTDX_disableOutput
      .endif
      .endm

RTDX_enableInput                .macro ichan
      Error_Check ichan,3
      
      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_enableInput
      LD          #ichan,A
      .if         __far_mode
      FCALL       #_RTDX_enableInput
      .else
      CALL        #_RTDX_enableInput
      .endif
      .endm

RTDX_disableInput	        .macro ichan
      Error_Check ichan,3
      
      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_disableInput
      LD          #ichan,A
      .if         __far_mode
      FCALL       #_RTDX_disableInput
      .else
      CALL        #_RTDX_disableInput
      .endif
      .endm

RTDX_write                      .macro ochan,buffptr,bsize
      Error_Check ochan,3
      Error_Check buffptr,1
      Error_Check bsize,1
      
      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_write

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      PSHM        bsize
      .else
      STM         bsize,BL
      PSHM        BL
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))     
      PSHM        buffptr
      .else
      STM         buffptr,BL
      PSHM        BL
      .endif

* Call the RTDX data write function
      LD          #ochan,A
      .if         __far_mode
      FCALL       #_RTDX_write
      .else
      CALL        #_RTDX_write                  ; return param in
                                                ;     register A
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))
      POPM        buffptr
      .else
      POPM        BL
      .endif

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      POPM        bsize
      .else
      POPM        BL
      .endif
      .endm
    
RTDX_read                       .macro ichan,buffptr,bsize
      Error_Check ichan,3
      Error_Check buffptr,1
      Error_Check bsize,1

      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_read

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      PSHM        bsize
      .else
      STM         bsize,BL
      PSHM        BL
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))     
      PSHM        buffptr
      .else
      STM         buffptr,BL
      PSHM        BL
      .endif

* Call the RTDX read function
      LD          #ichan,A
      .if         __far_mode
      FCALL       #_RTDX_read
      .else
      CALL        #_RTDX_read                   ; return param in
                                                ;     register A
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))
      POPM        buffptr
      .else
      POPM        BL
      .endif

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      POPM        bsize
      .else
      POPM        BL
      .endif
      .endm

RTDX_readNB                     .macro ichan,buffptr,bsize
      Error_Check ichan,3
      Error_Check buffptr,1
      Error_Check bsize,1

      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_readNB

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      PSHM        bsize
      .else
      STM         bsize,BL
      PSHM        BL
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))     
      PSHM        buffptr
      .else
      STM         buffptr,BL
      PSHM        BL
      .endif

* Call the RTDX non-blocking read function

      LD          #ichan,A
      .if         __far_mode
      FCALL       #_RTDX_readNB
      .else
      CALL        #_RTDX_readNB                 ; return param in
                                                ;     register A
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))
      POPM        buffptr
      .else
      POPM        BL
      .endif

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      POPM        bsize
      .else
      POPM        BL
      .endif
      .endm

RTDX_Enable_Event_Class	        .macro eclass
      Error_Check eclass,3

      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_Enable_Event_Class
      LD          eclass,A
      .if         __far_mode
      FCALL       #_RTDX_Enable_Event_Class
      .else
      CALL        #_RTDX_Enable_Event_Class
      .endif
      .endm

RTDX_Disable_Event_Class        .macro eclass
      Error_Check eclass,3

      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_Disable_Event_Class
      LD          eclass,A
      .if         __far_mode
      FCALL       #_RTDX_Disable_Event_Class
      .else
      CALL        #_RTDX_Disable_Event_Class
      .endif
      .endm

RTDX_Log_Event                  .macro event
      Error_Check event,3

      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_Log_Event_Data
      STM         #0,BL
      PSHM        BL
      STM         #0,BL
      PSHM        BL
      LD          #event,A
      .if         __far_mode
      FCALL       #_RTDX_Log_Event_Data
      .else
      CALL        #_RTDX_Log_Event_Data
      .endif
      POPM        BL
      POPM        BL
      .endm

RTDX_Log_Event_Data             .macro event,buffptr,bsize
      Error_Check event,3
      Error_Check buffptr,1
      Error_Check bsize,1

      SSBX        CPL                           ; set the CPL bit
      .ref        _RTDX_Log_Event_Data

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      PSHM        bsize
      .else
      STM         bsize,BL
      PSHM        BL
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))     
      PSHM        buffptr
      .else
      STM         buffptr,BL
      PSHM        BL
      .endif

* Call the RTDX log event function
      LD          #event,A
      .if         __far_mode
      FCALL       #_RTDX_Log_Event_Data
      .else
      CALL        #_RTDX_Log_Event_Data         ; return param in
                                                ;     register A
      .endif

* Testing to see if parameter 2 is a register or memory address
      .if         ($isreg(buffptr))
      POPM        buffptr
      .else
      POPM        BL
      .endif

* Testing to see if parameter 3 is a register or memory address
      .if         ($isreg(bsize))
      POPM        bsize
      .else
      POPM        BL
      .endif
      .endm

************************** Channel Test Macros **************************

RTDX_channelBusy                .macro ichan
      Error_Check ichan,3
      CMPM        *(#ichan+2),#1 ; Compare and set the TC bit
      .endm

RTDX_sizeofInput                .macro ichan
      Error_Check ichan,3
      LD          *(#ichan+1),A  ; load accumulator with buffer size
      .endm

RTDX_isInputEnabled             .macro ichan
      Error_Check ichan,3
      CMPM        #ichan,#4112   ; Compare and set the TC bit
      .endm

RTDX_isOutputEnabled            .macro ochan
      Error_Check ochan,3
      CMPM        #ochan,#4112   ; Compare and set the TC bit
      .endm
