/*
 *  Copyright 2001 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) XDAS 2.2.1 12-07-01 (__imports)" */
/*
 *  ======== tst.c ========
 */
#include <std.h>
#include <itst.h>
#include <tst.h>
#include <alg.h>

/*
 *  ======== TST_create ========
 */
TST_Desc *TST_create(TST_Desc *obj, ALG_Handle alg, ITST_Fxns *fxns)
{
    if (obj != NULL) {
        /* verify that alg and tst fxns are from same concrete implementation*/
        if (fxns->implementationId == alg->fxns->implementationId) {
            obj->handle = (ITST_Handle)alg;
            obj->fxns = fxns;
            return (obj);
        }
        obj->fxns = NULL;
    }

    return (NULL);
}

/*
 *  ======== TST_exit ========
 */
Void TST_exit(Void)
{
}

/*
 *  ======== TST_getParams ========
 */
Void TST_getParams(TST_Desc *tst, Int op, TST_ParamRec in[],TST_ParamRec out[])
{
    if (tst && tst->fxns) {
        if (tst->fxns->tstGetParams == NULL) {
            in[0].maxFrameSize = 0;
            out[0].maxFrameSize = 0;
        }
        else {
            tst->fxns->tstGetParams(tst->handle, op, in, out);
        }
    }
}

/*
 *  ======== TST_init ========
 */
Void TST_init(Void)
{
}

/*
 *  ======== TST_numOps ========
 */
Int TST_numOps(TST_Desc *tst)
{
    if (tst && tst->fxns) {
        if (tst->fxns->tstNumOps == NULL) {
            return (ITST_DEFNUMOPS);
        }
        else {
            return (tst->fxns->tstNumOps(tst->handle));
        }
    }

    return (0);
}

/*
 *  ======== TST_numParams ========
 */
Void TST_numParams(TST_Desc *tst, Int op, Int *numIn, Int *numOut)
{
    if (tst && tst->fxns) {
        if (tst->fxns->tstNumParams == NULL) {
            *numIn  = ITST_DEFNUMPARMS;
            *numOut = ITST_DEFNUMPARMS;
        }
        else {
            tst->fxns->tstNumParams(tst->handle, op, numIn, numOut);
        }
    }
    else {
        *numIn  = 0;
        *numOut = 0;
    }
}

/*
 *  ======== TST_process ========
 */
Void TST_process(TST_Desc *tst, Int opCode, TST_Frame *in, TST_Frame *out)
{
    if (tst && tst->fxns && tst->fxns->tstProcess) {
        tst->fxns->tstProcess(tst->handle, opCode, in, out);
    }
}

