/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/*
 *  ======== atm.h ========
 *
 *  Atomic processor operations:
 *      ATM_and()   ATM_clear() ATM_dec()
 *      ATM_inc()   ATM_or()    ATM_set()
 *
 */

#ifndef ATM_
#define ATM_

#ifdef __cplusplus
extern "C" {
#endif

/*
 *  ======== ATM_and ========
 *  atomically and integer or unsigned with mask and return its old value
 */
extern Int ATM_andi( volatile Int *dst, Int mask );
extern Uns ATM_andu( volatile Uns *dst, Uns mask );

/*
 *  ======== ATM_clear ========
 *  atomically clear integer or unsigned and return its old value
 */
extern Int ATM_cleari( volatile Int *dst );
extern Uns ATM_clearu( volatile Uns *dst );

/*
 *  ======== ATM_dec ========
 *  atomically decrement integer or unsigned and return new value
 */
extern Int ATM_deci( volatile Int *dst );
extern Uns ATM_decu( volatile Uns *dst );

/*
 *  ======== ATM_inc ========
 *  atomically increment integer or unsigned and return new value
 */
extern Int ATM_inci( volatile Int *dst );
extern Uns ATM_incu( volatile Uns *dst );

/*
 *  ======== ATM_or ========
 *  atomically or integer or unsigned with mask and return its old value
 */
Int ATM_ori( volatile Int *dst, Int mask );
Uns ATM_oru( volatile Uns *dst, Uns mask );

/*
 *  ======== ATM_set ========
 *  atomically set integer or unsigned and return its old value
 */
Int ATM_seti( volatile Int *dst, Int x );
Uns ATM_setu( volatile Uns *dst, Uns x );

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* ATM_ */
