/*
 *  Copyright 2000 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  U.S. Patent Nos. 5,283,900  5,392,448
 */
/* "@(#) DSP/BIOS Patch 03-30-01 (patch010330-a00)" */
/*
 *  ======== clk_start_omap.c =========
 *
 */

#include <std.h>

#define CLK_LORES_BASE     0x2800  /* I/O address of low res timer */
#define CLK_LORES_IER1_BIT 0x80	   /* bit in IER1 for low res timer */
#define CLK_LORES_PRD_LO   0x53d9  /* LSBs of count for 1 msec interrupt rate */
#define CLK_LORES_PRD_HI   0x0	   /* MSBs */

#define CLK_HIRES_BASE     0x2c00  /* I/O address of high res timer */
#define CLK_HIRES_PRD_LO   0xffff  /* LSBs of high res roll over count */
#define CLK_HIRES_PRD_HI   0xffff  /* MSBs of high res roll over count */

typedef struct {
    Uns CNTL_TIMER;	/* timer control register */
    Uns unused;		
    Uns LOAD_TIM_HI;	/* load timer high register */
    Uns LOAD_TIM_LO;	/* load timer low register */
    Uns VALUE_TIM_HI;	/* high bits of time  */
    Uns VALUE_TIM_LO;	/* low bits of time  */
} CLK_Regs;


/*
 *  ======== CLK_start ========
 */
Void CLK_start(Void)
{
    ioport CLK_Regs *timerLO = (CLK_Regs *) CLK_LORES_BASE;
    ioport CLK_Regs *timerHI= (CLK_Regs *) CLK_HIRES_BASE;
    ioport Uns *DSP_CKCTL = (Uns *) 0x4000;
    ioport Uns *DSP_IDLECT2 = (Uns *) 0x4004;
    Uns *IER1 = (Uns *) 0x45;

    /* setup Helen clock manager (CLKM) to gate clock signal to timers */
    *DSP_CKCTL = *DSP_CKCTL | 0x100;
    *DSP_IDLECT2 = *DSP_IDLECT2 | 0x20;

    /* setup low resolution timer and interrupt */
    timerLO->CNTL_TIMER = timerLO->CNTL_TIMER | 0x20;   /* CLK EN=1 */
    timerLO->CNTL_TIMER = timerLO->CNTL_TIMER & 0xffe2; /* PTV=0, START=0 */
    timerLO->CNTL_TIMER = timerLO->CNTL_TIMER | 0x82;   /* AR=1, SOFT=1, 
							   FREE=0 */
    timerLO->LOAD_TIM_HI = CLK_LORES_PRD_HI;	        /* interrupt rate */
    timerLO->LOAD_TIM_LO = CLK_LORES_PRD_LO;
    *IER1 = *IER1 | CLK_LORES_IER1_BIT;		        /* set timer IER bit */

    /* setup high resolution timer */
    timerHI->CNTL_TIMER = timerHI->CNTL_TIMER | 0x20;   /* CLK EN=1 */
    timerHI->CNTL_TIMER = timerHI->CNTL_TIMER & 0xffe2; /* PTV=0, START=0 */
    timerHI->CNTL_TIMER = timerHI->CNTL_TIMER | 0x82;   /* AR=1, SOFT=1, 
							   FREE=0 */
    timerHI->LOAD_TIM_HI = CLK_HIRES_PRD_HI;	        /* rollover count */
    timerHI->LOAD_TIM_LO = CLK_HIRES_PRD_LO;

    /* start timers ticking */
    timerLO->CNTL_TIMER = timerLO->CNTL_TIMER | 0x1;	/* START = 1 */
    timerHI->CNTL_TIMER = timerHI->CNTL_TIMER | 0x1;	/* START = 1 */
}

