/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/*
 *  ======== i16tof32.c ========
 *
 *  These functions are used with the DGS stacking driver to provide
 *  conversion to/from packed signed 16-bit integers to 32-bit floating
 *  point values.
 */

#include <std.h>

/*
 *  ======== i16tof32 ========
 *
 *  Convert an array of packed 16-bit integer values to 32-bit
 *  floating-point values.
 *
 *  The buffer must contain an even amount of 16-bit integers.
 *
 *  Paramaters:
 *      arg - unused
 *
 *      src - pointer to array of packed values (input)
 *
 *      dst - pointer to array of Float values (output)
 *
 *      size - number of bytes in the src array
 */
Int i16tof32(Arg arg, Uns *src, Float *dst, Int size)
{
    Int         tmp;
    Int         i;
    Int         nUns;

    nUns = size / sizeof (Uns);

    for (i = nUns; i > 0; i--) {
        tmp = ((Int) *src) >> 16;
        *dst++ = ((Float)tmp);
        tmp = *src++ & (Uns) 0xffff;
        tmp |= ((tmp & (Uns) 0x8000) ? (Uns) 0xffff0000 : 0x0);
        *dst++ = ((Float)tmp); 
    }

    return (size * 2);
}

/*
 *  ======== f32toi16 ========
 *  Convert an array of 32-bit
 *  floating-point values to packed 16-bit integer values.
 *
 *  The buffer must contain an even amount of 32-bit Floats.
 *
 *  Paramaters:
 *      arg - unused
 *
 *      src - pointer to array of Float values (input)
 *
 *      dst - pointer to array of packed values (output)
 *
 *      size - number of bytes in the src array
 */
Int f32toi16(Arg arg, Float *src, Uns *dst, Int size)
{
    Int         i;
    Int         tmp;
    Int         nFloats;

    nFloats = size / sizeof (Float);

    for (i = nFloats / 2; i > 0; i--) {
        tmp = ((Uns) (Int)(*src++)) << 16;
        tmp |= ((Uns)(Int)(*src++)) & (Uns) 0xffff;
        *dst++ = tmp;
    }

    return (size / 2);
}
