/****************************************************************************
* FILENAME: evm55xctrl.c
* VERSION:  1.00  23-MAR-2000
* VERSION:  2.00  05-FEB-2001
* SCCS ID: 
*
* NOTES:
*   TI Proprietary Information - Internal Data.
*   Copyright (c) 2001, DNA Enterprises, Inc.
*
*****************************************************************************/

#include <windows.h>
#include <stdio.h>
#include <conio.h>
#include "ddpci2040.h"
#include "evm55xdll.h"


/*****************************************************************************/
/* Macro Definitions                                                         */
/*****************************************************************************/
#define RESET_TBC	4
#define BUF_SIZE	1024


/*****************************************************************************/
/* Function Prototypes                                                       */
/*****************************************************************************/
void sarg( char **var, char *def_string );
void arg( char *fmt, ULONG *var, int def_value );
static void PrintBanner ( void );
static void help( void );
static void PressAnyKey( void );
void abend( int iQuit );

static int doMemRead( LPVOID hHpi, UINT length, ULONG src_addr, UINT dspNum );
static int doMemWrite( LPVOID hHpi, ULONG fillValue, UINT length,ULONG dest_addr, UINT dspNum );

static int doPCI2040Read(HANDLE hDevice, ULONG addr);

static int doPCI2040Write(HANDLE hDevice, ULONG addr, ULONG value);
static void displayData(PUSHORT pData, ULONG len);
static int memRead( LPVOID hHpi, UINT length, ULONG src_addr, UINT dspNum );

/*****************************************************************************/
/* Help Text                                                                 */
/*****************************************************************************/
char helpTxtAll1[] = 
"\n\
Syntax:\n\
  evm55xctrl [options]\n\n\
Options (Default parameter values in parentheses):\n\
  -?|h          Display summary of command syntax and options.\n\n\
  -bi           Display board information.\n\n\
  -cp           Display CPLD registers.\n\n";

char helpTxtAll2[] = "\
  -e sector     Erase Flash memory sector (0)-10.  Entire Chip = -1.\n\n\
  -hr reg       Read and display HPI register.\n\
                reg  - HPI register to read\n\
                0 - HPIC, 1 - HPID with auto-increment, 2 - HPIA,\n\
                3 - HPID with no auto-increment\n\n\
  -hw reg data  Write HPI register.\n\
                reg  - HPI register to write\n\
                0 - HPIC,  1 - HPID with auto-increment, 2 - HPIA,\n\
                3 - HPID with no auto-increment.\n\
                data - Value to write.\n\n\
  -id int       Interrupt DSP using HPI DSPINT (0), NMI (1) or DSPINT5 (2).\n\n\
  -l fname      Load DSP application. fname is the name of the COFF file.\n\n";

char helpTxtAll3[] = "\
  -mr addr [count]\n\
                Read and display DSP memory at address.\n\
                   addr  - DSP memory word address\n\
                   count - Number of locations to read (1)\n\
                   NOTE: addr and count can be decimal or hexadecimal.\n\n\
  -mw addr data [count]\n\
                Write or fill DSP memory at address.\n\
                   addr  - DSP memory word address\n\
                   data  - Value to write (0)\n\
                   count - Number of locations to fill (1)\n\
                   NOTE: addr, data and count can be decimal or hexadecimal.\n\n\
  -q            Quiet mode.  Suppresses the banner and progress information.\n\n\
  -rb           Reset board.\n\n\
  -rd [0 | 1]   Reset DSP. (0=unreset, 1=reset). Default is reset.\n\n\
  -ru           Run DSP. Allows DSP to keep running during execution.\n\n\
  -rt [0 | 1]   Reset JTAG TBC. (0=unreset, 1=reset). Default is reset.\n\n";


char helpTxtAll4[] = "\
  -b num        Selects specific PCI EVM board. (0)\n\n\
  -cr ofs       Read PCI2040 config register on the PCI connected EVM.\n\
                    ofs   - Register byte offset (0)\n\n\
  -cw ofs data  Write PCI2040 config register on the PCI connected EVM.\n\
                    ofs   - Register byte offset (0)\n\
                    data  - Data to write (0)\n\n\
  -d            Debug mode.\n\n\
  -hp           Display PCI2040 HPI configuration  on the PCI connected EVM.\n\n\
  -p            Displays board PCI configuration information.\n\n\
  -x            Initialize DSP and JTAG TBC to known state.\n\n";



/*****************************************************************************/
/* Global declarations                                                       */
/*****************************************************************************/
int   argc;    // Character count      
char  **argv;  // Cmd line buffer      
int   argIndx; // Current char index   
char  *argp;   // Current char pointer 

EVM55X_BOARD_TYPE  BdInfo  = TYPE_UNKNOWN; // EVM Board type      
PEVM55X_BOARD_TYPE pBdInfo = &BdInfo;

ULONG  RevId   = 0;            // Revision identifier 
PULONG pRevId  = &RevId;

HANDLE hBd = NULL;// Board device handle   
BOOL   bExcl=TRUE;   // Exclusive open = TRUE 
LPVOID hHpi=NULL; // HPI interface handle 

USHORT data[BUF_SIZE];

static int dbg = FALSE;

int hpi_open = FALSE;
int device_open = FALSE;
int p=1;

int    iBr=0;     // Board Reset request 
                                 
int    iHr=0;     // HPI register write request                                  
int    iHw=0;     // HPI register read request                                  
int    hrReg=0;   // HPI register to read
int    hwReg=0;   // HPI register to write                                     
ULONG  hwVal=0;   // HPI register value to write                                     

int    iDr=0;     // DSP Reset request                                    
int    iDrVal=0;  // DSP Reset value 
int    iTr=0;     // TBC Reset request
int    iTrVal=0;  // TBC Reset value                                     

int    iCr=0;     // PCI2040 configuration read request                   
int    iCw=0;     // PCI2040 configuration write request                  
ULONG  crOffset=0;  // read request address                                 
ULONG  cwOffset=0;  // Write request address                                
ULONG  cwValue=0; // PCI2040 device register Write value                  

int    iFe=0;     // Flash erase request
int    feSector=0;// Flash sector

int    iMr=0;     // Memory read request                                  
int    iMw=0;     // Memory write request                                 
ULONG  mrAddr=0;  // Memory read request address                          
ULONG  mrCount=1; // number of times to write value                       
ULONG  mwAddr=0;  // Memory write request address                         
ULONG  mwValue=0; // DSP memory write value                               
ULONG  mwCount=1; // number of times to write value   

ULONG  intType=0; // interrupt type (DSPINT or NMI)                    

int    iBd = 0;       // board number 
int    iKnownState=0; // set JTAG TBC/DSP in known state
int    iInt;      // DSP interrupt request                                
int    iPci=0;    // Display PCI config request                           
int    iCp=0;     // Display CPLD config                                  
int    iHpi=0;    // Display PCI2040 HPI configuration                      
int    iBdInfo=0; // Display board information  
int    iDrun=0;   // Run DSP                         

int    iLd;         // file to load 
CHAR   *iName=NULL; // Filename to store data received from DSP           
UINT    dspNum = 0;     // DSP to talk to                                     

char   bType[8];    // Board type 

ULONG dumpIndx = 0;
ULONG dumpAddr = 0;

/*****************************************************************************/
/**** main()                                                              ****/
/*****************************************************************************/
void main(int argc1, char *argv1[])
{
   /* Copy arguments to global variables */
   argc=argc1;
   argv=argv1;

   if (argc < 2)
	   help();
   
   /***************************************************************************/
   /* READ FILE NAME ARGUMENTS AND COMMAND LINE OPTIONS                       */
   /***************************************************************************/
   for (argIndx = 1; argIndx < argc; ++argIndx)
   {
      argp = argv[argIndx];
      
      if (*argp == '-')
      {
         while (*++argp) 
         {
            switch(*argp)
            { 
            case '?': case 'H': case 'h':
               
               switch (*++argp)
               {
               case 'P': case 'p':
                  iHpi = 1;
                  break;

               case 'R': case 'r':
                  iHr = 1;
                  arg("%d",&hrReg, 0);
                  break;

               case 'W': case 'w':
                  iHw = 1;
                  arg("%d",&hwReg, 0);
                  arg("%d",&hwVal, 0);
                  break;
                  
               default:
                  help();  break;
               }
               
               break;
               
            case 'N': case 'n':
               arg("%d",&dspNum,0);  break;
          
            case 'I': case 'i':
               
               switch (*++argp)
               {
               case 'D': case 'd':
                  iInt = 1;
                  arg("%l",&intType, 0);
				  break;
                  
               default:
                  help();  break;
               }
               
               break;

            case 'L': case 'l':
               iLd = 1;   
               sarg(&iName, "\0" );

               if (*iName == '\0') help();

               break;

            // Display PCI Device Config
            case 'P': case 'p':
               iPci = 1;          break;
               
            //set board num
            case 'B': case 'b':
               switch (*++argp)
               {
                 case 'I': case 'i':
                    iBdInfo = 1;
                    break;
                  
                 default:	
					--argp;
                    arg("%d",&iBd,0);  break;
			   }
			   break;

            // -cr offset 
            // -cw offset data
            case 'C': case 'c':
                  
               switch (*++argp)
               {
               case 'R': case 'r':
                  iCr = 1;
                  arg("%l",&crOffset, 0);
                  break;
                     
               case 'W': case 'w':
                  iCw = 1;
                  arg("%l",&cwOffset, 0);
                  arg("%d",&cwValue, 0);
                  break;

               case 'P': case 'p':
                  iCp = 1;
                  break;

			   default:
				  help();
				  break;

               }
                  
            break;

			// -d
			case 'D':
			case 'd':
				dbg = 1;
				break;

			case 'E': case 'e':
			   iFe = 1;
			   arg("%d",&feSector, 0);
			   break;

            case 'M': 
			case 'm':
                  
               switch (*++argp)
               {
               case 'R': case 'r':
                  iMr = 1;
                  arg("%l",&mrAddr, -1);
                  arg("%d",&mrCount, 1);
                  break;
                     
               case 'W': case 'w':
                  iMw = 1;
                  arg("%l",&mwAddr, -1);
                  arg("%d",&mwValue, 0);
                  arg("%d",&mwCount, 1);
                  break;
			   
			   default:
				  help();
				  break;
			   }
                  
            break;

            // -rb [reset]
            // -rd [reset]
			// -rt [reset]
            case 'R': case 'r':
               switch (*++argp)
               {
               case 'B': case 'b':
                  iBr = 1;  break;
                        
               case 'D': case 'd':
                  iDr = 1;
                  arg("%l",&iDrVal, 1);
                  break;

               case 'T': case 't':
                  iTr = 1;
                  arg("%l",&iTrVal, 1);
				  break;

			   case 'U': case 'u':
			      iDrun = 1;
				  break;

			   default:
				  help();
				  break;
               }
            break;

			case 'Q': case 'q':
			   p = 0;  
			   break;


			case 'X': case 'x':
			   iKnownState = 1;
			   break;

            default :
               if (p) 
                  printf("Unknown option: \"-%s\"\n",argp);   /* Proceed to help  */
               help();
            }
         }
      }
	  else
	  {
		  printf("Unknown option: \"%s\"\n",argp);   /* Proceed to help  */
		  help();
	  }
   }
   
   /***************************************************************************/
   /* Open a driver connection to a specific board.                           */
   /***************************************************************************/
   hBd = evm55x_open( iBd, bExcl );

   if ( hBd == INVALID_HANDLE_VALUE )
   {
      if (p) printf( "**Error:: Board open failure.\n" ); abend(0);
   }
   
   device_open = TRUE;
   
   /* Open HPI. */
   if (dbg) 
   { 
      if (p) printf( "Opening HPI.\n" );
       PressAnyKey();
   }
   
   hHpi = evm55x_hpi_open(hBd);
   
   if ( hHpi == NULL )
   {
      if (p) printf( "**Error:: Failure opening HPI.\n" ); 
      
      abend(0);
   }
   
   hpi_open = TRUE;


   if (iKnownState)
   {
		// Reset and unreset DSP to bring DSP to known state
        // If this is not done, then user could have problems due
        // to an unknown state of the DSP.
        evm55x_reset_dsp(hBd,0);
        evm55x_unreset_dsp(hBd,0);

        // Reset/unreset TBC to prevent problems with user exiting
        // emulator and not being able to access board properly
        evm55x_tbc_reset(hBd);
        evm55x_tbc_unreset(hBd);
   }

   
   /***************************************************************************/
   /* Get the board type and revision of a target board as stored in the PCI  */
   /* configuration space of the board.                                       */
   /***************************************************************************/
   if (dbg)
   { 
      if (p) printf( "Reading board type and revision.\n" );
       PressAnyKey(); 
   }
   
   if (iBdInfo) 
   {
      if ( evm55x_board_info( hBd, pBdInfo, pRevId ) )
      {
         switch (BdInfo)
         {
         case TYPE_PCI2040_C5510_EVM:   
            strcpy(bType,"TMX320VC5510 EVM");  
            break;
                        
         default: strcpy(bType,"Unknown");
         }
         
		 if (p) 
		 {
			 if (RevId == PCI_INVALID_REV_ID)
				    printf("Board Type: %s,  Revision: Unknown\n",bType);
			 else   printf("Board type: %s,  Revision: %d\n", bType, (int) RevId );
		 }
      }
      else
      {
         if (p) printf("**Error:: Failure reading board type and revision.\n" ); 
         
         abend(0);
      }
   }
   
   /***************************************************************************/
   /* Cause a hardware reset on the target board.                             */
   /***************************************************************************/
   if (iBr == 1)
   {
	   if (p) printf( "Resetting board................");
	   
	   if (dbg) PressAnyKey();
	   
	   if ( !evm55x_reset_board(hBd) )
	   {
		   if(p)printf( "\n\n**Error:: Failure resetting board.\n\n" ); abend(0);
	   }
	   
	   if (p) printf( "done.\n\n");
   }
   
   /***************************************************************************/
   /* Reset DSP                                                               */
   /***************************************************************************/
   if (iDr == 1)
   {
      if (iDrVal == 1)
      {        
         if (dbg) PressAnyKey();
         
         if ( !evm55x_reset_dsp(hBd, dspNum) )
         {
            if (p) printf("**Error:: Failure resetting DSP %d.\n", dspNum); 
            
            abend(0);
         }

         if (p) printf("DSP %d successfully reset.\n",dspNum); 
      }
      else
      {
         if (dbg) PressAnyKey();
         
         if ( !evm55x_unreset_dsp(hBd, dspNum) )
         {
            if (p) printf("**Error:: Failure unresetting DSP %d.\n", dspNum); 
            
            abend(0);
         }

         if (p) printf("DSP %d successfully removed from reset.\n",dspNum); 
      }
   }

   /***************************************************************************/
   /* Run DSP                                                                 */
   /***************************************************************************/
   if (iDrun == 1)
   {
          if (dbg) PressAnyKey();
         
         if ( !evm55x_run_dsp(hBd, dspNum) )
         {
            if (p) printf("**Error:: Failure running DSP %d.\n", dspNum); 
            
            abend(0);
         }

         if (p) printf("DSP %d is now running.\n",dspNum); 
   }


   /***************************************************************************/
   /* Reset JTAG TBC                                                          */
   /***************************************************************************/
   if (iTr == 1)
   {
      if (iTrVal == 1)
      {        
         if (dbg) PressAnyKey();
         
         if (evm55x_tbc_reset(hBd))
            if (p) printf("JTAG TBC successfully reset.\n"); 
      }
      else
      {
         if (dbg) PressAnyKey();
         
         if (evm55x_tbc_unreset(hBd))
            if (p) printf("JTAG TBC successfully removed from reset.\n"); 
      }
   }
   
   
   /***************************************************************************/
   /* Display PCI2040 HPI configuration                                       */
   /***************************************************************************/
   if (iHpi == 1)
   {
	   PPCI2040_HPI_CSR pHpiCsr;
	   
	   pHpiCsr  = (PPCI2040_HPI_CSR)evm55x_get_base_address(hBd, CSR_BAR);
	   
	   
	   printf("PCI2040 HPI Configuration\n");
	   printf("=========================\n");
	   printf("Master Int Enable :  %d\n\n", (pHpiCsr->IntMaskSet & MASTERINTENABLE) ? 1 : 0); 
	   
	   printf("Event       IntEvent     IntMask\n"); 
	   printf("-----       --------     -------\n"); 
	   printf("DSP0           %d            %d\n",	
		   (pHpiCsr->IntEventSet & INTDSP0) ? 1 : 0, (pHpiCsr->IntMaskSet & INTDSP0) ? 1 : 0); 
	   printf("DSP1           %d            %d\n",	
		   (pHpiCsr->IntEventSet & INTDSP1) ? 1 : 0, (pHpiCsr->IntMaskSet & INTDSP1) ? 1 : 0); 
	   printf("DSP2           %d            %d\n",	
		   (pHpiCsr->IntEventSet & INTDSP2) ? 1 : 0, (pHpiCsr->IntMaskSet & INTDSP2) ? 1 : 0); 
	   printf("DSP3           %d            %d\n",	
		   (pHpiCsr->IntEventSet & INTDSP3) ? 1 : 0, (pHpiCsr->IntMaskSet & INTDSP3) ? 1 : 0); 
	   printf("GPINT          %d            %d\n",	
		   (pHpiCsr->IntEventSet & GPINT) ? 1 : 0, (pHpiCsr->IntMaskSet & GPINT) ? 1 : 0); 
	   printf("INTGPIO2       %d            %d\n",	
		   (pHpiCsr->IntEventSet & INTGPIO2) ? 1 : 0, (pHpiCsr->IntMaskSet & INTGPIO2) ? 1 : 0); 
	   printf("INTGPIO3       %d            %d\n",	
		   (pHpiCsr->IntEventSet & INTGPIO3) ? 1 : 0, (pHpiCsr->IntMaskSet & INTGPIO3) ? 1 : 0); 
	   printf("GPERROR        %d            %d\n",	
		   (pHpiCsr->IntEventSet & GPERROR) ? 1 : 0, (pHpiCsr->IntMaskSet & GPERROR) ? 1 : 0); 
	   printf("HPIERROR       %d            %d\n\n",	
		   (pHpiCsr->IntEventSet & HPIERROR) ? 1 : 0, (pHpiCsr->IntMaskSet & HPIERROR) ? 1 : 0); 
	   
	   PressAnyKey();
	   
	   printf("DSP     Reset   Present  Data Width  HPI Error\n"); 
	   printf("----    -----   -------  ----------  ---------\n"); 
	   printf("DSP0     %3s      %3s        %2s        %3s\n", 
		   (pHpiCsr->HPIResetRegister & HPI0_RST) ? "YES" : "NO ",
		   (pHpiCsr->HPIImplementation & DSP_PRSNT0) ? "YES" : "NO ",
		   (pHpiCsr->HPIDataWidth & DWIDTH0) ? "16" : "8 ",
		   (pHpiCsr->HPIErrorReport & HPIERR0) ? "YES" : "NO ");
	   printf("DSP1     %3s      %3s        %2s        %3s\n", 
		   (pHpiCsr->HPIResetRegister & HPI1_RST) ? "YES" : "NO ",
		   (pHpiCsr->HPIImplementation & DSP_PRSNT1) ? "YES" : "NO ",
		   (pHpiCsr->HPIDataWidth & DWIDTH1) ? "16" : "8 ",
		   (pHpiCsr->HPIErrorReport & HPIERR1) ? "YES" : "NO ");
	   printf("DSP2     %3s      %3s        %2s        %3s\n",
		   (pHpiCsr->HPIResetRegister & HPI2_RST) ? "YES" : "NO ",
		   (pHpiCsr->HPIImplementation & DSP_PRSNT2) ? "YES" : "NO ",
		   (pHpiCsr->HPIDataWidth & DWIDTH2) ? "16" : "8 ",
		   (pHpiCsr->HPIErrorReport & HPIERR2) ? "YES" : "NO ");
	   printf("DSP3     %3s      %3s        %2s        %3s\n",
		   (pHpiCsr->HPIResetRegister & HPI3_RST) ? "YES" : "NO ",
		   (pHpiCsr->HPIImplementation & DSP_PRSNT3) ? "YES" : "NO ",
		   (pHpiCsr->HPIDataWidth & DWIDTH3) ? "16" : "8 ",
		   (pHpiCsr->HPIErrorReport & HPIERR3) ? "YES" : "NO ");
   }
 
   /***************************************************************************/
   /* Display CPLD configuration                                        */
   /***************************************************************************/
   if (iCp == 1)
   {
	   USHORT  regs[6];
	   
	   if (!evm55x_cpld_read_all(hBd, regs))
	   {
		   printf("**Error: evm55x_cpld_read_all failed\n");
           abend(0);
	   }
	   
	   printf("============================================\n");
	   printf("=            CPLD Register Values          =\n");
	   printf("============================================\n");
	   printf( "CNTL          : 0x%02X\n", regs[0] & 0x1f );
	   printf( "STAT1         : 0x%02X\n", regs[1] & 0x1f );
	   printf( "STAT2         : 0x%02X\n", regs[2] & 0x1f );
	   printf( "CPLDREV       : 0x%02X   (%d)\n", regs[3] & 0x1f , regs[3]&0x1f);
	   printf( "SEM0          : 0x%02X   ", regs[4] & 0x1f );

	   if (regs[4] & 1) 
		   printf("(Owned)\n");
	   else
		   printf("(Not Owned)\n");

	   printf( "SEM1          : 0x%02X   ", regs[5] & 0x1f );

	   if (regs[5] & 1) 
		   printf("(Owned)\n");
	   else
		   printf("(Not Owned)\n");

	   printf( "\n" );
	   printf("============================================\n");
	   printf("=                Board State               =\n");
	   printf("============================================\n");
	   
	   if (regs[0] & 0x08)
	   {
		   printf("DSP Reset     : YES    ");
	   }
	   else
	   {
		   printf("DSP Reset     : NO     ");
	   }	   
	   
	   if (regs[2] & 0x1)
	   {
		   printf("Board Voltage : BAD\n");
	   }
	   else
	   {
		   printf("Board Voltage : GOOD\n");
	   }
	   
	   
	   if (regs[0] & 0x04)
	   {
		   printf("TBC Reset     : YES    ");
	   }
	   else
	   {
		   printf("TBC Reset     : NO     ");
	   }
	   
	   if (regs[1] & 0x10)
	   {
		   printf("TBC Ready     : YES\n");
	   }
	   else
	   {
		   printf("TBC Ready     : NO\n");
	   }
	   
	   if (regs[1] & 0x08)
	   {
		   printf("DSP Mode      : MP     ");
	   }
	   else
	   {
		   printf("DSP Mode      : MC     ");
	   }

	   if (regs[0] & 0x02)
	   {
		   printf("NMI           : YES\n");
	   }
	   else
	   {
		   printf("NMI           : NO\n");
	   }

	   if (regs[0] & 0x01)
	   {
		   printf("DSPINT5       : YES    ");
	   }
	   else
	   {
		   printf("DSPINT5       : NO     ");
	   }
	   
	   if (regs[0] & 0x10)
	   {
		   printf("HINT MASK     : YES\n");
	   }
	   else
	   {
		   printf("HINT MASK     : NO\n");
	   }
	   
	   if (regs[1] & 0x02)
	   {
		   printf("User Switch 1 : ON     ");
	   }
	   else
	   {
		   printf("User Switch 1 : OFF    ");
	   }
	   
	   if (regs[1] & 0x01)
	   {
		   printf("User Switch 0 : ON\n");
	   }
	   else
	   {
		   printf("User Switch 0 : OFF\n");
	   }
	   
	   if (regs[1] & 0x04)
	   {
		   printf("DSP EHPIENA   : YES    ");
	   }
	   else
	   {
		   printf("DSP EHPIENA   : NO     ");
	   }
	   
	   if (regs[2] & 0x02)
	   {
		   printf("Daughterboard : YES\n");
	   }
	   else
	   {
		   printf("Daughterboard : NO\n");
	   }
	   
	   if (regs[2] & 0x04)
	   {
		   printf("HINT          : YES    ");
	   }
	   else
	   {
		   printf("HINT          : NO     ");
	   }
	   
	   if (regs[2] & 0x08)
	   {
		   printf("HREADY        : YES\n");
	   }
	   else
	   {
		   printf("HREADY        : NO\n");
	   }
	   
	   if (regs[4] & 0x01)
	   {
		   printf("Semaphore 0   : YES    ");
	   }
	   else
	   {
		   printf("Semaphore 0   : NO     ");
	   }
	   
	   if (regs[5] & 0x01)
	   {
		   printf("Semaphore 1   : YES\n");
	   }
	   else
	   {
		   printf("Semaphore 1   : NO\n");
	   }
	   printf("============================================\n");
   }

   /***************************************************************************/
   /* Display PCI Device configuration                                        */
   /***************************************************************************/
   if (iPci == 1)
   {
	   PCI2040_CONFIG_DATA regs;
	   
	   if ( !evm55x_get_pci_configuration(hBd, &regs) )
	   {
		   if (p) printf("**Error:: Failure getting PCI info\n"); 
		   
		   abend(0);
	   }
	   
	   printf("========================================================\n");
	   printf("=            PCI2040 Configuration Registers           =\n");
	   printf("========================================================\n");
	   printf("00:VendorID      = 0x%04X       ", regs.VendorID); 
	   printf("3C:IRQLine      = 0x%04X\n", regs.IRQLine); 
	   printf("02:DeviceID      = 0x%04X       ", regs.DeviceID);
	   printf("3D:IRQPin       = 0x%04X\n", regs.IRQPin);	  
	   printf("04:Command       = 0x%04X       ", regs.Command); 
	   printf("3E:MinGnt       = 0x%04X\n", regs.MinGnt); 
	   printf("06:Status        = 0x%04X       ", regs.Status);
	   printf("3F:MaxLat       = 0x%04X\n", regs.MaxLat); 
	   printf("08:RevisionID    = 0x%04X       ", regs.RevisionID); 
	   printf("44:GPIOSelect   = 0x%04X\n", regs.GPBSelect); 
	   printf("09:ProgIf        = 0x%04X       ", regs.VendorID); 
	   printf("45:GPInData     = 0x%04X\n", regs.GPBInData); 
	   printf("0A:SubClass      = 0x%04X       ", regs.SubClass); 
	   printf("46:GPDirCntl    = 0x%04X\n", regs.GPBDataDir);
	   printf("0B:BaseClass     = 0x%04X       ", regs.BaseClass); 
	   printf("47:GPOutData    = 0x%04X\n", regs.GPBOutData); 
	   printf("0C:CacheLineSize = 0x%04X       ", regs.CacheLineSize); 
	   printf("48:GPBInTyp     = 0x%04X\n", regs.GPBIntType); 
	   printf("0D:LatencyTimer  = 0x%04X       ", regs.LatencyTimer); 
	   printf("4C:MiscControl  = 0x%04X\n", regs.MiscControl); 
	   printf("0E:HeaderType    = 0x%04X       ", regs.HeaderType); 
	   printf("4F:Diagnostic   = 0x%04X\n", regs.Diag); 
	   printf("0F:BIST          = 0x%04X       ", regs.BIST); 
	   printf("50:PMCapID      = 0x%04X\n", regs.PMCapID); 
	   printf("10:HPICSRBar     = 0x%08X   ", regs.HPICSRBar); 
	   printf("51:PMNext       = 0x%04X\n", regs.PMNext); 
	   printf("14:CSpaceBar     = 0x%08X   ", regs.CSpaceBar); 
	   printf("52:PMCap        = 0x%04X\n", regs.PMCap); 
	   printf("18:GPBBar        = 0x%08X   ", regs.GPBBar); 
	   printf("54:PMCntlStat   = 0x%04X\n", regs.PMCntlStat); 
	   printf("2C:SubVendorID   = 0x%04X       ", regs.SubVendorID); 
	   printf("58:HPICSRIOBar  = 0x%04X\n", regs.HPICSRIOBar); 
	   printf("2E:SubSysID      = 0x%04X       ", regs.SubSysID); 
	   printf("5C:HSCapID      = 0x%04X\n", regs.HSCapID); 
	   printf("34:CapPointer    = 0x%04X       ", regs.CapPointer);
	   printf("5D:HSNext       = 0x%04X\n", regs.HSNext); 
	   printf("                                ");
	   printf("5E:HSCSR        = 0x%04X\n", regs.HSCSR);
   }
   
   /***************************************************************************/
   /* Interrupt DSP using DSPINT                                              */
   /***************************************************************************/
   if (iInt == 1)
   {
	  PCI2040_DSP_EVENT intEvent;


	  if (intType == 0) intEvent = DSP_INT;
	  else              
	  if (intType == 1) intEvent = NMI_INT;
	  else
	  if (intType == 2) intEvent = DSP_INT5;
	  else {
         if (p)
			printf("**Error:: Invalid DSP interrupt selection (must be 0-2).\n");
            abend(0);
	  }

      if (!evm55x_generate_int(hHpi, intEvent, dspNum))
      {
         if (p) 
            printf( "**Error:: evm55x_hpi_generate_int failure .\n" ); 
         
         abend(0);
      }
   }

   /***************************************************************************/
   /* Read HPI register                                                       */
   /***************************************************************************/
   if (iHr == 1)
   {
      Register reg = {0, 0};
      char *str = NULL;

      switch (hrReg)
      {
      case 0:
         str = "HPIC";
         reg.Regoff = C55X_HPIC;
         break;

      case 1:
         str = "HPID (auto-increment)";
         reg.Regoff = C55X_HPID_AUTOINC;
         break; 
		 
      case 2:
         //Special case: Support for 20-bit extended addresses requires two reads
		 str = "HPIA";
   
         reg.Regoff = C55X_HPIA;			 
	     if (!evm55x_read_hpi_reg(hHpi, &reg, dspNum))
		 {
            if (p) 
               printf( "**Error:: evm55x_read_hpi_reg() failure .\n" ); 
         
            abend(0);
		 }

         printf("%s = 0x%05X\n", str, reg.DataVal);
         return; // from special case
  
      case 3:
         str = "HPID (no auto-increment)";
         reg.Regoff = C55X_HPID_NOAUTOINC;
         break;
         
      default:
         if (p) printf( "**Error: Invalid HPI register value .\n" ); 

         abend(0);
         break;
      }
      
      if (!evm55x_read_hpi_reg(hHpi, &reg, dspNum))
      {
         if (p) 
            printf( "**Error:: evm55x_read_hpi_reg() failure .\n" ); 
         
         abend(0);
      }

      printf("%s = 0x%04X\n", str, reg.DataVal);
   }  
   
   /***************************************************************************/
   /* Write HPI register                                                      */
   /***************************************************************************/
   if (iHw == 1)
   {
      Register reg = {0, 0};
      char *str = NULL;

      switch (hwReg)
      {
      case 0:
         str = "HPIC";
         reg.Regoff = C55X_HPIC;
         break;
         
      case 1:
         str = "HPID (auto-increment)";
         reg.Regoff = C55X_HPID_AUTOINC;
         break;

      case 2:
		 // Special case which supports 20-bit address
         str = "HPIA";

         reg.Regoff = C55X_HPIA;
         reg.DataVal = hwVal;
         if (!evm55x_write_hpi_reg(hHpi, &reg, dspNum))
		 {
            if (p) 
               printf( "**Error:: evm55x_write_hpi_reg() failure .\n" ); 
         
            abend(0);
		 }	
		 
		 printf("Writing 0x%05X to %s register.\n",hwVal,str);        
		 
		 return; 
		 
      case 3:
         str = "HPID (no auto-increment)";
         reg.Regoff = C55X_HPID_NOAUTOINC;
         break;
         
      default:
         if (p) printf( "**Error: Invalid HPI register value .\n" ); 

         abend(0);
         break;
      }

      reg.DataVal = (USHORT)hwVal;

      if (!evm55x_write_hpi_reg(hHpi, &reg, dspNum))
      {
         if (p) 
            printf( "**Error:: evm55x_read_hpi_reg() failure .\n" ); 
         
         abend(0);
      }

	  printf("Writing 0x%04X to %s register.\n",reg.DataVal,str);
   }  

   /***************************************************************************/
   /* Load a COFF file to the DSP                                             */
   /***************************************************************************/
   if (iLd == 1)
   {
      if (dbg) 
      { 
         if (p) printf( "Loading COFF file into DSP memory.\n" );
         
         PressAnyKey(); 
      }

      if (!evm55x_coff_load(hBd,hHpi,iName,0,0,0,0))
      {
         if(p)printf("**Error:: evm55x_coff_load() failed.\n");
         
         exit(1);
      }
   }
   
   /***************************************************************************/
   /* Read PCI2040 Device                                                     */
   /***************************************************************************/
   if (iCr == 1)
   {
	   if (doPCI2040Read(hBd, crOffset))
	   {
		   if (p) 
		   {
		   printf("**Error:: Could not read PCI2040 config register offset 0x%02X.\n\
               Byte offset must be on non-reserved register boundary.\n",crOffset);
		   exit(1);
		   }
	   }
   }
   
   /***************************************************************************/
   /* Write PCI2040 Device                                                    */
   /***************************************************************************/
   if (iCw == 1)
   {
	   if (doPCI2040Write(hBd, cwOffset, cwValue))
	   {
		   if (p) 
		   {
		   printf("**Error:: Could not write PCI2040 config register offset 0x%02X.\n\
               Byte offset must be on non-reserved register boundary.\n",cwOffset);
		   exit(1);
		   }
	   }
   }

   /***************************************************************************/
   /* Erase Flash sector                                                      */
   /***************************************************************************/
   if (iFe == 1)
   {
	  if ((feSector == -1) || ((feSector >= 0) && (feSector <= 10)))
	  {
         if (!evm55x_erase_flash(hBd, feSector))
		 {
            if (p) printf("**Error:: Erase Flash operation failed.\n");
            exit(1);
		 }
		 else {
			 if (p) {
				 if (feSector == -1)
				      printf("All of Flash memory was successfully erased.\n");
				 else printf("Flash memory sector #%d was successfully erased.\n",feSector);
			 }
		 }
      }
	  else
	  {
            if (p) 
			{
				printf("**Error:: Invalid sector number.\n");
				printf("          Sector must be -1 or 0-10.\n\n");
			}
            exit(1);
	  }
   }


   /***************************************************************************/
   /* Read and display DSP memory                                             */
   /***************************************************************************/
   if (iMr == 1)
   {
      if (doMemRead(hHpi, mrCount, mrAddr, dspNum))
      {
         if (p) printf("**Error:: Could not read DSP memory.\n");
         
         exit(1);
      }
   }
   
   /***************************************************************************/
   /* Write DSP Memory                                                        */
   /***************************************************************************/
   if (iMw == 1)
   {
      if (doMemWrite(hHpi, mwValue, mwCount, mwAddr, dspNum))
      {
         if (p) printf("**Error:: Could not write DSP memory.\n");
         
         exit(1);
      }
   }   

   /***************************************************************************/
   /* Cleanup and exit                                                        */
   /***************************************************************************/
   
   /* Close HPI connection. */
   if(dbg) 
   { 
      if(p)printf( "Closing HPI connection.\n" );
      
      PressAnyKey(); 
   }
   
   if (!evm55x_hpi_close(hHpi))
   {
      if(p)printf("**Error:: Failure closing HPI connection.\n"); abend(0);
   }
   
   // Close EVM board
   if (dbg) 
   { 
      if (p) printf( "Closing %s board.\n",bType );
      
      PressAnyKey(); 
   }
   
   if (!evm55x_close(hBd))
   {
      if (p) printf( "**Error:: evm55x_close() failed.\n" ); abend(0);
   }
}

/*****************************************************************************/
/****        end of main()                                                ****/
/*****************************************************************************/

/*****************************************************************************/
/* sarg() -- Assign variable from current argument - string variation        */
/*****************************************************************************/
void sarg( char **var, char *def_string )
{ 
   if ( *++argp == '\0' )
   { 
      if ( ++argIndx < argc )
      { 
         argp = argv[argIndx]; 

		 *var = _strdup(argp); 
		 argp += strlen(*var);
		 --argp;
      }
      else
      { 
         *var = _strdup(def_string);
         *--argp; return; 
      }
   }
   else
   {
	   *var = _strdup(argp); 
	   argp += strlen(*var);
	   --argp;
   }   
} // end of sarg()

/*****************************************************************************/
/* arg() -- Assign variable from current argument.                           */
/*****************************************************************************/
void arg( char *fmt, ULONG *var, int def_value )
{ 
	char *temp = NULL;
	char *stp = "";
	
	if ( *++argp == '\0' )
	{ 
		if ( ++argIndx < argc )
		{ 
			argp = argv[argIndx];
			temp= argp;
			
			//sscanf( argp, fmt, var ); // Assign variable using specified format
			*var = strtol( argp, &stp, 0 );
			argp += (strlen(temp) - 1);
		}
		else
		{ 
			*var = (int) def_value; 
			*--argp;
		}
	}
	else
	{ 
		*var = strtol( argp, &stp, 0 );

		if ((*var == 0) && (*argp != '0') )
		{
			*var = (int) def_value;
		}
		else
		{
			argp += (strlen(argp) - 1);
		}
	}
	
	return; 
} // end of arg() 




/*****************************************************************************/
/* PrintBanner() -- Prints program banner.                                   */
/*****************************************************************************/
static void PrintBanner (void)
{
   if (p)  
   {
	   printf("\nTMX320VC5510 Board Control Utility, Version 2.01\n");
   }
}


/*****************************************************************************/
/* help() -- Provide assistance to the naive, then exit.                     */
/*****************************************************************************/
static void help( void )
{
  if(p)
  {
    PrintBanner();

    printf(helpTxtAll1);
    PressAnyKey();
    printf(helpTxtAll2);
    PressAnyKey();
    printf(helpTxtAll3);
    PressAnyKey();
    printf(helpTxtAll4);
  }
  exit(1);
}


/*****************************************************************************/
/* PressAnyKey() -- In debug mode, wait for key press after each step.       */
/*****************************************************************************/
static void PressAnyKey( void )
{
    int c;

    if (p) printf(   "Press any key to continue (Ctrl-C to abort)." );

    c = _getch();

    if (p) printf( "\r                                             \r" );

    if ( c == 0x03 ) exit(1);

    if ( c == 0x1b ) dbg=0;

    return;
} //end of PressAnyKey()

/*****************************************************************************/
/* abend() -- Abnormal end of execution, i.e., after an error.               */
/*****************************************************************************/
void abend( int iQuit )
{
  if (hpi_open == TRUE) 
     evm55x_hpi_close(hHpi);

  if (device_open == TRUE) 
     evm55x_close(hBd);

  exit(1);
}

/*****************************************************************************/
/* doMemRead() -- Read and display memory                                       */
/*****************************************************************************/
static int doMemRead(LPVOID hHpi, 
                     UINT length, 
                     ULONG src_addr, 
                     UINT dspNum )
{
    if ( dbg )
       printf( "Memory Read: addr=0x%04X, len=0x%04X\n", src_addr, length ); 

	printf( "Memory Display Starting at 0x%04X\n", src_addr );
	printf( "========================================================" );

	if (memRead(hHpi, length, src_addr, dspNum) == -1)
		printf("\nError reading DSP memory at address 0x%05x\n", src_addr );
	
    return (0);
}


/*****************************************************************************/
/* doMemWrite() -- Write to DSP memory                                       */
/*****************************************************************************/
static int doMemWrite(LPVOID hHpi, 
                      ULONG fillValue, 
                      UINT length, 
                      ULONG dest_addr, 
                      UINT dspNum )
{

    ULONG       sz;

    if ( dbg )
    { 
       printf( "doMemWrite(): addr=0x%04X, len=0x%04X, value=0x%04X\n", 
                                     dest_addr, length, fillValue ); 
    }

	if (p)
	{
	   if (length > 1)
	   printf("Writing 0x%04X, with count = 0x%04X, to DSP memory address 0x%04X.\n",
	           fillValue,length,dest_addr);
	   else
	   printf("Writing 0x%04X to DSP memory address 0x%04X.\n",fillValue,dest_addr);
	}


    /* write DSP memory */
    sz = length;

    if ( !evm55x_hpi_fill( hHpi, (USHORT)fillValue, &sz, 
                          dest_addr, dspNum) )
    {
        printf( "**Error: evm55x_hpi_fill() general failure.\n" );
        return(-1);
    }

    if ( length != sz )
    {
        printf( "**Error: evm55x_hpi_fill() failed, length error\n" );
        printf( "       length requested = 0x%x, completed = 0x%x.\n",
                                        length, sz );
        return(-1);
    }

    return(0);
}

/*****************************************************************************/
/* doPCI2040Read() -- Read PCI2040 register                                  */
/*****************************************************************************/
static int doPCI2040Read(HANDLE hDevice, ULONG offset)
{
   Register reg;


   reg.Regoff = (USHORT)offset;
   reg.DataVal = -1;
   
   if (!evm55x_read_pci_reg(hDevice, &reg))
   {
	  printf( "**Error: evm55x_read_pci_reg() failed.\n" );
     return(-1);
   }
   
   printf( "PCI2040 Register Offset 0x%02X = 0x%02X\n", offset, reg.DataVal );


   return (0);
}

/*****************************************************************************/
/* doPCI2040Write() -- Write to PCI2040 register                             */
/*****************************************************************************/
static int doPCI2040Write(HANDLE hDevice, ULONG offset, ULONG data)
{
   Register reg;

   reg.Regoff = (USHORT)offset;
   reg.DataVal = (USHORT)data;
   
   if (!evm55x_write_pci_reg(hDevice, &reg))
   {
      printf( "**Error: evm55x_write_pci_reg() failed.\n" );
      return(-1);
   }
      
   reg.DataVal = -1;

   if (!evm55x_read_pci_reg(hDevice, &reg))
   {
      printf( "**Error: evm55x_read_pci_reg() failed.\n" );
      return(-1);
   }

   printf( "Write PCI2040 Register Offset 0x%02X\n",offset);
   printf( "==================================\n");
   printf( "Wrote:   0x%x\n", data );
   printf( "Read :   0x%x\n", reg.DataVal );

   return (0);
}

/******************************************************************************/
/* Format data and write to stdout
/******************************************************************************/
void displayData(PUSHORT pData, ULONG len)
{
	ULONG i;

	dumpIndx = 0;

	for (i=0; i<len; i++)
	{
		if (!(dumpIndx % 8))
		{
			printf("\n0x%X:", dumpAddr);

			dumpAddr += 8;
		}
		
		printf(" %04X", pData[i]);

		dumpIndx++;
	}
}


static int memRead( LPVOID hHpi, UINT length, ULONG src_addr, UINT dspNum )
{
    ULONG        sz;

	dumpAddr = src_addr;

	while (length > 0)
	{
		sz = (length > BUF_SIZE) ? BUF_SIZE : length;

		if(evm55x_hpi_read(hHpi, (PULONG)data, &sz, src_addr, 0)) 
		{
			displayData(data, sz);
		} 
		else 
		{
			return (-1);
		}

		length -= sz;
		src_addr += sz;
	}
	
	printf("\n\n");

    return (0);
}
