/******************************************************************************/
/*     File:   _evm16test.h                                                   */
/*                                                                            */
/*     Purpose: Private header file for the C54x                              */
/*     EVM/DSK                                                                */
/******************************************************************************/
#include <windows.h>

#define BLANK(str)  memset(str, '\0', strlen(str))

#define DEFAULT_PCI_PORT		0

#define PCI_INTERFACE_ENABLE	1    // DSK card does not have the PCI interface. Enable for EVM

#define SLEEP_TIME				1000
#define EVM_OK					0
#define EVM_ERROR               -1
#define EVM_FIFO_ERROR			-2
#define ABORT					-2
#define ERR_INVALID_CMD			-5
#define WAIT					0
#define NOWAIT					1

#define MAX_CMD_LENGTH			5
#define MAX_ACK_TIME			5  // msecs
#define MAX_CMD_TIME			2  // msecs

#define SBSRAM_ADDR		    0x28000
#define SBSRAM_LEN			0x80000

#define WAIT_FOR_INPUT          0
#define DONT_WAIT_FOR_INPUT     1

typedef enum
{
   MONTANA,
   TBC
} DeviceReg;

typedef enum
{
  DATA_BUS_TEST_NUM = 0,
  ADDRESS_BUS_TEST_NUM,
  SBSRAM_DEVICE_TEST_NUM
} SbsramTestNumber;

typedef enum
{
    LED_TEST_NUM = 0,
    CPU_CLOCK_TEST_NUM,
    DSPINT_TEST_NUM,
    HOSTINT_TEST_NUM,
    HOSTOWNED_SEM_TEST_NUM,
    DSPOWNED_SEM_TEST_NUM,
	DSP_REV_TEST_NUM,
    NO_MORE_TEST_NUM
} TestNumber;

typedef enum
{
    DATA_LOOPBACK_NUM = 0,
    INIT_TEST_NUM,
    CONT_SINEPLAY_NUM,
    CONT_LOOPBACK_NUM,
    NO_MO_CODEC_TEST_NUM
} CodecTestNumber;

typedef enum
{
    DAA_TEST_NUM = 0,
    NO_MO_DAA_TEST_NUM // This indicates no more tests
} DaaTestNumber;

typedef enum
{
    SLC_TEST_NUM = 0,
    NO_MO_SLC_TEST_NUM // This indicates no more tests
} SlicTestNumber;

typedef enum
{
    FLASH_SAVE_TEST = 0,
	FLASH_A5_TEST,
    FLASH_ERASE_TEST,
	FLASH_RESTORE_TEST,
    FLASH_NO_MO_TEST
} FlashTestNumber;


typedef enum
{
    MEM_A5_TEST = 0,
    MEM_WALK_TEST,
    MEM_ADDR_TEST,
	MEM_PULSE_TEST
} MemTestNumber;

typedef enum
{
    UART_REG_TEST = 0,
    UART_LOOPBACK_TEST,
    UART_INTERRUPT_TEST,
    UART_COMM_TEST,
    UART_TEST_LAST    //This is not a test, used to indicate no more tests
} UartTestNumber;

typedef enum
{
	LEFT_CHAN_TONE_NUM = 0,
	RIGHT_CHAN_TONE_NUM,
	BOTH_CHAN_TONE_NUM,
	LINE_LOOPBACK_NUM,
	MIC_LOOPBACK_NUM
} Aic27TestNumber;

typedef enum
{
	DAA_AIC10_REG_TEST_NUM = 0,
	SLIC_AIC10_REG_TEST_NUM,
	DAA_AIC10_DATA_LOOPBACK_NUM,
	SLIC_AIC10_DATA_LOOPBACK_NUM
} Aic10TestNumber;

/*--------------------------------------------------------------------------*
 *  Local #defines
 *--------------------------------------------------------------------------*/
#define STRING_BUFFER_SIZE          (80)

/*--------------------------------------------------------------------------*
 *  Public function prototypes
 *--------------------------------------------------------------------------*/
int do_interrupt_tests(void);
int do_cpld_tests(void);
int do_sem_tests(void);
int do_jtag_tests(void);
int do_clock_tests(void);
int do_led_tests(void);
int do_uart_tests(void);
int do_daa_tests(void);
int do_slic_tests(void);
int do_flash_tests(void);
int do_PCI2040_tests(void);
int do_memory_tests(void);
int do_aic27_tests(void);
int do_aic10_tests(void);
int doOnChipTest(MemTestNumber testNum, ULONG addr, ULONG len, ULONG dspNum);
int do_dsprev_tests(void);

int waitForInterrupt(HANDLE ev1);
int execute_test(short *sendBuf, ULONG sendWords, 
				 short *rcvBuf,  ULONG rcvWords, UINT dspNum, int wait);
BOOL verifyReg(PRegister pReg, USHORT mask);
void PressAnyKey( void );
void LogPrint( char *format, ULONG parm1, ULONG parm2,
                     ULONG parm3, ULONG parm4 );
static void help( void );
static int Load_Dsp_Test_Application(char *app, int dsp);

