/******************************************************************************/
/*  DNA PROPRIETARY INFORMATION                                               */
/*  (C) Copyright 1997,1998 by DNA Enterprises, Inc.                          */
/*  All rights reserved                                                       */
/******************************************************************************/
/*  FILEIO.C - module for handling File I/O with the DSP.                     */
/*                                                                            */
/*   This module allows the use of play/record facilities to pass data        */
/*   between the host and the DSP and any peripherals connected to the DSP    */ 
/*   Two threads are available for handling play and record seperately.  These*/
/*   threads may be run at the same time or individually.                     */
/*                                                                            */
/*  MACRO FUNCTIONS:                                                          */
/*                                                                            */
/*  FUNCTIONS:                                                                */
/*   file_io() - support simple file I/O to DSP                               */
/*   killMe() - CNTL-C, close window handler                                  */
/*                                                                            */
/*  REVISION HISTORY:                                                         */
/*                                                                            */
/******************************************************************************/



#ifndef FILE_IO_H_
#define FILE_IO_H_

/*----------------------------------------------------------------------------*/
/* PUBLIC FUNCTION PROTOTYPES                                                 */
/*----------------------------------------------------------------------------*/

/******************************************************************************/
/*   file_io() - support simple file I/O to DSP                               */
/*                                                                            */
/*    This function handles opening of of play and record files, and starting */
/*    play and record threads.  The play and record processes may be opened   */
/*    and run independently or simultaneously.  The play process runs         */
/*    until data is exhausted or a <CNTL-Z> is entered.  The record process   */
/*    runs indefinetly or until <CNTL-Z> is enterned or until an optional     */
/*    time limit is reached or until an an optional file size limit is reached*/
/*                                                                            */
/******************************************************************************/
BOOL file_io(LPVOID pHpi_, 
             ULONG dspNum, 
             char *sReadFileName, 
             char *sWriteFileName,
             LPDWORD lpReadBytesParm, 
             LPDWORD lpWriteBytesParm,
             DWORD dwMaxSeconds );

/*****************************************************************************/
/*  killMe() - CNTL-C, close window handler                                  */
/*                                                                           */
/*    This module is called when a <CNTL-C> is entered or when the window is */
/*    closed while the program is active.  This function allows any threads  */
/*    running to be closed to allow a clean program termination.             */
/*                                                                           */
/*****************************************************************************/
void killMe( void );


#endif /* end of #ifndef FILE_IO_H_ */
