/*****************************************************************************/
/*	hpitest.c	-  example to access the EVM's memory from the host          */
/*				   using the host port interface (HPI). This example also    */
/*				   does various tests on the DSP memory from the host side.  */
/*****************************************************************************/
#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <winioctl.h>
#include <string.h>
#include <process.h>
#include <conio.h>

#include <ddpci2040.h>     // public header file used by higher level apps
#include <evm55xdll.h>     // public header file used by higher level apps

PDWORD pHpic;
PDWORD pHpid1;
PDWORD pHpia;
PDWORD pHpid2;
ULONG  hpierr;


/*****************************************************************************/
/*	Functions																 */
/*****************************************************************************/
BOOL testHpi(ULONG addr, ULONG len);
BOOL testDataBus(ULONG addr);

void usage()
{
	printf("usage: \n");
	printf("hpitest <address> <length> [iterations]\n\n");	
    printf("address:    Start address of DSP memory in SARAM\n\n");
    printf("length:     Memory length to test\n\n");
    printf("iterations: Number of times to repeat test (default = 1)\n\n");

	exit(-1);
}


/*****************************************************************************/
/*	Global variables														 */
/*****************************************************************************/
USHORT	*writeBuf;
USHORT	*readBuf;
HANDLE hd;
LPVOID hm;


/*****************************************************************************/
/*	MAIN																	 */
/*****************************************************************************/
int main(int argc, char **argv)
{
	USHORT err = 0;
	ULONG addr, reps = 1, len = 0x4e000;
	char *stp = "";
	USHORT port;
	ULONG data;
	ULONG i = 0;
	ULONG totalreps;
	
	printf("\nHPI Test Program\n");

	if (argc < 3)
		usage();
	
	addr = strtol( argv[1], &stp, 0 );
	len = strtol( argv[2], &stp, 0 );
	port = 0x0;

    if (argc == 4) 
        reps = strtol( argv[3], &stp, 0 );
	
	totalreps = reps;

    // Open EVM
	if ((hd = evm55x_open(port, 1))	== INVALID_HANDLE_VALUE)
	{
		printf ("evm55x_open failed\n");
		return (-1);
	}
	
	// Open HPI interface
	if (!(hm = evm55x_hpi_open(hd)))
	{
		printf ("evm55x_hpi_open failed\n");
		return (-1);
	}

	// Reset board
	evm55x_reset_board(hd);
    
	// Get addresses of HPI registers
	pHpic  = (PDWORD)evm55x_get_base_address(hd, HPI_BAR);
	pHpid1 = (PDWORD)((char *)pHpic  + HPI_REG_OFFSET);
	pHpia  = (PDWORD)((char *)pHpid1 + HPI_REG_OFFSET);
	pHpid2 = (PDWORD)((char *)pHpia  + HPI_REG_OFFSET);

	data = 0;
	i = 0;

	// Allocate memory for write and read buffers
	if ((writeBuf = (PUSHORT) malloc (len*sizeof(USHORT))) == NULL)
	{
		printf("\nMemory allocation error.\n");
		return (-1);
	}
	
	if ((readBuf  = (PUSHORT) malloc (len*sizeof(USHORT))) == NULL)
	{
		printf("\nMemory allocation error.\n");
		return (-1);
	}

    printf("==================================================\n");
    printf("HPI TEST (Iterations = %d)\n", reps);
    printf("==================================================\n");
    printf("Start Address: 0x%X\n", addr);
    printf("End Address  : 0x%X\n", addr+len-1);
    printf("Length       : 0x%X\n\n", len);
    
	// Perform tests
    for (i=0; i<reps; i++) 
    {
        printf("Performing iteration %d of %d...\n",i+1,totalreps);
		// Write data patterns to memory
        if (!testHpi(addr, len))
        {
            err = 1;
            break;
        }

        // Test data bus for errors 
		if (!testDataBus(0x8000))
		{
            err = 1;
            break;
		}

		printf("Press any key to continue.\n");
        _getch();
    }
    
	// Display pass/fail message
    if (!err)
        printf("HPI test was successful!\n");
    else
        printf("HPI test failed!\n");

	// Close EVM board
	if (!evm55x_close(hd))
	{
		printf ("evm55x_close failed\n");
		return (-1);
	}
	
	// Free memory
	free(writeBuf);
	free(readBuf);
	
	return (0);
}



/*****************************************************************************/
/*	Function: BOOL testDataBus(ULong addr)									 */
/*																			 */
/*	Description: This function tests to see for a write mismatch             */
/*				 resulting from data bus errors.                             */
/*																			 */
/*	Return:	TRUE on success and FALSE on failure							 */
/*****************************************************************************/
BOOL testDataBus(ULONG addr)
{
	USHORT pattern, readBack = 0, bit = 0;
	ULONG cnt = 1;

	for (pattern = 1; pattern != 0; pattern <<= 1)
	{
		evm55x_hpi_write(hm, (PULONG)&pattern, &cnt, addr, 0);
		
		evm55x_hpi_read(hm, (PULONG)&readBack, &cnt, addr, 0);

		if (pattern != readBack)
		{
			printf("\n\nDATA BUS ERROR!!\n\n", bit);
			printf("Data bit %d must be stuck!\n\n", bit);
			getchar();
			return FALSE;
		}

		bit++;
	}

	return TRUE;
}


/*****************************************************************************/
/*	Function: BOOL testHpi(ULONG addr, ULONG len)							 */
/*																			 */
/*	Description: This function is used to test any write mismatch            */
/*				 in the DSP memory.											 */
/*																			 */
/*	Returns: TRUE for success and 0 on failure                               */
/*****************************************************************************/
BOOL testHpi(ULONG addr, ULONG len)
{
    ULONG i, cnt = 0, data = 0x3111;

	// Initialize write buffer
	for (i=0; i<len; i++)
	{
		if (!(data & 0x7fff))
		{
			data += 0x10;
			cnt = 0;
		}

		writeBuf[i] = (USHORT)(data + cnt++);
		readBuf[i]  = 0;
	}
	
	cnt = len;

	// Write buffer of data to DSP memory
	if (!evm55x_hpi_write(hm, (PULONG)writeBuf, &cnt, addr, 0))
        return 0;
	
	// Read buffer of data from DSP memory
	if (!evm55x_hpi_read(hm, (PULONG)readBuf, &cnt, addr, 0))
        return 0;

	cnt = 0;

	// Compare buffers
    for (i=0; i<len; i += 1)
    {
        if (writeBuf[i] != readBuf[i])
        {
			++cnt;

            printf("Addr: 0x%06x    Read: %04x    Expect: %04x\n", addr+i, readBuf[i], writeBuf[i]);
        }
    }

	printf("\nTest Results:\n");
	printf("   Memory Length = 0x%X\n", len);    
	printf("   Error Count   = 0x%X\n\n",cnt);   
    printf("==================================================\n");
    
    return TRUE;
}


