/****************************************************************************/
/*     File:   _evm55xdll.h                                                 */
/*                                                                          */
/*     Purpose: This is the private header file for the C55x EVM DLL        */
/*                                                                          */
/*     Copyright (c) 1998, DNA Enterprises, Inc.                            */
/****************************************************************************/
#ifndef _EVM55XDLL_PRIV_H_
#define _EVM55XDLL_PRIV_H_

#define     DllRevMajor     2
#define     DllRevMinor     3
#define     DllBuildNum     1     /* MUST CHANGE THIS VALUE */


/****************************************************************************/
/* Defines                                                                  */
/****************************************************************************/
#define     HPI_VISIBLE             0
#define     NOT_HPI_VISIBLE         1
#define     INVALID_ADDR            -1

#define     MAX_TIME_CNT            3
#define     DEFAULT_TIMEOUT         0
#define     DEV_NAME_SIZE           32

#define     PRINTF_STR_SIZE			512
#define     COMM_FILE_SIZE			255
 
#define     MAX_PCI2040_EVENTS      12
#define     MAX_SPACES              4
#define     NUM_HPI_REGS            4
#define		MAX_TRANSFER_SIZE       2048

#define     HPI_REG_SIZE            (sizeof(USHORT))

#undef		OK
#define		OK                       0

#undef		ERROR
#define		ERROR                   -1

#define		CLOSED                   0
#define		OPEN                     1
#define		BUSY                     2

#define		IO_READ                  0
#define		IO_WRITE                 1

#define     REG_READ                 0
#define     REG_WRITE                1

/* 32 word FIFO at word address 0x25FB0 (byte address 0x4BF60) */
#define     FIFO_ADDR				 0x25FB0ul    
#define		FIFO_SIZE                32

#define		ABORT                    -2
#define		ERR_INVALID_CMD          -5   
      
/* Communication kernel area at 0x27FC0 (byte address 0x4FF80) */
/* Assumes communication structure resides from 0x27FC0-0x27FFF */
#define		COMM_ADDR				 0x27FC0ul
#define     COMM_DATA_SIZE			 0x3Aul
#define     COMM_STRUCT_SIZE         0x40ul

//B P24 opcode =  0110 1010 PPPP PPPP  PPPP PPPP PPPP PPPP		
#define     C55X_BRANCH_OPCODE		 0x6A000000 //without branch target address

#define     EXT_DATA_WRITE			 0
#define     EXT_DATA_READ			 1
#define     EXT_FLASH_WRITE			 2
#define     EXT_FLASH_ERASE			 3
#define     EXT_FLASH_RESET			 4

#define     DEFAULT_COMM_TIMEOUT     1000 //Default to 1 second

#define     EVM55XDLL_ERROR       "\n[E] evm55x.dll: "
#define     EVM55XDLL_INFO        "\n[I] evm55x.dll: "

typedef struct _FifoChannel{
   USHORT takePtr;				    //ptr to end of written data
   USHORT putPtr;					//ptr to beginning of no-read data
   char	  data[FIFO_SIZE];			//address of FIFO buffer
} FifoChannel, *PFifoChannel;

typedef struct _FIFO {
   FifoChannel dsp_ch;
   FifoChannel host_ch;
} FIFO, *PFIFO;

typedef BOOL (*IntMemFunc)(LPVOID pBd_, PULONG p_buffer, 
                          PULONG p_len, ULONG addr, ULONG dspNum);

typedef BOOL (*ExtMemFunc)(LPVOID pBd_, PULONG p_buffer, 
                          PULONG p_len, ULONG addr, ULONG dspNum);

/****************************************************************************/
/* Structures defined for local use                                         */
/****************************************************************************/
typedef struct _DspDevice {
   BOOL		isPresent;  // reflects presence of DSPS
   PULONG	pHpic;
   PULONG	pHpia;
   PULONG	pHpid1;     //HPID with auto_increment
   PULONG	pHpid2;     //HPID with no auto_increment
} DspDevice, *PDspDevice;

typedef struct _SpaceStruct {
   ULONG       mapIoctlCode;
   ULONG       unmapIoctlCode;
   char        *printStr;
} SpaceStruct, *PSpaceStruct;

typedef struct _BoardStruct {
   int                     index;
   HANDLE                  hDevice;
   HANDLE                  hEvent;
   HANDLE                  outThr;
   HANDLE                  inThr;
   HANDLE                  hMutex;     // mutex between threads using HPI
   DspDevice               dsp[MAX_PCI2040_DSPS];
   ULONG				   timeout;
   ULONG				   mappedAddr[MAX_SPACES];
   BOOL                    state;
   BOOL                    excl;
   PCI2040DLL_INIT_DATA    initDefaults;
   FileIOFunc              ioFunc;
   HANDLE                  events[MAX_PCI2040_EVENTS];
   EVM55X_BOARD_TYPE	   boardType;
   IntMemFunc              intReadFunc;
   ExtMemFunc              extReadFunc;
   IntMemFunc              intWriteFunc;
   ExtMemFunc              extWriteFunc;
   BOOL					   flashAccess;
   BOOL					   inReset;
} BoardStruct, *PBoardStruct;

//used to generate comm kernel buffer addresses
typedef struct _ExtMemDummyStruct {
   short       len;
   short       addr;
   short       memSpace;
   char        data;
} ExtMemDummyStruct, *PExtMemDummyStruct;

typedef struct _ExtMemStruct {
   ULONG         len;
   ULONG         addr;
   ULONG         memSpace;
   USHORT        data[COMM_DATA_SIZE];
} ExtMemStruct, *PExtMemStruct;

typedef struct _EvmMemSpace {
   ULONG startAddr;
   ULONG endAddr;
} EvmMemSpace, *PEvmMemSpace;


/****************************************************************************/
/* Enums                                                                    */
/****************************************************************************/

/****************************************************************************/
/* private functions                                                        */
/****************************************************************************/
BOOL    internalRead(LPVOID pBd_, PULONG p_buffer, PULONG p_len, 
                         ULONG src_addr, ULONG dspNum);
BOOL    internalWrite(LPVOID pBd_, PULONG p_buffer, PULONG p_len, 
                          ULONG dest_addr, ULONG dspNum);
BOOL    externalRead(LPVOID pBd_, PULONG p_buffer, PULONG p_len, 
                         ULONG src_addr, ULONG dspNum);
BOOL    externalWrite(LPVOID pBd_, PULONG p_buffer, PULONG p_len, 
                          ULONG dest_addr, ULONG dspNum);

static void setupHpiFunctions(PBoardStruct pBd);

static PBoardStruct getBoard(HANDLE hDevice);
static PBoardStruct getUnusedBoard();

static BOOL    map_spaces(PBoardStruct pBd);
static BOOL    unmap_spaces(PBoardStruct pBd);
static BOOL    map_space(HANDLE hDevice,ULONG ioctlCode, PULONG pMappedAddr);
static BOOL    unmap_space(HANDLE hDevice, ULONG ioctlCode, PULONG pMappedAddr);
static BOOL    detectDsps(PBoardStruct pBd);
static void    hpi_close_all(VOID);
void		   RedirectPrintf (char *errType, char *errStr);
static void    RedirectStdin(char *pBuf, ULONG *cnt);
static BOOL    setPCIRegs(HANDLE hDevice, PPCI2040_CONFIG_DATA pRegs);
static BOOL    setPCIDefaults(PBoardStruct pBd);
static BOOL    getInterruptInfo(HANDLE hDevice, PULONG pReg);
static DWORD   WINAPI waitForPciEvent(LPVOID hDevice);
static DWORD   WINAPI waitForParallelEvent(LPVOID hDevice);
static DWORD   WINAPI stdinHandler(LPVOID hDevice);
static BOOL    install_vxd_event(PBoardStruct pBd);
static BOOL    validBoard(PBoardStruct pBd);
static void    pci2040EventHandler(PBoardStruct pBd);
static void    setupPci2040Events(int board_index, PBoardStruct pBd);
static BOOL    evm55x_clear_event(HANDLE hDevice, HANDLE event);
static BOOL    CheckPci2040RegOfs(ULONG ofs);
static BOOL    CheckCpldRegOfs(ULONG offset, BOOL type);
static BOOL    CheckTBCRegOfs(ULONG offset, BOOL type);

BOOL  waitForCompletion(PBoardStruct pBd, ULONG cnt);
void  initEnvironment();
BOOL  fifo_write(PBoardStruct pBd, PFIFO dummy_io, 
                       PULONG pbuf,PULONG pCnt, ULONG  dspNum);
BOOL  fifo_read(PBoardStruct pBd, PFIFO dummy_io, 
                      PULONG pbuf,PULONG pCnt, ULONG  dspNum);
BOOL loadCommKernel(PBoardStruct pBd);
BOOL isKernelPresent(PBoardStruct pBd);
static void pciOpen(PBoardStruct pBd);

BOOL setCommKernelFile(void);
int  mem5510Location(ULONG addr, PBoardStruct pBd);
ULONG getS2Record(PULONG pAddr);
int verifyBlock(PBoardStruct pBd, char *hexFile, ULONG address);
static BOOL WINAPI ControlHandler ( DWORD dwCtrlType );
static void ProgramExit(int exitcode);

#endif // _EVM55XDLL_PRIV_H_