/****************************************************************************/
/*     File:   cloadsup.c                                                   */
/*                                                                          */
/*     Purpose: support module for COFF load operations                     */
/*                                                                          */
/*     Copyright (c) 1998, DNA Enterprises, Inc. All rights reserved        */
/****************************************************************************/

/****************************************************************************/
/*                                                                          */
/*    Module description here                                               */
/*                                                                          */
/*  FUNCTIONS                                                               */
/*                                                                          */
/*                                                                          */
/*  STATIC FUNCTIONS                                                        */
/*                                                                          */
/*                                                                          */
/*  GLOBAL VARIABLES DEFINED                                                */
/*                                                                          */
/****************************************************************************/


#include <windows.h>
#include <stdio.h>
#include <stdlib.h>

#define evm55xdll_c          // to prevent importing of DLL calls within DLL

#include <evm55xdll.h>       // public header file for DLL

//#define EXTERNAL_TO_CLOAD   /* to prevent requirement of other headers */
#include "header.h"
#include "cloadsup.h"       // suplemental cload routines header file


/* private function prototypes */
static void *get_hpi_handle(void);
static void writeOddAddr(LPVOID h_hpi, ULONG addr, char byte, ULONG dspNum);
static void writeLastByte(LPVOID h_hpi, ULONG addr, char byte, ULONG dspNum);
static void byteSwap(char *pBuf, ULONG len);

/* Globals */
ULONG relocValue;               /* RELOCATION AMOUNT               */
ULONG noload;                   /* set for dump only mode          */
ULONG dbgLev;                   /* default debug level of 0        */

static HANDLE cloadsup_h_device;  /* driver handle to target board   */
static LPVOID cloadsup_lp_hpi;    /* pointer for HPI operations      */
static BOOL   cloadsup_hpi_opened;/* flag if HPI opened here         */
static ULONG   dspNum;            /* dsp number                      */

extern FILE   *cload_fin;        /* INPUT FILE                         */
extern char   printf_str;    // printf string

/****************************************************************************/
/* call_cload()                                                             */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
BOOL call_cload(HANDLE h_device, LPVOID lp_hpi, FILE *fin,
                BOOL load_flag, BOOL verbose_flag,
                BOOL clear_bss_flag, BOOL dump_flag, ULONG dspNum_)
{
    BOOL        result = FALSE;

    // setup cload environment
    cloadsup_h_device = h_device;
    cloadsup_lp_hpi = lp_hpi;
    cloadsup_hpi_opened = FALSE;
    cload_fin = fin;

    dspNum = dspNum_;

    relocValue = 0;

    noload = 0;
    if ( !load_flag ) { noload = 1; }

    verbose = 0;
    if ( verbose_flag ) { verbose = 1; }

    clear_bss = 0;
    if ( clear_bss_flag ) { clear_bss = 1; }

    dbgLev = 0;
    if ( dump_flag ) { dbgLev = 2; }

    // call the cload routine
    if (cload()) { result = TRUE; }

    // cleanup cload environment
    if ( cloadsup_hpi_opened && (cloadsup_lp_hpi != NULL))
    {
        evm55x_hpi_close( cloadsup_lp_hpi );
    }

    cloadsup_hpi_opened = FALSE;

    return(result);
}


/****************************************************************************/
/****************************************************************************/
/*        The following routine is private to this module                   */
/****************************************************************************/
/****************************************************************************/

/****************************************************************************/
/* get_hpi_handle()                                                         */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
static void *get_hpi_handle(void)
{
    if ( cloadsup_lp_hpi == NULL )
    {
        cloadsup_lp_hpi = evm55x_hpi_open( cloadsup_h_device );
        cloadsup_hpi_opened = TRUE;
    }
    return(cloadsup_lp_hpi);
}


/****************************************************************************/
/****************************************************************************/
/*        The following routines are required by the cload function.        */
/****************************************************************************/
/****************************************************************************/

/****************************************************************************/
/* set_reloc_amount()                                                       */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
int    set_reloc_amount()    /* DETERMINE RELOCATION FOR ALL SECTIONS */
{
    int i;

    for(i=0;i<n_sections;++i) reloc_amount[i] = relocValue;
    return TRUE;
} /* end of set_reloc_amount() */


/****************************************************************************/
/* lookup_sym()                                                             */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
void    lookup_sym()           /* LOOKUP AN UNDEFINED SYMBOL AND DEF IT */
{
    return;
} /* end of lookup_sym() */


/****************************************************************************/
/* load_syms()                                                              */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
int load_syms()            /* BUILD THE SYMBOL TABLE                */
{
    printf( "load_syms() called.\n" );
    return 0;
} /* end of load_syms() */


/****************************************************************************/
/* myalloc()                                                                */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
char *myalloc( size_t size )/* MEMORY ALLOCATION FUNCTIONS           */
{
    char *p = (char *)malloc(size);
    if (p) return p;

    printf("\n>> out of memory\n");
    exit( -1 );
} /* end of myalloc() */


/****************************************************************************/
/* mralloc()                                                                */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
                                /* MEMORY ALLOCATION FUNCTIONS           */
char *mralloc( void *p, size_t size )
{
    p = realloc(p, size);
    if (p) return( (void *)p );

    printf("\n>> out of memory\n");
    exit( -1 );
} /* end of mralloc() */


/****************************************************************************/
/* load_msg()                                                               */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
                                /* WRITE OUT LOADER DEBUG INFO           */
void load_msg( char *a, long b, char *c, char *d, char *e, char *f, char *g)
{
    printf( a, b, c, d, e, f, g );
    return;
} /* end of load_msg() */


/****************************************************************************/
/* mem_write()                                                              */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
                               /* WRITE TO TARGET MEMORY                */
int mem_write( unsigned char *buffer, int nbytes, ULONG addr, int page )
{
   int   i;
   ULONG temp_addr = addr; //convert to word address
   ULONG wordAddr;
   
   if (dbgLev>1)
   {
      USHORT  *wp = (USHORT *)buffer;
      int     dis_pos = 1;
      
      printf("[%06x]:0x%x(bytes):\n", addr, nbytes);

      for (i = 0; i < nbytes/2; ++i)
      {
         if ( dis_pos == 1 ) 
			 printf( "0x%06x: ", temp_addr);

         printf( "  %04x", wp[i] );

		 temp_addr += 2;;

         if ( ++dis_pos >= 5 ) 
         {
            printf( "\n" ); 
            dis_pos = 1;
         }
      }
      
	  i *= 2;
      if ( nbytes > i )
      {
         UCHAR *cp = (UCHAR *)wp;
         cp += i;

         if ( dis_pos == 1 ) 
			 printf( "0x%06x: ", temp_addr );

         dis_pos++;
         printf( "  " );

         while ( nbytes > i )
         {
            printf( "%04x ", /*(ULONG)*/(*((UCHAR *)cp++)) );
            i++;
         }

         if ( dis_pos >= 5 ) 
         { 
            printf( "\n" ); 
            dis_pos = 1; 
         }
      }
      
      if ( dis_pos != 1 ) 
		  printf( "\n" );
   }
   
   
   if (!noload)
   {
      int         wordCnt;
      void *      h_hpi;
      
      if ((h_hpi = get_hpi_handle()) == NULL)
      { return( 0 ); }

      if ( verbose || dbgLev )
      {
			printf("-- Writing Code: byte addr 0x%06x, byte cnt 0x%lx\n\n\n", addr, nbytes);
      }

	  byteSwap(buffer, nbytes);

	  //if odd addr
	  if (addr & 1)
	  {
		  writeOddAddr(h_hpi, addr, buffer[0], dspNum);

		  addr++;
		  nbytes--;
		  buffer++;
	  }

      wordCnt = nbytes >> 1;
	  wordAddr = addr >> 1;

      evm55x_hpi_write(h_hpi, (ULONG *)buffer, &wordCnt, wordAddr, dspNum);

	  //if odd section length
	  if (nbytes & 1)
	  {
		  writeLastByte(h_hpi, addr+nbytes, buffer[nbytes], dspNum);
	  }
	  
   } /* end of if (!noload) */

    return 1;
} /* end of mem_write() */



/****************************************************************************/
/* mem_fill()                                                               */
/*  FILL TARGET MEMORY                                                      */
/*                                                                          */
/****************************************************************************/
int mem_fill( unsigned char c_value, int nbytes, ULONG addr, int page )
{
   int         i;
   USHORT      w_value;
   
   ULONG wordAddr;

   w_value = (c_value << 8) | c_value;
   
   if (dbgLev>1)
   {
      int     dis_pos = 1;
      
      printf("[%06x]:0x%x(bytes):\n", addr, nbytes);

      for (i = 0; i < nbytes/2; ++i)
      {
         if ( dis_pos == 1 ) printf( "0x%06x: ", addr + (i * 2 ) );

         printf( "  %08x", w_value );
         dis_pos++;

         if ( dis_pos >= 5 ) 
         { 
            printf( "\n" ); 
            dis_pos = 1; 
         }
      }
      
      if ( nbytes > i*2 )
      {
         i = i * 2;
         if ( dis_pos == 1 ) printf( "0x%06x: ", addr + i );

         dis_pos++;
         printf( "  " );

         while ( nbytes > i )
         {
            printf( "%02lx ", (ULONG)(c_value) );
            i++;
         }

         if ( dis_pos >= 5 ) 
         { 
            printf( "\n" ); 
            dis_pos = 1; 
         }
      }
      
      if ( dis_pos != 1 ) printf( "\n" );
   }
   
   
   if (!noload)
   {
      int         wordCnt;
      void *      h_hpi;
      
      if ((h_hpi = get_hpi_handle()) == NULL) return( 0 );

      if ( verbose || dbgLev )
      {
         printf( " -- hpi_fill: byte addr 0x%06x, byte cnt 0x%lx\n",
            addr, nbytes );
      }

      wordCnt = nbytes >> 1;
	  wordAddr = addr >> 1;

      evm55x_hpi_fill(h_hpi, w_value, &wordCnt, wordAddr, dspNum);
      
   } /* end of if (!noload) */
   
   return 1;
} /* end of mem_fill() */


/****************************************************************************/
/* cload_fread()                                                            */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
size_t cload_fread( void *buffer, size_t size, size_t count, FILE *stream )
{
    return(fread(buffer, size, count, stream));
}

/****************************************************************************/
/* cload_fseek()                                                            */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
int cload_fseek( FILE *stream, long offset, int origin )
{
    return(fseek(stream, offset, origin));
}


/****************************************************************************/
/* cload_rewind()                                                           */
/*                                                                          */
/*                                                                          */
/****************************************************************************/
void cload_rewind( FILE *stream )
{
    rewind(stream);
    return;
}

static void writeOddAddr(LPVOID h_hpi, ULONG addr, char byte, ULONG dspNum)
{
	ULONG wordAddr = addr >> 1;
	ULONG len = 1;
	USHORT data = 0;

	evm55x_hpi_read(h_hpi, (ULONG *)&data, &len, wordAddr, dspNum);

	data = (data & 0xff00u) | (USHORT)byte;

	evm55x_hpi_write(h_hpi, (ULONG *)&data, &len, wordAddr, dspNum);
}

static void writeLastByte(LPVOID h_hpi, ULONG addr, char byte, ULONG dspNum)
{
	ULONG wordAddr = addr >> 1;
	ULONG len = 1;
	USHORT data = 0;

	evm55x_hpi_read(h_hpi, (ULONG *)&data, &len, wordAddr, dspNum);

	data = (data & 0x00ffu) | ((USHORT)byte << 8);

	evm55x_hpi_write(h_hpi, (ULONG *)&data, &len, wordAddr, dspNum);
}

static void byteSwap(char *pBuf, ULONG len)
{
	ULONG i;
	char byte;

	for (i=0; i<len; i += 2)
	{
		byte = pBuf[i];
		pBuf[i] = pBuf[i+1];
		pBuf[i+1] = byte;
	}
}
