/*****************************************************************************
 * Copyright 2001 DNA Enterprises, Inc.
 *
 * File name - evm55xhex.c
 * Description - This file contains the function definitions
 *
 * File revision history
 *   Date		Author							Description
 *   7/18/2000	T. Kyiamah               		Original
 *
 *****************************************************************************/

 /*****************************************************************************
*              Include files
*****************************************************************************/
#include <windows.h>
#include <stdio.h>
#include <stdlib.h>

#define evm55xdll_c          // to prevent importing of DLL calls within DLL

#include "evm55xdll.h"       // public header file for DLL
#include "_evm55xdll.h"		// private header file 

/*****************************************************************************
*              Macros
*****************************************************************************/
#define BUF_SIZE 				128
#define BLOCK_SIZE				0x1000
#define MAX_S2DATA_SIZE			0x22

#define S2_LEN_SIZE				2
#define S2_ADDR_SIZE			6
#define S2_TYPE_SIZE			2
#define S2_DATA_SIZE			(MAX_S2DATA_SIZE-8)

#define BOOT_ADDR				0x200000


/*****************************************************************************
*              Private Functions
*****************************************************************************/
static char * _getS2Data(FILE *fp, char *pHexFile, PULONG addr, PULONG len);

/*****************************************************************************
*              Global variables
*****************************************************************************/
extern char   printf_str[PRINTF_STR_SIZE];                    // printf string


static char *pData;
static char *pDataStart;
static char *pDataEnd;
static int  lastBuffer;

/*****************************************************************************
*              Structures
*****************************************************************************/
typedef struct _S2Record
{
	char type[S2_TYPE_SIZE];
	char len[S2_LEN_SIZE];
	char addr[S2_ADDR_SIZE];
	char pData[S2_DATA_SIZE];
} S2Record, *PS2Record;

/*****************************************************************************
*              Public functions implementation
*****************************************************************************/
int getSector(ULONG addr);

/*****************************************************************************
* Function: Write Hex file to DSP memory
*****************************************************************************/
BOOL loadHex(BoardStruct *pBd, char *hexFile, ULONG dspNum)
{
	FILE  *fin;
	char *pHexFile = NULL;	
	ULONG i = 0;
	char temp[7];
	char *stp = "";
	ULONG len = 0;
	ULONG addr = 0;
	S2Record *pS2;
	int currSector  = 0xf0f0;
	int startSector = 0xf0f0;
	int endSector;
	int sector;
	USHORT *pBuf;


	// Open Motorola Hex file
	if( (fin = fopen( hexFile, "r" )) == NULL )
	{
		sprintf(printf_str,"The file \"%s\" could not be opened for reading.\n",
			hexFile );
		
		RedirectPrintf(EVM55XDLL_ERROR, printf_str);
		
		return(FALSE);
	}

	// Allocate memory for file contents and read into array
    pHexFile = (char *)malloc(BLOCK_SIZE*sizeof(short));

	// Set current data pointer to start of data
	pDataStart = pHexFile;
	pData = pHexFile;
    
    if (len = fread(pData, sizeof(char), BLOCK_SIZE, fin))
	{
        if (len < BLOCK_SIZE)  
		{    // last buffer

			 // set end of buffer to EOFs
		     memset(pData+len, EOF, BLOCK_SIZE-len);

			 // set last buffer
			 lastBuffer = 1;
		}
		else
		{    // not last buffer
             lastBuffer = 0;

    		 //Initialize pDataEnd
			 pDataEnd = (char *)((ULONG)pData + len);
		}


		RedirectPrintf("", "");
		RedirectPrintf(EVM55XDLL_INFO, "Programming Flash....");
	}
	else
    {
		sprintf(printf_str,"Failed to program Flash! Check your HEX file -> %s\n", hexFile); 
		RedirectPrintf(EVM55XDLL_ERROR, printf_str);

		free(pHexFile);

		return (FALSE);
    }


	// Verify value hex file
	if (!(pData =_getS2Data(fin, pData, &addr, &len)))
		// NOTE: Previously mandated start of Flash, but this is restrictive.
		// Users may want to put actual code in Flash in various places.
		// || (addr != (BOOT_ADDR<<1)))
	{
		free (pHexFile);
		return FALSE;
	}

	// Allocate buffer for file data
	pBuf = (USHORT *)malloc(BUF_SIZE*sizeof(USHORT));

	// Initialize temp hex string
	memset(temp, '\0', 7);
	strcpy(temp, "0x");

	// Process each S record in file
	do
	{
		pS2 = (S2Record *)pData;

        // Get data from S record
		for (i=0; i<len; i++)
        {
			memcpy((temp+2), &pS2->pData[i<<2], 4);
			pBuf[i] = (USHORT)strtol( temp, &stp, 0 );
        }

		// The sector must be checked for the whole range
		// to determine if sector erase must be performed

		startSector = getSector(addr);
		endSector   = getSector(addr+len-1);
		
        // Erase sectors as needed
		for (sector = startSector; sector <= endSector; sector++)
		{

			// If new sector, erase it
		    if (sector != currSector)
			{
			   currSector = sector;
			   evm55x_erase_flash(pBd->hDevice, sector);
			}
		}

		// Program Flash with S record data
		evm55x_hpi_write((LPVOID)pBd, (ULONG *)pBuf, &len, addr, dspNum);

		// increment pData to end of current S record
		pData = (char *)((ULONG)pData + S2_TYPE_SIZE + S2_ADDR_SIZE + S2_LEN_SIZE + (len<<2) + 2);
	}
	while (pData =_getS2Data(fin, pData, &addr, &len));  // Get next S record and loop

    // Free file data buffer
	free (pHexFile);
	
	// Free data buffer
	free (pBuf);

	// Close hex file
	fclose (fin);

	return TRUE;
}

BOOL verifyBlock(BoardStruct *pBd, char *hexFile, ULONG dspNum) 
{
	ULONG i = 0;
	FILE	*fin;
	char temp[7];
	char *stp = "";
	ULONG	len, addr;
	BOOL	ret = TRUE;
	S2Record *pS2;
	char *pHexFile;
	USHORT *pFlashData, *pS2Data;


	// Open Motorola Hex file
	if( (fin = fopen( hexFile, "r" )) == NULL )
	{
		sprintf(printf_str,"The file \"%s\" could not be opened for reading.\n",
			hexFile );
		
		RedirectPrintf(EVM55XDLL_ERROR, printf_str);
		
		return(FALSE);
	}

	// Allocate memory for file contents and read into array
    pHexFile = (char *)malloc(BLOCK_SIZE*sizeof(short));

	// Set current data pointer to start of data
	pDataStart = pHexFile;
	pData = pHexFile;
    
    if (len = fread(pData, sizeof(char), BLOCK_SIZE, fin))
	{
        if (len < BLOCK_SIZE)  
		{    // last buffer

			 // set end of buffer to EOFs
		     memset(pData+len, EOF, BLOCK_SIZE-len);

			 // set last buffer
			 lastBuffer = 1;
		}
		else
		{    // not last buffer
             lastBuffer = 0;

    		 //Initialize pDataEnd
			 pDataEnd = (char *)((ULONG)pData + len);
		}

	}
	else
    {
		free(pHexFile);
		return (FALSE);
    }	
	

	strcpy(temp, "0x0000");

	memset(pData+len, EOF, BLOCK_SIZE-len);

	pFlashData = (USHORT *)malloc(MAX_S2DATA_SIZE*sizeof(USHORT));
	pS2Data = (USHORT *)malloc(MAX_S2DATA_SIZE*sizeof(USHORT));

	while (pData = _getS2Data(fin, pData, &addr, &len))
	{
		pS2 = (S2Record *)pData;

        for (i=0; i<len; i++)
        {
			memcpy((temp+2), &pS2->pData[i<<2], 4);
			pS2Data[i] = (USHORT)strtol( temp, &stp, 0 );
        }

		evm55x_hpi_read((LPVOID)pBd, (PULONG)pFlashData, &len, addr, dspNum);
			
		if (memcmp((char *)pS2Data, (char *)pFlashData, len*sizeof(short)))
		{
			ret = FALSE;
			break;
		}

		// increment pData to end of current S record
		pData = (char *)((ULONG)pData + S2_TYPE_SIZE + S2_ADDR_SIZE + S2_LEN_SIZE + (len<<2) + 2);
	}

	free(pHexFile);
	free(pS2Data);
	free(pFlashData);
	
	fclose(fin);
	
	return (ret);
}

/*****************************************************************************
*              Private functions
*****************************************************************************/
static char * _getS2Data(FILE *fp, char *pData, PULONG addr, PULONG len)
{
	char temp[] = "0x00000000";
	char *stp = "";
	ULONG numRead;
	S2Record *pS2;


    //Check if at end of buffer and read in more data if needed
	if (lastBuffer == 0)
	{
		if ((ULONG)pData + 80 > (ULONG)pDataEnd)
		{
			ULONG remain;

			// determine number of remaining char in current buffer
			remain = (ULONG)pDataEnd - (ULONG)pData;

			// copy remainder of current buffer to beginning of buffer
			memcpy(pDataStart,pData,(size_t)remain);

			// temporarily set pDataEnd to end of old data
			pDataEnd = (char *)((ULONG)pDataStart + remain);

			// read data into buffer after current data
	        
			//Read block of data from file
			numRead = fread(pDataEnd, sizeof(char), (BLOCK_SIZE-remain), fp);

			//File rest of array with EOF
			if (numRead < (BLOCK_SIZE-remain))
			{
				lastBuffer = 1;
				memset(pDataEnd+numRead, EOF, BLOCK_SIZE-remain-numRead);
			}
			else 
			{
				//Initialize pDataEnd
				pDataEnd = (char *)((ULONG)pDataEnd + numRead);
			}

		    // reset current pointer
		    pData = pDataStart;	
		}

	}

	if ((pData = strstr(pData, "S2")) == NULL)
		return (char *)NULL;

	pS2 = (S2Record *)pData;

	memset(temp+2, '\0', 8);

	memcpy(temp+2, pS2->len, S2_LEN_SIZE);
	*len = (strtoul(temp, &stp, 0) - (S2_ADDR_SIZE>>1) - (S2_LEN_SIZE>>1)) >> 1; // in words

	memcpy(temp+2, pS2->addr, S2_ADDR_SIZE);

	*addr = strtoul( temp, &stp, 0 );
	*addr >>= 1;   // convert to word address

	return pData;
}

int getSector(ULONG addr)
{
    if ((addr >= FLASH_START_ADDR) && (addr <= (FLASH_START_ADDR+0x77fff)))
        return (((addr-FLASH_START_ADDR) & 0x30000) >> 16);
    else if ( (addr >= (FLASH_START_ADDR+0x78000)) && (addr <= (FLASH_START_ADDR+0x79fff)) )
        return 0x8;
    else if ( (addr >= (FLASH_START_ADDR+0x7a000)) && (addr <= (FLASH_START_ADDR+0x7bfff)) )
        return 0x9;
    else if ( (addr >= (FLASH_START_ADDR+0x7c000)) && (addr <= (FLASH_START_ADDR+0x7ffff)) )
        return 0xA;
    else
        return -1;
}
