/*****************************************************************************/
/*	fifo.c  - demonstrates how the software-implemented FIFO in DSP memory   */
/*            can be used to stream data between the host and the DSP        */
/*****************************************************************************/
#include <type.h>
#include <board.h>

/*****************************************************************************/
/*	defines                                                                  */
/*****************************************************************************/
#define SIZE    8192

/******************************************************************************/
/* Global variables   														  */
/******************************************************************************/
u16 rxLen;
u16 inBuf[SIZE];

/*****************************************************************************/
/* MAIN                                                                      */
/*****************************************************************************/
void main()
{
    // Initialize board
    brd_init(160);

    // Light first LED
    brd_led_enable(BRD_LED0);

    // Reset FIFOs
    brd_fifo_reset();

    // Get amount of data to read
    brd_fifo_read ((char*)&rxLen,1);

    // Light second LED to indicate read
    brd_led_enable(BRD_LED1);

    // Get data
    brd_fifo_read ((char*)inBuf,rxLen);

    // Light third LED to indicate write
    brd_led_enable(BRD_LED2);

    // Write data to FIFO
    brd_fifo_write((char *)inBuf,rxLen);

    // Flash all LEDs
    while (1)
    {
        brd_led_disable(BRD_LED0);
        brd_led_disable(BRD_LED1);
        brd_led_disable(BRD_LED2);

        brd_busy_delay(500);

        brd_led_enable(BRD_LED0);
        brd_led_enable(BRD_LED1);
        brd_led_enable(BRD_LED2);
    }
}
