;****************************************************************************
;*  boot   v1.10                                                            *
;*  Copyright (c) 1993-1995 Texas Instruments Incorporated                  *
;*                                                                          *
;*  Modified by Glen Chason, DNA Enterprises, Inc. 1996                     *
;*  - removed call to abort routine                                         *
;*  Modified by Bill Wrightson, DNA Enterprises, Inc. 1997                  *
;*  - added boot section to call _c_int00 from the boot loader              *
;*    (this must be the first section linked, it allows data to be located  *
;*     before code - the TI boot loader calls the boot table destination    *
;*     address which may be the address of the .data section)               *
;****************************************************************************
        .mmregs

;****************************************************************************
;*                                                                          *
;*   This module contains the following definitions :                       *
;*                                                                          *
;*         __stack    - Stack memory area                                   *
;*         _c_int00   - Boot function                                       *
;*                                                                          *
;****************************************************************************
        .global  _c_int00
        .global  cinit
        .global  _main 
        .global  __STACK_SIZE,__SYSSTACK_SIZE 

;****************************************************************************
;* Declare the stack.  Size is determined by the linker option -stack.  The *
;* default value is 1K words.                                               *
;****************************************************************************
__stack:        .usect  ".stack",0x200      ;__STACK_SIZE
__sysstack:     .usect  ".sysstack",0x200   ;__SYSSTACK_SIZE

;****************************************************************************
;* FUNCTION DEF : _c_int00                                                  *
;*                                                                          *
;*   1) Set up stack                                                        *
;*   2) Set up proper status                                                *
;*   3) If "cinit" is not -1, init global variables                         *
;*   4) call users' program                                                 *
;*                                                                          *
;****************************************************************************
        .text

_c_int00:
        bit(st1, #st1_xf) = #0

        repeat(#998)
        nop

        bit(st1, #st1_xf) = #1

        repeat(#98)
        nop

        bit(st1, #st1_xf) = #0

;****************************************************************************
;*  INIT STACK POINTER.  REMEMBER STACK GROWS FROM HIGH TO LOW ADDRESSES.   *
;****************************************************************************
        sp = #(__stack + __STACK_SIZE)          ;set to top of stack memory
        ssp = #(__sysstack + __SYSSTACK_SIZE)   ;init system stack pointer
        
        bit(st1, #st1_sxmd) = #1        ; turn on SXM for xar1 = #cinit

;****************************************************************************
;* SET UP REQUIRED VALUES IN STATUS REGISTER                                *
;****************************************************************************
        bit(st1, #st1_cpl) = #0         ; Use dp with direct addresses

;****************************************************************************
;* SETTING THESE STATUS BITS TO RESET VALUES.  IF YOU RUN _c_int00 FROM     *
;* RESET, YOU CAN REMOVE THIS CODE                                          *
;****************************************************************************

;****************************************************************************
;*  IF cinit IS NOT -1, PROCESS INITIALIZATION TABLES                       *
;****************************************************************************
        xar1 = #cinit                   ; Get pointer to init tables
        ac0 = *ar1
        ac1 = ac0 + #1
        if (ac1 == #0) goto _done_init  ; if (cinit == -1) no init tables

;****************************************************************************
;*  PROCESS INITIALIZATION TABLES.  TABLES ARE IN PROGRAM MEMORY IN THE     *
;*  FOLLOWING FORMAT:                                                       *
;*       .field <reserved>, 2                                               *
;*       .field <length>,   14                                              *
;*       .field <address>,  24                                              *
;*       .field <page>,     8                                               *
;*       .word  <init data>                                                 *
;*       .word  ...                                                         *
;*                                                                          *
;*  The init table is terminated with a zero length                         *
;*                                                                          *
;****************************************************************************
        goto  _start                    ; start processing

_loop:
        dr0 = ac0 - #1                  ; length -= 1
        csr = dr0

       ac1 = *ar1+ << #8                ; get MSW of 24-bit addr

        ac0 = *ar1+                     ; get LSB of 24-bit addr
        ac0 = ac0 & #00ffh
        
        ac1 = ac1 | ac0
        xar2 = ac1
         
        repeat(csr)                     ; repeat length+1 times
        *ar2+ = *ar1+                   ; copy from table to memory

_start:
        ac0 = *ar1+ << #-2              ; get length
        if (ac0 != #0)  goto _loop      ; if (length != 0) continue

;****************************************************************************
;*  CALL USER'S PROGRAM                                                     *
;****************************************************************************
_done_init:
        call    _main


;****************************************************************************
;*  Create boot section to place at beginning of program load;
;****************************************************************************
        .sect   ".boot"

        goto  _c_int00                  ; this is called from boot loader


        .end

