/*****************************************************************************
**  $Id: $
******************************************************************************
**
**  Revision History
**  ----------------
**   $Log: $
**
**
*****************************************************************************
**  DSPSHELL.C
**  ----------
**  Processing Shell for the 5510 EVM Memory Transfer module
**                                                                   
**  main:            Main routine
**                         
*****************************************************************************/

#include "emif.h"
#include "regs55x.h"
#include "type.h"  
#include "board.h"
#include "dspshell.h"

#define OSC 	20    

void brdInit();
void emifInit();
void delay(u16 cnt);
       
static volatile u16 freq = 160;

int main()
{       
    /************************************************************************/
    /*   Initialize DSP                                                     */
    /************************************************************************/
    brdInit();                           /* Set up C5510 EVM                 */ 
    
    dspInit();                           /* Set up transfer data structures  */

    while (1)
    {
        processData();                   /* Go look for memory xfer requests */
            
        /*delay(10);*/                   /* Delay loop between request polls */
        
        *(volatile u16 *)0x600000 &= ~7; /* Turn off LEDS */
    }
}

void brdInit()
{ 
#if 0
    u16 pllmult, clkmd;
#endif
            
	freq = 160;
	
#if 0
    CLKMD &= ~(1<<PLL_ENABLE);	//force into BYPASS mode
    while (CLKMD & (1<<LOCK));	//wait for BYPASS mode to be active

	pllmult = (freq / OSC) * (PLL_DIV_2+1);

	if (pllmult > 1)
	{
		clkmd = (pllmult & 0x1f) << PLL_MULT;
		clkmd |= ((PLL_DIV_2 << PLL_DIV) | (PLL_DIV_2 << BYPASS_DIV) | (1<<PLL_ENABLE));
			
		CLKMD = clkmd;

		while (!(CLKMD & (1<<LOCK))); //wait for PLL mode to be active
	}
	else
	{
		CLKMD = ((PLL_DIV_2 << PLL_DIV) | (PLL_DIV_2 << BYPASS_DIV) | (1<<PLL_ENABLE));
	}	
#endif

    brd_set_cpu_freq(freq);
	
	emifInit();
}
    
void emifInit()
{
	u16 writeSetup, writeStrobe, writeHold;	
	u16 readSetup, readStrobe, readHold;

	if (freq > 120)
		EMIF_GCTRL = (1 << MEMCEN) | (1 << MEMFREQ);
	else
		EMIF_GCTRL = (1 << MEMCEN);

	//1M SBSRAM. if MTYPE selects SBSRAM, remaining 
	//fields (ctrl1, ctrl2, ctrl3) do not apply
	EMIF_CE0_CTRL1 = (MTYPE_32SBSRAM << MTYPE);
	EMIF_CE0_CTRL2 = 0;
	EMIF_CE0_CTRL3 = 0;

	writeSetup = readSetup = 0;

	freq = freq / 10;

	readStrobe = ((READ_STROBE_NS * freq) / 100) + 1;
	readHold = ((READ_HOLD_NS * freq) / 100) + 1;
	writeStrobe = ((WRITE_STROBE_NS * freq) / 100) + 1;
	writeHold = ((WRITE_HOLD_NS * freq) / 100) + 1;

	//1M Flash
	EMIF_CE1_CTRL1 =	(MTYPE_32ASYNC << MTYPE)	| 
						(0xf << READ_SETUP)			| 
						(0x3f << READ_STROBE)		| 
						(0x3 << READ_HOLD);

	EMIF_CE1_CTRL2 =	(0xf << WRITE_SETUP)		| 
						(0x3f << WRITE_STROBE)		| 
						(0x3 << WRITE_HOLD)			|
						(0x1 << EXT_HOLD_WRITE)     |
						(0x1 << EXT_HOLD_READ);


	EMIF_CE1_CTRL3 = 0;

	//CPLD
	EMIF_CE3_CTRL1 =	(MTYPE_16ASYNC << MTYPE)	| 
						(readSetup << READ_SETUP)	| 
						(readStrobe << READ_STROBE) | 
						(readHold << READ_HOLD);

	EMIF_CE3_CTRL2 =	(writeSetup << WRITE_SETUP)	  | 
						(writeStrobe << WRITE_STROBE) | 
						(writeHold << WRITE_HOLD)	  |
						(0x1 << EXT_HOLD_WRITE)       |
						(0x1 << EXT_HOLD_READ);

	EMIF_CE3_CTRL3 = 0;
}
 
                     
