/******************************************************************************/
/*  MCBSP55.C - MCBSP55 routines .c file                                      */
/*                                                                            */
/*     This module provides the devlib implementation for the MCBSP           */
/*     on the TMS320C55x DSP.                                                 */
/*                                                                            */
/*  MACRO FUNCTIONS:                                                          */
/*                                                                            */
/*  FUNCTIONS:                                                                */
/*	mcbsp_init - initialize and start serial port operation                   */
/*                                                                            */
/*                                                                            */
/*  AUTHOR:                                                                   */
/*     Stefan Haas                                                            */
/*                                                                            */
/*  REVISION HISTORY:                                                         */
/*                                                                            */
/*    DATE       AUTHOR                       DESCRIPTION                     */
/*   -------   -------------      ------------------------------------------  */
/*   13OCT98   St Haas            Original.                                   */
/*                                                                            */
/******************************************************************************/
#include "mcbsp55x.h"

/******************************************************************/
/* mcbsp_init - initialize and start serial port operation        */
/******************************************************************/
void mcbsp_init(PMcBspConfig pBsp)
{
	/****************************************************************/
	/* Place port in reset - setting XRST & RRST to 0               */
	/****************************************************************/
	MCBSP_RX_RESET(pBsp->port);
	MCBSP_TX_RESET(pBsp->port);
	
	/****************************************************************/
	/* Set values of all control registers                          */
	/****************************************************************/
	RCR1(pBsp->port)  = pBsp->rcr1;
	RCR2(pBsp->port)  = pBsp->rcr2;
	XCR1(pBsp->port)  = pBsp->xcr1;
	XCR2(pBsp->port)  = pBsp->xcr2;
	SRGR1(pBsp->port) = pBsp->srgr1;
	SRGR2(pBsp->port) = pBsp->srgr2;
	MCR1(pBsp->port)  = pBsp->mcr1;
	MCR2(pBsp->port)  = pBsp->mcr2;
	PCR(pBsp->port)   = pBsp->pcr; 
	
	RCERA(pBsp->port) = pBsp->rcera;
	RCERB(pBsp->port) = pBsp->rcerb;
	RCERC(pBsp->port) = pBsp->rcerc;
	RCERD(pBsp->port) = pBsp->rcerd;
	RCERE(pBsp->port) = pBsp->rcere;
	RCERF(pBsp->port) = pBsp->rcerf;
	RCERG(pBsp->port) = pBsp->rcerg;
	RCERH(pBsp->port) = pBsp->rcerh;
	
	XCERA(pBsp->port) = pBsp->xcera;
	XCERB(pBsp->port) = pBsp->xcerb;
	XCERC(pBsp->port) = pBsp->xcerc;
	XCERD(pBsp->port) = pBsp->xcerd;
	XCERE(pBsp->port) = pBsp->xcere;
	XCERF(pBsp->port) = pBsp->xcerf;
	XCERG(pBsp->port) = pBsp->xcerg;
	XCERH(pBsp->port) = pBsp->xcerh;
}
