/*
 *  Copyright 2001 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) XDAS 2.2.1 12-07-01 (__imports)" */
/*
 *  ======== itst.h ========
 */
#ifndef ITST_
#define ITST_

#ifdef __cplusplus
extern "C" {
#endif

/*---------------------------*/
/*    TYPES AND CONSTANTS    */
/*---------------------------*/

#define ITST_DEFNUMOPS      1
#define ITST_DEFNUMPARMS    1

/*
 *  ======== ITST_Handle ========
 *  Handle to a testable instance object
 */
typedef struct ITST_Obj *ITST_Handle;

/*
 *  ======== ITST_Flag ========
 *  This bit set describes the data in a ITST_Frame buffer
 */
typedef LgBits  ITST_Flag;

#define ITST_LEFT   ((ITST_Flag)1)  /* items MSB is in left most position */
#define ITST_PACKED ((ITST_Flag)2)  /* items are packed (span char boundry) */
#define ITST_SIGNED ((ITST_Flag)4)  /* items are signed */

/*
 *  ======== ITST_ParamRec ========
 */
typedef struct ITST_ParamRec {
    Int         maxFrameSize;       /* number of chars in each frame */
    Int         itemSize;           /* number of chars for each item */
    Int         itemBits;           /* number of bits in each item */
    ITST_Flag   flags;              /* attributes of the frame data */
} ITST_ParamRec;

/*
 *  ======== ITST_Frame ========
 */
typedef struct ITST_Frame {
    Int     size;       /* physical size (in chars) of buffer */
    Int     len;        /* number of chars in the buffer */
    Void    *buffer;    /* the buffer itself */
} ITST_Frame;

/*
 *  ======== ITST_Fxns ========
 */
typedef struct ITST_Fxns {
    Void    *implementationId;
    Int     (*tstNumOps)(ITST_Handle);
    Void    (*tstNumParams)(ITST_Handle, Int op, Int *numIn, Int *numOut);
    Void    (*tstGetParams)(ITST_Handle, Int op, ITST_ParamRec in[], ITST_ParamRec out[]);
    Void    (*tstProcess)(ITST_Handle, Int op, ITST_Frame in[], ITST_Frame out[]);
} ITST_Fxns;


#ifdef __cplusplus
}
#endif

#endif  /* ITST_ */
