/*
 *  Copyright 2001 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) XDAS 2.2.1 12-07-01 (__imports)" */
/*
 *  ======== rtc.c ========
 */
#include <std.h>
#include <irtc.h>
#include <rtc.h>
#include <alg.h>
#include <log.h>

/*
 *  ======== RTC_bind ========
 */
Void RTC_bind(IRTC_Fxns *fxns, LOG_Obj *log)
{
    if (fxns != NULL) {
        fxns->rtcBind(log);
    }
}

/*
 *  ======== RTC_create ========
 */
RTC_Desc *RTC_create(RTC_Desc *obj, ALG_Handle alg, IRTC_Fxns *fxns)
{
    if (obj != NULL) {
        /* verify that alg and rtc fxns are from same concrete implementation*/
        if (fxns->implementationId == alg->fxns->implementationId) {
            obj->handle = (IRTC_Handle)alg;
            obj->fxns = fxns;
            return (obj);
        }
        obj->fxns = NULL;
    }

    return (NULL);
}

/*
 *  ======== RTC_disable ========
 */
Void RTC_disable(const RTC_Desc *rtc)
{
    if (rtc && rtc->fxns) {
        rtc->fxns->rtcSet(rtc->handle, (IRTC_Mask)0);
    }
}

/*
 *  ======== RTC_enable ========
 */
Void RTC_enable(const RTC_Desc *rtc)
{
    if (rtc && rtc->fxns) {
        rtc->fxns->rtcSet(rtc->handle, rtc->mask);
    }
}

/*
 *  ======== RTC_exit ========
 */
Void RTC_exit(Void)
{
}

/*
 *  ======== RTC_get ========
 */
IRTC_Mask RTC_get(RTC_Desc *rtc)
{
    if (rtc && rtc->fxns) {
        return(rtc->fxns->rtcGet(rtc->handle));
    }
    else {
        return(NULL);
    }
}

/*
 *  ======== RTC_init ========
 */
Void RTC_init(Void)
{
}

/*
 *  ======== RTC_set ========
 */
Void RTC_set(RTC_Desc *rtc, IRTC_Mask mask)
{
    if (rtc && rtc->fxns) {
        rtc->fxns->rtcSet(rtc->handle, (IRTC_Mask)mask);
        rtc->mask = mask;
    }
}
