/****************************************************************/
/* THS1007/1009/1207/1209 driver version 2.0 for C5000          */
/* $Revision: 2 $                         $JustDate: 24.11.00 $ */
/****************************************************************/
#ifndef T100x_FN_H
#define T100x_FN_H

/* needs the new v 2.0 API definition! */
#include "TIDC_API.h"

#if _INLINE
#define __INLINE  static inline
#else
#define __INLINE
#endif

/****************************************************************/
/* Define double name for bit2 of control register 1            */
/****************************************************************/
#ifndef frst
#define frst ovfl
#endif

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0                  */
/****************************************************************/
typedef union
{
    unsigned int value;
    struct
    {
        unsigned int vsel     :1;
        unsigned int mode     :1;
        unsigned int pd       :1;
        unsigned int chs      :2;
        unsigned int df       :2;
        unsigned int as       :1;
        unsigned int test     :2;
        unsigned int address  :2;
        unsigned int reserved :4;
    } control_bit;
} THS1206CREG0;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 1                  */
/****************************************************************/
typedef union
{
    unsigned int value;
    struct
    {
        unsigned int rst      :1;
        unsigned int ovfl     :1;
        unsigned int ftl      :2;
        unsigned int data_t   :1;
        unsigned int data_p   :1;
        unsigned int rw       :1;
        unsigned int comp     :1;
        unsigned int ofse     :1;
        unsigned int dbg      :1;
        unsigned int address  :2;
        unsigned int reserved :4;
    } control_bit;
} THS1206CREG1;

/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/
typedef struct
{
    TTIDC f;                          /* common functions       */

    volatile int *const adc_adr;      /* ADC address            */
    
    THS100XCREG0        creg0;
    THS100XCREG1        creg1;
    
    unsigned short      IntNum;                           
    unsigned short      data_shift;
} TTHS100X;

typedef TTHS100X TTHS1207;        /* more types for each device */            
typedef TTHS100X TTHS1209;
typedef TTHS100X TTHS1007;                  
typedef TTHS100X TTHS1009;


/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* THS100X defines for control registers bit set/clear          */
/****************************************************************/

#define T100X_VSEL       (0x1)
#define T100X_MODE       (0x2)
#define T100X_PD         (0x4)
#define T100X_CHSEL0     (0x8)
#define T100X_CHSEL1     (0x10)
#define T100X_DIFF0      (0x20)
#define T100X_DIFF1      (0x40)
#define T100X_SCAN       (0x80)
#define T100X_TEST0      (0x100)
#define T100X_TEST1      (0x200)

#define T100X_RST        (0x1)
#define T100X_OVFL       (0x2)    
#define T100X_F0         (0x4)
#define T100X_F1         (0x8)
#define T100X_DATA_T     (0x10)
#define T100X_DATA_P     (0x20)
#define T100X_RW         (0x40)
#define T100X_COMP       (0x80)
#define T100X_OFSE       (0x100)
#define T100X_DBG        (0x200)

#define T100X_CR0        (0x0)
#define T100X_CR1        (0x400)

/****************************************************************/
/* FUNCTION DEFINITIONS C5000                                   */
/* PART 1: DATA CONVERTER                                       */
/****************************************************************/
TTIDCSTATUS ths100x_configure(void *pDC);
void        ths100x_power(void *pDC, int bDown);
long        ths100x_read(void *pDC);
void        ths100x_write(void *pDC, long lData);
void        ths100x_rblock(void          *pDC, 
                           void          *pData, 
                           unsigned long ulCount,
                           void          (*callback) (void *)
                          );
void        ths100x_wblock(void          *pDC, 
                           void          *pData, 
                           unsigned long ulCount, 
                           void          (*callback) (void *)
                          );

/****************************************************************/
/* FUNCTION DEFINITIONS C5000                                   */
/* PART 1: DATA CONVERTER                                       */
/****************************************************************/
void ths100x_init(void *pDC, int sel);
__INLINE void ths100x_reset(void *pDC);
__INLINE void ths100x_init_obj(void           *pDC,
                               unsigned int   uintcreg0,
                               unsigned int   uintcreg1,
                               unsigned short shift
                              );
__INLINE void ths100x_read_CR(void         *pDC,
                              unsigned int *uintcreg0,
                              unsigned int *uintcreg1
                             );
__INLINE void ths100x_powerdown(void *pDC);
__INLINE void ths100x_powerwake(void *pDC);

/****************************************************************/
/* PART 2: DSP PERIPHERALs                                      */
/****************************************************************/

#if defined(_INLINE)
/****************************************************************/
/* PART 3: DSP FUNCTIONS                                        */
/****************************************************************/
/* inline function(s)                                           */
/****************************************************************/
/* ths100x_reset                                                */
/* This function resets the THS100X control register            */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths100x_reset(void *pDC)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = 0x401 << pAdc->data_shift;
    PORTADDR = 0x400 << pAdc->data_shift;
}


/****************************************************************/
/* ths100x_init_obj                                             */
/* This function initializes the data converter object          */
/* Calling this function is always necessary as a first step    */
/* Parameters:    pointer to DC object                          */
/*                adc_mem should contain the address of the DC  */
/*                uintcreg0 contains the init value for creg0   */
/*                uintcreg1 contains the init value for creg1   */
/*                shift contains the init value for data_shift  */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths100x_init_obj(void           *pDC,
                                    unsigned int   uintcreg0,
                                    unsigned int   uintcreg1,
                                    unsigned short shift)
{
    TTHS100X *pAdc = pDC;

    pAdc->creg0.value = uintcreg0;
    pAdc->creg1.value = uintcreg1;
    pAdc->data_shift  = shift;
}
 
 
/****************************************************************/
/* ths100x_read_CR                                              */
/* This function reads the control registers of the device      */
/* and return the data. No changes to the object data are made  */
/* Parameters:    pointer to DC object                          */
/*                2 pointers to unsigned int variable           */
/* Return Values: updates pointer contents                      */
/****************************************************************/
static inline void ths100x_read_CR(void         *pDC,
                                   unsigned int *uintcreg0,
                                   unsigned int *uintcreg1)
{
    TTHS100X *pAdc = pDC;

    PORTADDR   = (pAdc->creg1.value | T100X_DBG) 
        << pAdc->data_shift;

    *uintcreg0 = PORTADDR >> pAdc->data_shift;
    *uintcreg1 = PORTADDR >> pAdc->data_shift;
}


/****************************************************************/
/* ths100x_powerdown                                            */
/* This sets the THS100X in powerdown mode                      */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths100x_powerdown(void *pDC)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = (pAdc->creg0.value | T100X_PD) 
        << pAdc->data_shift;
}
   
   
/****************************************************************/
/* ths100x_powerwake                                            */
/* This sets the THS100X in active mode (wakeup)                */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths100x_powerwake(void *pDC)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = (pAdc->creg0.value & !T100X_PD) 
        << pAdc->data_shift;
}


/****************************************************************/
/* ths100x_read                                                 */
/* This function reads the (FIFO) data                          */
/* Parameters:    pointer to DC object                          */
/* Return Values: one sample value, not shifted!                */
/****************************************************************/
static inline unsigned int ths100x_read(void *pDC)
{
    TTHS100X *pAdc = pDC;

    return (PORTADDR);
}

#endif /* _INLINE   */
#endif /* T100X_FN_H */
