/****************************************************************/
/* THS1007/1009/1207/1209 driver version 2.0 for C5000          */
/* $Revision: 2 $                         $JustDate: 24.11.00 $ */
/****************************************************************/

#undef _INLINE

#include "dc_conf.h"
#include "t100x_fn.h"

/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&


/****************************************************************/
/* DSP FUNCTIONS                                                */
/****************************************************************/

TTIDCSTATUS ths100x_configure(void *pDC)
{
    TTHS100X *pAdc = pDC;

    /* set reset bit in control register 1 */
    PORTADDR = 0x401 << pAdc->data_shift;        

    /* clear reset bit in control register 1 */
    PORTADDR = 0x400 << pAdc->data_shift;    

    /* write PlugIn generated control register 0 value in ADC   */
    PORTADDR = pAdc->creg0.value << pAdc->data_shift; 
    
    /* write PlugIn generated control register 1 value in ADC   */    
    PORTADDR = (pAdc->creg1.value | 0x400) << pAdc->data_shift;

    return TIDC_NO_ERR;
}


/****************************************************************/
/* ths100x_power                                                */
/* This sets the ths100x in powerdown mode                      */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
void ths100x_power(void *pDC, int bDown)
{
    TTHS100X *pAdc = pDC;

    if (bDown)
    {
        PORTADDR = (pAdc->creg0.value | T100X_PD) 
            << pAdc->data_shift;
    }
    else
    {
        PORTADDR = (pAdc->creg0.value & !T100X_PD) 
            << pAdc->data_shift;
    }
}


/****************************************************************/
/* ths100x_read                                                 */
/* This function reads the (FIFO) data                          */
/* Parameters:    pointer to DC object                          */
/* Return Values: one sample value, not shifted!                */
/****************************************************************/
long ths100x_read(void *pDC)
{
    return (PORTADDR);
}
 

/****************************************************************/
/* ths100x_write                                                */
/* This function writes data to ADC                             */
/* Parameters:    pointer to DC object                          */
/* Return Values: one sample value, not shifted!                */
/****************************************************************/
void ths100x_write(void *pDC, long lData)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = (lData) << pAdc->data_shift;     
}


/****************************************************************/
/* ths100x_rblock                                               */
/* NOT IMPLEMENTED                                              */
/****************************************************************/
void ths100x_rblock(void          *pDC, 
                    void          *pData, 
                    unsigned long ulCount, 
                    void          (*callback) (void *))
{
}


/****************************************************************/
/* ths100x_wblock                                               */
/* NOT IMPLEMENTED                                              */
/****************************************************************/
void ths100x_wblock(void          *pDC, 
                    void          *pData, 
                    unsigned long ulCount, 
                    void          (*callback) (void *))
{
}    
    
    
/****************************************************************/
/* ths100x_init                                           V1.20 */
/* This function initializes the control registers              */
/* zero and one of the THS100X.                                 */
/* Parameters:    pointer to DC object                          */
/*                int sel: -1 init all registers                */
/*                          0 init CR0 only                     */
/*                          1 init CR1 only                     */
/* Return Values: NONE                                          */
/****************************************************************/
void ths100x_init (void *pDC, int sel)
{
    TTHS100X *pAdc = pDC;

    switch (sel)
    {
        case -1:
            PORTADDR = pAdc->creg0.value << pAdc->data_shift;
            PORTADDR = (pAdc->creg1.value | 0x400) 
                << pAdc->data_shift;
            break;
        
        case  0:
            PORTADDR = pAdc->creg0.value << pAdc->data_shift;
            break;
        
        case  1:
            PORTADDR = (pAdc->creg1.value | 0x400) 
                << pAdc->data_shift;
            break;  
            
        default:
            break;
    }
}


/****************************************************************/
/* ths100x_reset                                          V1.20 */
/* This function resets the ths100x control register            */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
void ths100x_reset(void *pDC)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = 0x401 << pAdc->data_shift;
    PORTADDR = 0x400 << pAdc->data_shift;
}


/****************************************************************/
/* ths100x_init_obj                                       V1.10 */
/* This function initializes the data converter object          */
/* Calling this function is always necessary as a first step    */
/* Parameters:    pointer to DC object                          */
/*                adc_mem should contain the address of the DC  */
/*                uintcreg0 contains the init value for creg0   */
/*                uintcreg1 contains the init value for creg1   */
/*                shift contains the init value for data_shift  */
/* Return Values: NONE                                          */
/****************************************************************/
void ths100x_init_obj(void           *pDC,
                      unsigned int   uintcreg0,
                      unsigned int   uintcreg1,
                      unsigned short shift)
{
    TTHS100X *pAdc = pDC;

    pAdc->creg0.value = uintcreg0;
    pAdc->creg1.value = uintcreg1;
    pAdc->data_shift  = shift;
}
  
  
/****************************************************************/
/* ths100x_read_CR                                        V1.20 */
/* This function reads the control registers of the device      */
/* and return the data. No changes to the object data are made  */
/* Parameters:    pointer to DC object                          */
/*                2 pointers to unsigned int variable           */
/* Return Values: updates pointer contents                      */
/****************************************************************/
void ths100x_read_CR(void         *pDC,
                     unsigned int *uintcreg0,
                     unsigned int *uintcreg1)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = (pAdc->creg1.value | T100X_DBG) 
        << pAdc->data_shift;
    
    *uintcreg0 = PORTADDR >> pAdc->data_shift;
    *uintcreg1 = PORTADDR >> pAdc->data_shift;
}


/****************************************************************/
/* ths100x_powerdown                                      V1.20 */
/* This sets the ths100x in powerdown mode                      */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
void ths100x_powerdown(void *pDC)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = (pAdc->creg0.value | T100X_PD) 
        << pAdc->data_shift;
}


/****************************************************************/
/* ths100x_powerwake                                      V1.20 */
/* This sets the ths100x in active mode (wakeup)                */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
void ths100x_powerwake(void *pDC)
{
    TTHS100X *pAdc = pDC;

    PORTADDR = (pAdc->creg0.value & !T100X_PD) 
        << pAdc->data_shift;
}
