/****************************************************************/
/* THS1206/10064/12064/10082 driver version 2.0 for C5000       */
/* $Revision: 11 $                        $JustDate: 24.11.00 $ */
/****************************************************************/
#ifndef T1206_FN_H
#define T1206_FN_H

/* needs the new v 2.0 API definition! */
#include "TIDC_API.h"

#if _INLINE
#define __INLINE  static inline
#else
#define __INLINE
#endif

/****************************************************************/
/* Define double name for bit2 of control register 1            */
/****************************************************************/
#ifndef frst
#define frst ovfl
#endif

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0                  */
/****************************************************************/
typedef union
{
    unsigned int value;
    struct
    {
        unsigned int vsel     :1;
        unsigned int mode     :1;
        unsigned int pd       :1;
        unsigned int chs      :2;
        unsigned int df       :2;
        unsigned int as       :1;
        unsigned int test     :2;
        unsigned int address  :2;
        unsigned int reserved :4;
    } control_bit;
} THS1206CREG0;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 1                  */
/****************************************************************/
typedef union
{
    unsigned int value;
    struct
    {
        unsigned int rst      :1;
        unsigned int ovfl     :1;
        unsigned int ftl      :2;
        unsigned int data_t   :1;
        unsigned int data_p   :1;
        unsigned int rw       :1;
        unsigned int comp     :1;
        unsigned int ofse     :1;
        unsigned int dbg      :1;
        unsigned int address  :2;
        unsigned int reserved :4;
    } control_bit;
} THS1206CREG1;

/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/
typedef struct
{
    TTIDC f;                               /* common functions  */

    volatile int *const adc_adr;           /* ADC address       */

    THS1206CREG0        creg0;
    THS1206CREG1        creg1;

    unsigned int        TriggerLvl;
    unsigned short      IntNum;                           
    unsigned short      data_shift;
} TTHS1206;

typedef TTHS1206 TTHS10064;       /* more types for each device */            
typedef TTHS1206 TTHS12082;
typedef TTHS1206 TTHS10082;

/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* THS1206 defines for control registers bit set/clear          */
/****************************************************************/

#define T1206_VSEL       (0x1)
#define T1206_MODE       (0x2)
#define T1206_PD         (0x4)
#define T1206_CHSEL0     (0x8)
#define T1206_CHSEL1     (0x10)
#define T1206_DIFF0      (0x20)
#define T1206_DIFF1      (0x40)
#define T1206_SCAN       (0x80)
#define T1206_TEST0      (0x100)
#define T1206_TEST1      (0x200)

#define T1206_RST        (0x1)
#define T1206_OVFL       (0x2)   /* Overflow and FIFO reset     */
#define T1206_FRST       (0x2)   /* share the same bit position */
#define T1206_F0         (0x4)
#define T1206_F1         (0x8)
#define T1206_DATA_T     (0x10)
#define T1206_DATA_P     (0x20)
#define T1206_RW         (0x40)
#define T1206_COMP       (0x80)
#define T1206_OFSE       (0x100)
#define T1206_DBG        (0x200)

#define T1206_CR0        (0x0)
#define T1206_CR1        (0x400)

/****************************************************************/
/* FUNCTION DEFINITIONS C5000                                   */
/* PART 1: DATA CONVERTER                                       */
/****************************************************************/
TTIDCSTATUS ths1206_configure(void *pDC);
void        ths1206_power(void *pDC, int bDown);
long        ths1206_read(void *pDC);
void        ths1206_write(void *pDC, long lData);
void        ths1206_rblock(void          *pDC, 
                           void          *pData, 
                           unsigned long ulCount, 
                           void          (*callback) (void *)
                          );
void        ths1206_wblock(void          *pDC, 
                           void          *pData, 
                           unsigned long ulCount, 
                           void          (*callback) (void *)
                          );

/****************************************************************/
/* FUNCTION DEFINITIONS C5000                                   */
/* PART 1: DATA CONVERTER                                       */
/****************************************************************/
void          ths1206_init(void *pDC, int sel);
__INLINE void ths1206_reset(void *pDC);
__INLINE void ths1206_freset(void *pDC);
__INLINE void ths1206_init_obj(void *pDC,
                               unsigned int   uintcreg0,
                               unsigned int   uintcreg1,
                               unsigned short shift
                              );
__INLINE void ths1206_read_CR(void         *pDC,
                              unsigned int *uintcreg0,
                              unsigned int *uintcreg1
                             );
__INLINE void ths1206_powerdown(void *pDC);
__INLINE void ths1206_powerwake(void *pDC);

/****************************************************************/
/* PART 2: DSP PERIPHERALs                                      */
/****************************************************************/

#if defined(_INLINE)
/****************************************************************/
/* PART 3: DSP FUNCTIONS                                        */
/****************************************************************/
/* inline function(s)                                           */
/****************************************************************/
/* ths1206_reset                                                */
/* This function resets the ths1206 control register            */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths1206_reset(DEV_1206 *pAdc)
{
    PORTADDR = 0x401 << pAdc->data_shift;
    PORTADDR = 0x400 << pAdc->data_shift;
}

/****************************************************************/
/* ths1206_freset                                               */
/* This function resets just the FIFO of the THS1206            */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths1206_freset(DEV_1206 *pAdc)
{
    PORTADDR = (pAdc->creg1.value | T1206_FRST | 0x400)
        << pAdc->data_shift;
}

/****************************************************************/
/* ths1206_init_obj                                             */
/* This function initializes the data converter object          */
/* Calling this function is always necessary as a first step    */
/* Parameters:    pointer to DC object                          */
/*                adc_mem should contain the address of the DC  */
/*                uintcreg0 contains the init value for creg0   */
/*                uintcreg1 contains the init value for creg1   */
/*                shift contains the init value for data_shift  */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths1206_init_obj(DEV_1206       *pAdc,
                                    unsigned int   uintcreg0,
                                    unsigned int   uintcreg1,
                                    unsigned short shift)
{
    pAdc->creg0.value = uintcreg0;
    pAdc->creg1.value = uintcreg1;
    pAdc->data_shift = shift;
}

/****************************************************************/
/* ths1206_read_CR                                              */
/* This function reads the control registers of the device      */
/* and return the data. No changes to the object data are made  */
/* Parameters:    pointer to DC object                          */
/*                2 pointers to unsigned int variable           */
/* Return Values: updates pointer contents                      */
/****************************************************************/
static inline void ths1206_read_CR(DEV_1206     *pAdc,
                                   unsigned int *uintcreg0,
                                   unsigned int *uintcreg1)
{
    PORTADDR = (pAdc->creg1.value | T1206_DBG) 
        << pAdc->data_shift;
    
    *uintcreg0 = PORTADDR >> pAdc->data_shift;
    *uintcreg1 = PORTADDR >> pAdc->data_shift;
}

/****************************************************************/
/* ths1206_powerdown                                            */
/* This sets the ths1206 in powerdown mode                      */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths1206_powerdown(DEV_1206 *pAdc)
{
    PORTADDR = (pAdc->creg0.value | T1206_PD) 
        << pAdc->data_shift;
}

/****************************************************************/
/* ths1206_powerwake                                            */
/* This sets the ths1206 in active mode (wakeup)                */
/* Parameters:    pointer to DC object                          */
/* Return Values: NONE                                          */
/****************************************************************/
static inline void ths1206_powerwake(DEV_1206 *pAdc)
{
    PORTADDR = (pAdc->creg0.value & !T1206_PD) 
        << pAdc->data_shift;
}

/****************************************************************/
/* ths1206_read                                                 */
/* This function reads the (FIFO) data                          */
/* Parameters:    pointer to DC object                          */
/* Return Values: one sample value, not shifted!                */
/****************************************************************/
static inline unsigned int ths1206_read(DEV_1206 *pAdc)
{
    return (PORTADDR);
}

#endif /* _INLINE   */
#endif /* T1206_FN_H */
