/****************************************************************/
/* TLV1504/08 driver for C5400                                  */
/* $Revision:: 7   $                     $JustDate:: 18.10.00 $ */
/****************************************************************/
#ifndef T150X_FN_H
#define T150x_FN_H

#include "TIDC_API.H"

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER                    */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int trig               :2;
          unsigned int eoc                :1;
          unsigned int sweep              :2;
          unsigned int mode               :2;
          unsigned int src                :2;
          unsigned int period             :1;
          unsigned int refvolt            :1;
          unsigned int ref                :1;
          unsigned int reserved           :4;
      } control_bit;
} TLV150xCREG;                                                

/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/
typedef struct
{
    TTIDC f;                        /* common functions */
    void(*CallBack)    (void *);    /* CallBack function */
    unsigned int *     BufferAddr;  /* buffer address */
    DCP_SERIAL*        serial;      /* Pointer to the serial port config object */
    unsigned int       command;
    TLV150xCREG        creg;
    unsigned int       EventId;     /* sync event number */
} TTLV150X;

typedef TTLV150X TTLV1504;
typedef TTLV150X TTLV1508;

/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* TLV150x API 2.0 functions                                    */
/****************************************************************/
TTIDCSTATUS tlv150x_configure(void *pDC);
void tlv150x_power(void *pDC, int bDown);
long tlv150x_read(void *pDC);
void tlv150x_write(void *pDC, long lData);
void tlv150x_rblock(void *pDC, void *pData, 
                    unsigned long ulCount, 
                    void (*callback) (void *));
void tlv150x_wblock(void *pDC, void *pData, 
                    unsigned long ulCount, 
                    void (*callback) (void *));

/****************************************************************/
/* TLV150x MACORS FOR BIT FIELD DEFINITIONS                     */
/****************************************************************/
/* TLV150x macros for control registers integer assignments     */
/* of the control register 1                                    */
/****************************************************************/ 

#define TLV150X_TRIG0           (0x1)
#define TLV150X_TRIG1           (0x2)
#define TLV150X_EOC             (0x4)
#define TLV150X_SWEEP0          (0x8)
#define TLV150X_SWEEP1          (0x10)
#define TLV150X_MODE0           (0x20)
#define TLV150X_MODE1           (0x40)
#define TLV150X_SRC0            (0x80)
#define TLV150X_SRC1            (0x100)
#define TLV150X_PERIOD          (0x200)
#define TLV150X_REFVOLT         (0x400)
#define TLV150X_REF             (0x800)

/****************************************************************/
/* TLV150x macros for Command Set                               */
/* see datasheet for examples                                   */
/****************************************************************/ 
#define TLV1504_INP0	(0x0)			// 2544 chan 0
#define TLV1504_INP1	(0x2000)		// 2544 chan 1
#define TLV1504_INP2	(0x4000)		// 2544 chan 2
#define TLV1504_INP3	(0x6000)		// 2544 chan 3
#define TLV1508_INP0	(0x0)			// 2548 chan 0
#define TLV1508_INP1	(0x1000)		// 2548 chan 1
#define TLV1508_INP2	(0x2000)		// 2548 chan 2
#define TLV1508_INP3	(0x3000)		// 2548 chan 3
#define TLV1508_INP4	(0x4000)		// 2548 chan 4
#define TLV1508_INP5	(0x5000)		// 2548 chan 5
#define TLV1508_INP6	(0x6000)		// 2548 chan 6
#define TLV1508_INP7	(0x7000)		// 2548 chan 7
#define TLV150X_SWPD	(0x8000)		// software power down
#define TLV150X_RCFR	(0x9000)		// read CFR
#define TLV150X_WCFR	(0xA000)		// write CFR (or with data!)
#define TLV150X_REF2	(0xB000)		// select test (refp+refm)/2
#define TLV150X_REFM	(0xC000)		// select test refm
#define TLV150X_REFD	(0xD000)		// select test refp
#define TLV150X_FFRD	(0xE000)		// read FIFO
#define TLV150X_RESV	(0xF000)		// reserved?
/***************************************************************/ 
#endif /* T150X_FN_H */
