/****************************************************************/
/* TLC1514/18, TLC2554/58 driver version 2.1 for C5400          */
/* $Revision: 6 $                         $JustDate: 18.10.00 $ */
/****************************************************************/
#ifndef T151X_FN_H
#define T151x_FN_H

#include "TIDC_API.H"

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER                    */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int trig               :2;
          unsigned int eoc                :1;
          unsigned int sweep              :2;
          unsigned int mode               :2;
          unsigned int inpsel             :1;
          unsigned int clksrc             :1;
          unsigned int period             :1;
          unsigned int outsel             :1;
          unsigned int ref                :1;
          unsigned int reserved           :4;
      } control_bit;
} TLC151xCREG;                                                

/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/
typedef struct
{
    TTIDC f;                        /* common functions */
    void(*CallBack)    (void *);    /* CallBack function */
    unsigned int *     BufferAddr;  /* buffer address */
    DCP_SERIAL*        serial;      /* Pointer to the serial port config object */
    unsigned int       command;	/* command value         */
    TLC151xCREG        creg;        /* control reg value     */
    unsigned int       EventId;     /* sync event number */
} TTLC151X;

typedef TTLC151X TTLC1514;
typedef TTLC151X TTLC1518;
typedef TTLC151X TTLC2554;
typedef TTLC151X TTLC2558;

/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* TLC151x API 2.0 functions                                    */
/****************************************************************/
TTIDCSTATUS tlc151x_configure(void *pDC);
void tlc151x_power(void *pDC, int bDown);
long tlc151x_read(void *pDC);
void tlc151x_write(void *pDC, long lData);
void tlc151x_rblock(void *pDC, void *pData, 
                    unsigned long ulCount, 
                    void (*callback) (void *));
void tlc151x_wblock(void *pDC, void *pData, 
                    unsigned long ulCount, 
                    void (*callback) (void *));

/****************************************************************/
/* TLC151x MACORS FOR BIT FIELD DEFINITIONS                     */
/****************************************************************/
/* TLC151x macros for control registers integer assignments     */
/* of the control register                                      */
/****************************************************************/ 

#define TLC151X_TRIG0           (0x1)
#define TLC151X_TRIG1           (0x2)
#define TLC151X_EOC             (0x4)
#define TLC151X_SWEEP0          (0x8)
#define TLC151X_SWEEP1          (0x10)
#define TLC151X_MODE0           (0x20)
#define TLC151X_MODE1           (0x40)
#define TLC151X_INPSEL          (0x80)
#define TLC151X_CLKSRC          (0x100)
#define TLC151X_PERIOD          (0x200)
#define TLC151X_OUTSEL          (0x400)
#define TLC151X_REF             (0x800)

/****************************************************************/
/* TLV150x macros for Command Set                               */
/* see datasheet for examples                                   */
/****************************************************************/ 
#define TLC1514_INP0	(0x0)			// 1514 chan 0
#define TLC1514_INP1	(0x2000)		// 1514 chan 1
#define TLC1514_INP2	(0x4000)		// 1514 chan 2
#define TLC1514_INP3	(0x6000)		// 1514 chan 3
#define TLC1518_INP0	(0x0)			// 1518 chan 0
#define TLC1518_INP1	(0x1000)		// 1518 chan 1
#define TLC1518_INP2	(0x2000)		// 1518 chan 2
#define TLC1518_INP3	(0x3000)		// 1518 chan 3
#define TLC1518_INP4	(0x4000)		// 1518 chan 4
#define TLC1518_INP5	(0x5000)		// 1518 chan 5
#define TLC1518_INP6	(0x6000)		// 1518 chan 6
#define TLC1518_INP7	(0x7000)		// 1518 chan 7
#define TLC151X_SWPD	(0x8000)		// software power down
#define TLC151X_RCFR	(0x9000)		// read CFR
#define TLC151X_WCFR	(0xA000)		// write CFR (or with data!)
#define TLC151X_REF2	(0xB000)		// select test (refp+refm)/2
#define TLC151X_REFM	(0xC000)		// select test refm
#define TLC151X_REFD	(0xD000)		// select test refp
#define TLC151X_FFRD	(0xE000)		// read FIFO
#define TLC151X_RESV	(0xF000)		// reserved?
/***************************************************************/ 
#endif /* T151X_FN_H */
