/****************************************************************/
/* TLC1514/TLC1518 driver version 2.0 for C5400	                */
/* TLC2554/TLC2558 driver version 2.0 for C5400                 */
/* $Revision: 4 $                      $JustDate: 21.09.00 $ */
/****************************************************************/

#undef _INLINE
#include "dc_conf.h"
#include "t151x_fn.h" 

/* needs -i <drive>\ti\c5400\dsk\include option */             
#include <regs54xx.h>
#include <std.h>
#include <hwi.h>

/* Define an unused interrupt which can be used                */
/* by the Read Block Function                                  */                                 
#define ADC_INTNUM (9)

/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&                                                 

                        
/****************************************************************/
/* DSP FUNCTIONS                                                */
/****************************************************************/
#define DMSA	0x55
#define DMSDN	0x57
#define DMSRC0	0x00
#define DMDST0	0x01
#define DMCTR0	0x02
#define DMSFC0	0x03
#define DMMCR0	0x04
#define DMSRC1	0x05
#define DMDST1	0x06
#define DMCTR1	0x07
#define DMSFC1	0x08
#define DMMCR1	0x09
#define DMSRC2	0x0A
#define DMDST2	0x0B
#define DMCTR2	0x0C
#define DMSFC2	0x0D
#define DMMCR2	0x0E
#define DMAPREC	0x54
#define DMIDX0	0x20

/****************************************************************/
/* DSP FUNCTIONS                                                */
/****************************************************************/

/****************************************************************/
/*	IRQ call-back instance                                    	*/
/****************************************************************/
void (*tlc151x_rcallback) (void *);
                        

/****************************************************************/
/*Function:       tlc151x_configure()                           */
/*Description:    Configure the TLC1514/TLC1518 ADC or          */ 
/*                Configure the TLC2554/TLC2558 ADC             */
/*Input:          Data Converter Object                         */
/*Note:           ADC selected before calling this Function     */
/****************************************************************/
TTIDCSTATUS tlc151x_configure(void *pDC)   
{ 
    TTLC151X *pTLC = pDC;

    if (!pTLC)
        return TIDC_ERR_NODEVICE;

    /* open and configure MCBSP, if not done yet */
    if (!pTLC->serial->hMcbsp)
    {
        switch (pTLC->serial->port)
        {
        case 0: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV0, MCBSP_OPEN_RESET); 
                break;
        case 1: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV1, MCBSP_OPEN_RESET); 
                break;
        case 2: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV2, MCBSP_OPEN_RESET); 
                break;
        default: return TIDC_ERR_MCBSP;
        }               
    }

    MCBSP_ConfigA(pTLC->serial->hMcbsp, &pTLC->serial->sConfig);
    pTLC->serial->sConfig.spcr	|= 0x00010001;        
    MCBSP_ConfigA(pTLC->serial->hMcbsp, &pTLC->serial->sConfig);

    MCBSP_Write(pTLC->serial->hMcbsp, pTLC->creg.value | TLC151X_WCFR);
	
    return TIDC_NO_ERR;
}

/************************************************************/
/*Function: tlc151x_power()                                 */
/*Description: Places the TLC151x/TLC255x in Power Down     */
/*             mode or in Normal(Powered Up) Mode.          */
/*Input: Data Converter Object                              */
/*Output: None                                              */
/*Note:  bDown=0 Powerdown - write TLC151X_SWPD to ADC	    */
/*       bDown=1 Power Up - Configure ADC 	                */
/************************************************************/
void tlc151x_power(void *pDC, int bDown)
{ 
    if (bDown) 
        MCBSP_Write(((TTLC151X *)pDC)->serial->hMcbsp, TLC151X_SWPD);
    else
        tlc151x_configure(pDC); 
 	
}          

/************************************************************/
/*Function:      tlc151x_read()                             */
/*Description:   Reads from McBSP Receive Register          */
/*Input:         Data Converter Object                      */
/*Output:        Read value from McBSP receive register DRR1*/
/*Note:          None                                       */
/************************************************************/
long tlc151x_read(void *pDC)
{  
   if (!pDC) return 0;
   return MCBSP_Read(((TTLC151X *) pDC)->serial->hMcbsp); 

}      
                                   
/************************************************************/
/*Function:       tlc151x_write()                           */
/*Description:    Write Word to McBSP Transmit Register     */
/*Input:          Data Converter Object                     */
/*                lData to Write to ADC                     */
/*Output:         Read value from ADC                       */
/*Note:           Suggest calling dc_read() following       */
/*    dc_read(), ensures conversion cycle sychronization.   */
/************************************************************/
void tlc151x_write(void *pDC, long lData)
{          
   if (!pDC) return;
   MCBSP_Write(((TTLC151X *) pDC)->serial->hMcbsp, lData);
   return;
}      


/************************************************************/
/*	isr, called upon end of read block                      */
/************************************************************/
interrupt void tlc151x_isr(void)
{                              
    if (tlc151x_rcallback)
        tlc151x_rcallback(0);
}     
                                                                           
/************************************************************/
/*Function:     tlc151x_rblock()                            */
/*Description:  Configures the ADC, DMA and triggers first	*/
/*      conversion cycle.  Then DMA channels collect ulCount*/
/*      number of samples.  Enable DMAC2 in IMR, and map    */
/*      tlc151x_isr() as ISR for DMAC2.			            */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/*Note: Configuration Word MUST set ADC configuration word  */
/*      for Single Shot Mode BEFORE calling this function	*/
/*      The Channel to be coverted is specified by user in	*/
/*      the data converter object(pTLV->command) as well.	*/
/************************************************************/
void tlc151x_rblock(void *pDC, void *pData, 
                    unsigned long ulCount, void (*callback) (void *))
{
    TTLC151X *pTLC = pDC;

    if (!pDC)
        return;
	
    tlc151x_configure(pTLC);  /*Configure ADC for single shot mode*/


/*	flush MCBSP receive register */
    if (MCBSP_Rfull(pTLC->serial->hMcbsp))
        MCBSP_Read(pTLC->serial->hMcbsp);  

/*	Set up DMA Channel which stores samples*/
/*	setup DMA transfer */
/*	source = MCBSP receive register */ 
    *(unsigned int *) DMSA	= DMSRC2;
    switch (pTLC->serial->port)
    {  
    case 0:
        *(unsigned int *) DMSDN	= 0x0021; 	/*MCBSP0_DRR1*/
        break;
    case 1: 
        *(unsigned int *) DMSDN	= 0x0041; 	/*MCBSP1_DRR1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x0031; 	/*MCBSP2_DRR1*/
        break;
    }

    /* destination = data space at uiAddress + 1 */
    *(unsigned int *) DMSA	= DMDST2;
    *(unsigned int *) DMSDN	= (unsigned int) pData;    
    /* transfer uiCount number of words for each */
    *(unsigned int *) DMSA	= DMCTR2;
    *(unsigned int *) DMSDN	= ulCount - 1; 
    /* McBSP Receive Event sync, one frame */
    *(unsigned int *) DMSA	= DMSFC2;
    switch (pTLC->serial->port)
    {  
    case 0:
        *(unsigned int *) DMSDN	= 0x1000;   /*McBSP0 REVT0*/
        break;                             	
    case 1: 
        *(unsigned int *) DMSDN	= 0x5000;   /*McBSP1 REVT1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x3000;   /*McBSP2 REVT2*/
        break;
    }	
	
    /*Transfer Mode Control Register*/
    *(unsigned int *) DMSA	= DMMCR2; /*Interrupt after block transfer*/
    *(unsigned int *) DMSDN	= 0x4005; /*Postincrement destination address*/
                                        /*Destination address in data space*/

    /* setup DMA transfer */
    /* source = ADC command  */    
    *(unsigned int *) DMSA	= DMSRC1;
    *(unsigned int *) DMSDN	= (unsigned int)&(pTLC->command);
    /* destination =  McBSP Transmit Register*/   
    *(unsigned int *) DMSA	= DMDST1;
    switch (pTLC->serial->port)
    {
    case 0:
        *(unsigned int *) DMSDN	= 0x0023; /*MCBSP0_DXR1*/
        break;
    case 1: 
        *(unsigned int *) DMSDN	= 0x0043; /*MCBSP1_DXR1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x0033; /*MCBSP2_DXR1*/
        break;
    }

    /* transfer uiCount number of words*/
    *(unsigned int *) DMSA	= DMCTR1;
    *(unsigned int *) DMSDN	= ulCount - 1;

    /* DMA sync with INT3 event, one frame */
    *(unsigned int *) DMSA	= DMSFC1;
    *(unsigned int *) DMSDN	= 0xE000;
	
    *(unsigned int *) DMSA	= DMMCR1;
    *(unsigned int *) DMSDN	= 0x4000;  /*interrupt generated after block transfer*/

    /*set DMA priority and start */	    
    *(unsigned int *) DMAPREC = 0x8686;	/* DMA transfers regardless of whether emulation stops */
    									/* CH1 & CH2 has high priority, enable CH1 and CH2 */
    									/* Interrupts are multiplex per 'c5402 assignments.	*/
    									/* INT0SEL=10b */

/*	flush MCBSP receive register */
    if (MCBSP_Rfull(pTLC->serial->hMcbsp))
        MCBSP_Read(pTLC->serial->hMcbsp);  

    /*Trigger first conversion cycle*/
    tlc151x_write(pTLC, pTLC->command);	    	/*First Value in Data Table is invalid*/
    tlc151x_read(pTLC);							

    HWI_enable();
    IMR |= 0x0400;                    /* unmask interrupt #10  (DMAC2) */

    tlc151x_rcallback = callback;
}   

/************************************************************/
/*Function:     tlc151x_wblock()                            */
/*Description:   Empty Function								*/
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/*Note:   None                                              */
/************************************************************/
void tlc151x_wblock(void *pDC, void *pData, 
                    unsigned long ulCount, void (*callback) (void *))
{
}

