/****************************************************************/
/* TLV1570 driver for C5400                                     */
/* $Revision:: 3 $                      $JustDate:: 23.10.00  $ */
/****************************************************************/
#ifndef T1570_FN_H
#define T1570_FN_H

/* needs the 2.0 API definition! */
#include "TIDC_API.h"

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0                  */
/****************************************************************/
typedef union
{
    unsigned int value;
    struct
    {
        unsigned int chsel        :3;	    
        unsigned int modesel      :1; 	  
        unsigned int swpdwn       :1; 	  
        unsigned int clksel       :1; 	  
        unsigned int progeoc      :1; 	  
        unsigned int startsel     :1; 	  
    } control_bit;
} TLV1570CREG;


/****************************************************************/
/* STRUCTURE DEFINITION FOR DEVICE                              */
/****************************************************************/
typedef struct
{   
    TTIDC           f;         /* common functions */
    void(*CallBack) (void *);  /* CallBack function */
    DCP_SERIAL*     serial;    /* Pointer to serial port object */
    TLV1570CREG     creg;      /* Control register value */  
} TTLV1570;

/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* data converter API function prototypes                       */
/****************************************************************/
TTIDCSTATUS tlv1570_configure(void *pDC);
void tlv1570_power(void *pDC, int bDown);
long tlv1570_read(void *pDC);
void tlv1570_write(void *pDC, long lData);
void tlv1570_rblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *));
void tlv1570_wblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *));


/****************************************************************/
/* TLV1570 macros for Cconfiguration register                   */
/* see datasheet for examples                                   */
/****************************************************************/ 				  
#define TLV1570_DSWPDN	   (0x0000)    // normal mode-disable SWPD
#define TLV1570_ESWPDN	   (0x8000)    // software power down
#define TLV1570_NRML       (0x0000)    // normal mode
#define TLV1570_RCFR       (0x4000)    // read CFR
#define TLV1570_NRMLAIN    (0x0000)    // AIN come in normally
#define TLV1570_REFVREF	   (0x2000)    // apply (vref)/2 to AIN
#define TLV1570_REFAGND    (0x1000)    // apply AGND to AIN
#define TLV1570_HSPEED     (0x0000)    // high speed
#define TLV1570_LSPEED     (0x0800)    // low speed
#define TLV1570_EAUTOSCN   (0x0400)    // auto-scan enabled
#define TLV1570_DAUTOSCN   (0x0000)    // auto-scan disable
#define TLV1570_CH0        (0x0000)    // channel 0
#define TLV1570_CH1        (0x0080)    // channel 1
#define TLV1570_CH2        (0x0100)    // channel 2
#define TLV1570_CH3        (0x0180)    // channel 3
#define TLV1570_CH4        (0x0200)    // channel 4
#define TLV1570_CH5        (0x0280)    // channel 5
#define TLV1570_CH6        (0x0300)    // channel 6
#define TLV1570_CH7        (0x0380)    // channel 7
#define TLV1570_CHSWP0     (0x0000)    // sweep ch0,ch1,ch2,ch3,
                                       // ch4,ch5,ch6,ch7
#define TLV1570_CHSWP1     (0x0100)    // sweep ch1,ch3,ch5,ch7
#define TLV1570_CHSWP2     (0x0200)    // sweep ch0,ch2,ch4,ch6
#define TLV1570_CHSWP3     (0x0300)    // sweep ch7,ch6,ch5,ch4,
                                       // ch3,ch2,ch1,ch0
#define TLV1570_AUTOSCN    (0x0000)    // no reset auto-scan
#define TLV1570_RSTAUTO    (0x0080)    // reset auto-scan
#define TLV1570_EXTREF     (0x0000)    // external reference
#define TLV1570_INTREF     (0x0040)    // internal reference
#define TLV1570_23VREF     (0x0000)    // 2.3V internal reference
#define TLV1570_38VREF     (0x0020)    // 3.8V internal reference
#define TLV1570_EAPDWN     (0x0010)    // enable auto powerdown
#define TLV1570_DAPDWN     (0x0000)    // disable auto powerdown
#define TLV1570_5VOPT      (0x0000)    // 5.5V to 3.6V optimizer
#define TLV1570_3VOPT      (0x0008)    // 3.5V to 2.7V optimizer
#define TLV1570_RESV       (0x000)     // reserved
   

#endif /* T1570_FN_H */


        


