/****************************************************************/
/* TLV1570 driver for C5400                                     */
/* $Revision:: 3   $                     $JustDate:: 23.10.00 $ */
/****************************************************************/

#include "t1570_fn.h"
#include "dc_conf.h"	 

/* needs -i <drive>\ti\c5400\dsk\include option */             
#include <regs54xx.h>
#include <std.h>
#include <hwi.h>

#define ADC_INTNUM (0) 

/****************************************************************/
/* DSP FUNCTIONS                                                */
/****************************************************************/
#define DMSA	0x55
#define DMSDN	0x57
#define DMSRC0	0x00
#define DMDST0	0x01
#define DMCTR0	0x02
#define DMSFC0	0x03
#define DMMCR0	0x04
#define DMSRC1	0x05
#define DMDST1	0x06
#define DMCTR1	0x07
#define DMSFC1	0x08
#define DMMCR1	0x09
#define DMSRC2	0x0A
#define DMDST2	0x0B
#define DMCTR2	0x0C
#define DMSFC2	0x0D
#define DMMCR2	0x0E
#define DMAPREC	0x54
#define DMIDX0	0x20
	 
/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&

/****************************************************************/
/* DSP Functions                                                */
/****************************************************************/
/****************************************************************/
/* IRQ call-back instance                                       */
/****************************************************************/
void (*tlv1570_rcallback) (void *);


/****************************************************************/
/*Function:       tlv1570_configure()                           */
/*Description:    Configure the TLV1571/TLV1578 ADC             */
/*Input:          Data Converter Object                         */
/*Note:           None                                          */
/****************************************************************/

TTIDCSTATUS tlv1570_configure(void *pDC)
{    
    TTLV1570 *pTLV = pDC;

    if (!pTLV)
        return TIDC_ERR_NODEVICE;

    /* open and configure MCBSP, if not done yet */
    if (!pTLV->serial->hMcbsp)
    {
        switch (pTLV->serial->port)
        {
            case 0: pTLV->serial->hMcbsp = MCBSP_Open(MCBSP_DEV0, MCBSP_OPEN_RESET); 
                    break;
            case 1: pTLV->serial->hMcbsp = MCBSP_Open(MCBSP_DEV1, MCBSP_OPEN_RESET); 
                    break;
            case 2: pTLV->serial->hMcbsp = MCBSP_Open(MCBSP_DEV2, MCBSP_OPEN_RESET); 
                    break;
            default: 
                    return TIDC_ERR_MCBSP;
        }               
    }

    MCBSP_ConfigA(pTLV->serial->hMcbsp, &pTLV->serial->sConfig);
    pTLV->serial->sConfig.spcr |= 0x00010001;        
    MCBSP_ConfigA(pTLV->serial->hMcbsp, &pTLV->serial->sConfig);
											
    MCBSP_Write(pTLV->serial->hMcbsp, pTLV->creg.value);
	        	                  
    return TIDC_NO_ERR;
}

/************************************************************/
/*Function: tlv1570_power()                                 */
/*Description: Places the TLV157x in Power Down mode or     */
/*             in Normal(Powered Up) Mode.                  */
/*Input: Data Converter Object                              */
/*Output: None                                              */
/*Note:  bDown=0 Powerdown - write TLV157X_SWPDWN to ADC    */
/*       bDown=1 Power Up - Configure ADC                   */
/************************************************************/
void tlv1570_power(void *pDC, int iDown)
{
    if (iDown) 
        MCBSP_Write(((TTLV1570 *)pDC)->serial->hMcbsp, TLV1570_ESWPDN);
    else
        tlv1570_configure(pDC); 

   return;         
}  


/************************************************************/
/*Function:      tlv1570_read()                             */
/*Description:   Reads from I/O space                       */
/*Input:         Data Converter Object                      */
/*Output:        Value read                                 */
/*Note:          None                                       */
/************************************************************/
long tlv1570_read(void *pDC)
{   
    if (!pDC) return 0;
    return MCBSP_Read(((TTLV1570 *) pDC)->serial->hMcbsp); 
} 
/************************************************************/
/*Function:      tlv1570_write()                            */
/*Description:   Write to I/O space                         */
/*Input:         Data Converter Object                      */
/*Output:        None                                       */
/*Note:          None                                       */
/************************************************************/
void tlv1570_write(void *pDC, long lData)
{   
    if (!pDC) return;
    MCBSP_Write(((TTLV1570 *) pDC)->serial->hMcbsp, lData);
        
}

/************************************************************/
/*	isr, called upon end of read block                    */
/************************************************************/
interrupt void tlv1570_isr(void)
{                              
    if (tlv1570_rcallback)
        tlv1570_rcallback(0);
}     
 

/************************************************************/
/*Function:     tlv1570_rblock()                            */
/*Description:  Configures the ADC and triggers first	      */
/*      conversion cycle in Software start Conversion Mode. */
/*      Input values are storaged in gTLV1578Globals        */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/************************************************************/
void tlv1570_rblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{  
    TTLV1570 *pTLV = pDC;

    if (!pDC)
        return;
	
    tlv1570_configure(pTLV);	  			/*Configure ADC for single shot mode*/

/*	flush MCBSP receive register */
    if (MCBSP_Rfull(pTLV->serial->hMcbsp))
        MCBSP_Read(pTLV->serial->hMcbsp);  

/*	Set up DMA Channel which stores samples*/
/*	setup DMA transfer */
/*	source = MCBSP receive register */ 
    *(unsigned int *) DMSA	= DMSRC2;
    switch (pTLV->serial->port)
    {  
    case 0:
        *(unsigned int *) DMSDN	= 0x0021; 	/*MCBSP0_DRR1*/
        break;
    case 1: 
        *(unsigned int *) DMSDN	= 0x0041; 	/*MCBSP1_DRR1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x0031; 	/*MCBSP2_DRR1*/
        break;
    }

    /* destination = data space at uiAddress + 1 */
    *(unsigned int *) DMSA	= DMDST2;
    *(unsigned int *) DMSDN	= (unsigned int) pData;    
    /* transfer uiCount number of words for each */
    *(unsigned int *) DMSA	= DMCTR2;
    *(unsigned int *) DMSDN	= ulCount - 1; 
    /* McBSP Receive Event sync, one frame */
    *(unsigned int *) DMSA	= DMSFC2;
    switch (pTLV->serial->port)
    {  
    case 0:
        *(unsigned int *) DMSDN	= 0x1000;   /*McBSP0 REVT0*/
        break;                             	
    case 1: 
        *(unsigned int *) DMSDN	= 0x5000;   /*McBSP1 REVT1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x3000;   /*McBSP2 REVT2*/
        break;
    }	
	
    /*Transfer Mode Control Register*/
    *(unsigned int *) DMSA	= DMMCR2;  /*Interrupt after block transfer*/
    *(unsigned int *) DMSDN	= 0x4005;  /*Postincrement destination address*/
                                         /*Destination address in data space*/

    /* setup DMA transfer */
    /* source = ADC command  */    
    *(unsigned int *) DMSA	= DMSRC1;
    *(unsigned int *) DMSDN	= (unsigned int)&(pTLV->creg.value);
    /* destination =  McBSP Transmit Register*/   
    *(unsigned int *) DMSA	= DMDST1;
    switch (pTLV->serial->port)
    {
    case 0:
        *(unsigned int *) DMSDN	= 0x0023; /*MCBSP0_DXR1*/
        break;
    case 1: 
        *(unsigned int *) DMSDN	= 0x0043; /*MCBSP1_DXR1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x0033; /*MCBSP2_DXR1*/
        break;
    }

    /* transfer uiCount number of words*/
    *(unsigned int *) DMSA	= DMCTR1;
    *(unsigned int *) DMSDN	= ulCount - 1;

    /* DMA sync with XEVT event, one frame */
    *(unsigned int *) DMSA	= DMSFC1;
    switch (pTLV->serial->port)
    {  
    case 0:
        *(unsigned int *) DMSDN	= 0x2000;   /*McBSP0 XEVT0*/
        break;                             	
    case 1: 
        *(unsigned int *) DMSDN	= 0x6000;   /*McBSP1 XEVT1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x4000;   /*McBSP2 XEVT2*/
        break;
    }	
    *(unsigned int *) DMSA	= DMMCR1;
    *(unsigned int *) DMSDN	= 0x4000; /*interrupt generated after block transfer*/

    /*set DMA priority and start */	    
    *(unsigned int *) DMAPREC = 0x8686; /* DMA transfers regardless of whether emulation stops */
                                        /* CH1 & CH2 has high priority, enable CH1 and CH2 */
                                        /* Interrupts are multiplex per 'c5402 assignments.	*/
                                        /* INT0SEL=10b */

/*	flush MCBSP receive register */
    if (MCBSP_Rfull(pTLV->serial->hMcbsp))
        MCBSP_Read(pTLV->serial->hMcbsp);  

    /*Trigger first conversion cycle*/
    tlv1570_write(pTLV, pTLV->creg.value); /*First Value in Data Table is invalid*/
    tlv1570_read(pTLV);							

    HWI_enable();
    IMR |= 0x0400;                    /* unmask interrupt #10 (DMAC2) */

    tlv1570_rcallback = callback;
}

/************************************************************/
/*Function:     tlv1570_wblock()                            */
/*Description:   Empty Function                             */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/*Note:   None                                              */
/************************************************************/
void tlv1570_wblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{
}

