/****************************************************************/
/* TLV1571/78 driver version 1.0 for C5400                      */
/* $Revision: 3 $                      $JustDate: 18.10.00 $ */
/****************************************************************/
#ifndef T157X_FN_H
#define T157X_FN_H

/* needs the 2.0 API definition! */
#include "TIDC_API.h"

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0                  */
/****************************************************************/
typedef union
{
    unsigned int value;
    struct
    {
        unsigned int chsel        :3;	    
        unsigned int modesel      :1; 	  
        unsigned int swpdwn       :1; 	  
        unsigned int clksel       :1; 	  
        unsigned int progeoc      :1; 	  
        unsigned int startsel     :1; 	  
    } control_bit;
} TLV157XCREG0;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 1                  */
/****************************************************************/
typedef union
{
    unsigned int value;
    struct
    {
        unsigned int stest        :2; 	  
        unsigned int readreg      :1; 	  
        unsigned int outcode      :1; 	  
        unsigned int reserved     :2; 	  
        unsigned int oscspd       :1; 	  
        unsigned int reserved1    :1;
    } control_bit;
} TLV157XCREG1;

/****************************************************************/
/* STRUCTURE DEFINITION FOR DEVICE                              */
/****************************************************************/
typedef struct
{   
    TTIDC f;                                /* common functions */
    volatile int *const adc_adr;            /* ADC address      */
    TLV157XCREG0        creg0;
    TLV157XCREG1        creg1;
    unsigned int        IntNum;                           
    unsigned int        data_shift; 
    
} TTLV157X;

typedef TTLV157X TTLV1571;
typedef TTLV157X TTLV1578;

typedef struct
{
    unsigned int iuNumSamples;             /* size of DataTable */
    unsigned int iuCount;                /* index for DataTable */
    unsigned int *piuDataTable;                 /* Sample Table */
    void (*tlv157x_rcallback) (void *);
} DcpGlobals;

extern DcpGlobals gTLV1578Globals;

/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

extern DcpGlobals gTLV1578Globals;

/****************************************************************/
/* data converter API function prototypes                       */
/****************************************************************/
TTIDCSTATUS tlv157x_configure(void *pDC);
void tlv157x_power(void *pDC, int bDown);
long tlv157x_read(void *pDC);
void tlv157x_write(void *pDC, long lData);
void tlv157x_rblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *));
void tlv157x_wblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *));



/****************************************************************/
/* TLV157x MACORS FOR BIT FIELD DEFINITIONS                     */
/****************************************************************/
/* TLV157x macros for control register zero integer assignments */
/* of the control register                                      */
/****************************************************************/ 

#define TLV157X_CH0             (0x000)
#define TLV157X_CH1             (0x001)
#define TLV157X_CH2             (0x002)
#define TLV157X_CH3             (0x003)
#define TLV157X_CH4             (0x004)
#define TLV157X_CH5             (0x005)
#define TLV157X_CH6             (0x006)
#define TLV157X_CH7             (0x007)
#define TLV157X_SINGLECHAN      (0x000)
#define TLV157X_SWEEPCHAN       (0x008)
#define TLV157X_NORMAL          (0x000)
#define TLV157X_SWPDWN          (0x010)
#define TLV157X_INTCLK          (0x000)
#define TLV157X_EXTCLK          (0x020)
#define TLV157X_INT             (0x000)
#define TLV157X_EOC             (0x040)
#define TLV157X_CSTARTMODE      (0x000)
#define TLV157X_SOFTWAREMODE    (0x080)

/***************************************************************/ 

#endif /* T157X_FN_H */


        


