/****************************************************************/
/* TLV1571/TLV1578 driver version 1.00 for C5400                */
/* $Revision: 2 $                      $JustDate: 21.09.00 $ */
/****************************************************************/

#include "t157x_fn.h"
#include "dc_conf.h"	 

/* needs -i <drive>\ti\c5400\dsk\include option */              
#include <std.h>
#include <hwi.h>   
#include <regs54xx.h>

#define ADC1_INTNUM (0) 
	 
/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&

DcpGlobals gTLV1578Globals;


/****************************************************************/
/* DSP Functions                                                */
/****************************************************************/

/****************************************************************/
/*Function:       tlv157x_configure()                           */
/*Description:    Configure the TLV1571/TLV1578 ADC             */
/*Input:          Data Converter Object                         */
/*Note:           None                                          */
/****************************************************************/

TTIDCSTATUS tlv157x_configure(void *pDC)
{    
    TTLV157X *pTLV = pDC; 
    
    /*Function assume data converter is selected*/
    /* write word into control register 1 */
    PORTADDR= pTLV->creg0.value << pTLV->data_shift ;		
    
    /* write CR1 register word into control register 1 */
    PORTADDR= (pTLV->creg1.value | 0x0100 ) << pTLV->data_shift;
   
    return 0;
}

/************************************************************/
/*Function: tlv157x_power()                                 */
/*Description: Places the TLV157x in Power Down mode or     */
/*             in Normal(Powered Up) Mode.                  */
/*Input: Data Converter Object                              */
/*Output: None                                              */
/*Note:  bDown=0 Powerdown - write TLV157X_SWPDWN to ADC    */
/*       bDown=1 Power Up - Configure ADC                   */
/************************************************************/
void tlv157x_power(void *pDC, int bDown)
{
    TTLV157X *pAdc = pDC;
	
    if (bDown) {                             /*powerdown ADC*/
        PORTADDR = (pAdc->creg0.value | TLV157X_SWPDWN) << pAdc->data_shift;   
    }		                        
    else {                                        /*power up*/
    	  tlv157x_configure(pAdc);
    }
    return;         
}  


/************************************************************/
/*Function:      tlv157x_read()                             */
/*Description:   Reads from I/O space                       */
/*Input:         Data Converter Object                      */
/*Output:        Value read 								*/
/*Note:          None                                       */
/************************************************************/
long tlv157x_read(void *pDC)
{   
    return PORTADDR;
} 
/************************************************************/
/*Function:      tlv157x_write()                            */
/*Description:   Write to I/O space                         */
/*Input:         Data Converter Object                      */
/*Output:        None										*/
/*Note:          None                                       */
/************************************************************/
void tlv157x_write(void *pDC, long Data)
{   
    PORTADDR = Data; 
    return;
}

/************************************************************/
/*Function:      tlv157x_isr()                              */
/*Description:   isr used by read block to 					*/
/*       trigger/capture/save data.  After collecting all   */
/*       data, function calls user defined callback function*/
/*Input:         None                                       */
/*Output:        None									    */
/*Note:          None                                       */
/************************************************************/
interrupt void tlv157x_isr(void)
{   
    gTLV1578Globals.piuDataTable[(gTLV1578Globals.iuCount)++] = 
              PORTADDR;   

    if (gTLV1578Globals.iuCount >= gTLV1578Globals.iuNumSamples)
    {  
        if ( gTLV1578Globals.tlv157x_rcallback)
	      gTLV1578Globals.tlv157x_rcallback(0);
    } 

    return;
}

/************************************************************/
/*Function:     tlv157x_rblock()                            */
/*Description:  Configures the ADC and triggers first	    */
/*      conversion cycle in Software start Conversion Mode. */
/*      Input values are storaged in gTLV1578Globals        */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/*Note: Configuration Word MUST set ADC configuration word  */
/*      for Single Channel Mode BEFORE calling this         */
/*      The User is required to map tlv157x_isr as INT0# ISR*/
/*		  tlv157x_isr() reads the specificed number of data */
/*      stores it in *pData, then calls the user callback   */
/*      function.                                           */
/************************************************************/
void tlv157x_rblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{  
    TTLV157X *pAdc = pDC;   
    
    gTLV1578Globals.iuNumSamples =ulCount;
    gTLV1578Globals.iuCount=0;
    gTLV1578Globals.piuDataTable=pData;
      
    tlv157x_configure(pAdc); 
    
    HWI_enable();
    IMR |= 0x0001;   /*Enable INT0# */   
    
    gTLV1578Globals.tlv157x_rcallback = callback;
   
    return; 
}

/************************************************************/
/*Function:     tlv157x_wblock()                            */
/*Description:   Empty Function								*/
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/*Note:   None                                              */
/************************************************************/
void tlv157x_wblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{
}

