/****************************************************************/
/* TLV2544/48 driver version 2.0 for C5400                      */
/* $Revision: 6 $                         $JustDate: 18.10.00 $ */
/****************************************************************/
#ifndef T254X_FN_H
#define T254x_FN_H

#include "TIDC_API.H"

/****************************************************************/                                                      
/* STRUCTURE DEFINITION FOR CONTROL REGISTER                    */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int trig               :2;
          unsigned int eoc                :1;
          unsigned int sweep              :2;
          unsigned int mode               :2;
          unsigned int src                :2;
          unsigned int period             :1;
          unsigned int refvolt            :1;
          unsigned int ref                :1;
          unsigned int reserved           :4;
      } control_bit;
} TLV254xCREG;                                                

/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/
typedef struct
{
    TTIDC f;                        /* common functions */
    void(*CallBack)    (void *);    /* CallBack function */
    unsigned int *     BufferAddr;  /* buffer address */
    DCP_SERIAL*        serial;      /* Pointer to the serial port config object */
    unsigned int       command;
    TLV254xCREG        creg;
    unsigned int       EventId;     /* sync event number */
} TTLV254X;

typedef TTLV254X TTLV2544;
typedef TTLV254X TTLV2548;

/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* TLV254x API 2.0 functions                                    */
/****************************************************************/
TTIDCSTATUS tlv254x_configure(void *pDC);
void tlv254x_power(void *pDC, int bDown);
long tlv254x_read(void *pDC);
void tlv254x_write(void *pDC, long lData);
void tlv254x_rblock(void *pDC, void *pData, 
                    unsigned long ulCount, 
                    void (*callback) (void *));
void tlv254x_wblock(void *pDC, void *pData, 
                    unsigned long ulCount, 
                    void (*callback) (void *));

/****************************************************************/
/* TLV254x MACORS FOR BIT FIELD DEFINITIONS                     */
/****************************************************************/
/* TLV254x macros for control registers integer assignments     */
/* of the control register 1                                    */
/****************************************************************/ 

#define TLV254X_TRIG0           (0x1)
#define TLV254X_TRIG1           (0x2)
#define TLV254X_EOC             (0x4)
#define TLV254X_SWEEP0          (0x8)
#define TLV254X_SWEEP1          (0x10)
#define TLV254X_MODE0           (0x20)
#define TLV254X_MODE1           (0x40)
#define TLV254X_SRC0            (0x80)
#define TLV254X_SRC1            (0x100)
#define TLV254X_PERIOD          (0x200)
#define TLV254X_REFVOLT         (0x400)
#define TLV254X_REF             (0x800)

/****************************************************************/
/* TLV254x macros for Command Set                               */
/* see datasheet for examples                                   */
/****************************************************************/ 
#define TLV2544_INP0	(0x0)			// 2544 chan 0
#define TLV2544_INP1	(0x2000)		// 2544 chan 1
#define TLV2544_INP2	(0x4000)		// 2544 chan 2
#define TLV2544_INP3	(0x6000)		// 2544 chan 3
#define TLV2548_INP0	(0x0)			// 2548 chan 0
#define TLV2548_INP1	(0x1000)		// 2548 chan 1
#define TLV2548_INP2	(0x2000)		// 2548 chan 2
#define TLV2548_INP3	(0x3000)		// 2548 chan 3
#define TLV2548_INP4	(0x4000)		// 2548 chan 4
#define TLV2548_INP5	(0x5000)		// 2548 chan 5
#define TLV2548_INP6	(0x6000)		// 2548 chan 6
#define TLV2548_INP7	(0x7000)		// 2548 chan 7
#define TLV254X_SWPD	(0x8000)		// software power down
#define TLV254X_RCFR	(0x9000)		// read CFR
#define TLV254X_WCFR	(0xA000)		// write CFR (or with data!)
#define TLV254X_REF2	(0xB000)		// select test (refp+refm)/2
#define TLV254X_REFM	(0xC000)		// select test refm
#define TLV254X_REFD	(0xD000)		// select test refp
#define TLV254X_FFRD	(0xE000)		// read FIFO
#define TLV254X_RESV	(0xF000)		// reserved?

/***************************************************************/ 
/*TLV2548 Configuration Register Bits                          */
/***************************************************************/ 
#define INT_AFTER_8     0x000		/*FIFO Triggers after all 8 levels filled	*/
#define INT_AFTER_6     0x001		/*FIFO Triggers after 6 levels filled	*/
#define INT_AFTER_4     0x002		/*FIFO Triggers after 4 levels filled	*/
#define INT_AFTER_2     0x003		/*FIFO Triggers after 2 levels filled	*/

#define INT_EOC         0x01 << 2	/*EOC/INT pin to function as INT#		*/
#define INT_INT0        0x00 << 2   /*EOC/INT pin to function as EOC		*/

#define SWEEP_8_CH      0 << 3      /*Sweep Auto Sequence 00={0,1,2,3,4,5,6,7}*/
#define SWEEP_4_CH      1 << 3      /*Sweep Auto Sequence 01={0,2,4,6,0,2,4,6}*/
#define SWEEP_2x4_CH    2 << 3      /*Sweep Auto Sequence 10={0,0,2,2,4,4,6,6}*/
#define SWEEP_2_CH      3 << 3      /*Sweep Auto Sequence 11={0,2,0,2,0,2,0,2}*/

#define SINGLE_SHOT     0 << 5      /*Conversion Mode= Single Shot		*/
#define REPEAT_MODE     1 << 5      /*Conversion Mode= Repeat Mode		*/
#define SWEEP_MODE      2 << 5      /*Conversion Mode= Sweep  Mode		*/
#define REPEAT_SWEEP    3 << 5      /*Conversion Mode= Repeat Sweep Shot	*/

#define CONV_INT_OSC    0 << 7      /*Conversion Clock Source = Internal OSC	*/
#define CONV_SCLK	      1 << 7      /*Conversion Clock Source = SCLK		*/
#define CONV_SCLK_DIV_2	2 << 7      /*Conversion Clock Source = SCLK/2		*/
#define CONV_SCLK_DIV_4 3 << 7      /*Conversion Clock Source = SCLK/4		*/

#define SHORT_SAMPLING  0 << 9      /*Short Sampling Period, sample for 12 SCLKs*/
#define LONG_SAMPLING   1 << 9      /*Long  Sampling Period, sample for 24 SCLKs*/

#define REF_2V          1 << 10     /*Internal Reference voltage set to 2 Volts*/
#define REF_4V          0 << 10     /*Internal Reference voltage set to 4 Volts*/

#define EXT_REF_SEL     0 << 11     /*Choose to use External Reference 		*/
#define INT_REF_SEL     1 << 11     /*Choose to use Internal Reference 		*/



#endif /* T254X_FN_H */
