/****************************************************************/
/* TLV2541/42/45 and TLC2551/52/55 driver for C5400             */
/* also for ADS8320 and TLV1572                                 */
/* $Revision:: 3   $                     $JustDate:: 21.11.00 $ */
/****************************************************************/

#include "t25xx_fn.h"
#include "dc_conf.h"	 

//#define ADC_INTNUM (0) 
	 
/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&

/****************************************************************/
/* DSP Functions                                                */
/****************************************************************/


/****************************************************************/
/*Function:       multi_adc_configure()                         */
/*Description:    Configure the McBSP                           */
/*Input:          Data Converter Object                         */
/*Note:           None                                          */
/****************************************************************/
TTIDCSTATUS multi_adc_configure(void *pDC)
{    
	TTLC25XX *pTLC = pDC;

	if (!pTLC)
		return TIDC_ERR_NODEVICE;

	/*	open and configure MCBSP, if not done yet */
	if (!pTLC->serial->hMcbsp)
	{
		switch (pTLC->serial->port)
		{
		case 0: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV0, MCBSP_OPEN_RESET); break;
		case 1: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV1, MCBSP_OPEN_RESET); break;
		case 2: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV2, MCBSP_OPEN_RESET); break;
		default: return TIDC_ERR_MCBSP;
		}               
	}

	MCBSP_ConfigA(pTLC->serial->hMcbsp, &pTLC->serial->sConfig);
	pTLC->serial->sConfig.spcr	|= 0x00010001;        
	MCBSP_ConfigA(pTLC->serial->hMcbsp, &pTLC->serial->sConfig);

	
	return TIDC_NO_ERR;
}

/************************************************************/
/*Function: multi_adc_power()                               */
/*Description:   N/A                                        */
/*Input: Data Converter Object                              */
/*Output: None                                              */
/*Note:  bDown=0 Powerdown                                  */
/*       bDown=1 Power Up                                   */
/************************************************************/
void multi_adc_power(void *pDC, int bDown)
{
    return;         
}  

/************************************************************/
/*Function:      multi_adc_read()                           */
/*Description:   Reads from McBSP receive data register     */
/*Input:         Data Converter Object                      */
/*Output:        Value read                                 */
/*Note:          Does not check to see whether Receiver     */
/*              is ready with new data.                     */
/************************************************************/
long multi_adc_read(void *pDC)
{   
   	if (!pDC) return 0;
	return MCBSP_Read(((TTLC25XX *) pDC)->serial->hMcbsp);
} 
/************************************************************/
/*Function:      multi_adc_write()                          */
/*Description:   Write to McBSP Transmit Data Register      */
/*Input:         Data Converter Object                      */
/*Output:        None                                       */
/*Note:          Does not check to see whether transmitter  */
/*              is ready for new data.                      */
/************************************************************/
void multi_adc_write(void *pDC, long lData)
{   
	if (!pDC) return;
	MCBSP_Write(((TTLC25XX *) pDC)->serial->hMcbsp, lData);
	return;
}


/************************************************************/
/*Function:     multi_adc_rblock()                          */
/*Description:  Empty Function                              */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/************************************************************/
void multi_adc_rblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{  
    return; 
}

/************************************************************/
/*Function:     multi_adc_wblock()                          */
/*Description:   Empty Function                             */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/*Note:   None                                              */
/************************************************************/
void multi_adc_wblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{
}

