/****************************************************************/
/* TLC2574/74, TLC3544/48/74/78 driver for C5400                */
/* $Revision:: 2 $                      $JustDate:: 13.11.00  $ */
/****************************************************************/
#ifndef T35XX_FN_H
#define T35XX_FN_H

/* needs the 2.0 API definition! */
#include "TIDC_API.h"

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0                  */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int trig               :2;
          unsigned int eoc                :1;
          unsigned int sweep              :2;
          unsigned int conv_mode          :2;
          unsigned int input_mode         :1;
          unsigned int clk_src            :1;
          unsigned int sample             :1;
	    unsigned int format             :1;
	    unsigned int ref                :1;
      } control_bit;
} TLC35XXCREG;               

/****************************************************************/
/* STRUCTURE DEFINITION FOR DEVICE                              */
/****************************************************************/
typedef struct
{   
    TTIDC            f;           /* common functions */
    void(*CallBack)  (void *);    /* CallBack function */
    unsigned int *   BufferAddr;  /* Basisaddress buffer */
    DCP_SERIAL*      serial;      /* Pointer to serial port object */
    unsigned int     command;     /* Command value */
    TLC35XXCREG      creg;        /* Control register value */  
} TTLC35XX;

typedef TTLC35XX TTLC3544;     /* unique type naming  */
typedef TTLC35XX TTLC3548;     /* one for each device */
typedef TTLC35XX TTLC3574;
typedef TTLC35XX TTLC3578;
typedef TTLC35XX TTLC2574;
typedef TTLC35XX TTLC2578;

/****************************************************************/
/* define external DC address pointer(s)                        */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* data converter API function prototypes                       */
/* supports all 6 devices                                       */
/****************************************************************/
TTIDCSTATUS tlc35xx_configure(void *pDC);
void tlc35xx_power(void *pDC, int bDown);
long tlc35xx_read(void *pDC);
void tlc35xx_write(void *pDC, long lData);
void tlc35xx_rblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *));
void tlc35xx_wblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *));

/****************************************************************/
/* TLC35XX macros for Command Set                               */
/* see datasheet for examples                                   */
/****************************************************************/ 
#define TLC35XX_INP0	(0x0)			// 3574/44 chan 0
#define TLC35XX_INP1	(0x1000)		// 3574/44 chan 1
#define TLC35XX_INP2	(0x2000)		// 3574/44 chan 2
#define TLC35XX_INP3	(0x3000)		// 3574/44 chan 3
#define TLC35XX_INP0	(0x0)			// 3578/48 chan 0
#define TLC35XX_INP1	(0x1000)		// 3578/48 chan 1
#define TLC35XX_INP2	(0x2000)		// 3578/48 chan 2
#define TLC35XX_INP3	(0x3000)		// 3578/48 chan 3
#define TLC35XX_INP4	(0x4000)		// 3578/48 chan 4
#define TLC35XX_INP5	(0x5000)		// 3578/48 chan 5
#define TLC35XX_INP6	(0x6000)		// 3578/48 chan 6
#define TLC35XX_INP7	(0x7000)		// 3578/48 chan 7
#define TLC35XX_SWPD	(0x8000)		// software power down
#define TLC35XX_RCFR	(0x9000)		// read CFR
#define TLC35XX_WCFR	(0xA000)		// write CFR (or with data!)
#define TLC35XX_REF2	(0xB000)		// select test (refp+refm)/2
#define TLC35XX_REFM	(0xC000)		// select test refm
#define TLC35XX_REFD	(0xD000)		// select test refp
#define TLC35XX_FFRD	(0xE000)		// read FIFO
#define TLC35XX_RESV	(0xF000)		// reserved?

#endif /* T35XX_FN_H */
    
        


