/****************************************************************/
/* TLC2574/74, TLC3544/48/74/78 driver for C5400                */
/* $Revision:: 2   $                     $JustDate:: 13.11.00 $ */
/****************************************************************/

#include "t35xx_fn.h"
#include "dc_conf.h"	 
/* needs -i <drive>\ti\c5400\dsk\include option */             
#include <regs54xx.h>
#include <std.h>
#include <hwi.h>

#define ADC_INTNUM (0) 
	 
/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&

/****************************************************************/
/* DSP FUNCTIONS                                                */
/****************************************************************/
#define DMSA	0x55
#define DMSDN	0x57
#define DMSRC0	0x00
#define DMDST0	0x01
#define DMCTR0	0x02
#define DMSFC0	0x03
#define DMMCR0	0x04
#define DMSRC1	0x05
#define DMDST1	0x06
#define DMCTR1	0x07
#define DMSFC1	0x08
#define DMMCR1	0x09
#define DMSRC2	0x0A
#define DMDST2	0x0B
#define DMCTR2	0x0C
#define DMSFC2	0x0D
#define DMMCR2	0x0E
#define DMAPREC	0x54
#define DMIDX0	0x20


/****************************************************************/
/* IRQ call-back instance                                       */
/****************************************************************/
void (*tlc35xx_rcallback) (void *);

/****************************************************************/
/*Function:       tlc35xx_configure()                           */
/*Description:    Configure McBSP and the ADC                   */
/*Input:          Data Converter Object                         */
/*Note:           None                                          */
/****************************************************************/

TTIDCSTATUS tlc35xx_configure(void *pDC)
{    
	TTLC35XX *pTLC = pDC;

	if (!pTLC)
		return TIDC_ERR_NODEVICE;

	/*	open and configure MCBSP, if not done yet */
	if (!pTLC->serial->hMcbsp)
	{
		switch (pTLC->serial->port)
		{
		case 0: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV0, MCBSP_OPEN_RESET); break;
		case 1: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV1, MCBSP_OPEN_RESET); break;
		case 2: pTLC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV2, MCBSP_OPEN_RESET); break;
		default: return TIDC_ERR_MCBSP;
		}               
	}

	MCBSP_ConfigA(pTLC->serial->hMcbsp, &pTLC->serial->sConfig);
	pTLC->serial->sConfig.spcr	|= 0x00010001;        
	MCBSP_ConfigA(pTLC->serial->hMcbsp, &pTLC->serial->sConfig);
									
	MCBSP_Write(pTLC->serial->hMcbsp, pTLC->creg.value | TLC35XX_WCFR);
	
	return TIDC_NO_ERR;
}

/************************************************************/
/*Function: tlc35xx_power()                                 */
/*Description: Places the TLC25xx/TLC35xx in Power Down mode*/
/*        or in Normal(Powered Up) Mode.                    */
/*Input:  Data Converter Object                             */
/*Output: None                                              */
/*Note:  bDown=0 Powerdown - write TLV254X_SWPD to ADC      */
/*       bDown=1 Power Up - Configure ADC 	            */
/************************************************************/

void tlc35xx_power(void *pDC, int bDown)
{
    if (bDown) 
        MCBSP_Write(((TTLC35XX *)pDC)->serial->hMcbsp, TLC35XX_SWPD);
    else
        tlc35xx_configure(pDC);        
}  


/************************************************************/
/*Function:      tlc35xx0_read()                            */
/*Description:   Reads from McBSP register data register    */
/*Input:         Data Converter Object                      */
/*Output:        Value read                                 */
/*Note:          Does not check to see whether receiver is  */
/*              ready with new data.                        */
/************************************************************/

long tlc35xx_read(void *pDC)
{   
	if (!pDC) return 0;
	return MCBSP_Read(((TTLC35XX *) pDC)->serial->hMcbsp); 
} 

/************************************************************/
/*Function:      tlc35xx_write()                            */
/*Description:   Write to McBSP Transmit Data Register      */
/*Input:         Data Converter Object                      */
/*Output:        None                                       */
/*Note:          Does not check to see whether transmitter  */
/*              is ready for new data.                      */
/************************************************************/
void tlc35xx_write(void *pDC, long lData)
{   
	if (!pDC) return;
	MCBSP_Write(((TTLC35XX *) pDC)->serial->hMcbsp, lData);
	return;
}

/************************************************************/
/*	isr, called upon end of read block                  */
/************************************************************/

interrupt void tlc35xx_isr(void)
{                              
	if (tlc35xx_rcallback)
		tlc35xx_rcallback(0);
}

/************************************************************/
/*Function:     tlc35xx_rblock()                            */
/*Description:  Function begins by configuring McBSP,       */
/*  configures the ADC for single shot conversion mode, sets*/
/*  up DMAC0 and DMAC1 for transfers.  DMAC0 will interrupt */
/*  the DSP after it's read and stored ALL digital samples. */
/*  After the first conversion cycle is triggered,          */
/*  interrupts enabled, and user callback function is       */
/*  assigned the functions returns.                         */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/************************************************************/
void tlc35xx_rblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{  
	TTLC35XX *pTLC = pDC;

	if (!pDC)
          return;
	/*Configure for Single Shot Conversion Mode*/
 	pTLC->creg.control_bit.conv_mode=0;
	tlc35xx_configure(pTLC);   


      /* flush MCBSP receive register */
	if (MCBSP_Rfull(pTLC->serial->hMcbsp))
		MCBSP_Read(pTLC->serial->hMcbsp);  

      /* Set up DMA Channel which stores samples*/
      /* setup DMA transfer */
      /* source = MCBSP receive register */ 
	*(unsigned int *) DMSA	= DMSRC0;
	switch (pTLC->serial->port)
	{  
	case 0:
		*(unsigned int *) DMSDN	= 0x0021; 	/*MCBSP0_DRR1*/
		break;
	case 1: 
		*(unsigned int *) DMSDN	= 0x0041; 	/*MCBSP1_DRR1*/
		break;
	case 2: 
		*(unsigned int *) DMSDN	= 0x0031; 	/*MCBSP2_DRR1*/
		break;
	}

    /* destination = data space at uiAddress + 1 */
    *(unsigned int *) DMSA	= DMDST0;
    *(unsigned int *) DMSDN	= (unsigned int) pData;    
    /* transfer uiCount number of words for each */
    *(unsigned int *) DMSA	= DMCTR0;
    *(unsigned int *) DMSDN	= ulCount - 1; 
    /* McBSP Receive Event sync, one frame */
    *(unsigned int *) DMSA	= DMSFC0;
    switch (pTLC->serial->port)
    {  
    case 0:
        *(unsigned int *) DMSDN	= 0x1000;   /*McBSP0 REVT0*/
        break;                             	
    case 1: 
        *(unsigned int *) DMSDN	= 0x5000;   /*McBSP1 REVT1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x3000;   /*McBSP2 REVT2*/
        break;
    }	
	
	/*Transfer Mode Control Register*/
    *(unsigned int *) DMSA	= DMMCR0; 	/*Interrupt after block transfer*/
    *(unsigned int *) DMSDN	= 0x4005;   /*Postincrement destination address*/
                                          /*Destination address in data space*/

    /* setup DMA transfer */
    /* source = ADC command  */    
    *(unsigned int *) DMSA	= DMSRC1;
    *(unsigned int *) DMSDN	= (unsigned int)&(pTLC->command);
    /* destination =  McBSP Transmit Register*/   
    *(unsigned int *) DMSA	= DMDST1;
    switch (pTLC->serial->port)
    {
    case 0:
        *(unsigned int *) DMSDN	= 0x0023; /*MCBSP0_DXR1*/
        break;
    case 1: 
        *(unsigned int *) DMSDN	= 0x0043; /*MCBSP1_DXR1*/
        break;
    case 2: 
        *(unsigned int *) DMSDN	= 0x0033; /*MCBSP2_DXR1*/
        break;
    }

    /* transfer uiCount number of words*/
    *(unsigned int *) DMSA	= DMCTR1;
    *(unsigned int *) DMSDN	= ulCount - 1;

    /* DMA sync with INT3 event, one frame */
    *(unsigned int *) DMSA	= DMSFC1;
    *(unsigned int *) DMSDN	= 0xE000;
	
    *(unsigned int *) DMSA	= DMMCR1;
    *(unsigned int *) DMSDN	= 0x0000;

    /*set DMA priority and start */	    
    *(unsigned int *) DMAPREC = 0x8383;   /* DMA transfers regardless of whether emulation stops */
                                          /* CH1 & CH0 has high priority, enable CH1 and CH0 */
                                          /* Interrupts are multiplex per 'c5402 assignments.	*/
                                          /* INT0SEL=10b */

    /* flush MCBSP receive register */
    if (MCBSP_Rfull(pTLC->serial->hMcbsp))
		MCBSP_Read(pTLC->serial->hMcbsp);  

    /*Trigger first conversion cycle*/
    tlc35xx_write(pTLC, pTLC->command);	    	/*First Value in Data Table is invalid*/
    tlc35xx_read(pTLC);							

    HWI_enable();
    IMR |= 0x0040;                     /* unmask interrupt #6 (DMAC0) */

    tlc35xx_rcallback = callback;
 
}

/************************************************************/
/*Function:     tlc35xx_wblock()                            */
/*Description:   Empty Function                             */
/*Input:  uiAddress:  start address in data space           */
/*        ulCount  :  length of block                       */
/*        callback :  function pointer. will be called upon */
/*                    completion of block transfer          */
/*Output: None                                              */
/*Note:   None                                              */
/************************************************************/
void tlc35xx_wblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{
}

