/****************************************************************/
/* TLV56xx driver version 1.0 for C5400                         */
/* Supports: TLC5617A/18A, TLV5617A/18A, TLV5606/16             */
/*           TLV5623/24/25/26/36/37/38                          */
/* $Revision: 4 $                         $JustDate: 18.10.00 $ */
/****************************************************************/
#ifndef T56XX_FN_H
#define T56XX_FN_H

#include "tidc_api.h"

/****************************************************************/                                                      
/* STRUCTURE DEFINITION FOR SERIAL DATA WORD                    */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int ref           :2;   /* two bit reference */
          unsigned int data          :10;  /* 8-10 bits data    */
          unsigned int r0            :1;   /* channel control 0 */
          unsigned int pwr           :1;   /* power down        */
          unsigned int spd           :1;   /* settling time     */
          unsigned int r1            :1;   /* channel control 1 */
      } control_bit;    /* for DACs with interal reference */
   struct
      {
          unsigned int data          :12;  /* 8-12 bits data    */
          unsigned int r0            :1;   /* channel control 0 */
          unsigned int pwr           :1;   /* power down        */
          unsigned int spd           :1;   /* settling time     */
          unsigned int r1            :1;   /* channel control 1 */
      } control_bit2;  /* for DACs without interal reference */
} TLV56XXDAT;                                                

/****************************************************************/
/* data converter structure definition                          */
/****************************************************************/
typedef struct
{
    TTIDC            f;             /* common functions     */
    void(*CallBack)  (void *);      /* CallBack function    */
    unsigned int *   BufferAddr;    /* Basisaddress buffer  */
    DMA_HANDLE       dc_dma;        /* DMA Handle           */ 
    DCP_SERIAL       *serial;       /* Pointer to the serial port config object */
    unsigned short   refreg;        /* The voltage reference register (0xFFFF if not required) */
    TLV56XXDAT       creg;          /* DAC configuration registar */
} TDAC56XX;

typedef TDAC56XX TDAC5606;
typedef TDAC56XX TDAC5616;
typedef TDAC56XX TDAC5617;
typedef TDAC56XX TDAC5618;
typedef TDAC56XX TDAC5623;
typedef TDAC56XX TDAC5624;
typedef TDAC56XX TDAC5625;
typedef TDAC56XX TDAC5626;
typedef TDAC56XX TDAC5636;
typedef TDAC56XX TDAC5637;
typedef TDAC56XX TDAC5638;

/****************************************************************/
/* define external DC object pointer(s)                         */
/****************************************************************/
&&EXTERN_DEV&&

/****************************************************************/
/* function definitions                                         */
/****************************************************************/
TTIDCSTATUS t56xx_configure(void *pDC);
void t56xx_power(void *pDC, int bDown);
long t56xx_read(void *pDC);
void t56xx_write(void *pDC, long lData);
void t56xx_rblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *));
void t56xx_wblock(void *pDC, void *pData, 
              unsigned long ulCount, void (*callback) (void *)); 
void t56xx_write_done(void *ptD);              

#endif /* T56XX_FN_H */
