/****************************************************************/
/* TLV320AIC10/11 driver version 1.0 for C5400                  */
/* $Revision: 8 $                         $JustDate: 18.10.00 $ */
/****************************************************************/

#ifndef TAIC10_FN_H
#define TAIC10_FN_H

/* needs the new v 2.0 API definition! */
#include "TIDC_API.h"

/****************************************************************/                                                      
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 1                  */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
     {
          unsigned int dac_form      :1;
          unsigned int trx_amps      :1;
          unsigned int byp_fir       :1;
          unsigned int sw_res        :1;
          unsigned int adc_in        :1;
          unsigned int byp_alias     :1;
          unsigned int rcv_amp       :1;
          unsigned int ovf           :1;
          unsigned int reserved      :8;
      } control_bit;
} AIC10CREG1; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 1                     */
/****************************************************************/                                                      

#define AIC10_DAC_16BIT     (0x0001)
#define AIC10_DAC_15BIT     (0x0000)
#define AIC10_TRXAMP_ON     (0x0001)
#define AIC10_TRXAMP_OFF    (0x0000)
#define AIC10_FIR_OFF       (0x0001)
#define AIC10_FIR_ON        (0x0000)
#define AIC10_SWRES_ON      (0x0001)
#define AIC10_SWRES_OFF     (0x0000)
#define AIC10_ADCIN_AUX     (0x0001)
#define AIC10_ADCIN_IN      (0x0000)
#define AIC10_ALIAS_OFF     (0x0001)
#define AIC10_ALIAS_ON      (0x0000)
#define AIC10_RCVAMP_ON     (0x0001)
#define AIC10_RCVAMP_OFF    (0x0000)                                           

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 2                  */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int freq_div           :5;
          unsigned int reserved0          :1;
          unsigned int sdmod              :1;
          unsigned int low_pow            :1;
          unsigned int reserved1          :8;
      } control_bit;
} AIC10CREG2; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 2                     */
/****************************************************************/                                                      

#define AIC10_LOWPOW_ON      (0x0001)
#define AIC10_LOWPOW_OFF     (0x0000)
#define AIC10_SDMOD_STOP     (0x0001)
#define AIC10_SDMOD_RUN      (0x0000)

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 3                  */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int adc_form           :1;
          unsigned int pwconf             :2;
          unsigned int flag_val           :1;
          unsigned int flag_out           :1;
          unsigned int contin             :1;
          unsigned int mode		          :2;
          unsigned int reserved           :8;
      } control_bit;
} AIC10CREG3; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 3                     */
/****************************************************************/                                                      

#define AIC10_MODE_DEFAULT   (0x0000)
#define AIC10_MODE_ANALOOP   (0x0001)
#define AIC10_MODE_DIGLOOP   (0x0002)
#define AIC10_MODE_EVENT     (0x0003)
#define AIC10_DATAC_ON       (0x0001)
#define AIC10_DATAC_OFF      (0x0000)
#define AIC10_FLAG_D3        (0x0001)
#define AIC10_FLAG_SCF       (0x0000)
#define AIC10_CONF_DEFAULT   (0x0000)
#define AIC10_CONF_ADCOFF    (0x0001)
#define AIC10_CONF_DACOFF    (0x0002)
#define AIC10_CONF_POWOFF    (0x0003)
#define AIC10_ADC_16BIT      (0x0001)
#define AIC10_ADC_15BIT      (0x0000)                                           

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 4                  */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int dac_gain           :4;
          unsigned int adc_gain           :4;
          unsigned int reserved           :8;
      } control_bit;
} AIC10CREG4; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 4                     */
/****************************************************************/                                                      

#define AIC10_ADC_MUTE		(0x000F)
#define AIC10_ADC_24DB		(0x000E)
#define AIC10_ADC_18DB		(0x000D)
#define AIC10_ADC_12DB		(0x000C)
#define AIC10_ADC_09DB		(0x000B)
#define AIC10_ADC_06DB		(0x000A)
#define AIC10_ADC_03DB		(0x0009)
#define AIC10_ADC_M03DB		(0x0008)
#define AIC10_ADC_M06DB		(0x0007)
#define AIC10_ADC_M09DB		(0x0006)
#define AIC10_ADC_M12DB		(0x0005)
#define AIC10_ADC_M18DB		(0x0004)
#define AIC10_ADC_M24DB		(0x0003)
#define AIC10_ADC_M30DB		(0x0002)
#define AIC10_ADC_M36DB		(0x0001)
#define AIC10_ADC_00DB		(0x0000)

#define AIC10_DAC_MUTE		(0x000F)
#define AIC10_DAC_24DB		(0x000E)
#define AIC10_DAC_18DB		(0x000D)
#define AIC10_DAC_12DB		(0x000C)
#define AIC10_DAC_09DB		(0x000B)
#define AIC10_DAC_06DB		(0x000A)
#define AIC10_DAC_03DB		(0x0009)
#define AIC10_DAC_M03DB		(0x0008)
#define AIC10_DAC_M06DB		(0x0007)
#define AIC10_DAC_M09DB		(0x0006)
#define AIC10_DAC_M12DB		(0x0005)
#define AIC10_DAC_M18DB		(0x0004)
#define AIC10_DAC_M24DB		(0x0003)
#define AIC10_DAC_M30DB		(0x0002)
#define AIC10_DAC_M36DB		(0x0001)
#define AIC10_DAC_00DB		(0x0000)

/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/

typedef struct
{
    unsigned int       uiID;
    AIC10CREG1         creg1;       /* control regs 1-4 */
    AIC10CREG2         creg2;
    AIC10CREG3         creg3;
    AIC10CREG4         creg4;
} _TAIC10;

typedef struct
{
    TTIDC f;                        /* common functions */
    DCP_SERIAL         *serial;     /* pointer to serial port object */
    unsigned int       uiCount;	/* # of AICs in the chain */
    _TAIC10            devices[8];	/* array of AIC10s in the chain */
} TAIC10;                       

typedef TAIC10 TTLV320AIC10;
typedef TAIC10 TTLV320AIC11;                  

/****************************************************************/
/* data converter API function prototypes                       */
/****************************************************************/
TTIDCSTATUS aic1x2x_configure(void *pDC);
void aic1x2x_power(void *pDC, int bDown);
long aic1x2x_read(void *pDC);
void aic1x2x_write(void *pDC, long lData);
void aic1x2x_rblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *));
void aic1x2x_wblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *));

/****************************************************************/
/* data converter external address definitions                  */
/****************************************************************/
&&EXTERN_DEV&&

#endif /* TAIC10_FN_H */
