/****************************************************************/
/* TLV320AIC10/11 driver version 2.0 for C5400                  */
/* $Revision: 6 $                      $JustDate: 21.09.00 $ */
/****************************************************************/

#undef _INLINE
#include "dc_conf.h"
#include "taic10_fn.h" 
  
/* needs -i <drive>\ti\c5400\dsk\include option */              
#include <std.h>
#include <hwi.h>   
#include <regs54xx.h>

/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&                                                                     
                                  
/****************************************************************/
/* DSP FUNCTIONS                                                */
/****************************************************************/

/* global isr data */
volatile int *pWData = 0;	/* current write block address */
volatile int *pRData = 0;    /* current read block address */
volatile unsigned int uiWCount = 0;  /* write block size */
volatile unsigned int uiRCount = 0;  /* read block size */
volatile int iRxData;		/* last valid read result */
volatile int iWFrame = 0;	/* write isr semaphore */
volatile int iRFrame = 0;	/* read isr semaphore */
void (*aic1x2x_rcallback) (void *); /* pointer to read callback function */
void (*aic1x2x_wcallback) (void *); /* pointer to write callback function */
volatile TAIC10 *piAIC;              		/* current AIC10 device */
volatile int iAIC = -1;               /* current AIC10 # in chain */                                       
volatile unsigned int uiWMask = 0xFFFE; 		/* mask for DAC data */

/****************************************************************/
/*	isr, called upon rx event                                 */
/****************************************************************/
interrupt void aic1x2x_risr(void)
{                                   
	iRxData = MCBSP_Read(piAIC->serial->hMcbsp);
	iRFrame = 1;
	/* synchronize risr with AIC chain */
	if (iRxData & 0x01)
		iAIC = 0; /* current data is from master */
	else           
	{
		if (iAIC < 0)	/* never synchronized ? */
			return;
		iAIC++;			/* next time -> next AIC in chain */
	}

	/* wrap around AIC counter */
	iAIC %= (piAIC->uiCount);

	if (uiRCount) /* if read block in progress, store data */
	{
		*pRData++ = iRxData & 0xFFFE;
		uiRCount--;
		if (!uiRCount && aic1x2x_rcallback) /* if end of block, stop and call call-back function */
			aic1x2x_rcallback(0);       
	}
}

/****************************************************************/
/*	isr, called upon end of write block                       */
/****************************************************************/
interrupt void aic1x2x_tisr(void)
{               
	iWFrame = 1;
	       
	if (uiWCount) /* if write block in progress, send data to AIC */
	{
		MCBSP_Write(piAIC->serial->hMcbsp, *pWData++ & uiWMask); /* mask data according to uiWMask*/
		uiWCount--;
		if (!uiWCount && aic1x2x_wcallback) /* if end of block, stop and call call-back function */
				aic1x2x_wcallback(0);       
	}       
	else
		MCBSP_Write(piAIC->serial->hMcbsp, 0); /* write 0 by default to keep interrupts going */
}

/****************************************************************/
/* reads data from AIC chain until next result is from master AIC */
/* used to synchronize DSP program with AIC10 chain             */
/****************************************************************/
void aic1x2x_wait_for_master(TAIC10 *pDC)
{        
	while (iAIC != pDC->uiCount - 1) {};
}
           
/****************************************************************/
/*	configuration function.                                   */
/*	sets up MCBSP, if required.                               */
/*	writes all configuration data to all AICs in chain        */
/****************************************************************/
TTIDCSTATUS aic1x2x_configure(void *pDC)
{                   
	int i;
	
	TAIC10 *pAIC = pDC;
	
	if (!pAIC)
		return TIDC_ERR_NODEVICE;
		
/* disable McBSP rx, tx interrupts */
	IMR &= !0x0030;
	
/*	open and configure MCBSP, if not done yet */
	if (!pAIC->serial->hMcbsp)
	{
		switch (pAIC->serial->port)
		{
		case 0: pAIC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV0, MCBSP_OPEN_RESET); break;
		case 1: pAIC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV1, MCBSP_OPEN_RESET); break;
		case 2: pAIC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV2, MCBSP_OPEN_RESET); break;
		default: return TIDC_ERR_MCBSP;
		}

		MCBSP_ConfigA(pAIC->serial->hMcbsp, &pAIC->serial->sConfig);
		pAIC->serial->sConfig.spcr	|= 0x00010001; /* enable receiver and transmitter */       
		MCBSP_ConfigA(pAIC->serial->hMcbsp, &pAIC->serial->sConfig);
	}

/*	start background ISRs for read/write block */
	aic1x2x_rcallback = 0;
	aic1x2x_wcallback = 0;
	uiWCount = 0;
	uiRCount = 0;
	piAIC = pAIC;
	IMR |= 0x0030;
	HWI_enable();
	
	MCBSP_Write(pAIC->serial->hMcbsp, 0);
		
/*	start configuration sequence.
	first, as many requests for secondary transfers as AICs in the chain are necessary.
	it must be ensured that the requests start with the master */
	aic1x2x_wait_for_master(pAIC);
                  
    uiWMask = 0xFFFF;	/* enable secondary request bit */

/*	reset AICs in chain */ 
	for (i = 0; i < pAIC->uiCount; i++) 
		aic1x2x_write(pAIC, 1); 
	for (i = pAIC->uiCount - 1; i >= 0; i--)
		aic1x2x_write(pAIC, 0x0200 + 8 + (pAIC->devices[i].uiID << 13));

	aic1x2x_wait_for_master(pAIC);

/*	write creg1 values to all AICs in chain */
	for (i = 0; i < pAIC->uiCount; i++) 
		aic1x2x_write(pAIC, 1);
	for (i = pAIC->uiCount - 1; i >= 0; i--)
		aic1x2x_write(pAIC, 0x0200 + pAIC->devices[i].creg1.value + (pAIC->devices[i].uiID << 13));

/*	write creg2 values to all AICs in chain */
	for (i = 0; i < pAIC->uiCount; i++) 
		aic1x2x_write(pAIC, 1);
	for (i = pAIC->uiCount - 1; i >= 0; i--)
		aic1x2x_write(pAIC, 0x0400 + pAIC->devices[i].creg2.value + (pAIC->devices[i].uiID << 13));

/*	write creg3 values to all AICs in chain */
	for (i = 0; i < pAIC->uiCount; i++) 
		aic1x2x_write(pAIC, 1);
	for (i = pAIC->uiCount - 1; i >= 0; i--)
		aic1x2x_write(pAIC, 0x0600 + pAIC->devices[i].creg3.value + (pAIC->devices[i].uiID << 13));

/*	write creg4 values to all AICs in chain */
	for (i = 0; i < pAIC->uiCount; i++) 
		aic1x2x_write(pAIC, 1);
	for (i = pAIC->uiCount - 1; i >= 0; i--)
		aic1x2x_write(pAIC, 0x0800 + pAIC->devices[i].creg4.value + (pAIC->devices[i].uiID << 13));
    
/*	make sure, that MCBSP puts out 0 to avoid erronous secondary requests */
	aic1x2x_write(pAIC, 0);                                           
	
/*	clear out decimation filter */
	for (i = 0; i < 32 * pAIC->uiCount; i++)
		aic1x2x_read(pAIC);
	
	uiWMask = 0xFFFE;	/* disable secondary request bit */
	return TIDC_NO_ERR;
}

/****************************************************************/
/* set power mode for all AICs in chain                         */
/*   bDown = 0:   power up                                      */
/*   bDown = 1;   power down                                    */
/****************************************************************/
void aic1x2x_power(void *pDC, int bDown)
{
	TAIC10 *pAIC = pDC;
	unsigned int ui;
	       
	for (ui = 0; ui < pAIC->uiCount; ui++)
		pAIC->devices[ui].creg2.control_bit.low_pow = bDown;		

	aic1x2x_configure(pAIC);
}          

/****************************************************************/
/*	read one word from AIC chain                              */
/****************************************************************/
long aic1x2x_read(void *pDC)
{          
//	TAIC10 *pAIC = pDC;
	
	if (!pDC)
		return 0;
		               
	iRFrame = 0;
	while (!iRFrame) {};
	
	return iRxData;
}      
                                   
/****************************************************************/
/*	write one word to AIC chain                               */                                  
/****************************************************************/
void aic1x2x_write(void *pDC, long lData)
{          
//	TAIC10 *pAIC = pDC;
	static int iData;
	                
	iData = lData;
	if (!pDC)
		return;
		
	iWFrame = 0;
	while (!iWFrame) {};
	pWData = &iData;
	aic1x2x_wcallback = 0;
	uiWCount = 1;
}      
                                  
/****************************************************************/
/* transfer block of data from AIC chain to memory              */
/* uiAddress: start address in data space                       */
/* ulCount  : length of block                                   */
/* callback : function pointer. will be called upon completion  */
/*            of block transfer                                 */
/****************************************************************/
void aic1x2x_rblock(void *pDC, void *pData, unsigned long ulCount,
                    void (*callback) (void *))
{ 
	TAIC10 *pAIC = pDC;
	
	if (!pDC)
		return;
	              
	piAIC = pAIC;          
	pRData = pData;
	aic1x2x_rcallback = callback;
	uiRCount = ulCount * pAIC->uiCount;
}

/****************************************************************/
/* transfer block of data from memory to AIC chain              */
/* uiAddress: start address in data space                       */
/* ulCount  : length of block                                   */
/* callback : function pointer. will be called upon             */
/*            completion of block transfer                      */
/****************************************************************/
void aic1x2x_wblock(void *pDC, void *pData, unsigned long ulCount, 
                    void (*callback) (void *))
{ 
	TAIC10 *pAIC = pDC;
    
	if (!pDC)
		return;

	piAIC = pAIC;
	pWData = pData;
	aic1x2x_wcallback = callback;
	uiWCount = ulCount * pAIC->uiCount;
}
