/****************************************************************/
/* TLV320AIC22 driver version 1.0 for C5400                     */
/* $Revision: 2 $                      $JustDate: 21.09.00 $ */
/****************************************************************/

#ifndef TAIC22_FN_H
#define TAIC22_FN_H

#include "TIDC_API.h"

/****************************************************************/                                                      
/* STRUCTURE DEFINITION FOR CONTROL REGISTERS 1 and 6           */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int nreg      :4;
       unsigned int dreg      :4;
   } control_bit;
} AIC22CREG1_6; 

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTERS 2 AND 7           */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int reset       :1;
       unsigned int pwdn        :1;
       unsigned int dig_lbck    :1;
       unsigned int an_lbck     :1;
       unsigned int ireg        :4;
   } control_bit;
} AIC22CREG2_7; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTERS 2 and 7              */
/****************************************************************/                                                      

#define AIC22_RESET_ENA       (0x01)
#define AIC22_RESET_OFF       (0x00)
#define AIC22_PWDN_ENA        (0x01)
#define AIC22_PWDN_OFF        (0x00)
#define AIC22_DIG_LBCK_ENA    (0x01)
#define AIC22_DIG_LBCK_OFF    (0x00)
#define AIC22_AN_LBCK_ENA     (0x01)
#define AIC22_AN_LBCK_OFF     (0x00)

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 3 AND 8            */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
        unsigned int an_out_line     :1;
        unsigned int adcout_gain     :6;
        unsigned int ovf             :1;
   } control_bit;
} AIC22CREG3_8; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTERS 3 AND 8              */
/****************************************************************/                                                      

#define AIC22_NO_LNOUT          (0x00)
#define AIC22_LNOUT             (0x01)
#define AIC22_ADCMUTE           (0x30)
#define AIC22_ADC_12P0DB        (0x21)
#define AIC22_ADC_10P5DB        (0x20)
#define AIC22_ADC_9P0DB         (0x1F)
#define AIC22_ADC_7P5DB         (0x1E)
#define AIC22_ADC_6P0DB         (0x1D)
#define AIC22_ADC_4P5DB         (0x1C)
#define AIC22_ADC_3P0DB         (0x1B)
#define AIC22_ADC_1P5DB         (0x1A)
#define AIC22_ADC_M1P5DB        (0x18)
#define AIC22_ADC_M3P0DB        (0x17)                                           
#define AIC22_ADC_M4P5DB        (0x16)
#define AIC22_ADC_M6P0DB        (0x15)    
#define AIC22_ADC_M7P5DB        (0x14)    
#define AIC22_ADC_M9P0DB        (0x13)    
#define AIC22_ADC_M10P5DB       (0x12)    
#define AIC22_ADC_M12P0DB       (0x11)    
#define AIC22_ADC_M13P5DB       (0x10)    
#define AIC22_ADC_M15P0DB       (0x0F)    
#define AIC22_ADC_M16P5DB       (0x0E)    
#define AIC22_ADC_M18P0DB       (0x0D)    
#define AIC22_ADC_M19P5DB       (0x0C)    
#define AIC22_ADC_M21P0DB       (0x0B)    
#define AIC22_ADC_M22P5DB       (0x0A)    
#define AIC22_ADC_M24P0DB       (0x09)    
#define AIC22_ADC_M25P5DB       (0x08)
#define AIC22_ADC_M27P0DB       (0x07)    
#define AIC22_ADC_M28P5DB       (0x06)    
#define AIC22_ADC_M30P0DB       (0x05)    
#define AIC22_ADC_M31P5DB       (0x04)    
#define AIC22_ADC_M33P0DB       (0x03)
#define AIC22_ADC_M34P5DB       (0x02)    
#define AIC22_ADC_M36P0DB       (0x01)
#define AIC22_ADC_0DB           (0x00)        
            
/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTERS 4 AND 9           */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int dac_gain       :6;
       unsigned int reserved1      :2;
   } control_bit;
} AIC22CREG4_9; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTERS 4 AND 9              */
/****************************************************************/                                                      
#define AIC22_DAC_MUTE          (0x30)
#define AIC22_DAC_12P0DB        (0x21)
#define AIC22_DAC_10P5DB        (0x20)
#define AIC22_DAC_9P0DB         (0x1F)
#define AIC22_DAC_7P5DB         (0x1E)
#define AIC22_DAC_6P0DB         (0x1D)
#define AIC22_DAC_4P5DB         (0x1C)
#define AIC22_DAC_3P0DB         (0x1B)
#define AIC22_DAC_1P5DB         (0x1A)
#define AIC22_DAC_M1P5DB        (0x18)
#define AIC22_DAC_M3P0DB        (0x17)                                           
#define AIC22_DAC_M4P5DB        (0x16)
#define AIC22_DAC_M6P0DB        (0x15)    
#define AIC22_DAC_M7P5DB        (0x14)    
#define AIC22_DAC_M9P0DB        (0x13)    
#define AIC22_DAC_M10P5DB       (0x12)    
#define AIC22_DAC_M12P0DB       (0x11)    
#define AIC22_DAC_M13P5DB       (0x10)    
#define AIC22_DAC_M15P0DB       (0x0F)    
#define AIC22_DAC_M16P5DB       (0x0E)    
#define AIC22_DAC_M18P0DB       (0x0D)    
#define AIC22_DAC_M19P5DB       (0x0C)    
#define AIC22_DAC_M21P0DB       (0x0B)    
#define AIC22_DAC_M22P5DB       (0x0A)
#define AIC22_DAC_M24P0DB       (0x09)    
#define AIC22_DAC_M25P5DB       (0x08)
#define AIC22_DAC_M27P0DB       (0x07)    
#define AIC22_DAC_M28P5DB       (0x06)    
#define AIC22_DAC_M30P0DB       (0x05)    
#define AIC22_DAC_M31P5DB       (0x04)    
#define AIC22_DAC_M33P0DB       (0x03)
#define AIC22_DAC_M34P5DB       (0x02)    
#define AIC22_DAC_M36P0DB       (0x01)
#define AIC22_DAC_0DB           (0x00)

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTERS 5 AND 10          */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int an_out_sp       :1;
       unsigned int an_out_hd       :1;
       unsigned int an_out_hs       :1;
       unsigned int an_in_cid       :1;
       unsigned int an_in_line      :1;
       unsigned int an_in_mic       :1;
       unsigned int an_in_hd        :1;
       unsigned int an_in_hs        :1;                    
   } control_bit;
} AIC22CREG5_10; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTERS 5 AND 10             */
/****************************************************************/                                                      
#define AIC22_NO_SPOUT       (0x00)
#define AIC22_SPOUT          (0x01)
#define AIC22_NO_HDOUT       (0x00)
#define AIC22_HDOUT          (0x01)
#define AIC22_NO_HSOUT       (0x00)
#define AIC22_HSOUT          (0x01)
#define AIC22_NO_CIDIN       (0x00)
#define AIC22_CIDIN          (0x01)
#define AIC22_NO_LNIN        (0x00)
#define AIC22_LNIN           (0x01)
#define AIC22_NO_MICIN       (0x00)
#define AIC22_MICIN          (0x01)
#define AIC22_NO_HDIN        (0x00)
#define AIC22_HDIN           (0x01)
#define AIC22_NO_HSIN        (0x00)
#define AIC22_HSIN           (0x01)
 
/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 11                 */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int spk_out           :1;
       unsigned int reserved2         :1;
       unsigned int mic_in_gain       :2;
       unsigned int hd_in_gain        :2;
       unsigned int hs_in_gain        :2;
   } control_bit;
} AIC22CREG11; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 11                    */
/****************************************************************/                                                      
#define AIC22_SPK_ENA            (0x00)
#define AIC22_SPK_MUTE           (0x01)
#define AIC22_MIC_32DB           (0x00)
#define AIC22_MIC_42DB           (0x01)
#define AIC22_MIC_MUTE           (0x03)
#define AIC22_HD_14DB            (0x00)
#define AIC22_HD_23DB            (0x01)
#define AIC22_HD_INMUTE          (0x03)
#define AIC22_HS_14DB            (0x00)
#define AIC22_HS_23DB            (0x01)
#define AIC22_HS_INMUTE          (0x03)
                          
/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 12                 */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
      unsigned int lcd_dac           :4;
      unsigned int fsync             :3;
      unsigned int reserved3         :1;
   } control_bit;
} AIC22CREG12; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 12                    */
/****************************************************************/                                                      
#define AIC22_LCD_1P3125         (0x0F)
#define AIC22_LCD_1P125          (0x0E)
#define AIC22_LCD_0P9375         (0x0D)
#define AIC22_LCD_0P75           (0x0C)
#define AIC22_LCD_0P5625         (0x0B)
#define AIC22_LCD_0P375          (0x0A)
#define AIC22_LCD_0P1875         (0x09)
#define AIC22_LCD_0              (0x08)
#define AIC22_LCD_2P8125         (0x07)
#define AIC22_LCD_2P625          (0x06)
#define AIC22_LCD_2P4375         (0x05)
#define AIC22_LCD_2P25           (0x04)
#define AIC22_LCD_2P0625         (0x03)
#define AIC22_LCD_1P875          (0x02)
#define AIC22_LCD_1P6875         (0x01)
#define AIC22_LCD_1P5            (0x00)
#define AIC22_FSYNC64_48         (0x07)
#define AIC22_FSYNC16K32M        (0x03)
#define AIC22_FSYNC16K24M        (0x02)
#define AIC22_FSYNC8K32M         (0x01)
#define AIC22_FSYNC8K24M         (0x00)

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 13                 */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int reserved4         :2;
       unsigned int hs_echo           :3;
       unsigned int reserved5         :2;
       unsigned int hs_ena            :1;
   } control_bit;
} AIC22CREG13; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 13                    */
/****************************************************************/                                                      
#define AIC22_HS_MUTE           (0x07)
#define AIC22_HS_M24DB          (0x06)
#define AIC22_HS_M22DB          (0x05)
#define AIC22_HS_M20DB          (0x04)
#define AIC22_HS_M18DB          (0x03)
#define AIC22_HS_M16DB          (0x02)
#define AIC22_HS_M14DB          (0x01)
#define AIC22_HS_M12DB          (0x00)
#define AIC22_HS_ENA            (0x00)
#define AIC22_HS_POWDWN         (0x01)

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 14                 */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int ln_vcom_out       :1;
       unsigned int reserved6         :1;
       unsigned int hd_echo           :3;
       unsigned int ln_amp_pole       :2;
       unsigned int hd_ena            :1;
   } control_bit;
} AIC22CREG14; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 14                    */
/****************************************************************/                                                      
#define AIC22_LN_ENA            (0x00)
#define AIC22_LN_PWDN           (0x01)
#define AIC22_HD_MUTE           (0x07)
#define AIC22_HD_M24DB          (0x06)
#define AIC22_HD_M22DB          (0x05)
#define AIC22_HD_M20DB          (0x04)
#define AIC22_HD_M18DB          (0x03)
#define AIC22_HD_M16DB          (0x02)
#define AIC22_HD_M14DB          (0x01)
#define AIC22_HD_M12DB          (0x00)
#define AIC22_POLE_16k          (0x03)
#define AIC22_POLE_21.3k        (0x02)
#define AIC22_POLE_32k          (0x01)
#define AIC22_POLE_64k          (0x00)
#define AIC22_HD_ENA            (0x00)
#define AIC22_HD_POWDWN         (0x01)

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTERS 15 AND 16         */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int zlsbs         :2;
       unsigned int zctrl         :1;
       unsigned int iir           :1;
       unsigned int reserved7     :2;
       unsigned int mode          :2;
   } control_bit;
} AIC22CREG15_16; 
   
/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTERS 15 AND 16            */
/****************************************************************/                                                      
#define AIC22_Z10           (0x03)
#define AIC22_Z8            (0x02)
#define AIC22_Z4            (0x01)
#define AIC22_Z6            (0x00)
#define AIC22_ZENA          (0x00)
#define AIC22_ZOFF          (0x01)
#define AIC22_IIRON         (0x00)
#define AIC22_IIRBYP        (0x01)
#define AIC22_ULAW          (0x03)
#define AIC22_ALAW          (0x02)
#define AIC22_LINEAR        (0x00)

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 17                 */
/****************************************************************/                                                      
typedef union
{
   unsigned int value;
   struct
   {
       unsigned int num_ctrl_frames   :8;
   } control_bit;
} AIC22CREG17; 

/****************************************************************/
/* VALUE DEFINITIONS FOR CONTROL REGISTER 17                    */
/****************************************************************/     
                          
/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/

typedef struct
{
    unsigned int       uiID;         /* device address    */
    AIC22CREG1_6       creg01;       /* control regs 1-17 */
    AIC22CREG2_7       creg02;
    AIC22CREG3_8       creg03;
    AIC22CREG4_9       creg04;
    AIC22CREG5_10      creg05;
    AIC22CREG1_6       creg06;
    AIC22CREG2_7       creg07;
    AIC22CREG3_8       creg08;
    AIC22CREG4_9       creg09;
    AIC22CREG5_10      creg10;
    AIC22CREG11        creg11;
    AIC22CREG12        creg12;
    AIC22CREG13        creg13;
    AIC22CREG14        creg14;
    AIC22CREG15_16     creg15;
    AIC22CREG15_16     creg16;
    AIC22CREG17        creg17;
} _TAIC22;

typedef struct
{
    TTIDC f;                        /* common functions         */
    DCP_SERIAL*        serial;      /* serial port structure    */
    unsigned int       uiCount;     /* # of AICs in the chain   */
    _TAIC22            devices[4];	/* array of AIC22s in chain */
} TAIC22;                       

/****************************************************************/
/* data converter API function prototypes                       */
/****************************************************************/
TTIDCSTATUS aic22_configure(void *pDC);
void aic22_power(void *pDC, int bDown);
long aic22_read(void *pDC);
void aic22_write(void *pDC, long lData);
void aic22_rblock(void *pDC, void *pData, unsigned long ulCount, 
                  void (*callback) (void *));
void aic22_wblock(void *pDC, void *pData, unsigned long ulCount,
                  void (*callback) (void *));

/****************************************************************/
/* data converter external address definitions                  */
/****************************************************************/
&&EXTERN_DEV&&

#endif /* TAIC22_FN_H */

