/****************************************************************/
/* TLV320AIC27 driver version 1.0 for C6000                     */
/* main structures and pointers are at the end of the file!     */
/* $Revision: 4 $                      $JustDate: 21.09.00 $ */
/****************************************************************/

#ifndef TAIC27_FN_H
#define TAIC27_FN_H

/* needs the new v 2.0 API definition! */
#include "TIDC_API.h"

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 00h                */
/* Name: Reset                                                  */
/* Default: 6150h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int id                 :10;
          unsigned int se                 :5;
          unsigned int reserved           :1;
      } control_bit;
} TLV320AIC27_CR00;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 02h                */
/* Name: master volume                                          */
/* Default: 8000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int mr                 :5;
          unsigned int reserved_1         :3;
          unsigned int ml                 :5;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR02;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 04h                */
/* Name: LNLVL volume                                           */
/* Default: 8000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int mr                 :5;
          unsigned int reserved_1         :3;
          unsigned int ml                 :5;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR04;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 06h                */
/* Name: master volume mono                                     */
/* Default: 8000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int mm                 :5;
          unsigned int reserved_1         :10;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR06;

// register 08h reserved/ not listed?

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0Ah                */
/* Name: PC beep volume                                         */
/* Default: x000h (?)                                           */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int reserved_1         :1;
          unsigned int pv                 :4;
          unsigned int reserved_2         :10;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR0A;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0Ch                */
/* Name: phone volume                                           */
/* Default: 8008h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gn                 :5;
          unsigned int reserved_1         :10;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR0C;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 0Eh                */
/* Name: mic volume                                             */
/* Default: 8008h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gn                 :5;
          unsigned int reserved_1         :1;
          unsigned int db20               :1;
          unsigned int reserved_2         :8;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR0E;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 10h                */
/* Name: Line in volume                                         */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :5;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR10;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 12h                */
/* Name: CD volume                                              */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :5;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR12;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 14h                */
/* Name: Video volume                                           */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :5;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR14;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 16h                */
/* Name: Aux volume                                             */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :5;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR16;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 18h                */
/* Name: PCM out volume                                         */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :5;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR18;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 1Ah                */
/* Name: Rec select                                             */
/* Default: 0000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int sr                 :3;
          unsigned int reserved_1         :5;
          unsigned int sl                 :3;
          unsigned int reserved_2         :5;
      } control_bit;
} TLV320AIC27_CR1A;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 1Ch                */
/* Name: Rec gain                                               */
/* Default: 8000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :4;
          unsigned int reserved_1         :4;
          unsigned int gl                 :4;
          unsigned int reserved_2         :3;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR1C;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 20h                */
/* Name: General purpose                                        */
/* Default: 8000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int reserved_1         :7;
          unsigned int lpbk               :1;
          unsigned int ms                 :1;
          unsigned int mix                :1;
          unsigned int reserved_2         :2;
          unsigned int id                 :1;   // ld? notsupported
          unsigned int b3d                :1;
          unsigned int st                 :1;	// not supported
          unsigned int pop                :1;
      } control_bit;
} TLV320AIC27_CR20;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 22h                */
/* Name: 3d control                                             */
/* Default: 0000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int dp                 :4;
          unsigned int reserved           :12;
      } control_bit;
} TLV320AIC27_CR22;

// register 24h reserved

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 26h                */
/* Name: Power down/control status                              */
/* Default: 000Fh                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int adc                :1;
          unsigned int dac                :1;
          unsigned int anl                :1;
          unsigned int ref                :1;
          unsigned int reserved_1         :4;
          unsigned int pr0                :1;
          unsigned int pr1                :1;
          unsigned int pr2                :1;
          unsigned int pr3                :1;
          unsigned int pr4                :1;
          unsigned int pr5                :1;
          unsigned int reserved_2         :1;	// PR6 not supported
          unsigned int eapd               :1;
      } control_bit;
} TLV320AIC27_CR26;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 28h                */
/* Name: Extended audio ID (read only)                          */
/* Default: 0281h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int vra                :1;	
          unsigned int dra                :1;
          unsigned int reserved_1         :1;
          unsigned int vrm                :1;
          unsigned int reserved_2         :2;
          unsigned int cdac               :1;
          unsigned int sdac               :1;
          unsigned int ldac               :1;
          unsigned int mdac               :1;
          unsigned int reserved_3         :4;
          unsigned int id                 :2;
      } control_bit;
} TLV320AIC27_CR28;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 2Ah                */
/* Name: Extended audio status/control                           */
/* Default: 0080h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int vra                :1;
          unsigned int dra                :1;	// not supported
          unsigned int reserved_1         :1;
          unsigned int vrm                :1;	// not supported
          unsigned int reserved_2         :2;
          unsigned int cdac               :1;
          unsigned int sdac               :1;
          unsigned int ldac               :1;
          unsigned int madc               :1;	// not supported
          unsigned int reserved_3         :1;
          unsigned int pri                :1;
          unsigned int prj                :1;
          unsigned int prk                :1;
          unsigned int prl                :1;
          unsigned int reserved_4         :1;
      } control_bit;
} TLV320AIC27_CR2A;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 2Ch                */
/* Name: Front DAC rate                                         */
/* Default: BB80h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int sr                 :16;
      } control_bit;
} TLV320AIC27_CR2C;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 2Eh                */
/* Name: Rear DAC rate                                          */
/* Default: BB80h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int sr                 :16;
      } control_bit;
} TLV320AIC27_CR2E;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 30h                */
/* Name: LFE DAC rate                                           */
/* Default: BB80h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int sr                 :16;
      } control_bit;
} TLV320AIC27_CR30;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 32h                */
/* Name: Audio ADC rate                                         */
/* Default: BB80h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int sr                 :16;
      } control_bit;
} TLV320AIC27_CR32;

// register 34h reserved/ not listed?

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 36h                */
/* Name: 6 channel volume center/LFE                            */
/* Default: 8080h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int cnt                :5;
          unsigned int reserved_1         :2;
          unsigned int mute_c             :1;
          unsigned int lfe                :5;
          unsigned int reserved_2         :2;
          unsigned int mute_lfe           :1;
      } control_bit;
} TLV320AIC27_CR36;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 38h                */
/* Name: 6 channel volume left/right surround                   */
/* Default: 8080h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int rsr                :5;
          unsigned int reserved_1         :2;
          unsigned int mute_r             :1;
          unsigned int lsr                :5;
          unsigned int reserved_2         :2;
          unsigned int mute_l             :1;
      } control_bit;
} TLV320AIC27_CR38;

// register 3Ah reserved/ not listed?

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 3Ch                */
/* Name: Extended modem id                                      */
/* Default: x00xh                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int lin                :2;
          unsigned int hset               :1;	// not supported
          unsigned int cid                :2;
          unsigned int reserved_1         :9;
          unsigned int id                 :2;
      } control_bit;
} TLV320AIC27_CR3C;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 3Eh                */
/* Name: Extended modem status                                  */
/* Default: 0100h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gpio               :1;
          unsigned int mref               :1;
          unsigned int adc1               :1;
          unsigned int dac1               :1;
          unsigned int adc2               :1;
          unsigned int dac2               :1;
          unsigned int hadc               :1;	// not supported
          unsigned int hdac               :1;	// not supported
          unsigned int pra                :1;
          unsigned int prb                :1;
          unsigned int prc                :1;
          unsigned int pd                 :1;
          unsigned int pre                :1;	// not supported
          unsigned int prf                :1;	// not supported
          unsigned int prg                :1;	// not supported
          unsigned int prh                :1;	// not supported
      } control_bit;
} TLV320AIC27_CR3E;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 40h                */
/* Name: Line1 ADC/DAC sample rate                              */
/* Default: BB80h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int sr                 :16;
      } control_bit;
} TLV320AIC27_CR40;

// register 42h aliased to 40h
// register 44h reserved/ not listed?
// registers 46h, 48h, 4Ch, 4Eh, 50h, 52h, 54h not supported
// register 4Ah reserved/ not listed?

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 56h                */
/* Name: Misc modem status                                      */
/* Default: 0000h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int l1b                :3;
          unsigned int reserved_1         :1;
          unsigned int l2b                :3;
          unsigned int reserved_2         :1;
          unsigned int hsb                :3;
          unsigned int reserved_3         :1;
          unsigned int mlnk               :1;
          unsigned int cidr               :1;
          unsigned int cid                :2;
      } control_bit;
} TLV320AIC27_CR56;

// register 58h reserved/ not listed
/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 70h                */
/* Name: Rear PCM out volume                                    */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :1;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR70;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 72h                */
/* Name: Front mixer volume                                     */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :1;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR72;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 74h                */
/* Name: Rear mixer volume                                     */
/* Default: 8808h                                               */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int gr                 :5;
          unsigned int reserved_1         :3;
          unsigned int gl                 :1;
          unsigned int reserved_2         :2;
          unsigned int mute               :1;
      } control_bit;
} TLV320AIC27_CR74;

// register 76h, 78h, 7Ah reserved/ not listed or not supported

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 7Ch                */
/* Name: Vendor ID1                                             */
/* Default: 574Dh = 'WM'   ???                                  */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int s                  :8;
          unsigned int f                  :8;
      } control_bit;
} TLV320AIC27_CR7C;

/****************************************************************/
/* STRUCTURE DEFINITION FOR CONTROL REGISTER 7Eh                */
/* Name: Vendor ID2                                             */
/* Default: 4C03h = 'L3'    ???                                 */
/****************************************************************/
typedef union
{
   unsigned int value;
   struct
      {
          unsigned int rev                :8;
          unsigned int t                  :8;
      } control_bit;
} TLV320AIC27_CR7E;


/****************************************************************/
/* data converter structure definitions                         */
/****************************************************************/

typedef struct
{
    TTIDC              f;           /* common functions */
    DCP_SERIAL*        serial;      /* Pointer to the serial port config object */
    unsigned int       uiID;
	                              /* control regs 00h - 7Eh */
    TLV320AIC27_CR00   creg00;      /* reset              */    
    TLV320AIC27_CR02   creg02;      /* master volume      */    
    TLV320AIC27_CR04   creg04;      /* LNLVL volume       */    
    TLV320AIC27_CR06   creg06;      /* master volume mono */    
    TLV320AIC27_CR0A   creg0a;      /* PCBEEP volume      */
    TLV320AIC27_CR0C   creg0c;      /* phone volume       */   
    TLV320AIC27_CR0E   creg0e;      /* mic volume         */   
    TLV320AIC27_CR10   creg10;      /* line in volume     */   
    TLV320AIC27_CR12   creg12;      /* CD volume          */
    TLV320AIC27_CR14   creg14;      /* video volume       */
    TLV320AIC27_CR16   creg16;      /* aux volume         */
    TLV320AIC27_CR18   creg18;      /* pcm out volume     */
    TLV320AIC27_CR1A   creg1a;      /* record select      */
    TLV320AIC27_CR1C   creg1c;      /* record gain        */
    TLV320AIC27_CR20   creg20;      /* general purpose    */
    TLV320AIC27_CR22   creg22;      /* 3D control         */
    TLV320AIC27_CR26   creg26;      /* power down         */
    TLV320AIC27_CR2A   creg2a;      /* ext audio stat     */
    TLV320AIC27_CR2C   creg2c;      /* front dac rate     */
    TLV320AIC27_CR2E   creg2e;      /* rear dac rate      */
    TLV320AIC27_CR30   creg30;      /* LFE dac rate       */
    TLV320AIC27_CR32   creg32;      /* audio adc rate     */
    TLV320AIC27_CR36   creg36;      /* 6ch c,lfe volume   */
    TLV320AIC27_CR38   creg38;      /* 6ch surr colume    */
    TLV320AIC27_CR3C   creg3c;      /* ext modem id       */
    TLV320AIC27_CR3E   creg3e;      /* ext modem status   */
    TLV320AIC27_CR40   creg40;      /* line1 sample rate  */
    TLV320AIC27_CR56   creg56;      /* misc modem stat    */
    TLV320AIC27_CR70   creg70;      /* rear pcm out vol.  */
    TLV320AIC27_CR72   creg72;      /* front mix volume   */
    TLV320AIC27_CR74   creg74;      /* rear mix volume    */
    TLV320AIC27_CR7C   creg7c;      /* vendor ID 1        */
    TLV320AIC27_CR7E   creg7e;      /* vendor ID 2        */
} TAIC27;

/* AC97 enable bit masks */     
#define T_CMD_ADR	   0x4000
#define T_CMD_DATA   0x2000
#define T_PCM_LEFT   0x1000
#define T_PCM_RIGHT  0x0800
#define T_PCM_CENTER 0x0200
#define T_PCM_L_SURR 0x0100
#define T_PCM_R_SURR 0x0080
#define T_PCM_LFE    0x0040
#define T_GPIO_CTRL  0x0008

/* AC97 element indizes */
#define I_CMD_ADR    0
#define I_CMD_DATA   1
#define I_PCM_LEFT   2
#define I_PCM_RIGHT  3
#define I_PCM_CENTER 5
#define I_PCM_L_SURR 6
#define I_PCM_R_SURR 7
#define I_PCM_LFE    8
#define I_GPIO_CTRL  11

/* AC97 structure */            
typedef struct
{
	long TAG;
	long CMD_ADR;
	long CMD_DATA;
	long PCM_LEFT;
	long PCM_RIGHT;
	long RSRVD1;
	long PCM_CENTER;
	long PCM_L_SURR;
	long PCM_R_SURR;
	long PCM_LFE;
	long RSRVD2;
	long RSRVD3;
	long GPIO_CTRL;
} TAC97T;    
                                             
typedef struct
{
	unsigned int uiCount;
	long *pData;
	void (*callback) (void*);
} TAC97Element;

/* set of AC97 elements in block/callback functions */
typedef struct
{                
	unsigned int uiValid;
	unsigned int TAG;
	TAC97Element E[12]; /* CMD_DATA, PCM_LEFT, PCM_RIGHT.......GPIO_CTRL */
} TAC97Count;
            
/****************************************************************/
/* data converter API function prototypes                       */
/****************************************************************/
TTIDCSTATUS aic27_configure(void *pDC);
void        aic27_power(void *pDC, int bDown);
long        aic27_read(void *pDC);
void		aic27_read_frame(void *pDC, TAC97T *AC97T);
void        aic27_write(void *pDC, long lData);     
void		aic27_write_frame(void *pDC, TAC97T *AC97T);
void        aic27_rblock(void *pDC, void *pData, 
						 unsigned long ulCount, 
						 void (*callback) (void *));
void        aic27_wblock(void *pDC, void *pData, 
						 unsigned long ulCount, 
						 void (*callback) (void *));

/****************************************************************/
/* data converter external address definitions                  */
/****************************************************************/
&&EXTERN_DEV&&

#endif /* TAIC27_FN_H */
