/****************************************************************/
/* TLV320AIC27 driver version 1.0 for C6000                     */
/* $Revision: 5 $                      $JustDate: 21.09.00 $ */
/****************************************************************/

#undef _INLINE
#include "dc_conf.h"
#include "taic27_fn.h" 

/* needs -i <drive>\ti\c5400\dsk\include option */
#include <regs54xx.h>
#include <std.h>
#include <hwi.h>
                 
/****************************************************************/
/* define and initialize data converter objects                 */
/****************************************************************/
&&DEFINE_OBJECT&&
 
/****************************************************************/
/* DSP FUNCTIONS                                                */
/****************************************************************/
#define DMSA	0x55
#define DMSDN	0x57
#define DMSRC1	0x05
#define DMDST1	0x06
#define DMCTR1	0x07
#define DMSFC1	0x08
#define DMMCR1	0x09

#define DMSRC2	0x0A
#define DMDST2	0x0B
#define DMCTR2	0x0C
#define DMSFC2	0x0D
#define DMMCR2	0x0E

#define DMIDX0	0x20            

/****************************************************************/
/* tx_buf and rx_buf contain the data for two AC97 frames       */
/* they must be aligned to a 64 word boundary                   */
/* the DMA controller will treat this as a circular buffer      */
/****************************************************************/
extern unsigned long tx_buf[32];
extern unsigned long rx_buf[16];

/****************************************************************/
/* pull xf low to reset the AIC27                               */
/* must be changed for specific hardware                        */
/****************************************************************/
void aic27_reset(void)
{
	asm("	rsbx xf");
	asm("	rpt #100");
	asm("	nop");
	asm("	ssbx xf");
	asm("	rpt #16");
	asm("	nop");
}

/* contains the number of AC97 elements left in the block write */
TAC97Count AC97WC; 
int iTFrame;                             

/****************************************************************/
/* transmit interrupt service routine                           */
/****************************************************************/
interrupt void AC97_tisr(void)
{              
	int i;
	static int iTxIndex = 0;   
	unsigned int TAG = 0x8000;        

	/* the ISR works on two transmit buffers */
	/* select the transmit buffer which`s content just has been transmitted */
	if (iTxIndex != 0)
		iTxIndex = 0;
	else
		iTxIndex = 13;

	iTFrame = 1; /* used to synchronize with other task(s) */
	
	if (!AC97WC.uiValid)	/* return, if the AC97 write record is not valid */
		return;

	/* assemble new AC97 Frame */
	for (i = 0; i < 12; i++)
	{
		if (AC97WC.E[i].uiCount)
		{                                           
			TAG |= 0x4000 >> i;  /* create valid tag for current AC97 element */
			tx_buf[iTxIndex + i + 1] = *AC97WC.E[i].pData++; /* write data to tx_buf */
			AC97WC.E[i].uiCount--;
			if (!AC97WC.E[i].uiCount && AC97WC.E[i].callback)
				AC97WC.E[i].callback(0); /* callback at end of block */
		}
	}                  
	tx_buf[iTxIndex] = TAG;
}          

/* contains the number of AC97 elements left in the block read */
TAC97Count AC97RC; 
int iRFrame;

/****************************************************************/
/* transmit interrupt service routine                           */
/****************************************************************/
interrupt void AC97_risr(void)
{              
	int i;           

	iRFrame = 1; /* used to synchronize with other task(s) */
		
	if (!AC97RC.uiValid)	/* return, if the AC97 read record is not valid */
		return;
    
	/* disassemble new AC97 Frame */
	for (i = 0; i < 12; i++)
	{
		/* check, if pointer is valid and count is not 0 */
		if (AC97RC.E[i].uiCount && AC97RC.E[i].pData)
		{   
			/* store, if TAG for element is valid */
			if (rx_buf[0] & 0x4000 >> i)
			{
				*AC97RC.E[i].pData++ = rx_buf[i + 1]; 
				AC97RC.E[i].uiCount--;
				if (!AC97RC.E[i].uiCount && AC97RC.E[i].callback)
					AC97RC.E[i].callback(0); /* callback at end of block */
			}
		}                                                           
	}                  
}          

/****************************************************************/
/* write one AC97 frame to AIC27 (pDC is ignored)               */
/****************************************************************/
void aic27_write_frame(void *pDC, TAC97T *AC97T)
{       
	int i;

	/* prevent transmit ISR from working on partially updated AC97WC */	
	AC97WC.uiValid = 0;
                         
	/* merge AC97 TAGs */
	AC97WC.TAG |= AC97T->TAG;
	for (i = 0; i < 12; i++)
	{
		/* insert and substitute valid AC97 elements */                         
		if (AC97WC.TAG & (0x4000 >> i))
		{ 
			AC97WC.E[i].callback = 0;
			AC97WC.E[i].uiCount = 1;
			switch (i)
			{
			case 0:	AC97WC.E[i].pData = &AC97T->CMD_ADR; break;
			case 1:	AC97WC.E[i].pData = &AC97T->CMD_DATA; break;
			case 2:	AC97WC.E[i].pData = &AC97T->PCM_LEFT; break;
			case 3:	AC97WC.E[i].pData = &AC97T->PCM_RIGHT; break;
			case 4:	AC97WC.E[i].pData = &AC97T->RSRVD1; break;
			case 5:	AC97WC.E[i].pData = &AC97T->PCM_CENTER; break;
			case 6:	AC97WC.E[i].pData = &AC97T->PCM_L_SURR; break;
			case 7:	AC97WC.E[i].pData = &AC97T->PCM_R_SURR; break;
			case 8:	AC97WC.E[i].pData = &AC97T->PCM_LFE; break;
			case 9:	AC97WC.E[i].pData = &AC97T->RSRVD2; break;
			case 10:AC97WC.E[i].pData = &AC97T->RSRVD3; break;
			case 11:AC97WC.E[i].pData = &AC97T->GPIO_CTRL; break;
			default:;
			}
		}
	}       
	AC97WC.uiValid = 1;	

	/* synchronize with transmit ISR */	
	iTFrame = 0;
	while (!iTFrame){};
}

/****************************************************************/
/* read one AC97 frame from AIC27 (pDC is ignored) */
/****************************************************************/
void aic27_read_frame(void *pDC, TAC97T *AC97T)
{       
	/* synchronize with receive ISR */	
	iRFrame = 0;
	while (!iRFrame) {};
                               
	AC97T->TAG        = rx_buf[0];
	AC97T->CMD_ADR    = rx_buf[1];
	AC97T->CMD_DATA   = rx_buf[2];
	AC97T->PCM_LEFT   = rx_buf[3];
	AC97T->PCM_RIGHT  = rx_buf[4];
	AC97T->RSRVD1     = rx_buf[5];
	AC97T->PCM_CENTER = rx_buf[6];
	AC97T->PCM_L_SURR = rx_buf[7];
	AC97T->PCM_R_SURR = rx_buf[8];
	AC97T->PCM_LFE    = rx_buf[9];
	AC97T->RSRVD2     = rx_buf[10];
	AC97T->RSRVD3     = rx_buf[11];
	AC97T->GPIO_CTRL  = rx_buf[12];
}

/****************************************************************/
/* initialize the DSP (PLL, DMA, McBSP, IRQ)                    */
/****************************************************************/
void dsp_init(TAIC27 *pDC)
{
	CLKMD = 0x0004;
	asm("	rpt #1000");
	asm("	nop");	/* wait for PLL to lock */
	CLKMD = 0x37FF;	                          
	asm("	rpt #1000");
	asm("	nop");

	HWI_disable();
	IMR &= !0x0480;	/* mask int10 and int7 */

	/* open the McBSP */
	switch (pDC->serial->port)
	{
		case 0: pDC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV0, 0); break;
		case 1: pDC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV1, 0); break;
		case 2: pDC->serial->hMcbsp = MCBSP_Open(MCBSP_DEV2, 0); break;
		default:;
	}

	MCBSP_ConfigA(pDC->serial->hMcbsp, &pDC->serial->sConfig);

	*(unsigned int *) 0x54 = 0x0000;

/*	setup DMA transfer */
/*	source = buffer */    
	*(unsigned int *) DMSA	= DMSRC1;
	*(unsigned int *) DMSDN	= (unsigned int) &tx_buf;
/*	destination = DXR2 */
	*(unsigned int *) DMSA	= DMDST1;
	*(unsigned int *) DMSDN	= pDC->serial->hMcbsp + MCBSP_DXR2;

	*(unsigned int *) DMSA	= DMCTR1;
	*(unsigned int *) DMSDN	= 0x0034;

/*	transmit sync */
	*(unsigned int *) DMSA	= DMSFC1;
	switch (pDC->serial->port)
	{
	case 0:	*(unsigned int *) DMSDN	= 0x2800; break;
	case 1:	*(unsigned int *) DMSDN	= 0x6800; break;
	case 2:	*(unsigned int *) DMSDN	= 0x4800; break;
/*										 8		DBLW = 1, double words	*/
	}
	
	*(unsigned int *) DMSA	= DMMCR1;
	*(unsigned int *) DMSDN	= 0x7341;
    /*                            7    AUTOINIT = 0			*/
    /*                                 DINM = 1, interrupts based on IMOD bit */
    /*                                 IMOD = 1, interrupt at full buffer */
    /*                                 CTMOD = 1, ABU mode */
    /*                             3   SIND = 011, source post increment */
    /*                              4  DMS = 01, data space */
    /*                               1 DIND = 000, no destination increment */
    /*                                 DMD = 01, data space */ 
                               
/*	source = DRR2 */    
	*(unsigned int *) DMSA	= DMSRC2;
	*(unsigned int *) DMSDN	= pDC->serial->hMcbsp + MCBSP_DRR2;
/*	destination = rx_buf */
	*(unsigned int *) DMSA	= DMDST2;
	*(unsigned int *) DMSDN	= (unsigned int) &rx_buf;

	*(unsigned int *) DMSA	= DMCTR2;
	*(unsigned int *) DMSDN	= 0x001a;

/*	receive sync */
	*(unsigned int *) DMSA	= DMSFC2;
	switch (pDC->serial->port)
	{
	case 0:	*(unsigned int *) DMSDN	= 0x1800; break;
	case 1:	*(unsigned int *) DMSDN	= 0x5800; break;
	case 2:	*(unsigned int *) DMSDN	= 0x3800; break;
      /*                                       8 DBLW = 1, double words	*/
	}

	*(unsigned int *) DMSA	= DMMCR2;
	*(unsigned int *) DMSDN	= 0x504D;
     /*                           5	   AUTOINIT = 0 */
     /*		                     DINM = 1, interrupts based on IMOD bit */
     /*                                IMOD = 0, interrupt at full buffer */
     /*                                CTMOD = 1, ABU mode */
     /*                            0   SIND = 000, no source increment */
     /*                             4  DMS = 01, data space */
     /*                              D DIND = 011, destination post increment */
     /*                                DMD = 01, data space */ 
                               
	asm("	rpt #100");
	asm("	nop");
		
/*	increment = 0 */	
	*(unsigned int *) DMSA	= DMIDX0;
	*(unsigned int *) DMSDN	= 0x0001;

/*	set DMA priority and start */	
	*(unsigned int *) 0x54 = 0x0686;
	
	HWI_enable();
	IMR |= 0x0480;

	pDC->serial->sConfig.spcr = 0x00400000;
	MCBSP_ConfigA(pDC->serial->hMcbsp, &pDC->serial->sConfig);  
	pDC->serial->sConfig.spcr = 0x00410001;
	MCBSP_ConfigA(pDC->serial->hMcbsp, &pDC->serial->sConfig);  
	pDC->serial->sConfig.spcr = 0x00C10001;
	MCBSP_ConfigA(pDC->serial->hMcbsp, &pDC->serial->sConfig);  
}
                
/****************************************************************/
/* configuration function.                                      */
/*  sets up MCBSP, if required.                                 */
/*  writes all configuration data to all AICs in chain          */
/****************************************************************/
TTIDCSTATUS aic27_configure(void *pDC)
{                   
/* list of register addresses for initialization loop */
	unsigned int uiRegs[31] = {
		0x00, 0x02, 0x04, 0x06, 0x0a, 0x0c, 0x0e,
		0x10, 0x12, 0x14, 0x16, 0x18, 0x1a, 0x1c,
		0x20, 0x22, 0x26, 0x2a, 0x2c, 0x2e,
		0x30, 0x32, 0x36, 0x38, 0x3c, 0x3e,
		0x40,
		0x56,
		0x70, 0x72, 0x74};
	TAC97T AC97T; 
	static int iDSPinit = 0;
	int i;           
	
   	if (!iDSPinit)
   	{
		/* initialize AC97 element count structures */		          
		AC97RC.uiValid = 0;
		AC97WC.uiValid = 0;
		AC97RC.TAG = 0;
		AC97WC.TAG = 0;
		for (i = 0; i < 12; i++)
		{
			AC97RC.E[i].callback = 0;
			AC97WC.E[i].callback = 0;
			AC97RC.E[i].pData = 0;
			AC97WC.E[i].pData = 0;
			AC97RC.E[i].uiCount = 0;
			AC97WC.E[i].uiCount = 0;
		}      
	
		for (i = 0; i < 16; i++)
		{
			tx_buf[i] = 0;		/* first transmit buffer */
			tx_buf[i + 16] = 0; /* second transmit buffer */
			rx_buf[i] = 0;      /* receive buffer */
		}
    
	    /* initialize McBSP and DMA */
		dsp_init(pDC);

		aic27_reset();

		iDSPinit = 1;
	}

	/* initialize AC97 frame */	
	AC97T.PCM_LEFT = 0;
	AC97T.PCM_RIGHT = 0;
	AC97T.RSRVD1 = 0;
	AC97T.PCM_CENTER = 0;
	AC97T.PCM_L_SURR = 0;
	AC97T.PCM_R_SURR = 0;
	AC97T.PCM_LFE = 0;
	AC97T.RSRVD2 = 0;
	AC97T.RSRVD3 = 0;
	AC97T.GPIO_CTRL = 0;

	/* the AC97 frame contains a valid address and valid command data */	
	AC97T.TAG = T_CMD_ADR | T_CMD_DATA;

	/* go through all 31 configuration registers */	                      
	for (i = 0; i < 31; i++)
	{
		AC97T.CMD_ADR = (long) uiRegs[i] << 12;	/* AC97 address word has lsb at bit 12 */
		/* get the i. creg value from the TAIC27 structure */
		AC97T.CMD_DATA = *((&(((TAIC27*) pDC)->creg00.value)) + i) << 4;
		aic27_write_frame(pDC, &AC97T);
	}

	return TIDC_NO_ERR;
}

/****************************************************************/
/* set power mode                                               */
/****************************************************************/
void aic27_power(void *pDC, int bDown)
{
/* not implemented due to the variety of available power down modes.
   use aic27_write_frame instead */
}          

/****************************************************************/
/* read one word                                                */
/****************************************************************/
long aic27_read(void *pDC)
{          
/* not implemented due to the variety of available input channels.
   use aic27_read_frame instead */
   return 0;
}      
                                   
/****************************************************************/
/* write one word                                               */                                  
/****************************************************************/
void aic27_write(void *pDC, long lData)
{          
/* not implemented due to the variety of available output channels.
   use aic27_write_frame instead */
}      
                                  
/****************************************************************/
/* transfer block of data from AIC to memory                    */
/*   pData:    pointer to AC97Count structure                   */
/*   ulCount:  N/A                                              */
/*   callback: N/A                                              */
/****************************************************************/
void aic27_rblock(void *pDC, void *pData, unsigned long ulCount, void (*callback) (void *))
{ 
	int i;
	TAC97Count *pAC97RC = pData;

	/* prevent ISR from interfering with structure while structure is being updated */	
	AC97RC.uiValid = 0;
	
	/* only copy valid element pointers, counters and callback functions to AC97RC */
	for (i = 0; i < 12; i++)
	{
		if (pAC97RC->TAG & (0x4000 >> i))
		{
			AC97RC.E[i].pData = pAC97RC->E[i].pData;
			AC97RC.E[i].uiCount = pAC97RC->E[i].uiCount;
			AC97RC.E[i].callback = pAC97RC->E[i].callback;
		}
	}

	/* set AC97 tag and make AC97RC available to ISR */
	AC97RC.TAG = pAC97RC->TAG | 0x8000;	
	AC97RC.uiValid = 1;
}

/****************************************************************/
/* transfer block of data from memory to AIC                    */
/*   pData:    pointer to AC97Count structure                   */
/*   ulCount:  N/A                                              */
/*   callback: N/A                                              */
/****************************************************************/
void aic27_wblock(void *pDC, void *pData, unsigned long ulCount, void (*callback) (void *))
{ 
	int i;
	TAC97Count *pAC97WC = pData;
	
	/* prevent ISR from interfering with structure while structure is being updated */	
	AC97WC.uiValid = 0;
	
	/* only copy valid element pointers, counters and callback functions to AC97WC */
	for (i = 0; i < 12; i++)
	{
		if (pAC97WC->TAG & (0x4000 >> i))
		{
			AC97WC.E[i].pData = pAC97WC->E[i].pData;
			AC97WC.E[i].uiCount = pAC97WC->E[i].uiCount;
			AC97WC.E[i].callback = pAC97WC->E[i].callback;
		}
	}

	/* set AC97 tag and make AC97WC available to ISR */
	AC97WC.TAG = pAC97WC->TAG | 0x8000;	
	AC97WC.uiValid = 1;
}

