/****************************************************************/
/* Texas Instruments Data Converter API 2.1 for C5400           */
/* $Revision: 7 $                      $JustDate: 21.09.00 $ */
/****************************************************************/

#include "dc_conf.h"        /* has the CHIP_xxxx define for CSL */
#include "tidc_api.h"

/****************************************************************/
TTIDCSTATUS dc_configure(void *pDC)
{
#ifdef TIDC_DEBUG
      if(pDC == 0)
           return TIDC_ERR_FXNNULL;
#endif
	return ((TTIDC *) pDC)->configure(pDC);
}

void dc_power(void *pDC, int bDown)
{
#ifdef TIDC_DEBUG
      if(pDC == 0)
           return;
#endif
	((TTIDC *) pDC)->power(pDC, bDown);
}      

long dc_read(void *pDC)
{
#ifdef TIDC_DEBUG
      if(pDC == 0)
           return 0;
#endif
	return ((TTIDC *) pDC)->read(pDC);
}              

void dc_write(void *pDC, long lData)
{
#ifdef TIDC_DEBUG
      if(pDC == 0)
           return;
#endif
	((TTIDC *) pDC)->write(pDC, lData);
}              

void dc_rblock(void *pDC, void *pData, 
               unsigned long ulCount, void (*callback) (void *))
{
#ifdef TIDC_DEBUG
      if(pDC == 0)
           return;
#endif
	((TTIDC *) pDC)->rblock(pDC, pData, ulCount, callback);
}

void dc_wblock(void *pDC, void *pData, 
               unsigned long ulCount, void (*callback) (void *))
{
#ifdef TIDC_DEBUG
      if(pDC == 0)
           return;
#endif
	((TTIDC *) pDC)->wblock(pDC, pData, ulCount, callback);
}

/****************************************************************/
/* MCBSP support                                                */
/* version: 0.1                                                 */
/* provides basic MCBSP functions. compatible with CSL6000      */
/* once a Chip Support Library for C5400 is available this will */
/* not be required anymore                                      */
/* Texas Instruments Inc. 2000                                  */
/****************************************************************/

#ifndef CSL_AVAILABLE

#define MCBSP_ERR -1;
                
/****************************************************************/
/* retrieves a valid handle to the MCBSP port in hDevNum.       */
/* (de) allocates the handle, based on the state of bAllocate.  */ 
/****************************************************************/
MCBSP_HANDLE MCBSP_Handle(MCBSP_HANDLE hDevNum, int bAllocate)
{
	static unsigned int uiHandles = 0;                             
	unsigned int uiIndex = 0;
	
	switch (hDevNum)
	{
	case MCBSP_DEV0: uiIndex = 1; break;
	case MCBSP_DEV1: uiIndex = 2; break;
	case MCBSP_DEV2: uiIndex = 4; break;
	default: return MCBSP_NODEV;
	}
	           
	if (bAllocate)
		if (uiHandles && uiIndex)
			return MCBSP_NODEV;
		else
		{                  
			uiHandles |= uiIndex;
			return hDevNum;
		}
	else
		uiHandles &= !uiIndex;
		
	return MCBSP_NODEV;
}

/****************************************************************/
/* opens the MCBSP given in DevNum. see CSL spec                */
/****************************************************************/
MCBSP_HANDLE MCBSP_Open(MCBSP_HANDLE DevNum, UINT32 Flags)
{   
	MCBSP_HANDLE hMCBSP = MCBSP_Handle(DevNum, 1);
	
	if (!hMCBSP)
		return hMCBSP;
		
	if (Flags && MCBSP_OPEN_RESET)
		*(unsigned long *) (hMCBSP + MCBSP_SPCR) &= !0x00010001;
	
	return hMCBSP;
} 

/****************************************************************/
/* closes the MCBSP given in hMcbsp. see CSL spec               */
/****************************************************************/
void MCBSP_Close(MCBSP_HANDLE hMcbsp)
{                           
	MCBSP_CONFIG sConfig;
	sConfig.spcr = 0;
	sConfig.rcr = 0;
	sConfig.xcr = 0;
	sConfig.srgr = 0;
	sConfig.mcr = 0;
	sConfig.rcer = 0;
	sConfig.xcer = 0;
	sConfig.pcr = 0;
	
	MCBSP_ConfigA(hMcbsp, &sConfig);
	
	MCBSP_Handle(hMcbsp, 0);
}

/****************************************************************/
/* configures the MCBSP given in hMcbsp. see CSL spec           */           
/****************************************************************/
void MCBSP_ConfigA(MCBSP_HANDLE hMcbsp, MCBSP_CONFIG *Config)
{
	volatile unsigned int *pM = (unsigned int *) hMcbsp;
	volatile unsigned int *pS = (unsigned int *) hMcbsp - 1;
	
	*pS = MCBSP_SPCR + 1;	*pM = (Config->spcr & 0xFFFF0000) >> 16;
	*pS = MCBSP_SPCR;		*pM = Config->spcr & 0xFFFF;
	*pS = MCBSP_RCR + 1;	*pM = (Config->rcr & 0xFFFF0000) >> 16;
	*pS = MCBSP_RCR;		*pM = Config->rcr & 0xFFFF;
	*pS = MCBSP_XCR + 1;	*pM = (Config->xcr & 0xFFFF0000) >> 16;
	*pS = MCBSP_XCR;		*pM = Config->xcr & 0xFFFF;
	*pS = MCBSP_SRGR + 1;	*pM = (Config->srgr & 0xFFFF0000) >> 16;
	*pS = MCBSP_SRGR;		*pM = Config->srgr & 0xFFFF;
	*pS = MCBSP_MCR + 1;	*pM = (Config->mcr & 0xFFFF0000) >> 16;
	*pS = MCBSP_MCR;		*pM = Config->mcr & 0xFFFF;
	*pS = MCBSP_RCER + 1;	*pM = (Config->rcer & 0xFFFF0000) >> 16;
	*pS = MCBSP_RCER;		*pM = Config->rcer & 0xFFFF;
	*pS = MCBSP_XCER + 1;	*pM = (Config->xcer & 0xFFFF0000) >> 16;
	*pS = MCBSP_XCER;		*pM = Config->xcer & 0xFFFF;
	*pS = MCBSP_PCR;		*pM = Config->pcr & 0xFFFF;
}                   

#endif		/* CSL_AVAILABLE */

/****************************************************************/
/* END of preliminary MCBSP support                             */
/****************************************************************/