/****************************************************************/
/* Texas Instruments Data Converter API 2.1 for C5400           */
/* $Revision: 12 $                      $JustDate:  3/20/01 $ */
/****************************************************************/
#ifndef TIDC_API_H
#define TIDC_API_H

//#include <csl.h>			/* TI chip support library */

/****************************************************************/
/* return types and error values                                */
/****************************************************************/
#define TTIDCSTATUS       int
#define TIDC_NO_ERR       (0)
#define TIDC_ERR_NODEVICE (-1)
#define TIDC_ERR_MCBSP    (-2)
#define TIDC_ERR_FXNNULL  (-3)

/****************************************************************/
/* common DC structure                                          */
/****************************************************************/
typedef struct
{      
	TTIDCSTATUS (*configure) (void *pDc);
	void (*power) (void *pDc, int bDown);
	long (*read) (void *pDc);
	void (*write) (void *pDc, long lData); 
	void (*rblock) (void *pDC, void *pData, 
            unsigned long ulCount, void (*callback) (void *));
	void (*wblock) (void *pDC, void *pData, 
            unsigned long ulCount, void (*callback) (void *));
	void* reserved[4];
} TTIDC;

/****************************************************************/
/* API functions                                                */
/****************************************************************/
#ifdef __cplusplus
#define DCPAPI extern "C"
#else
#define DCPAPI extern
#endif

DCPAPI TTIDCSTATUS dc_configure(void *pDC);
DCPAPI void dc_power(void *pDC, int bDown);  
DCPAPI long dc_read(void *pDC);
DCPAPI void dc_write(void *pDC, long lData);
DCPAPI void dc_rblock(void *pDC, void *pData, unsigned long ulCount, 
               void (*callback) (void *));
DCPAPI void dc_wblock(void *pDC, void *pData, unsigned long ulCount, 
               void (*callback) (void *));

/****************************************************************/
/* MCBSP support                                                */
/* version: 0.1                                                 */
/* provides basic MCBSP functions. compatible with CSL6000      */
/* once a Chip Support Library for C5400 is available this will */
/* not be required anymore                                      */
/* Texas Instruments Inc. 2000                                  */
/****************************************************************/

#ifndef CSL_AVAILABLE
#define MCBSP_NODEV 0
#define MCBSP_DEV0  0x0039
#define MCBSP_DEV1  0x0049
#define MCBSP_DEV2  0x0035
                          
#define MCBSP_DRR2  0x0020 - MCBSP_DEV0
#define MCBSP_DRR1  0x0021 - MCBSP_DEV0
#define MCBSP_DXR2  0x0022 - MCBSP_DEV0
#define MCBSP_DXR1  0x0023 - MCBSP_DEV0
                          
#define MCBSP_SPCR  0x0000
#define MCBSP_RCR   0x0002
#define MCBSP_XCR   0x0004
#define MCBSP_SRGR  0x0006
#define MCBSP_MCR   0x0008
#define MCBSP_RCER  0x000A
#define MCBSP_XCER  0x000C
#define MCBSP_PCR   0x000E

#define MCBSP_OPEN_RESET 1
#define MCBSP_HANDLE unsigned long
#define UINT16 unsigned int
#define UINT32 unsigned long

/* configuration data structure, used by MCBSP_ConfigA function */
/* compatible with C6000 CSL. registers are 32-bit. */
/* spcr = spcr1 << 16 + spcr2 etc. */

typedef struct
{
    UINT32 spcr;
    UINT32 rcr;
    UINT32 xcr;
    UINT32 srgr;
    UINT32 mcr;
    UINT32 rcer;
    UINT32 xcer;
    UINT32 pcr;
} MCBSP_CONFIG;
                                                                  
/* MCBSP_Open opens a McBSP (MCBSP_DEVx x=0/1/2) and returns a valid handle */                                                                  
DCPAPI MCBSP_HANDLE MCBSP_Open(MCBSP_HANDLE DevNum, UINT32 Flags);                   

/* MCBSP_ConfigA configures the McBSP in hMcbsp with the data in Config. See DSP manual. */
DCPAPI void MCBSP_ConfigA(MCBSP_HANDLE hMcbsp, MCBSP_CONFIG *Config);

/* read one word from the McBSP. does not wait until data is available */
static inline unsigned int MCBSP_Read(MCBSP_HANDLE hMcbsp)
{
	*(unsigned int *) (hMcbsp - 1) = 0;
	switch (hMcbsp)
	{
	case MCBSP_DEV0: return *(unsigned int *) (0x0021);
	case MCBSP_DEV1: return *(unsigned int *) (0x0041);
	case MCBSP_DEV2: return *(unsigned int *) (0x0031);
	}
	return 0;
}

/* write one word to the McBSP. does not wait until data is transmitted */
static inline void MCBSP_Write(MCBSP_HANDLE hMcbsp, UINT32 Val)
{
	*(unsigned int *) (hMcbsp - 1) = 0;
	
	switch (hMcbsp)
	{
	case MCBSP_DEV0: 
		*(unsigned int *) (0x0022) = (Val & 0xFFFF0000) >> 16;
		*(unsigned int *) (0x0023) = (Val & 0xFFFF);
		break;
	case MCBSP_DEV1: 
		*(unsigned int *) (0x0042) = (Val & 0xFFFF0000) >> 16;
		*(unsigned int *) (0x0043) = (Val & 0xFFFF);
		break;
	case MCBSP_DEV2: 
		*(unsigned int *) (0x0032) = (Val & 0xFFFF0000) >> 16;
		*(unsigned int *) (0x0033) = (Val & 0xFFFF);
		break;
	}
} 

/* returns != 0, if receive register is full */
static inline int MCBSP_Rfull(MCBSP_HANDLE hMcbsp)
{
	*(unsigned int *) (hMcbsp - 1) = MCBSP_SPCR;
	return ((*(unsigned int *) hMcbsp) & 0x04);
}
               
/* returns != 0, if transmitter is empty */
static inline int MCBSP_Xempty(MCBSP_HANDLE hMcbsp)
{
	*(unsigned int *) (hMcbsp - 1) = MCBSP_SPCR + 1;
	return !((*(unsigned int *) hMcbsp) & 0x04);
}
     
static inline int MCBSP_XReady(MCBSP_HANDLE hMcbsp)
{
	*(unsigned int *) (hMcbsp - 1) = MCBSP_SPCR + 1;
	return ((*(unsigned int *) hMcbsp) & 0x02);
}
#endif    /* CSL_AVAILABLE */
/****************************************************************/
/* END of preliminary MCBSP support                             */
/****************************************************************/


/****************************************************************/
/* common serial port structure                                 */
/****************************************************************/
typedef struct
{
    MCBSP_CONFIG   sConfig;  /* Serial Port Config info               */    
    MCBSP_HANDLE   hMcbsp;   /* Serial Port Handle                    */     
    unsigned int   port;     /* number of serial port used            */
    unsigned short intnum;   /* Interrupt number to be used by driver */
} DCP_SERIAL;    
 
#endif      /* #ifndef TIDC_API_H  */
