/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... CSL - chip support library service layer interface
* FILENAME...... csl.h
* DATE CREATED.. Fri 06/11/1999 
* PROJECT....... CSL - Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:         06/11/1999  Created
*   MODIFIED:        11/13/1999  Modified for TMS320C54xx
*   MODIFIED:        04/12/2001  Changed CSL_version
*   LAST MODIFIED:   04/16/2001  updated CSL_init
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the CSL library)
*
*
*
\******************************************************************************/
#ifndef _CSL_H_
#define _CSL_H_   

#include <_csl.h>
#include <csl_timer.h>

/****************************************\
* CSL scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C" 
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CSL_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/****************************************\
* CSL global macro declarations
\****************************************/

#define __CSL_VERSION       "CSL VERSION 2.1.1.1b ["__DATE__"] ["__TIME__"]"

/****************************************\
* CSL global typedef declarations
\****************************************/
  
typedef union {
  struct {
    Uint16 biosPresent;
    _IRQ_Dispatch *dispatchTable;
    Uint16 timerUsed;
    Uint16 timerNum;
  } args;
  struct {
    TIMER_Handle hTimer;
    Uint32 *event2IntTbl;
    Uint32 *int2EventTbl;
  } ret;
} _CSL_Config;

   
/****************************************\
* CSL global variable declarations
\****************************************/

/****************************************\
* CSL global function declarations
\****************************************/

CSLAPI void CSL5510_LIB_();
CSLAPI void CSL5510_PG1_0_LIB_();
CSLAPI void CSL5510_PG2_0_LIB_();
CSLAPI void CSL5509_LIB_();
CSLAPI void CSL5509_PG2_0_LIB_();
CSLAPI void CSL5509_PG1_0_LIB_();

/****************************************\
* CSL inline function declarations
\****************************************/

IDECL void CSL_init(void);
IDECL void _CSL_init(_CSL_Config *config);

/*******************************************************************************\
* Setup (non Rom model) or retrieve (ROM model) address of global data
\*******************************************************************************/
/* ROM Area */

/*******************************************************************************\
* Chip Support Library Global Initialization Function
\*******************************************************************************/

#ifdef USEDEFS
 void CSL_init(void) {
    Uint16 i;

    *(_CSL_SysStatusObj **)CSL_DATA_PTR = (_CSL_SysStatusObj*)&_CSL_DataObj;

     CSL_SYS_DATA.Version = __CSL_VERSION;
     CSL_SYS_DATA.DateStamp =  __CSL_VERSION;

     CSL_SYS_DATA.DispatchTablePtr = 0xFFFFFFFFul;
     CSL_SYS_DATA.ErrFunc       = 0xFFFFFFFFul;

    /*********************************************\
    * Initialize global init flags for all modules
    \*********************************************/

     CSL_SYS_DATA.BiosPresent    = FALSE;
     CSL_SYS_DATA.DmaAllocMask   = 0x0000u;
    
     CSL_SYS_DATA.DatOpenFlag    = 0x0000u;
     CSL_SYS_DATA.DatSubmitMask  = 0x0000u;
     CSL_SYS_DATA.DatChaPriority = 0x0000u;
     
     CSL_SYS_DATA.McbspPortAllocMask = 0x0000u;
     CSL_SYS_DATA.TimerAllocMask = 0x0000u;
     CSL_SYS_DATA.PllAllocMask   = 0x0000u;
     CSL_SYS_DATA.ErrCnt         = 0x0000u;

     for(i=0; i<= IRQ_EVENT_CNT-1; i++) {
        CSL_IRQ_DATA.IrqIntTable[i] = i;
        CSL_IRQ_DATA.IrqEventTable[i] = IRQ_MASK32(i);
     }
    
  }  


 /*****************************************************************\
 \*****************************************************************/
 void _CSL_init(_CSL_Config *config) {

  Uint16 old_intm;
  _CSL_Config *cfg = config;
  TIMER_Handle hTimer   = (TIMER_Handle)INV;
  Uint16 biosPresent    = cfg->args.biosPresent;
  _IRQ_Dispatch *dispatchTable = cfg->args.dispatchTable;
  Uint16 timerUsed      = cfg->args.timerUsed;
  Uint16 timerNum       = cfg->args.timerNum;

  CSL_init();

  old_intm = IRQ_globalDisable();

  _IRQ_init(dispatchTable, biosPresent);

  if (timerUsed) {
    hTimer = TIMER_open(timerNum,0); 
  }

  cfg->ret.hTimer = hTimer;
  cfg->ret.event2IntTbl = (Uint32*)(&(CSL_IRQ_DATA.IrqEventTable));
  cfg->ret.int2EventTbl = (Uint32*)(&(CSL_IRQ_DATA.IrqIntTable));

  IRQ_globalRestore(old_intm);
}

#endif /* USEDEFS */ 
#endif /* _CSL_H_ */
/******************************************************************************\
* End of csl.h
\******************************************************************************/

