/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/*
 *  ======== dtr.h ========
 *  Transformer Device Module Interface
 *
 */

#ifndef DTR_
#define DTR_

#include <dev.h>
#include <fxn.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifdef _FLOAT_
typedef Float	DTR_Scale;
#else  /* _FLOAT_ */
typedef Int	DTR_Scale;
#endif /* _FLOAT_ */

typedef DTR_Scale	DTR_Elem;

#define DTR_init	((Fxn)FXN_F_nop)

extern DEV_Fxns DTR_FXNS;

#ifdef _FLOAT_
extern Void DTR_fix2flt(Arg arg, DTR_Elem *addr, Uns size);
extern Void DTR_flt2fix(Arg arg, DTR_Elem *addr, Uns size);
#endif /* _FLOAT_ */
extern Void DTR_multiply(Arg arg, DTR_Elem *addr, Uns size);

#ifdef _FLOAT_
#define DTR_FLOAT	(Int)DTR_fix2flt	/* fix-to-float */
#define DTR_FIX		(Int)DTR_flt2fix	/* float-to-fix */
#endif /* _FLOAT_ */
#define DTR_SCALE	(Int)DTR_multiply	/* float = float * arg */
#define DTR_USER	(Int)NULL		/* user transformation */

/*
 *  ======== DTR_Params ========
 */
typedef struct {	/* device parameters */
    struct {
	DTR_Scale	value;
    } scale;
    struct {
	Arg		arg;
	Fxn		fxn;
    } user;
} DTR_Params;

extern DTR_Params DTR_PARAMS;		/* default parameter values */

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* DTR_ */
