/****************************************************************************/
/* stdarg.h v2.04                                                          */
/* Copyright (c) 1996-2001 Texas Instruments Incorporated                   */
/****************************************************************************/

#ifndef _STDARG
#define _STDARG

#ifdef __cplusplus
namespace std {
#endif /* __cplusplus */

typedef int *va_list;

#ifdef __cplusplus
} /* namespace std */
#endif

#define va_start(ap, parmN) \
       (ap = ((int *)&parmN)+(sizeof(parmN)-sizeof(int)))

#define va_end(ap)

/****************************************************************************/
/* VA_ARG - Return pointer to the next argument                             */
/*                                                                          */
/* Conventions:                                                             */
/*   1) An argument of size greater then one word is aligned on an even     */
/*      word boundary.                                                      */
/*   2) Argument pointer points to the last word of the previous argument   */
/*      and is updated to point to the last word of the current argument.   */
/*                                                                          */
/* When an argument is passed by-reference (indicated by __va_argref being  */
/* true) the actual argument passed is a pointer and will be treated much   */
/* the same as a "void *" argument.                                         */
/*                                                                          */
/* The first expression of the outer comma expression adds in any necessary */
/* stack alignment per convention 1) above.                                 */
/*                                                                          */
/* The second expression of the outer comma expression increments the       */
/* argument pointer to point to the last word of the argument and produces  */
/* the address to use for the argument.                                     */
/****************************************************************************/

#define va_arg(ap, type)  (						     \
    __va_argref(type) ?							     \
      ((ap) += (sizeof(void *) > 1 && ( ! ((long)(ap) & 1)))) :		     \
      ((ap) += (sizeof(type  ) > 1 && ( ! ((long)(ap) & 1)))),		     \
    __va_argref(type) ?							     \
      ((ap) += sizeof(void *), (** (type **) ((ap) - (sizeof(void *)-1)))) : \
      ((ap) += sizeof(type  ), (*  (type *)  ((ap) - (sizeof(type  )-1))))   \
    )


#ifdef __cplusplus

#ifndef _CPP_STYLE_HEADER
using std::va_list;
#endif /* _CPP_STYLE_HEADER */

#endif /* __cplusplus */

#endif /* _STDARG */
