;***********************************************************
; Version 2.10.03                                           
;***********************************************************
; Note: a symbol "SI_BUGS" is used to make a work around for silicon
; 5510 version1.0. If you are going to use the code on 5510 version1.0
; silicon, you have to put switch -d"SI_BUGS" when you compile the code.
;*********************************************************************
; Function:    cbrev
; Processor:   C55xx
; Description: This function performs bit-reversal of complex data array x.
;              If x==y, in-place bit reversal is performed.
; Usage:    void cbrev (DATA *x, DATA *y, ushort n)
; Copyright Texas instruments Inc, 2000
;****************************************************************

		.mmregs  
		.cpl_on   

		.sect ".fftcode"
        .global _cbrev   

_cbrev:

;//-----------------------------------------------------------------------------
;// Context Save
;//-----------------------------------------------------------------------------

	PSH	mmap(ST2_55)		; preserve ST2 register  

;//-----------------------------------------------------------------------------
;// Initialize
;//-----------------------------------------------------------------------------

	BSET	AR1LC			; circular addressing for AR1
	.arms_off
	BCLR	ARMS			; reset ARMS bit

	MOV	T0, T1			; n in DR1
	SFTL	T1, #1			; 2*n
	MOV	mmap(T1), BK03		; circular buffer size is 2*n 
	MOV	mmap(AR1), BSA01	; circular buffer offset      
 
 	MOV	T0, T1			; n in DR1
	SUB	#1, T1
	MOV	mmap(T1), BRC0		; BRC0 = n - 1

	MOV	XAR1, AC0

	MOV	XAR0, AC1		; 
	MOV	#0, AR1			; output pointer (circular)


	SUB	AC1, AC0		; compare input and output pointers 
	BCC	off_place, AC0 != #0	; if x<>y, do off-place bit reversal

;//-----------------------------------------------------------------------------
;// In-place bit reversal
;//-----------------------------------------------------------------------------
in_place: 

	BSET	AR0LC			; circular addressing for AR0
	MOV	#0, AR0

	RPTBLOCAL	loop1-1 

	MOV	dbl(*AR0), AC0      
	AMOV	AR1, T1			; should be in parallel but CCS1.00b crashes
	
	MOV	dbl(*AR1), AC1
	ASUB	AR0, T1			; should be in parallel but CCS1.00b crashes

 	XCCPART	check1, T1>=#0		; swap only if AR3 < AR2 
	||MOV	AC1, dbl(*AR0+)		; otherwise they are swapped already	
check1:

	XCCPART	check2, T1>=#0
	||MOV	AC0, dbl(*(AR1+T0B))
check2:

loop1:

	B	end  
	
;//-----------------------------------------------------------------------------
;// Off-place bit reversal
;//-----------------------------------------------------------------------------
off_place:  						
 
	RPTBLOCAL	loop2-1            
	MOV	dbl(*AR0+), AC0
	MOV	AC0, dbl(*(AR1+T0B))  

loop2:

;//-----------------------------------------------------------------------------
;// Context Restore
;//-----------------------------------------------------------------------------
end:
      BSET	ARMS			; restore C environment
	POP	mmap(ST2_55)		; restore ST2 register

	RET				; return   

	.end     


