/****************************************************************************
* FILENAME: evm55xflash.c
* VERSION:  2.00  23-MAR-2000
* SCCS ID: 
*
* NOTES:
*   TI Proprietary Information - Internal Data.
*   Copyright (c) 2001, DNA Enterprises, Inc.
*
*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <windows.h>
#include <stdio.h>
#include <conio.h>
#include <io.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include "evm55xdll.h"

/******************************************************************************/
/* Defines
/******************************************************************************/
#define	FLASH_OK				TRUE
#define	FLASH_ERROR				FALSE

#define DEFAULT_PCI_PORT		0

#define BLOCK_SIZE				0x1000

#define S2DATA_SIZE				0x50
#define S2_LEN_SIZE				2
#define S2_ADDR_SIZE			6
#define S2_TYPE_SIZE			2

#define MEMORY_BOOT_START_ADDR	0x200000
#define INVALID_SECTOR			-1
/******************************************************************************/
/* Datat structures
/******************************************************************************/
typedef enum {
    FLASH_ERASE = 1,
    FLASH_READ_WORDS,
    FLASH_READ_COMPARE_HEX,
	FLASH_READ_COMPARE_BIN,
    FLASH_LOAD_HEX,
    FLASH_LOAD_BIN
} FlashCmd, *PFlashCmd;

typedef struct _S2Record {
    char type[2];
    char byteCnt[2];
    char addr[4];
    char *pData;
} S2Record, *PS2Record;

/******************************************************************************/
/* Function prototypes
/******************************************************************************/
int eraseFlash(HANDLE *bh, int sector);
int	loadBinFile(HANDLE *bh, char *filename, ULONG address);
int dumpFlash(HANDLE *bh, ULONG address, ULONG length, char *filename);
int verifyBlockBin(HANDLE *bh, char *filename, ULONG address);
int verifyBlockHex(HANDLE *bh, char *filename);
int loadHexFile(HANDLE *bh, char *filename);
int getSectorNumber(ULONG addr);
void hpiOn(HANDLE *bh, LPVOID *hh);
void hpiOff(LPVOID *hh);
void pressAnyKey(void);
void usage(void); 
void writeFlashData(PUSHORT pData, ULONG len, FILE *fp);
void parseArgs();
void sarg( char **var, char *def_string );
void arg( char *fmt, ULONG *var, int def_value );
ULONG getS2Record(FILE *fp, PULONG pAddr);

#define BUF_SIZE	0x100
USHORT buf[BUF_SIZE];


/******************************************************************************/
/* Global variables
/******************************************************************************/
int   argc;    // Character count      
char  **argv;  // Cmd line buffer      
int   argIndx; // Current char index   
char  *argp;   // Current char pointer 
int   iCmd = 0;
int   iSectorNum = -1;
int	  debugMode = 0;
char  *iName =NULL; // Filename to store data received from DSP           
int   iLen   = 0;   // number of words
int   iAddr  = 0;   // DSP address
int   iKnownState = 0;
ULONG boardIndex;
int	  target;
BOOL p = 1;
USHORT s2Data[S2DATA_SIZE];
ULONG dumpIndx = 0;
ULONG dumpAddr = 0;
BOOL  dumpFlag = FALSE;
static USHORT bootAddr = 0;
char *gPtr = NULL;
char *gFirstPtr = NULL;
char *gLastPtr = NULL;
int  lastBuffer = 0;
ULONG wordsWritten = 0;
const char *introSplash = "\n\
TMX320VC5510 Prototype Board Flash Utility, Version 2.04\n\n";
const char *usageHelp = "\
Usage: evm55xflash [ -h|? ] |\n\
                   [ -b num ] \n\
                   [ -d ] |\n\
                   [ -e sector] |\n\
                   [ -r address length [filename] ] |\n\
                   [ -cb filename address ] |\n\
                   ] -ch filename ]\n\
                   [ -lb filename address ] |\n\
                   [ -lh filename] |\n\
                   [ -x ]\n\
  -h|?    = Display this help text.\n\
  -b      = Selects specific PCI Prototype Board. (Default=0)\n\
  -d      = Debug mode.\n\
  -e      = Erase sector specified in Flash (0-10). Entire device=-1)\n\
  -r      = Read length words from Flash address and output to screen or file.\n\
  -cb     = Read data from binary file and compares to Flash memory at address.\n\
  -ch     = Reads data from S2 hex file and compares to Flash memory.\n\
  -lb     = Load binary file into Flash.\n\
  -lh     = Load hex file into Flash. Hex file in Motorola S2 record format.\n\
  -x      = Initialize DSP and JTAG TBC to known state.\n";


/*
// Test code to write binary file
void writeBin()
{
	FILE   *fp;
	ULONG  i;

	fp = fopen("binfile.bin", "wb");

	for (i=0; i<0x10000; i++)
	   fwrite(&i, sizeof(USHORT), 1, fp);

	fclose(fp);
}
*/


/******************************************************************************/
/* Main entry point
/******************************************************************************/
int main(int argc1, char *argv1[])
{
	int		argi = 1;			//arg index
	int		result;
	char	c;
	
	UCHAR	boardLabel[64];		//space for text description
	ULONG	rev;
	HANDLE	boardHandle;
	EVM55X_BOARD_TYPE realBoardType;
	
	// Copy arguments to global variables
	argc=argc1;
	argv=argv1;
	
	iCmd = 0;

	debugMode = 0; //defaults to on for now
	
	printf("%s", introSplash);
	
	if(argc < 2) //should be at least 2 as in "evm55xflash -E"
		usage();
	
	parseArgs();

	// Line below is to support binary file testing
	//writeBin();
	
	/***************************************************************************/
	/* Open a driver connection to a specific pci2040 board.                   */
	/***************************************************************************/
	if (debugMode) printf("Opening board\n"); 
	
	boardHandle = evm55x_open(boardIndex, 1);

	do {

	if(boardHandle == INVALID_HANDLE_VALUE) 
	{
		printf("**Error: Cannot connect to TMX320VC5510 Prototype Board board using:\n ");
		printf("         board index: 0x%03x\n", boardIndex);
		break;
	}

    // reset board
	evm55x_reset_board(boardHandle);

    if (iKnownState)
    {
	    if (debugMode) printf("Initializing DSP and JTAG TBC to known state.\n");

		// Reset and unreset DSP to bring DSP to known state
        // If this is not done, then user could have problems due
        // to an unknown state of the DSP.
        evm55x_reset_dsp(boardHandle,0);
        evm55x_unreset_dsp(boardHandle,0);

        // Reset/unreset TBC to prevent problems with user exiting
        // emulator and not being able to access board properly
        evm55x_tbc_reset(boardHandle);
        evm55x_tbc_unreset(boardHandle);
    }
	
	/***************************************************************************/
	/* Read board type and revision from PCI configuration space of the board. */
	/***************************************************************************/
	if (debugMode) printf("Reading board type and revision.\n");
	
	if(evm55x_board_info(boardHandle, &realBoardType, &rev)) 
	{
		switch (realBoardType)
		{
		case TYPE_PCI2040_C5510_EVM:   
            strcpy(boardLabel,"TMX320VC5510 Prototype Board");  
            break;
            
		default: strcpy(boardLabel,"Unknown");
		}
		if (rev == PCI_INVALID_REV_ID)
			 printf("Found board type: %s, Revision: Unknown\n",boardLabel);
		else printf("Found board type: %s, Revision: %d\n", boardLabel, rev);
	} 
	else 
	{
		printf("Error: evm55x_board_info() failed.\n");
		break;
	}
	
	result = 1;
	
	switch(iCmd) 
	{
	//-e = erase flash block
	case FLASH_ERASE:
        if (iSectorNum == -1)
            printf("\nErasing entire Flash...\n");
        else
            printf("\nErasing Flash sector number: %d...\n", iSectorNum);

        result = eraseFlash(&boardHandle, iSectorNum);
        break;
		
		//-r = read length words from flash at address and write to filename
	case FLASH_READ_WORDS:				
		result = dumpFlash(&boardHandle, iAddr, iLen, iName);
		break;
		
		//-cb = read words from flash at address and compare to data in bin file
	case FLASH_READ_COMPARE_BIN:				
		result = verifyBlockBin(&boardHandle, iName, iAddr);
		break;

		//-cb = read words from flash at address and compare to data in hex file
	case FLASH_READ_COMPARE_HEX:				
		result = verifyBlockHex(&boardHandle, iName);
		break;
		
		//-lh = read COFF file, interpret and write
	case FLASH_LOAD_HEX:				
		result = loadHexFile(&boardHandle, iName);
		break;
        		
        //-lb = load bin file
    case FLASH_LOAD_BIN:
		result = loadBinFile(&boardHandle, iName, iAddr);
		break;
		
	default:				//no operation specified
		printf("\n\nNo operation was specified: %s\n\n", argv[argi]);
		usage();
	}
	
	if(result != FLASH_OK)
		printf("\nError: Flash Operation Failed.\n");
	else
		printf("\nFlash Operation Successful.\n");
	
	if(!evm55x_close(boardHandle)) 
	{
		printf("Error: evm55x_close() failed.\n");
		break;
	}

	} while (0);

	// Allow user to see results ...
    printf( "\nPress any key to exit." );
	c = _getch();
	
	return (result);
}

/******************************************************************************/
/* erase entire flash memory
/******************************************************************************/
int eraseFlash(HANDLE *bh, int sector)
{
	int		rc;

	if((rc = evm55x_erase_flash(*bh, sector)) != FLASH_OK) 
	{								
		if((rc = evm55x_erase_flash(*bh, sector)) != FLASH_OK) 
		{								
        //If error, report problem
        if (sector == -1)
            printf("\n	Flash chip erase failed. (%X)\n", rc);
        else
            printf("\n	Flash sector (%d) erase failed. (%X)\n", sector, rc);
		}
	}

	return(rc);
}
			
/******************************************************************************/
/* load binary data into flash starting at address
/******************************************************************************/
int	loadBinFile(HANDLE *bh, char *filename, ULONG addr)
{
	int     fh;
	LPVOID	hh;
	int		rc = 0;
	ULONG   len;
	USHORT *pData = NULL;
	int     startSector;
	int     endSector;

	if(debugMode) printf("\nReading file %s to write to Flash memory\n", filename); 
	
    // open HPI
	hpiOn(bh, &hh);					
	    

    // open binary file
    if ((fh = _open( filename, _O_RDONLY | _O_BINARY )) == -1)
	{
        printf("\nCannot open file \"%s\" for reading.\n", filename);
        return (FLASH_ERROR);
	}

    // allocate memory for data
    pData = (USHORT *)malloc(BLOCK_SIZE*sizeof(short));
	if (pData == NULL)
	{
        printf("\nCannot allocate memory.\n");
		_close(fh);
		return (FLASH_ERROR);
	}

    // Determine size of binary file in words
	len = (ULONG)_lseek(fh,0,SEEK_END) >> 1;
	_lseek(fh,0,SEEK_SET);  // reset pointer to beginning of file

	//we need to determine what sector(s) to erase before writing
    if ((startSector = getSectorNumber(addr)) == INVALID_SECTOR)
	{			
		printf("\n**Error: Address (0x%X) is invalid.\n", addr);
		_close(fh);
        free(pData);
        hpiOff(&hh);
		return(FLASH_ERROR);
	}

    if ((endSector = getSectorNumber(addr+len-1)) == INVALID_SECTOR)
	{			
 		printf("\n**Error: Address (0x%X) is invalid.\n", addr+len-1);
		_close(fh);        
		free(pData);
        hpiOff(&hh);
		return(FLASH_ERROR);
	}

    for (iSectorNum=startSector; iSectorNum<=endSector; iSectorNum++)
    {
        if (p) printf("\nErasing Flash sector %d before programming", iSectorNum); 

        if (!evm55x_erase_flash(*bh, iSectorNum))
		{
			printf("\nError erasing Flash memory\n", filename);
			free(pData);
		    _close(fh);
			hpiOff(&hh);
			return (FLASH_ERROR);
		}
	}
            
    if (p) 
    {
        printf("\nErase complete!\n"); 
    }
         
    while (len = (_read(fh,pData,(BLOCK_SIZE<<1) * sizeof(short)) >> 1))
    {
		if (p)
		{
           printf("Programming Flash from 0x%X - 0x%X\n",addr, addr+len-1);
		}

		// write data to Flash
        rc = evm55x_hpi_write(hh, (PULONG)pData, &len, addr, 0);
            
        if(!rc) 
        {
            printf("Error writing Flash block 0x%X - 0x%X\n", addr, addr+len-1);
			rc = FLASH_ERROR;
			break;
        }	

		// increment address
		addr += len;
    }

	if (rc != FLASH_ERROR)
	{
	    printf("\nFlash was programmed with binary file \"%s\" successfully.\n",filename);
	}
    
    _close(fh);
    free(pData);
    hpiOff(&hh);					
    
	return(rc);
}

/******************************************************************************/
/* Dump length words from flash starting from address and write to filename
/******************************************************************************/
int dumpFlash(HANDLE *bh, ULONG address, ULONG length, char *filename) 
{
	FILE	*fp = NULL;  // default to stdio
	LPVOID	hh;
	ULONG	sz;
	int		rc;
	PUSHORT pData = NULL;

	if(p)
	{ 
		if (filename[0] == '\0')
		{
		   printf("\nReading 0x%X words from Flash at 0x%0X\n", length, address); 
		}
		else
		{
		  printf("\nReading 0x%X words from Flash at 0x%0X, writing to \"%s\"\n", length, address, filename); 
		}
	}

	if (filename[0] != '\0')
	{
	
  	  if((fp = fopen(filename, "w")) == NULL) 
	  {
		printf("\nCannot open file %s to write\n", filename);
		return(FLASH_ERROR);
	  }
	}

	hpiOn(bh, &hh);	//open HPI

	pData = (PUSHORT)malloc(BLOCK_SIZE*sizeof(short));
	
	dumpAddr = address;

	while (length > 0)
	{
		sz = (length > BLOCK_SIZE) ? BLOCK_SIZE : length;

		if((rc = evm55x_hpi_read(hh, (PULONG)pData, &sz, address, 0)) != FLASH_OK) 
		{
			printf("\nError reading Flash at address 0x%X\n", address );
			break;
		} 
		else 
		{			
			writeFlashData(pData, sz, fp);
		}

		length -= sz;
		address += sz;
	}
	
	if (p) printf("\n");

	//close HPI	
	hpiOff(&hh);
	
	if (fp != NULL)
	   fclose(fp);

	return(rc);
}

/******************************************************************************/
/* Format flash data and write to file pointed to by fp (NULL is screen)
/******************************************************************************/
void writeFlashData(PUSHORT pData, ULONG len, FILE *fp)
{
	ULONG i;
	ULONG indx = dumpIndx;
	ULONG addr = dumpAddr;

	if (fp == NULL)
	{
		 printf( "\nFlash memory display starting at 0x%X\n", dumpAddr );
	     printf( "====================================================" );
	}
	else 
	{
		fprintf(fp, "\nFlash memory display starting at 0x%X\n", dumpAddr );
	    fprintf(fp, "====================================================" );
	}

	for (i=0; i<len; i++)
	{
		if (!(dumpIndx % 8))
		{
			if (fp == NULL)
			     printf("\n0x%X:", dumpAddr);
			else fprintf(fp, "\n0x%X:", dumpAddr);

			dumpAddr += 8;
		}
		
		if (fp == NULL)
			 printf(" %04X", pData[i]);
		else fprintf(fp, " %04X", pData[i]);

		dumpIndx++;
	}

	if (!dumpFlag)
	{
		dumpIndx = indx;
		dumpAddr = addr;
		dumpFlag = TRUE;
	}
}


/******************************************************************************/
/* Verify data contained in binary file to data starting at address
/******************************************************************************/
int verifyBlockBin(HANDLE *bh, char *filename, ULONG address) 
{
	FILE	*fp;
	LPVOID	hh;
	ULONG	len;
	ULONG   addr = address;
	int		rc;
	PUSHORT pFileData  = NULL;
	PUSHORT pFlashData = NULL;


	if(debugMode) 
	{ 
		printf("\nComparing data in file \"%s\" with Flash memory at address 0x%X.\n", filename, address); 
	}
	
	//Read file and store in a string
	if((fp = fopen(filename, "rb")) == NULL) 
	{
		printf("\nCannot open file \"%s\" for reading.\n", filename);
		return(FLASH_ERROR);
	}
	
	//Get flash data buffer
    if ((pFlashData = (USHORT *)malloc(BLOCK_SIZE*sizeof(short))) == NULL)
	{
        printf("\nCannot allocate memory.\n");
		fclose(fp);
		return(FLASH_ERROR);
	}
    
	//Get file data buffer
	if ((pFileData  = (USHORT *)malloc(BLOCK_SIZE*sizeof(short))) == NULL)
	{
        printf("\nCannot allocate memory.\n");
		fclose(fp);
		free(pFlashData);
		return(FLASH_ERROR);
	}

    //open HPI	     
	hpiOn(bh, &hh);

	if(debugMode) printf("\nReading file %s to compare to Flash memory\n", filename);	
	
	//Read file 
    while (len = fread(pFileData, sizeof(short), BLOCK_SIZE, fp)) 
    {		
    	 rc = evm55x_hpi_read(hh, (PULONG)pFlashData, &len, addr, 0);
		
		 if(!rc) 
		 {
			printf("\nError reading Flash data from 0x%X - 0x%X\n", addr, addr+len);
			rc = FLASH_ERROR;
			break;
		 }
		
		 if (debugMode)
		 {
            printf("\nComparing file data to Flash block 0x%X - 0x%X...",addr, addr+len-1);
		 }

		 if (memcmp((char *)pFileData, (char *)pFlashData, len*sizeof(short)))
		 {
			printf("\n**Error: Flash mismatch at address block 0x%X - 0x%X\n", addr, addr+len-1);
			rc = FLASH_ERROR;
			break;
		 }
		 else
		 {
            if (debugMode) printf("<Matched>");
		 }

		 // update addr
		 addr += len;
	}

    //close HPI
	hpiOff(&hh);						
	free(pFlashData);
	free(pFileData);
	fclose(fp);
	
	if(rc == FLASH_OK) 
	{
		printf("\n\nBinary file data and Flash memory are the same.  Flash is okay.\n");
	}
	
	return(rc);
}


/******************************************************************************/
/* Verify data contained in HEX file to data in flash                         */
/******************************************************************************/
int verifyBlockHex(HANDLE *bh, char *filename) 
{
	FILE	*fp;
	LPVOID	hh;
	ULONG	len, addr;
	int		rc;
	PUSHORT pFlashData = NULL;
	char    *pFile1;

	if(debugMode) 
	{ 
		printf("\nComparing data in file \"%s\" with Flash memory.\n", filename); 
	}
	
	//Read file and store in a string
	if((fp = fopen(filename, "r")) == NULL) 
	{
		printf("\n	Cannot open file \"%s\" for reading.\n", filename);
		return(FLASH_ERROR);
	}

	//Get flash data buffer
    if ((pFlashData = (USHORT *)malloc(S2DATA_SIZE*sizeof(short))) == NULL)
	{
        printf("\nCannot allocate memory.\n");
		fclose(fp);
		return(FLASH_ERROR);
	}
    
	//Get file data buffer
	if ((pFile1  = (char *)malloc(BLOCK_SIZE*sizeof(short))) == NULL)
	{
        printf("\nCannot allocate memory.\n");
		fclose(fp);
		free(pFlashData);
		return(FLASH_ERROR);
	}

	//gPtr tracks through file data
	gPtr = pFile1;
	gFirstPtr = pFile1;
	
	//Read block of data from file
	if (!(len = fread(gPtr, sizeof(char), BLOCK_SIZE, fp)))
	{
		printf("**Error: \"%s\" is empty.\n", filename);
		fclose(fp);
		free(pFile1);
		free(pFlashData);
		return (FLASH_ERROR);
	}

	//File rest of array with EOF
	if (len < BLOCK_SIZE)
	{
		lastBuffer = 1;
	    memset(gPtr+len, EOF, BLOCK_SIZE-len);
	}
	else 
	{
		//Clear last buffer
		lastBuffer = 0;

    	//Initialize gLastPtr
	    gLastPtr = (char *)((ULONG)gPtr + len);
	}
		
	//Open HPI
	hpiOn(bh, &hh);					

	//Read S2 record data
	while (len = getS2Record(fp,&addr)) 
	{
		//Read Flash at location specified in S2 record
		rc = evm55x_hpi_read(hh, (PULONG)pFlashData, &len, addr, 0);
		
		 if(!rc) 
		 {
			printf("\nError reading Flash data from 0x%X - 0x%X\n", addr, addr+len);
			rc = FLASH_ERROR;
			break;
		 }
		
		 if (debugMode)
		 {
            printf("\nComparing file data to Flash block 0x%X - 0x%X...",addr, addr+len-1);
		 }


		 if (memcmp((char *)s2Data, (char *)pFlashData, len*sizeof(short)))
		 {  ULONG i;

		    printf("\nFile    Flash\n");
			printf("-------------\n");
		    for (i=0;i<len;i++)
				printf("\n0x%04X:0x%04X",s2Data[i],pFlashData[i]);

			printf("\n**Error: Flash mismatch at block 0x%X - 0x%X\n", addr, addr+len-1);

			rc = FLASH_ERROR;
			break;
		 }
		 else
		 {
            if (debugMode) printf("<Matched>");
		 }
	}

	hpiOff(&hh);						//close HPI
	free(pFile1);	
	fclose(fp);
	
	if(rc == FLASH_OK) 
	{
		printf("\n\nHex file data and Flash memory are the same.  Flash is okay.\n");
	}	
	
	return(rc);
}
			
/******************************************************************************/
/* Load Motorola S2 formatted HEX file into flash
/******************************************************************************/
int loadHexFile(HANDLE *bh, char *filename) 
{
	return (evm55x_program_flash(*bh, filename, 0));
}
			
/******************************************************************************/
/* utility functions
/******************************************************************************/
#define ADDRLEN		6
#define TEMPLEN		ADDRLEN+3

ULONG getS2Record(FILE *fp, PULONG pAddr)
{
	ULONG  len = 0, i;
	char   temp[TEMPLEN]; //"0x" + 6 bytes plus  +  NULL character
    char   *pData = NULL;
	char   *stp = "";

	temp[6] = '\0';

    //Check if at end of buffer and read in more data if needed
	if (lastBuffer == 0)
	{
		if ((ULONG)gPtr + 80 > (ULONG)gLastPtr)
		{
			ULONG remain;

			// determine number of remaining char in current buffer
			remain = (ULONG)gLastPtr - (ULONG)gPtr;

			// copy remainder of current buffer to beginning of buffer
			memcpy(gFirstPtr,gPtr,(size_t)remain);

			// temporarily set gLastPtr to end of old data
			gLastPtr = (char *)((ULONG)gFirstPtr + remain);

			// read data into buffer after current data
	        
			//Read block of data from file
			len = fread(gLastPtr, sizeof(char), (BLOCK_SIZE-remain), fp);

			//File rest of array with EOF
			if (len < (BLOCK_SIZE-remain))
			{
				lastBuffer = 1;
				memset(gLastPtr+len, EOF, BLOCK_SIZE-remain-len);
			}
			else 
			{
				//Initialize gLastPtr
				gLastPtr = (char *)((ULONG)gLastPtr + len);
			}

		    // reset gPtr
		    gPtr = gFirstPtr;
		}
	}

    //Search for S2 record
    if ((gPtr = strstr(gPtr, "S2")) != NULL)
    {    
		memset(temp, '\0', 8);
        memcpy(temp, "0x0000000", 7);

        //get record length and adjust for address and checksum fields
        memcpy(temp+strlen(temp)-2, gPtr+2, 2);
		len = strtol( temp, &stp, 0 );
        len -= ((ADDRLEN>>1) + 1);	//factor out address and checksum
        len >>= 1;					//divide by 2 to get actual # of 16-bit words

        //init temp again
		sprintf(temp, "0x000000");	

		//copy address from S2 record
		memcpy(temp+2, gPtr+4, ADDRLEN);

		*pAddr = strtol( temp, &stp, 0 ) >> 1;  // convert to word address

        //point to actual object code
        pData = gPtr+4+ADDRLEN;

        for (i=0; i<len; i++)
        {
			memcpy(temp+strlen(temp)-4, pData, 4);
			s2Data[i] = (USHORT)strtol( temp, &stp, 0 );
            pData += 4;
        }
    }

    // increment gPtr to end of current S record
	gPtr = (char *)((ULONG)gPtr + S2_TYPE_SIZE + S2_ADDR_SIZE + S2_LEN_SIZE + (len<<2) + 2);
 
	return len;
}


//Determine sector # from address 
int getSectorNumber(ULONG addr)
{
    if ((addr >= FLASH_START_ADDR) && (addr <= (FLASH_START_ADDR+0x77ffful)))
        return (((addr-FLASH_START_ADDR) & 0x30000) >> 16);
    else if ( (addr >= (FLASH_START_ADDR+0x78000)) && (addr <= (FLASH_START_ADDR+0x79ffful)) )
        return 0x8;
    else if ( (addr >= (FLASH_START_ADDR+0x7a000)) && (addr <= (FLASH_START_ADDR+0x7bffful)) )
        return 0x9;
    else if ( (addr >= (FLASH_START_ADDR+0x7c000)) && (addr <= (FLASH_START_ADDR+0x7fffful)) )
        return 0xA;
    else
        return INVALID_SECTOR;
}

void hpiOn(HANDLE *bh, LPVOID *hh) 
{
	*hh = evm55x_hpi_open(*bh);		//open HPI

	if(hh == NULL) 
	{
		printf("\n	Cannot gain exclusive access to HPI\n");
		pressAnyKey();
	}
}

void hpiOff(LPVOID *hh) 
{
	if(evm55x_hpi_close(*hh) == FLASH_ERROR) 
	{
		printf("\n	Cannot close/release exclusive access to HPI\n");
		pressAnyKey();
	}
}

void pressAnyKey(void)
{
    int     c;
	
    printf("Press any key to continue (Ctrl-C to abort).");
	
    c = _getch();
	printf( "\r                                             \r" );
	exit(1);
}

/***************************************************************************/
/* READ FILE NAME ARGUMENTS AND COMMAND LINE OPTIONS                       */
/***************************************************************************/
void parseArgs()
{
	for (argIndx = 1; argIndx < argc; ++argIndx)
	{
		argp = argv[argIndx];
		
		if ((*argp == '-') || (*argp == '/'))
		{
			while (*++argp) 
			{
				switch(*argp)
				{ 
				case '?': case 'H': case 'h':
					usage();  
					break;
					
					//set board index 
				case 'B': case 'b':
					arg("%d",&boardIndex,DEFAULT_PCI_PORT);
					break;
					
					//debug mode
				case 'D': case 'd':
					debugMode = 1;  
					break;
					
					//Erase all
				case 'E': case 'e':
					if (!iCmd)
					{
						arg("%d",&iSectorNum, -1);
						
						iCmd = FLASH_ERASE;
					}
					
					break;
					
				//read length words from flash at address and write to filename
				case 'R': case 'r':
					if (!iCmd)
					{
						iCmd = FLASH_READ_WORDS;

						arg("%d",&iAddr, 0);
						arg("%d",&iLen, 0);
						sarg(&iName, "\0" );										
					
						if (!iAddr || !iLen)
							usage();
					}
					else
					{
						argIndx += 2;
						argp = argv[argIndx];
						argp += strlen(argp)-1;
					}
					break;

					//read words from flash at address and compare to data in binfilename
				case 'C': 
				case 'c':
					
					switch (*++argp)
					{
						case 'B': case 'b':
                        // binary compare
				    	if (!iCmd)
						{
						   iCmd = FLASH_READ_COMPARE_BIN;
						
						   sarg(&iName, "\0" );
					  	   arg("%d",&iAddr, 0);
						
						   if ((*iName == '\0') || !iAddr)
							   usage();
						}
					    else
						{
					 	   argIndx += 2;
						   argp = argv[argIndx];
						   argp += strlen(argp)-1;
						}
						break;

						case 'H': case 'h':
                        // hex compare                      
				    	if (!iCmd)
						{
						   iCmd = FLASH_READ_COMPARE_HEX;
						
						   sarg(&iName, "\0" );
					  	   arg("%d",&iAddr, 0);  // NOTE: hex doesn't use address
						
						   if (*iName == '\0')
							   usage();
						}
					    else
						{
					 	   argIndx += 2;
						   argp = argv[argIndx];
						   argp += strlen(argp)-1;
						}
						break;

					   default: 
						   usage(); 
						   break;
				   }					
				   break;
					
					//Load file into flash
				case 'L': case 'l':
					switch (*++argp)
					{
						case 'B': case 'b':
                        // binary load

						if (!iCmd)
						{
							iCmd = FLASH_LOAD_BIN;
						
							sarg(&iName, "\0" );
							arg("%d",&iAddr, 0);
						
							if ((*iName == '\0') || !iAddr)
								usage();
						}
						else
						{
							argIndx += 2;
							argp = argv[argIndx];
							argp += strlen(argp)-1;
						}					
						break;


						case 'H': case 'h':

						if (!iCmd)
						{	
							iCmd = FLASH_LOAD_HEX;
						
							sarg(&iName, "\0" );
						
							if (*iName == '\0')
								usage();
						}
						else
						{
							argIndx += 1;
							argp = argv[argIndx];
							argp += strlen(argp)-1;
						}
						break;

						default:
							usage();
							break;
					}
					break;
					

				case 'X': case 'x':
					iKnownState = 1;
					break;
					
				default :
					printf("Unknown option: \"-%s\"\n",argp);   // Proceed to help
					
					usage();
            }
         }
      }
	  else
	  {
		  printf("Unknown option: \"%s\"\n",argp);   // Proceed to help
		  usage();
	  }
   }   
}

/*****************************************************************************/
/* sarg() -- Assign variable from current argument - string variation        */
/*****************************************************************************/
void sarg( char **var, char *def_string )
{ 
   if ( *++argp == '\0' )
   { 
      if ( ++argIndx < argc )
      { 
         argp = argv[argIndx]; 

		 *var = _strdup(argp); 
		 argp += strlen(*var);
		 --argp;
      }
      else
      { 
         *var = _strdup(def_string);
         *--argp; return; 
      }
   }
   else
   {
	   *var = _strdup(argp); 
	   argp += strlen(*var);
	   --argp;
   }   
} // end of sarg()

/*****************************************************************************/
/* arg() -- Assign variable from current argument.                           */
/*****************************************************************************/
void arg( char *fmt, ULONG *var, int def_value )
{ 
	char *temp = NULL;
	char *stp = "";
	
	if ( *++argp == '\0' )
	{ 
		if ( ++argIndx < argc )
		{ 
			argp = argv[argIndx];
			temp= argp;
			
			//sscanf( argp, fmt, var ); // Assign variable using specified format
			*var = strtol( argp, &stp, 0 );
			argp += (strlen(temp) - 1);
		}
		else
		{ 
			*var = (int) def_value; 
			*--argp;
		}
	}
	else
	{ 
		*var = strtol( argp, &stp, 0 );

		if ((*var == 0) && (*argp != '0') )
		{
			*var = (int) def_value;
		}
		else
		{
			argp += (strlen(argp) - 1);
		}
	}
	
	return; 
} // end of arg() 

void usage(void) 
{
	printf("%s", usageHelp);
	pressAnyKey();
}
