/****************************************************************************
* FILENAME: evm55xload.c
* VERSION:  2.0
*
* NOTES:
*   TI Proprietary Information - Internal Data.
*   Copyright (c) 2001, DNA Enterprises, Inc.
*
*****************************************************************************/

#include <windows.h>
#include <stdio.h>
#include <conio.h>
#include "evm55xdll.h"
#include "file_io.h"

/*****************************************************************************/
/* Function prototypes                                                       */
/*****************************************************************************/
void arg( char *fmt, ULONG *var, int def_value );
static void sarg( char **var, char *def_string );
static void PrintBanner ( void );
void help( void );
static void PressAnyKey( void );
void BadCommand(void);
static BOOL WINAPI ControlHandler ( DWORD dwCtrlType );

//void writeBin(void);

/*****************************************************************************/
/* Declare and initialize variables used in various calls:                   */
/*****************************************************************************/
HANDLE hStdout;        /* Handle to stdout                                   */
int    nArgs = 1;      /* No. of cmd-line arg's needed (allowed)             */
int    argc;           /* Character count                                    */
char   **argv;         /* Cmd line buffer                                    */
int    i;              /* Current char index                                 */
char   *argp;          /* Current char pointer                               */
BOOL   bClr  = 0;      /* COFF load clear bss flag                           */
BOOL   bDump = 0;      /* COFF load dump mode flag                           */
ULONG  iBd   = 0;      /* Board index                                        */
int    p     = 1;      /* Printf enable                                      */
int    iRs   = 1;      /* Board Reset request -- def=1  (perform reset)      */
BOOL   bShow = 0;      /* Show mode (if true, output to stdout only)         */
BOOL   bVerbose = 0;   /* COFF load verbose mode flag                        */
BOOL   dbg   = 0;      /* Debug mode                                         */
char   coffName[256];  /* COFF file name                                     */
char   cType[32];      /* Board type                                         */
HANDLE hBd = NULL;     /* Board device handle                                */
BOOL   bExcl = 1;      /* Exclusive board open request                       */
LPVOID hHpi  = NULL;   /* HPI interface handle                               */
ULONG  Buf[256];       /* HPI data buffer                                    */
PULONG pBuf  = Buf;    /* Pointer to Buf                                     */
ULONG  Len   = 0;      /* HPI data buffer length                             */
PULONG pLen  = &Len;   /* Pointer to Len                                     */
ULONG  uAddr = 0;      /* Destination address                                */
ULONG  RevId  = 0;     /* Revision identifier                                */
PULONG pRevId = &RevId;/* Pointer to RevId                                   */
EVM55X_BOARD_TYPE  BdType  = TYPE_UNKNOWN; /* DSP Board type                 */
PEVM55X_BOARD_TYPE pBdType = &BdType;      /* Pointer to BdType              */
CHAR   *iName=NULL;    /* Filename to store data received from DSP           */
CHAR   *oName=NULL;    /* Filename from which to send data to DSP            */
ULONG  ulOTime=0;      /* Time limit (secs) when receiving, 0 = no limit     */
ULONG  ulOSize=0;      /* Size limit (16-bit words) when receiving, 0 = no limit    */
ULONG  ulISize=0;      /* Number of 16-bit words sent to DSP                 */
ULONG  dspNum=0;       /* DSP number defaults to 0                           */
BOOL   board_open = FALSE;

/*****************************************************************************/

/*****************************************************************************/
/* Banner Text                                                               */
/*****************************************************************************/
char bannerTxt[] = 
"TMX320VC5510 Prototype Board Command Line COFF Loader Utility, Version 2.03\n\n";

/*****************************************************************************/
/* Help Text                                                                 */
/*****************************************************************************/
char helpTxt1[] = 
"Syntax:\n\
  evm55xload filename [options]\n\n\
  filename  Load file name -- the name of the COFF file to be\n\
            processed and loaded on the C55x Prototype Board.\n\n\
Options (Default parameter values in parentheses)\n\n\
  -?|h      Help -- Display this summary of command syntax and options.\n\n\
  -b num    Selects specific Prototype Board (Default = 0). \n\n\
  -c        Clear bss -- Set all bss section variables to zero.\n\n\
  -d        Dump -- Display all data via the standard output stream.\n\
            and download COFF file.\n\
            Note: This can be a large amount of data. The -d \n\
            option enables th -v (verbose) option.\n\n";

char helpTxt2[] = "\n\
  -i name   Input file -- File containing data to be sent to board's\n\
  (input.dat) PCI interface once the DSP is running with the COFF load.\n\n\
  -o name   Output file -- File to store data retrieved from the board's\n\
  (output.dat) PCI interface once the DSP is running with the COFF load.\n\n\
  -ls       Output file size limit (16-bit words) - Used with -o option to\n\
            limit the size of the output file.\n\n\
  -lt       Output file time limit (sec) - Used with -o option to limit\n\
            how long data is accepted from the board.\n\n\
  -q        Suppresses output to the display.\n\n\
  -s        Writes data to standard output stream but does not write data \n\
            to DSP memory. This option enables the -v option.\n\n\
  -v        Verbose -- Display basic COFF file information via the\n\
            standard output stream.\n\n\
  -z        Debug -- Displays loader status and wait for key press after\n\
            each step.\n\n";

PCI2040DLL_INIT_DATA initData;
int   argIndx; // Current char index
int   argOff;

/*****************************************************************************/
/**** main()                                                              ****/
/*****************************************************************************/
void main(int argc1, char *argv1[])
{

    // Install Ctrl-C handler
    SetConsoleCtrlHandler( ControlHandler, TRUE );

	// Copy arguments to global variables
	argc=argc1;
	argv=argv1;

	//writeBin();
	
	if (argc < 2)
	{
		PrintBanner();
		help();
	}

	/***************************************************************************/
	/* Before parsing command line, assume default values                      */
	/***************************************************************************/
	coffName[0] = '\0';
	
	/***************************************************************************/
	/* Parse command line for file names and other arguments.                  */
	/***************************************************************************/
	for (argIndx = 1; argIndx < argc; ++argIndx)
	{
		argp = argv[argIndx];
		
		if (*argp == '-')
		{
			while (*++argp)
			{
				switch(*argp)
				{
				default :
					// Proceed to help
					if(p)printf("Unknown option: \"-%s\"\n",argp);
					
					// -?|h      Help -- Display this summary of command syntax and options.
				case '?': case 'H': case 'h': 
					PrintBanner();
					help();
					break;
					
					// -c        Clear bss -- Set all bss section variables to zero.
				case 'C': case 'c':
					bClr     = TRUE;          
					
					break;
					
					// -d        Dump -- Display all data via the standard output stream.
					//           Note that this can be a large amount of data.
				case 'D': case 'd':
					bDump    = TRUE;          break;
					
					// -i filename   Filename to be read and sent to DSP
				case 'I': case 'i':
					sarg(&iName,"input.dat");   break;
					
					// -m        Maximum size, time limits for receiving data from DSP
				case 'L': case 'l':
					if (*++argp) 
					{
						switch(*argp)    
						{
						case 'S': case 's':
							arg("%d",&ulOSize,0); break;
							
						case 'T': case 't':
							arg("%d",&ulOTime,0); break;
						default:
							help();
						}
					}
					
					// these options cannot be ganged - at least for now
					while (*++argp) ;
					--argp;
					
					break;
					
					// -o filename   Filename to be written with data from DSP
				case 'O': case 'o':
					sarg(&oName,"stdout");   
					break;
					
					// -p port   Board index -- a zero-based relative index, ranging 
					// (0)       from 0 to N-1, if N [Mc]pci2040 boards are installed
				case 'B': case 'b':
					// Device #
					arg("%d",&iBd,0);  break;
/*					
				case 'N': case 'n':
					// DSP number
					arg("%d",&dspNum,0);  break;
*/
					
					// -q        Quiet mode (no terminal output).
				case 'Q': case 'q':
					p=0;                      break; 
					
					// -s        Show -- Output to the standard output stream ONLY, and
					//           do not write any data to DSP memory.  If the Dump option
					//           is also specified, all data is displayed.  Otherwise,
					//           basic information is displayed, as with Verbose option.
				case 'S': case 's':
					bShow    = TRUE;          break;
					
					// -v        Verbose -- Display basic COFF file information via the
					//           standard output stream.
				case 'V': case 'v':
					bVerbose = TRUE;          break;
					
					// -z        Debug -- Display status and wait for key press after each step.
				case 'Z': case 'z':
					dbg      = TRUE;          break;
				}
			}
		}
		else if (*argp != ' ')
		{
			if (nArgs--) 
			{
				sscanf( argp, "%s",coffName);
			}
			else
			{
				if (p)
					printf("**Error: Cannot process the argument: \"%s\"\n",argp);
				
				if (p)
					printf("         There are too many arguments on the command line.\n");
				
				BadCommand();
			}
		}
   }
   
   /***************************************************************************/
   /*  Print banner to window                                                 */
   /***************************************************************************/
   PrintBanner();
   
   /***************************************************************************/
   /*  Abort if no COFF file                                                  */
   /***************************************************************************/
   if (coffName[0]=='\0')
   {
	   if (p) printf("**Error: No COFF file name on command line.\n");
	   
	   BadCommand();
   }
   
   /***************************************************************************/
   /* If "-s" option is selected, send output to stdout only:                 */
   /***************************************************************************/
   if (bShow)
   {
	   /*************************************************************************/
	   /* Output COFF file information to standard out.                         */
	   /*************************************************************************/
	   if (!evm55x_coff_display((char *)coffName,bClr,bDump))
	   {
		   if (p) printf("**Error: evm55x_coff_display() failed.\n");
		   exit(1);
	   }
	   else 
		   exit(0);
   }
   
   /***************************************************************************/
   /* Otherwise ...                                                           */
   /***************************************************************************/
   
   /***************************************************************************/
   /* Open a driver connection to a specific pci2040 board.                   */
   /***************************************************************************/
   if(dbg) 
   { 
	   if (p) printf( "Debug enabled.\n" );
	   
	   if (p) printf( "Opening board.\n" ); 
   }
   
   hBd = evm55x_open( iBd, bExcl );
   
   if ( hBd == INVALID_HANDLE_VALUE )
   {
	   if (p) printf( "**Error: Board open failure.\n" );
	   
	   exit(1);
   }
   
   /***************************************************************************/
   /* Read board type and revision from PCI configuration space of the board. */
   /***************************************************************************/
   if (dbg) 
   { 
	   if (p) printf( "Reading board type and revision.\n" );
	   
	   PressAnyKey(); 
   }
   
   if ( evm55x_board_info( hBd, pBdType, pRevId ) )
   {
	   switch (BdType)
	   {
         case TYPE_PCI2040_C5510_EVM:   
            strcpy(cType,"TMX320VC5510 Prototype Board");  
            break;
            
	   default: strcpy(cType,"Unknown");
	   }
	   
	   if (p)
		   printf("Found board type: %s  Revision: %d\n", cType, (int) RevId );
   }
   else
   {
	   if (p) printf( "**Error: evm55x_board_info() failed.\n" );
	   exit(1);
   }
   
   /***************************************************************************/
   /* Cause a hardware reset on the target board.                             */
   /***************************************************************************/
   if (iRs==1)
   {
	   if (dbg) 
	   { 
		   if (p) printf( "Resetting %s board.\n",cType );
		   PressAnyKey(); 
	   }
	   
	   if ( !evm55x_reset_board(hBd) )
	   {
		   if (p) printf( "**Error: evm55x_reset_board() failed.\n" );
		   
		   exit(1);
	   }
   }
   
   /***************************************************************************/
   /* Establish a connection to the HPI of a target board.                    */
   /***************************************************************************/
   if (dbg) 
   { 
	   if (p) printf( "Opening HPI.\n" );
	   
	   PressAnyKey();
   }
   
   hHpi = evm55x_hpi_open(hBd);
   
   if ( hHpi == NULL )
   {
	   if (p) printf( "**Error: evm55x_hpi_open() failed.\n" );
	   
	   exit(1);
   }

   board_open = TRUE;
   
   /* Initialize required DSP and PCI2040 registers */
   if (dbg) 
   { 
	   if (p) printf( "Initializing DSP.\n" );
	   
	   PressAnyKey(); 
   }

   /***************************************************************************/
   /* Read a COFF image and write the data to DSP memory using the HPI.       */
   /***************************************************************************/
   if (dbg) 
   { 
	   if (p) printf( "Loading COFF file into DSP memory.\n" );
	   
	   PressAnyKey(); 
   }
   
   if (!evm55x_coff_load(hBd,hHpi,(char*)coffName,bVerbose,bClr,bDump,dspNum))
   {
	   if(p)printf("**Error: evm55x_coff_load() failed.\n");
	   
	   exit(1);
   }
   else
   {
       printf("\nDSP COFF application \"%s\" is now running.\n",coffName);

   }
   
   /***************************************************************************/
   /* Setup file I/O process                                                  */
   /***************************************************************************/
   if (dbg) 
   { 
	   if (p) printf( "\nBeginning play/record process (if used).\n" );
	   PressAnyKey(); 
   }

   // Delay to allow DSP to set FIFO pointers
   Sleep(500);
   
   // Perform file I/O
   file_io( hHpi, dspNum, iName, oName,
	   &ulISize, &ulOSize, ulOTime );
   
   /***************************************************************************/
   /* Close a previously opened driver connection to a board.                 */
   /***************************************************************************/
   if (dbg) 
   {
	   if (p) printf( "Closing %s board.\n",cType );
	   PressAnyKey();
   }
   
   if (!evm55x_close(hBd))
   {
	   if (p) printf( "**Error: evm55x_close() failed.\n" );
	   exit(1);
   }
   
   exit(0);
}

/*****************************************************************************/
/**** end of main()                                                       ****/
/*****************************************************************************/

/*****************************************************************************/
/* sarg() -- Assign variable from current argument - string variation        */
/*****************************************************************************/
void sarg( char **var, char *def_string )
{ 
	if ( *++argp == '\0' )
	{ 
		if ( ++argIndx < argc )
		{ 
			if (*(argv[argIndx]) == '-')
			{
				*var = _strdup(def_string);
				--argIndx;
				*--argp; return; 
			}
			else
			{
				argp = argv[argIndx]; 
				
				*var = _strdup(argp); 
				argp += strlen(*var);
				--argp;
			}
		}
		else
		{ 
			*var = _strdup(def_string);
			*--argp; return; 
		}
	}
	else
	{
		*var = _strdup(argp); 
		argp += strlen(*var);
		--argp;
	}   
} // end of sarg()

/*****************************************************************************/
/* arg() -- Assign variable from current argument.                           */
/*****************************************************************************/
void arg( char *fmt, ULONG *var, int def_value )
{ 
	char *temp = NULL;
	char *stp = "";
	
	if ( *++argp == '\0' )
	{ 
		if ( ++argIndx < argc )
		{ 
			if (*(argv[argIndx]) == '-')
			{
				*var = (int) def_value; 
				*--argp;
			}
			else
			{
				argp = argv[argIndx];
				temp= argp;
				//sscanf( argp, fmt, var ); // Assign variable using specified format
				*var = strtol( argp, &stp, 0 );
				argp += (strlen(temp) - 1);
			}
		}
		else
		{ 
			*var = (int) def_value; 
			*--argp;
		}
	}
	else
	{ 
		*var = strtol( argp, &stp, 0 );

		if ((*var == 0) && (*argp != '0') )
		{
			*var = (int) def_value;
		}
		else
		{
			argp += (strlen(argp) - 1);
		}
	}
	
	return; 
} // end of arg() 



/*****************************************************************************/
/* PrintBanner() -- Prints program banner.                                   */
/*****************************************************************************/
static void PrintBanner (void)
{
   if (p)  
   {
	   printf("%s",bannerTxt);
   }
}



/*****************************************************************************/
/* help() -- Provide assistance to the naive, then exit.                     */
/*****************************************************************************/
void help( void )
{
	if(p)
	{
		printf(helpTxt1);
		PressAnyKey();
		printf(helpTxt2);
	}
	exit(1);
}

/*****************************************************************************/
/* PressAnyKey() -- In debug mode, wait for key press after each step.       */
/*****************************************************************************/
static void PressAnyKey( void )
{
    int     c;
	
    if (p) printf(   "Press any key to continue (Ctrl-C to abort)." );
	
    c = _getch();
	
    if (p) printf( "\r                                             \r" );
	
    if ( c == 0x03 ) exit(1);
	
    if ( c == 0x1b ) dbg=0;
	
    return;
} /* end of PressAnyKey() */

/*****************************************************************************/
/* BadCommand() -- Response to bad command line.                             */
/*****************************************************************************/
void BadCommand(void)
{
	PressAnyKey();
	help();
}


//
//  FUNCTION: ControlHandler ( DWORD dwCtrlType )
//
//  PURPOSE: Handled console control events
//
//  PARAMETERS:
//    dwCtrlType - type of control event
//
//  RETURN VALUE:
//    True - handled
//    False - unhandled
//
//  COMMENTS:
//
static BOOL WINAPI ControlHandler ( DWORD dwCtrlType )
{
    switch( dwCtrlType )
    {
        case CTRL_BREAK_EVENT:  // use Ctrl+C or Ctrl+Break to simulate
        case CTRL_C_EVENT:      // SERVICE_CONTROL_STOP in debug mode
			
            killMe();
			return(TRUE);
    }
    return FALSE;
}

