/******************************************************************************/
/*  DNA PROPRIETARY INFORMATION                                               */
/*  (C) Copyright 1997,1998 by DNA Enterprises, Inc.                          */
/*  All rights reserved                                                       */
/******************************************************************************/
/*  FILEIO.C - module for handling File I/O with the DSP.                     */
/*                                                                            */
/*   This module allows the use of play/record facilities to pass data        */
/*   between the host and the DSP and any peripherals connected to the DSP    */
/*   Two threads are available for handling play and record seperately.  These*/
/*   threads may be run at the same time or individually.                     */
/*                                                                            */
/*  MACRO FUNCTIONS:                                                          */
/*                                                                            */
/*  FUNCTIONS:                                                                */
/*   file_io() - support simple file I/O to DSP                               */
/*   killMe() - Ctrl-C, close window handler                                  */
/*                                                                            */
/*  REVISION HISTORY:                                                         */
/*                                                                            */
/******************************************************************************/

/*----------------------------------------------------------------------------*/
/* INCLUDES                                                                   */
/*----------------------------------------------------------------------------*/
#include <windows.h>
#include <stdio.h>
#include <process.h>
#include <stdio.h>
#include <mbstring.h>
#include <stdlib.h>
#include <malloc.h>
#include <time.h>
#include <conio.h>
#include <io.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include "evm55xdll.h"
#include "file_io.h"
#include "os_port.h"


/*--------------------------------------------------------------------------*/
/*  Local #defines                                                          */
/*--------------------------------------------------------------------------*/
#define FIFO_TRANSFER_TIME_OUT      (200)     /* 2/10 second */
#define READ_BUFFER_SIZE            (32)      
#define WRITE_BUFFER_SIZE           (32)      

/*----------------------------------------------------------------------------*/
/* GLOBAL VARIABLES                                                           */
/*----------------------------------------------------------------------------*/
extern int p;
extern HANDLE hBd;

/*--------------------------------------------------------------------------*/
/*  File-local (static) variables                                           */
/*--------------------------------------------------------------------------*/
static BOOL     bReadFileComplete = FALSE;
static BOOL     bWriteFileComplete = FALSE;
static BOOL     fileioComplete = FALSE;
static DWORD    readFileLen = 0;
static LPDWORD  lpReadFile16BitWords;
static LPDWORD  lpWriteFile16BitWords;
static FILE     *hReadFile = NULL;
static FILE     *hWriteFile = NULL;
static LPDWORD  lpReadFileBuffer = NULL;
static LPDWORD  lpWriteFileBuffer = NULL;
static BOOL     bReadFileAbort = FALSE;
static BOOL     bWriteFileAbort = FALSE;
static HANDLE   hReadThread = NULL;
static HANDLE   hWriteThread = NULL;
static ULONG    dspNum;

extern LPVOID hHpi;
/*--------------------------------------------------------------------------*
*  File-local (static) function prototypes
*--------------------------------------------------------------------------*/
unsigned __stdcall doWriteFile(void *dummy);
unsigned __stdcall doReadFile(void *dummy );


/*--------------------------------------------------------------------------*/
/* FUNCTIONS                                                                */
/*--------------------------------------------------------------------------*/
/*
// Test code to write binary file
void writeBin()
{
	FILE    *fp;
	USHORT  i;
	USHORT  len = 256; 

	fp = fopen("fifotest.bin", "wb");

	for (i=0; i<len; i++)
	   fwrite(&i, sizeof(USHORT), 1, fp);

	fclose(fp);
}
*/


/******************************************************************************/
/*   file_io() - support simple file I/O to DSP                               */
/*                                                                            */
/*    This function handles opening of of play and record files, and starting */
/*    play and record threads.  The play and record processes may be opened   */
/*    and run independently or simultaneously.  The play process runs         */
/*    until data is exhausted or a <Ctrl-Z> is entered.  The record process   */
/*    runs indefinetly or until <Ctrl-Z> is enterned or until an optional     */
/*    time limit is reached or until an an optional file size limit is reached*/
/*                                                                            */
/******************************************************************************/
BOOL file_io(LPVOID hHpi_, 
             ULONG dspNum_, 
             char *sReadFileName, 
             char *sWriteFileName,
             LPDWORD lpReadFile16BitWordsParm, 
             LPDWORD lpWriteFile16BitWordsParm,
             DWORD dwMaxSeconds )
{
	BOOL        bResult = TRUE;
	HANDLE      hThreadArray[2];
	DWORD       dwThreadCount = 0;
	unsigned    uRdThrAddr;
	unsigned    uWrThrAddr;
	int         fh;
	
	lpReadFile16BitWords = lpReadFile16BitWordsParm;
	lpWriteFile16BitWords = lpWriteFile16BitWordsParm;
	
	dspNum = dspNum_;
	hHpi = hHpi_;
	
	/* prepare write file */
	while ( TRUE )
	{
		/* is there any write file to do? */
		if ( sWriteFileName == NULL )
		{
			*lpWriteFile16BitWords = 0;
			bWriteFileComplete = TRUE;
			break;
		}
		
		if (!strcmp(sWriteFileName,"stdout"))
		{
			hWriteFile = stdout;
		}
		else
		{
			/* make sure file does not already exist */
			if ( (hWriteFile = fopen( sWriteFileName, "rb" )) != NULL )
			{
				char ow;
				
				fclose( hWriteFile );
				
				if(p)printf( "\n**Warning: Write file \"%s\" already exists.\n",
					sWriteFileName );
				if(p)printf( "Enter 'y' to overwrite: ");
				
				scanf("%c",&ow);
				
				if(!(ow == 'y' || ow == 'Y'))
				{
					*lpReadFile16BitWords = 0;
					*lpWriteFile16BitWords = 0;
					return( FALSE );
				}
			}
			
			/* open write file */
			if ( (hWriteFile = fopen( sWriteFileName, "wb" )) == NULL )
			{
				if(p)printf( "\n**Error in file_io: failed to open \"%s\" for writing.\n",
					sWriteFileName );
				*lpReadFile16BitWords = 0;
				*lpWriteFile16BitWords = 0;
				return( FALSE );
			}
		}
		
		/* malloc write buffer */
		lpWriteFileBuffer = (LPDWORD)malloc(WRITE_BUFFER_SIZE*sizeof(short));
		if ( lpWriteFileBuffer == NULL )
		{
			if(p)printf( "\n**Error in file_io: malloc() failed.\n" );
			fclose( hWriteFile );
			*lpReadFile16BitWords = 0;
			*lpWriteFile16BitWords = 0;
			return( FALSE );
		}
		
		/* while loop used to ease breaking out */
		break;
	}
	
	/* prepare read file */
	while ( TRUE )
	{
		/* is there any read file to do? */
		if ( sReadFileName == NULL )
		{
			*lpReadFile16BitWords = 0;
			bReadFileComplete = TRUE;
			break;
		}
		
		/* open read file */
		if ( (hReadFile = fopen( sReadFileName, "rb" )) == NULL )
		{
			if(p)printf( "\n**Error in file_io: failed to open \"%s\" for reading.\n",
				sReadFileName );
			
			if ( hWriteFile != NULL ) { fclose( hWriteFile ); }
			
			*lpReadFile16BitWords = 0;
			*lpWriteFile16BitWords = 0;
			
			return( FALSE );
		}


		/* determine size of read file */
		// close file temporarily 
		fclose(hReadFile);
		
		// open binary file
		fh = _open( sReadFileName, _O_RDONLY | _O_BINARY );

		// Determine size of binary file in 16-bit words
		readFileLen = (ULONG)_lseek(fh,0,SEEK_END) >> 1;

        // Close and reopen file
		_close(fh);
		hReadFile = fopen( sReadFileName, "rb");
		
		/* malloc read buffer */
		lpReadFileBuffer = (LPDWORD)malloc(READ_BUFFER_SIZE*sizeof(short));
		
		if ( lpReadFileBuffer == NULL )
		{
			if(p)printf( "\n**Error in file_io: malloc() failed.\n" );
			if ( hWriteFile != NULL ) { fclose( hWriteFile ); }
			fclose( hReadFile );
			*lpReadFile16BitWords = 0;
			*lpWriteFile16BitWords = 0;
			return( FALSE );
		}
		
		/* while loop used to ease breaking out */
		break;
	}

	
	/* start read and write threads as needed */
	if ( !bWriteFileComplete )
	{
		hWriteThread =  (HANDLE)_beginthreadex((void *)NULL,0,&doWriteFile,(void *)NULL,0,&uWrThrAddr);
		if ( hWriteThread == NULL )
		{
			if (p) printf( "\n**Error in file_io: failed to create thread for file writing.\n" );
			bWriteFileComplete = TRUE;
			bResult = FALSE;
		}
		else
		{
			hThreadArray[dwThreadCount++] = hWriteThread;
		}
	}
	
	if ( !bReadFileComplete )
	{
		hReadThread = (HANDLE)_beginthreadex((void *)NULL,0,&doReadFile,(void *)NULL,0,&uRdThrAddr);
		if ( hReadThread == NULL )
		{
			if (p) printf( "\n**Error in file_io: failed to start thread for file reading.\n" );
			bReadFileComplete = TRUE;
			bResult = FALSE;
		}
		else
		{
			hThreadArray[dwThreadCount++] = hReadThread;
		}
	}
	
	/* wait for threads to finish */
	if ( dwThreadCount > 0 )
	{
		DWORD   dwTimeOut;
		DWORD   dwTemp;
		
		if (p) printf("\nI/O in progress <Ctrl-Z> to terminate\n");
		
#define TIME_RECORD_ONLY
#ifdef  TIME_RECORD_ONLY
		
		if(!bWriteFileComplete)
		{
			dwTimeOut = ((dwMaxSeconds == 0) ? INFINITE : dwMaxSeconds * 1000);
			dwTemp = WaitForSingleObject( hWriteThread, dwTimeOut );
			
			if ( dwTemp == WAIT_TIMEOUT )
			{
				if (p) printf( "WARNING in file_io: "
					"Time limit exceeded, record thread being terminated.\n" );
				
				bWriteFileAbort = TRUE;
				bResult = FALSE;
				
				/* wait briefly, then forcefully terminate thread */
				Sleep( 5 * FIFO_TRANSFER_TIME_OUT);
				
				if ( (hWriteThread != NULL) && !bWriteFileComplete)
				{
					TerminateThread( hWriteThread, 0 );
				}
			}
		}
		
		if(!bReadFileComplete)
		{
			dwTimeOut = INFINITE;
			dwTemp = WaitForSingleObject( hReadThread, dwTimeOut );
		}
		
#else
		dwTimeOut = ((dwMaxSeconds == 0) ? INFINITE : dwMaxSeconds * 1000);
		dwTemp = WaitForMultipleObjects( dwThreadCount, hThreadArray,
			TRUE /* bWaitAll */, dwTimeOut );
		
		if ( dwTemp == WAIT_TIMEOUT )
		{
			if(p)printf( "WARNING in file_io: "
				"Time limit exceeded, threads being terminated.\n" );
			bReadFileAbort = TRUE;
			bWriteFileAbort = TRUE;
			bResult = FALSE;
			
			/* wait briefly, then forcefully terminate threads */
			Sleep( 5 * FIFO_TRANSFER_TIME_OUT);
			if ( (hWriteThread != NULL) && !bWriteFileComplete)
			{
				TerminateThread( hWriteThread, 0 );
			}
			if ( (hReadThread != NULL) && !bReadFileComplete)
			{
				TerminateThread( hReadThread, 0 );
			}
		}
#endif
	}
	
	/* clean up */
	if ( hReadFile != NULL ) { fclose( hReadFile ); }
	if ( hWriteFile != NULL ) { fclose( hWriteFile ); }
	
	fileioComplete = TRUE;

	return( bResult );
} /* end of file_io() */

/*****************************************************************************/
/*  killMe() - Ctrl-C, close window handler                                  */
/*                                                                           */
/*    This module is called when a <Ctrl-C> is entered or when the window is */
/*    closed while the program is active.  This function allows any threads  */
/*    running to be closed to allow a clean program termination.             */
/*                                                                           */
/*****************************************************************************/
void killMe( void )
{
	/* abort any pending reads or writes on <Ctrl-C> */
	
	bReadFileAbort = TRUE;
	bWriteFileAbort = TRUE;
	
	while(!fileioComplete) ;
}

/****************************************************************************/
/*doWriteFile() - thread to handle data from DSP to file
/*
/*  This function ...
/****************************************************************************/
unsigned __stdcall doWriteFile(void *dummy)
{
	ULONG       ulLength, byteLen;
	ULONG       ulTotalLength = 0;
	unsigned    uRetCode = 1;

    // set timeout value for FIFO transfers
	evm55x_set_timeout(hBd,1000);

	// disable DLL printfs
	evm55x_printf_control(FALSE,NULL);
	
	while ( (*lpWriteFile16BitWords == 0) || (ulTotalLength < *lpWriteFile16BitWords) )
	{
		/* determine the length to request */
		if ( *lpWriteFile16BitWords == 0 ) 
		{ 
			ulLength = WRITE_BUFFER_SIZE; 
		}
		else
		{
			ulLength = *lpWriteFile16BitWords - ulTotalLength;
			if ( ulLength > WRITE_BUFFER_SIZE )
			{
				ulLength = WRITE_BUFFER_SIZE;
			}
		}
		
		//convert length to 16-bit word length
		/* request data from DSP */
		evm55x_fifo_read(hHpi, 
			(LPDWORD)lpWriteFileBuffer, 
			&ulLength,
			dspNum);

	    if (ulLength)
		{  

	 		/* write received data to file */
			byteLen = ulLength << 1;
			if ( byteLen > 0 )
			{
				size_t  temp;
				size_t  printlen;
				size_t  remlen;
				char    *curpos=(char *)lpWriteFileBuffer;
			
				if(hWriteFile == stdout)
				{
					remlen = byteLen;
					do
					{
						printlen = _mbsnbcnt(curpos,remlen);
						temp = fwrite( curpos, 1, printlen, hWriteFile );
						if(temp != printlen)
						{
							/* error condition */
							uRetCode = 0;
							bWriteFileAbort = TRUE;
							break;
						} 
						remlen -= printlen + 1;
						curpos += printlen + 1;
					} while (remlen < byteLen);
				}
				else
				{
					temp = fwrite( curpos, 2, ulLength, hWriteFile );
					if ( temp != ulLength )
					{
						/* error condition */
						uRetCode = 0;
						break;
					} 
				}
			
				ulTotalLength += ulLength;
			}	
		}
		
		if(_kbhit())
		{
			int c;
			c = _getch();
			if ( c == 0x1a) 
			{
				bWriteFileAbort = TRUE;
				bReadFileAbort = TRUE;
			}
		}

		/* check for abort request */
		if ( bWriteFileAbort )
		{
			break;
		}
		
	} /* end of while loop */
	
	*lpWriteFile16BitWords = ulTotalLength;

	return (uRetCode);

} /* end of doWriteFile() */

/****************************************************************************
/*doReadFile() - thread to handle data from file to DSP
/*
/*  This function ...
/****************************************************************************/
unsigned __stdcall doReadFile(void *dummy)
{
	ULONG       ulLength;
	ULONG       ulSentLen;
	ULONG       ulReadLen;
	ULONG       ulTotalLength = 0;
	unsigned    uRetCode = 1;
	ULONG       tempLen;
	unsigned    uReadSuccess = 1;

    // set timeout value for FIFO transfers
	evm55x_set_timeout(hBd,1000);

	// disable DLL printfs
	evm55x_printf_control(FALSE,NULL);

	/* determine length of file */
	ulReadLen = readFileLen;

	/* write length to FIFO */
    tempLen = 1;
	if (!evm55x_fifo_write(hHpi,&ulReadLen,&tempLen,dspNum))
	{
       uRetCode = 0;
	   printf("\n**Error: Write of data length to DSP FIFO failed.\n");
       return(0);
	}	
	
    /* clear sent counter */
	ulSentLen = 0;
		
	while (ulReadLen > ulSentLen)
	{
		/* read data from file */
		if (uReadSuccess)
		{
		   ulLength = ulReadLen - ulSentLen;

		   // transfer in 32-word blocks
		   if (ulLength > READ_BUFFER_SIZE) ulLength = READ_BUFFER_SIZE;
		   ulLength = fread( lpReadFileBuffer, sizeof(USHORT), ulLength, hReadFile );;
		}
	
		/* send data to DSP */
		evm55x_fifo_write(hHpi, 
			(LPDWORD)((char *)lpReadFileBuffer), 
			&ulLength,
			dspNum);

		if (ulLength)
		{				
			ulSentLen += ulLength;
		    ulTotalLength += ulSentLen;
			uReadSuccess = 1;
		}
		else 
		{
            uReadSuccess = 0;
		}
			
            
		if(_kbhit())
		{
			int c;

			c = _getch();
			if ( c == 0x1a) 
			{
				bWriteFileAbort = TRUE;
				bReadFileAbort = TRUE;
			}
		}

		 /* check for abort request */
		if ( bReadFileAbort )
		{
			break;
		}
		
		
	   	/* done if did not read a full buffer */
		if ( ulLength != READ_BUFFER_SIZE )
		{
			break;
		}
		
		
		/* check for abort request */
		if ( bReadFileAbort )
		{
			break;
		}
		
	} /* end of while loop */
	
	*lpReadFile16BitWords = ulTotalLength;
	
	return (uRetCode);
	
} /* end of doReadFile() */


