/*******************|*******************|*******************|******************
*                                                                             *
*   OS Ported routines (specific to each supported OS)
*                                                                             *
*******************************************************************************
*                                                                             *
*                       RESTRICTED RIGHTS LEGEND                              *
* This source code may not be reproduced or transmitted in any form or by     *
* any means, electronic or mechanical, for any purpose, without the express   *
* written permission of DNA Enterprises, Inc.                                 *
*                          DNA Enterprises, Inc.                              *
*                          269 W. Renner Parkway                              *
*                          Richardson, TX 75080                               *
*                                                                             *
*******************************************************************************
*                                                                             *
*                    Copyright (C) 1996 DNA Enterprises, Inc.                 *
*                             All Rights Reserved.                            *
*                                                                             *
* THIS IS UNPUBLISHED, CONFIDENTIAL AND PROPRIETARY SOURCE CODE OF            *
* DNA ENTERPRISES, INC. THE COPYRIGHT OF WHICH VESTS IN DNA ENTERPRISES,      *
* INC.                                                                        *
*                                                                             *
*                                                                             *
*******************************************************************************
* Modification History                                                        *
* --------------------                                                        *
*                                                                             *
*                                                                             *
******************************************************************************/
#include <windows.h>
#include <wincon.h>

#include "OS_Port.h"


/** Prototypes  **/
static BOOL CtrlHandler(DWORD fdwCtrlType);


/** Globals **/
static abortFunct   *abortFunctPntr = NULL;
static int          installDone = 0;

/*
 *  This routine will do the OS specific job of installing a supplied 
 *  routine to be called in the event of the OS shutting down the current
 *  process. Thus, the routine passed here to be installed will need to do
 *  some kind of cleanup and shutdown operations.
 *
 *  This routine may be called again to install a different function.
 *
 *  The _removeOsAbort function should be called to remove the function
 *  handling the abort conditions.
 */
int _installOsAbort( abortFunct *functPntr )
{
    BOOL fSuccess; 

    abortFunctPntr = functPntr;

    if ( installDone == 0 )
        {
        fSuccess = SetConsoleCtrlHandler( 
                    (PHANDLER_ROUTINE) abortFunctPntr,  /* handler function */ 
                    TRUE);                              /* add to list      */ 
        if (! fSuccess) 
            { return( -1 ); }
        installDone = 1;
        }

    return( 0 );
} /* end of _installOsAbort() */

int _removeOsAbort( void )
{
   BOOL fSuccess; 
   
   if ( installDone == 1 )
   {
      /* remove from list */ 
      if (!(fSuccess = SetConsoleCtrlHandler((PHANDLER_ROUTINE) CtrlHandler, FALSE))) 
      {
         return( -1 );
      }
      
      installDone = 0;
      abortFunctPntr = NULL;
   }
   return( 0 );
} /* end of _removeOsAbort() */
  
static BOOL CtrlHandler(DWORD fdwCtrlType)
{
   switch (fdwCtrlType)
   {
      
      /* CTRL+CLOSE: confirm that the user wants to exit. */ 
   case CTRL_CLOSE_EVENT: 
      //            return TRUE; 
      
      /** for now, all others call passed in abort function then return FALSE **/
      /* Handle the CTRL+C signal. */ 
   case CTRL_C_EVENT: 
      //Beep(1000, 1000); 
      //return TRUE; 
      
      /* Pass other signals to the next handler. */ 
   case CTRL_BREAK_EVENT: 
   case CTRL_LOGOFF_EVENT: 
   case CTRL_SHUTDOWN_EVENT: 
   default: 
      break;
   } /* end of switch */
   
   /** call provided abort routine, if not NULL **/
   if ( abortFunctPntr != NULL )
   {
      (*abortFunctPntr)();
   }
   
   return FALSE; 
} /* end of CtrlHandler() */


 
