/****************************************************************************
* FILENAME: evmdskrst.c
*
* NOTES:
*   TI Proprietary Information - Internal Data.
*   Copyright (c) 2001, DNA Enterprises, Inc.
*
*****************************************************************************/

#include <windows.h>
#include <stdio.h>
#include <conio.h>
#include <evm55xdll.h>

#define  C5510_BRANCH_OPCODE		 0x6a000000 //without branch target address

/*****************************************************************************/
/* Function Prototypes                                                       */
/*****************************************************************************/
void arg( char *fmt, ULONG *var, int def_value );
void help( void );
static void PressAnyKey( void );
void abend( int iQuit );

/*****************************************************************************/
/* Help Text                                                                 */
/*****************************************************************************/
char helpTxt[] = "\n\
Syntax:\n\n\
evm55xrst [Options]\n\n\
Options (default parameter values in parentheses)\n\n\
   -?|h       Help -- Display this summary of command syntax and options.\n\n\
   -b num     Selects specific EVM target board.(0)\n\n\
   -q         Quiet mode\n\n";

/*****************************************************************************/
/* Global declarations                                                       */
/*****************************************************************************/
int		argc;    // Character count      
char	**argv;  // Cmd line buffer      
int		argIndx; // Current char index   
char	*argp;   // Current char pointer 

EVM55X_BOARD_TYPE  BdInfo  = TYPE_UNKNOWN; // EVM Board type      

ULONG	RevId   = 0;            // Revision identifier 
PULONG	pRevId  = &RevId;

HANDLE	hBd = NULL;// Board device handle   
LPVOID	hHpi=NULL; // HPI interface handle 
BOOL	bExcl=1;   // Exclusive open = TRUE 

int		dbg = FALSE;
int		hpi_open = FALSE;
int		device_open = FALSE;
int		p=1;
int		iBd = 0;       // board number 
UINT    dspNum = 0;     // DSP to talk to                                     
char	bType[8];    // Board type 


void PrintBanner (void)
{
	/***************************************************************************/
	/*  Print banner to window                                                 */
	/***************************************************************************/
	if (p) printf("\nTMX320VC5510 Prototype Board Reset Utility, Version 2.01");
	
	if (p) printf("\n\n");
}


/*****************************************************************************/
/**** main()                                                              ****/
/*****************************************************************************/
void main(int argc1, char *argv1[])
{
	ULONG branchInstr;
	ULONG len = 2;
    char c;

	

	/* Copy arguments to global variables */
	argc=argc1;
	argv=argv1;
	
	/***************************************************************************/
	/* READ FILE NAME ARGUMENTS AND COMMAND LINE OPTIONS                       */
	/***************************************************************************/
	if (argc > 1)
	{
		for (argIndx = 1; argIndx < argc; ++argIndx)
		{
			argp = argv[argIndx];
			
			if ((*argp == '-') || (*argp == '/'))
			{
				while (*++argp) 
				{
					switch(*argp)
					{ 
						
					case '?': case 'H': case 'h':
						help();  
						break;      
						
					case 'Q': case 'q':
						p=0;  
						break;      
						
					case 'D': case 'd':
						dbg=TRUE;  
						break;   
/*						
					case 'N': case 'n':
						arg("%d",&dspNum,0);  break;
*/
						
						//set board num
					case 'B': case 'b':
						arg("%d",&iBd, 0);  break;
						
					case 'P': case 'p':
						arg("%d",&iBd, 0);  break;
						break;
						
					default :
                        printf("Unknown option: \"-%s\"\n\n",argp);
						help();
						exit(-1);
					}
				}
			}
			else
			{
				printf("Unknown option: \"%s\"\n",argp);   /* Proceed to help  */
				help();
			}
		}
	}

	// Print banner
	PrintBanner();

	/***************************************************************************/
	/* Open a driver connection to a specific [Mc] board.                      */
	/***************************************************************************/
	hBd = evm55x_open( iBd, bExcl );
	
	if ( hBd == INVALID_HANDLE_VALUE )
	{
		if (p) printf( "**Error: Board open failure.\n" );
		
		exit(1);
	}
	
	device_open = TRUE;
	
	//Open HPI
	if (dbg) 
	{ 
		if (p) printf( "Opening HPI.\n" );
		PressAnyKey();
	}
	
	hHpi = evm55x_hpi_open(hBd);
	
	if ( hHpi == NULL )
	{
		if (p) printf( "**Error:: Failure opening HPI.\n" ); 
		
		abend(0);
	}
	
	hpi_open = TRUE;
	
	/***************************************************************************/
	/* Get the board type and revision of a target board as stored in the PCI  */
	/* configuration space of the board.                                       */
	/***************************************************************************/
	if (dbg)
	{ 
		if (p) printf( "Reading board type and revision.\n" );
		PressAnyKey(); 
	}
	
    if ( evm55x_board_info( hBd, &BdInfo, &RevId ) )
    {
        USHORT regs[32];
        
        switch (BdInfo)
        {
        case TYPE_PCI2040_C5510_EVM:   
            strcpy(bType,"TMX320VC5510 Prototype Board");  
            break;
            
        default: strcpy(bType,"Unknown");
            break;
        }
        
        if (p) 
        {
            printf("Board type    : %s  \n", bType);
			if (RevId == PCI_INVALID_REV_ID)
                 printf("Board revision: Unknown\n" );
			else printf("Board revision: %d\n", (int) RevId );
            
            // read CPLD revision
            evm55x_cpld_read_all( hBd, regs);
            printf("CPLD revision : %d\n\n",regs[3]&0xFF);
        }
    }
    else
    {
        if (p) printf("**Error:: Failure reading board type and revision.\n" ); 
        abend(0);
    }
	
	/***************************************************************************/
	/* Cause a hardware reset on the target board.                             */
	/***************************************************************************/
	if (p) printf( "Resetting %s board.\n",bType );
	
	if (dbg) PressAnyKey();

	if (!evm55x_reset_board(hBd) )
	{
		if(p)printf( "**Error:: Failure resetting board.\n" ); 
		abend(0);
	}

	if (p) printf( "Resetting TMX320VC5510 DSP.\n" );
	
	if (dbg) PressAnyKey();
	
	if ( !evm55x_reset_dsp(hBd, dspNum) )
	{
		if(p)printf( "**Error:: Failure resetting DSP.\n" ); 
		abend(0);
	}

	if (p) printf( "Unresetting TMX320VC5510 DSP (HPI Boot Mode).\n",bType );
	
	if (dbg) PressAnyKey();
	
	if ( !evm55x_unreset_dsp(hBd, dspNum) )
	{
		if(p)printf( "**Error:: Failure unresetting DSP.\n" ); 
		abend(0);
	}
	
	if (p) printf("Writing infinite branch at HPI boot address (0x10000).\n",bType );
	
	if (dbg) PressAnyKey();
	
	Sleep(1000);
	
	//write branch instruction to 0x10000
	branchInstr = (C5510_BRANCH_OPCODE | ((C5510_HPI_BOOT_ADDR<<1) & 0x00ffffff));
	branchInstr = ((branchInstr & 0xffff) << 16) | ((branchInstr & 0xffff0000) >> 16);
	
	if (!evm55x_hpi_write(hHpi, (PULONG)&branchInstr, &len, (ULONG)C5510_HPI_BOOT_ADDR, 0))
	{
		if (p) printf("**Error: Could not initiate code execution\n");
		abend(0);
	}

	if (p) printf( "Running DSP.\n",bType );

	if ( !evm55x_run_dsp(hBd, dspNum) )
	{
		if(p)printf( "**Error:: Failure running DSP.\n" ); 
		abend(0);
	}
	
	/***************************************************************************/
	/* Cleanup and exit                                                        */
	/***************************************************************************/
	/* Close HPI connection. */
	if(dbg) 
	{ 
		if(p)printf( "Closing HPI connection.\n" );
		
		PressAnyKey(); 
	}
	
	if (!evm55x_hpi_close(hHpi))
	{
		if(p)printf("**Error:: Failure closing HPI connection.\n"); abend(0);
	}
	
	if(dbg) 
	{ 
		if (p) printf("Releasing DSP from HPI boot mode halted state.\n" );
		
		PressAnyKey(); 
	}
	
	// Close EVM board
	if (dbg) 
	{ 
		if (p) printf( "Closing %s board.\n",bType );
		
		PressAnyKey(); 
	}
	
	if (!evm55x_close(hBd))
	{
		if (p) printf( "**Error:: evm55x_close() failed.\n" ); abend(0);
	}

	// Allow user to see results ...
    printf( "\nPress any key to exit." );
    c = _getch();
}

/*****************************************************************************/
/****        end of main()                                                ****/
/*****************************************************************************/

/*****************************************************************************/
/* arg() -- Assign variable from current argument.                           */
/*****************************************************************************/
void arg( char *fmt, ULONG *var, int def_value )
{ 
	char *temp = NULL;
	char *stp = "";
	
	if ( *++argp == '\0' )
	{ 
		if ( ++argIndx < argc )
		{ 
			argp = argv[argIndx];
			temp= argp;
			
			//sscanf( argp, fmt, var ); // Assign variable using specified format
			*var = strtol( argp, &stp, 0 );
			argp += (strlen(temp) - 1);
		}
		else
		{ 
			*var = (int) def_value; 
			*--argp;
		}
	}
	else
	{ 
		*var = strtol( argp, &stp, 0 );
		
		if ((*var == 0) && (*argp != '0') )
		{
			*var = (int) def_value;
		}
		else
		{
			argp += (strlen(argp) - 1);
		}
	}
	
	return; 
} // end of arg() 

/*****************************************************************************/
/* help() -- Provide assistance to the naive, then exit.                     */
/*****************************************************************************/
void help( void )
{

	// Print banner
	PrintBanner();
	
	if(p)
	{
		printf(helpTxt);
	}
	exit(1);
}


/*****************************************************************************/
/* PressAnyKey() -- In debug mode, wait for key press after each step.       */
/*****************************************************************************/
static void PressAnyKey( void )
{
    int c;
	
    if (p) printf(   "Press any key to continue (Ctrl-C to abort)." );
	
    c = _getch();
	
    if (p) printf( "\r                                             \r" );
	
    if ( c == 0x03 ) exit(1);
	
    if ( c == 0x1b ) dbg=0;
	
    return;
} // end of PressAnyKey()

/*****************************************************************************/
/* abend() -- Abnormal end of execution, i.e., after an error.               */
/*****************************************************************************/
void abend( int iQuit )
{
	if (hpi_open == TRUE) 
		evm55x_hpi_close(hHpi);
	
	if (device_open == TRUE) 
		evm55x_close(hBd);
	
	exit(1);
}
