#include "board.h"
#include "intr.h"
   
// Function Prototypes
static void installHandler();
interrupt void _dspInt5Isr(void);    

// Global Variables
unsigned intCount;

/*****************************************************************************/
/* MAIN                                                                      */
/*****************************************************************************/
void main()
{
    // initialize board
    brd_init(160);   
    
    // clear interrupt count
    intCount = 0;

    // install interrupt handlers
    installHandler();

    // no foreground processing, just loop
    while (1) {
       if (intCount & 1) brd_led_enable(BRD_LED0);
       else              brd_led_disable(BRD_LED0);
       
       if (intCount & 2) brd_led_enable(BRD_LED1);
       else              brd_led_disable(BRD_LED1);
       
       if (intCount & 4) brd_led_enable(BRD_LED2);
       else              brd_led_disable(BRD_LED2); 
    };
}

/*****************************************************************************/
/* Installs handler for INT5 interrupt                                       */
/*****************************************************************************/
static void installHandler()
{
    //clear pending interrupts
    IFR0 |= IFR0;
    IFR1 |= IFR1;

    //hook interrupt vectors
    hook_interrupt(INT5_TRAP, _dspInt5Isr);

    //enable external DSP int 5
    IER1 |= (1<<INT5);

    //enable global interrupts
    INTR_GLOBAL_ENABLE;
}

/*****************************************************************************/
/* Isr to service host-to-dsp interrupts                                     */
/*****************************************************************************/
interrupt void _dspInt5Isr(void)
{
    // interrupt host whenever INT5 is received
    brd_interrupt_host(); 
    
    // interrupt count
    intCount++;   
    
    // mask interrupt count
    intCount &= 7;
}
