#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <process.h>

#include "evm55xdll.h"     // public header file used by higher level apps
#include "ddpci2040.h"

// Function prototypes
unsigned __stdcall Dsp_Interrupt_Handler( void* pArguments );

// DSP side interrupt test application
static char DspAppName[] = "dspint.out";

//=============================================================================
int main(void)
{
	HANDLE   hBd = NULL;  // Board device handle   
	LPVOID   hHpi=NULL;   // HPI interface handle 
	HANDLE   hEvent;      // Event handle
	HANDLE   hIrqHandler; // Interrupt handler handle
	unsigned threadID;    // Thread ID number
	DWORD    dwWaitResult;// Wait result


	// Print program title
	printf("\nDSP-to-Host Interrupt Test Program\n");
	printf("===========================================\n");

    // Open EVM
	if ((hBd = evm55x_open(0, 1))	== INVALID_HANDLE_VALUE)
	{
		printf ("evm55x_open failed\n");
		return (-1);
	}
	
	// Open HPI interface
	if (!(hHpi = evm55x_hpi_open(hBd)))
	{
		printf ("evm55x_hpi_open failed\n");
		return (-1);
	}

	if (!(evm55x_enable_int(hHpi, INTDSP0)))
	{
		printf("evm55x_enable_int failed\n");
		return (-1);
	}

	// Get event handle for DSP interrupt
	if ((hEvent = evm55x_get_event_handle(hBd,DSP0_INT)) == NULL)
	{
        printf("**Error:: evm55x_get_event_handle() failed.\n");
		exit(-1);
	}

	// Reset board
	evm55x_reset_board(hBd);

    // Load DSP test program
    if (!evm55x_coff_load(hBd,hHpi,DspAppName,0,0,0,0))
    {
        printf("**Error:: evm55x_coff_load() failed.\n");       
        exit(-1);
    }   

    // Delay 100 milliseconds to let DSP init and run
	Sleep(100);

    // Interrupt DSP (Int5) so that it interrupts host in response 
	evm55x_generate_int(hHpi,DSP_INT5,0);

	//--------------------------------------------------------------------------------------------------
    // Option 1: Handling interrupts within an application
	//--------------------------------------------------------------------------------------------------       
    // Wait for low-level driver to indicate that interrupt occurred
	// We will use a timeout of 2 seconds, but you can use INFINITE to wait for it
    dwWaitResult = WaitForSingleObject( hEvent, 2000 );

    // Check if interrupt did not occur
	if ( dwWaitResult != WAIT_OBJECT_0 )
	{  // Interrupt was not received
       printf("First interrupt was not received from DSP.\n");
	}
	else
	{  // Interrupt was received

	   printf("First interrupt was received from DSP.\n");
	}

	//--------------------------------------------------------------------------------------------------
    // Option 2: Handling interrupts with another thread
	//--------------------------------------------------------------------------------------------------
    // Setup an interrupt handler to wait.  We can do anything we want in the foreground.

	// Create the interrupt handler thread.
    hIrqHandler = (HANDLE)_beginthreadex( NULL, 0, &Dsp_Interrupt_Handler, (void *)&hEvent, 0, &threadID );

    // Interrupt DSP (Int5) so that it interrupts host in response 
	evm55x_generate_int(hHpi,DSP_INT5,0);

    // Wait for interrupt handler to complete
	// We will use a timeout of 2 seconds, but you can use INFINITE to wait for it
	// You don't have to wait for the interrupt handler to complete.  In fact, in 
	// most applications you would just go on and do other processing.
    dwWaitResult = WaitForSingleObject( hIrqHandler, 2000 );

    // Check if interrupt did not occur
	if ( dwWaitResult != WAIT_OBJECT_0 )
	{  // Interrupt was not received
       printf("Second interrupt was not received from DSP.\n\n");
	}

   /***************************************************************************/
   /* Cleanup and exit                                                        */
   /***************************************************************************/
   
   // Destroy the thread object.
   CloseHandle( hIrqHandler );

   // Close HPI
   evm55x_hpi_close(hHpi);

   // Close EVM
   evm55x_close(hBd);
  
   return (0);

}

//=============================================================================
unsigned __stdcall Dsp_Interrupt_Handler( void* hEvent )
{
    
    // Wait for interrupt handler to complete
    WaitForSingleObject( *(HANDLE *)hEvent, INFINITE );	

	printf( "Second interrupt was received from DSP.\n" );

    _endthreadex( 0 );

    return 0;
}

