#include <board.h>
#include <intr.h>
   
#define DSP_INT_COUNT     0x28000  
#define DSP_NMI_COUNT     0x28001
#define DSP_INT5_COUNT    0x28002


/* Global Variables */
unsigned int dspIntCount; 
unsigned int nmiIntCount;  
unsigned int dspInt5Count;


// Function Prototypes
static void installHandlers(); 
interrupt void _dspIntIsr(void); 
interrupt void _nmiIntIsr(void);
interrupt void _dspInt5Isr(void);


/*****************************************************************************/
/* MAIN                                                                      */
/*****************************************************************************/
void main()
{
    // initialize board
    brd_init(160);
    
    INTR_GLOBAL_DISABLE;

    // clear counters
    dspIntCount  = 0;
    nmiIntCount  = 0;
    dspInt5Count = 0;


    // install interrupt handlers
    installHandlers();

    // no foreground processing, just loop
    while (1) {};
}

/*****************************************************************************/
/* Installs handlers for NMI, DSPINT, & INT5 interrupts                      */
/*****************************************************************************/
static void installHandlers()
{
    //clear pending interrupts
    IFR0 |= IFR0;
    IFR1 |= IFR1;
    
    //hook interrupt vectors
    hook_interrupt(NMI_TRAP, _nmiIntIsr);
    hook_interrupt(INT5_TRAP, _dspInt5Isr);
    hook_interrupt(HPINT_TRAP, _dspIntIsr);

    //enable DSP int
    IER0 |= (1<<HINT);

    //enable external DSP int 5
    IER1 |= (1<<INT5);

    //enable NMI
    CPLD_CTRL1_REG |= 0x10;

    //enable global interrupts
    INTR_GLOBAL_ENABLE;
}

/*****************************************************************************/
/* Isrs to service all host-to-dsp interrupts                                */
/*****************************************************************************/
interrupt void _dspIntIsr(void)
{
    dspIntCount++;
    *(volatile unsigned int *)DSP_INT_COUNT = dspIntCount;

    // toggle first LED
    brd_led_toggle(BRD_LED0);
}  

interrupt void _nmiIntIsr(void)
{
    nmiIntCount++;
    *(volatile unsigned int *)DSP_NMI_COUNT = nmiIntCount;

    // toggle second LED
    brd_led_toggle(BRD_LED1);
}

interrupt void _dspInt5Isr(void)
{
    dspInt5Count++;
    *(volatile unsigned int *)DSP_INT5_COUNT = dspInt5Count;

    // interrupt host whenever INT5 is received
    brd_interrupt_host();

    // toggle third LED
    brd_led_toggle(BRD_LED2);
}

