/******************************************************************************/
/*  MCBSP55X.H - MCBSP55X routines header file.                                 */
/*                                                                            */
/*     This module provides the devlib implementation for the MCBSP           */
/*     on the TMS320C55x DSP.                                                 */
/*                                                                            */
/*  MACRO FUNCTIONS:                                                          */
/*                                                                            */
/*  FUNCTIONS:                                                                */
/*	mcbsp_init - initialize and start serial port operation                   */
/*                                                                            */
/*                                                                            */
/******************************************************************************/

/******************************************************************/
/* This header file  defines the data structures and macros to    */
/* necessary to address the Multi-Channel Serial Port             */
/******************************************************************/
#ifndef _MCBSP55X_H_
#define _MCBSP55X_H_

#include "regs55x.h"

/*********************************************************************/
/* Register Definition  MCBSP										 */
/*********************************************************************/

#define DRR2_ADDR(port)     (0x2800+(0x400*port))
#define DRR2(port)      	*(ioport volatile unsigned int *)DRR2_ADDR(port)

#define DRR1_ADDR(port)		(DRR2_ADDR(port)+1)
#define DRR1(port)      	*(ioport volatile unsigned int *)DRR1_ADDR(port)

#define DXR2_ADDR(port)     (DRR2_ADDR(port)+2)
#define DXR2(port)      	*(ioport volatile unsigned int *)DXR2_ADDR(port)

#define DXR1_ADDR(port)		(DRR2_ADDR(port)+3)
#define DXR1(port)      	*(ioport volatile unsigned int *)DXR1_ADDR(port)

#define SPCR2_ADDR(port)    (DRR2_ADDR(port)+4)
#define SPCR2(port)      	*(ioport volatile unsigned int *)SPCR2_ADDR(port)

#define SPCR1_ADDR(port)    (DRR2_ADDR(port)+5)
#define SPCR1(port)      	*(ioport volatile unsigned int *)SPCR1_ADDR(port)

#define RCR2_ADDR(port)		(DRR2_ADDR(port)+6)
#define RCR2(port)      	*(ioport volatile unsigned int *)RCR2_ADDR(port)

#define RCR1_ADDR(port)		(DRR2_ADDR(port)+7)
#define RCR1(port)      	*(ioport volatile unsigned int *)RCR1_ADDR(port)

#define XCR2_ADDR(port)		(DRR2_ADDR(port)+8)
#define XCR2(port)      	*(ioport volatile unsigned int *)XCR2_ADDR(port)

#define XCR1_ADDR(port)		(DRR2_ADDR(port)+9)
#define XCR1(port)      	*(ioport volatile unsigned int *)XCR1_ADDR(port)

#define SRGR2_ADDR(port)	(DRR2_ADDR(port)+10)
#define SRGR2(port)      	*(ioport volatile unsigned int *)SRGR2_ADDR(port)

#define SRGR1_ADDR(port)	(DRR2_ADDR(port)+11)
#define SRGR1(port)      	*(ioport volatile unsigned int *)SRGR1_ADDR(port)

#define MCR2_ADDR(port)		(DRR2_ADDR(port)+12)
#define MCR2(port)      	*(ioport volatile unsigned int *)MCR2_ADDR(port)

#define MCR1_ADDR(port)		(DRR2_ADDR(port)+13)
#define MCR1(port)      	*(ioport volatile unsigned int *)MCR1_ADDR(port)

#define RCERA_ADDR(port)	(DRR2_ADDR(port)+14)
#define RCERA(port)      	*(ioport volatile unsigned int *)RCERA_ADDR(port)

#define RCERB_ADDR(port)	(DRR2_ADDR(port)+15)
#define RCERB(port)      	*(ioport volatile unsigned int *)RCERB_ADDR(port)

#define XCERA_ADDR(port)	(DRR2_ADDR(port)+16)
#define XCERA(port)      	*(ioport volatile unsigned int *)XCERA_ADDR(port)

#define XCERB_ADDR(port)	(DRR2_ADDR(port)+17)
#define XCERB(port)      	*(ioport volatile unsigned int *)XCERB_ADDR(port)

#define PCR_ADDR(port)		(DRR2_ADDR(port)+18)
#define PCR(port)      		*(ioport volatile unsigned int *)PCR_ADDR(port)

#define RCERC_ADDR(port)	(DRR2_ADDR(port)+19)
#define RCERC(port)      	*(ioport volatile unsigned int *)RCERC_ADDR(port)

#define RCERD_ADDR(port)	(DRR2_ADDR(port)+20)
#define RCERD(port)      	*(ioport volatile unsigned int *)RCERD_ADDR(port)

#define XCERC_ADDR(port)	(DRR2_ADDR(port)+21)
#define XCERC(port)      	*(ioport volatile unsigned int *)XCERC_ADDR(port)

#define XCERD_ADDR(port)	(DRR2_ADDR(port)+22)
#define XCERD(port)      	*(ioport volatile unsigned int *)XCERD_ADDR(port)

#define RCERE_ADDR(port)	(DRR2_ADDR(port)+23)
#define RCERE(port)      	*(ioport volatile unsigned int *)RCERE_ADDR(port)

#define RCERF_ADDR(port)	(DRR2_ADDR(port)+24)
#define RCERF(port)      	*(ioport volatile unsigned int *)RCERF_ADDR(port)

#define XCERE_ADDR(port)	(DRR2_ADDR(port)+25)
#define XCERE(port)      	*(ioport volatile unsigned int *)XCERE_ADDR(port)

#define XCERF_ADDR(port)	(DRR2_ADDR(port)+26)
#define XCERF(port)      	*(ioport volatile unsigned int *)XCERF_ADDR(port)

#define RCERG_ADDR(port)	(DRR2_ADDR(port)+27)
#define RCERG(port)      	*(ioport volatile unsigned int *)RCERG_ADDR(port)

#define RCERH_ADDR(port)	(DRR2_ADDR(port)+28)
#define RCERH(port)      	*(ioport volatile unsigned int *)RCERH_ADDR(port)

#define XCERG_ADDR(port)	(DRR2_ADDR(port)+29)
#define XCERG(port)      	*(ioport volatile unsigned int *)XCERG_ADDR(port)

#define XCERH_ADDR(port)	(DRR2_ADDR(port)+30)
#define XCERH(port)      	*(ioport volatile unsigned int *)XCERH_ADDR(port)

/*********************************************************************/
/* MCBSP 0                  										 */
/*********************************************************************/
/*
#define DRR20_ADDR 			0x2800
#define DRR20	      		*(ioport volatile unsigned int *)DRR20_ADDR

#define DRR10_ADDR			(DRR20_ADDR+1)
#define DRR10       		*(ioport volatile unsigned int *)DRR10_ADDR

#define DXR20_ADDR			(DRR20_ADDR+2)
#define DXR20	      		*(ioport volatile unsigned int *)DXR20_ADDR

#define DXR10_ADDR			(DRR20_ADDR+3)
#define DXR10      			*(ioport volatile unsigned int *)DXR10_ADDR

#define SPCR20_ADDR			(DRR20_ADDR+4)
#define SPCR20      		*(ioport volatile unsigned int *)SPCR20_ADDR

#define SPCR10_ADDR			(DRR20_ADDR+5)
#define SPCR10      		*(ioport volatile unsigned int *)SPCR10_ADDR

#define RCR20_ADDR			(DRR20_ADDR+6)
#define RCR20      			*(ioport volatile unsigned int *)RCR10_ADDR

#define RCR10_ADDR			(DRR20_ADDR+7)
#define RCR10      			*(ioport volatile unsigned int *)RCR20_ADDR

#define XCR20_ADDR			(DRR20_ADDR+8)
#define XCR20      			*(ioport volatile unsigned int *)XCR20_ADDR

#define XCR10_ADDR			(DRR20_ADDR+9)
#define XCR10      			*(ioport volatile unsigned int *)XCR10_ADDR

#define SRGR20_ADDR			(DRR20_ADDR+10)
#define SRGR20      		*(ioport volatile unsigned int *)SRGR20_ADDR

#define SRGR10_ADDR			(DRR20_ADDR+11)
#define SRGR10      		*(ioport volatile unsigned int *)SRGR10_ADDR

#define MCR20_ADDR			(DRR20_ADDR+12)
#define MCR20      			*(ioport volatile unsigned int *)MCR20_ADDR

#define MCR10_ADDR			(DRR20_ADDR+13)
#define MCR10      			*(ioport volatile unsigned int *)MCR10_ADDR

#define RCERA0_ADDR			(DRR20_ADDR+14)
#define RCERA0     			*(ioport volatile unsigned int *)RCERA0_ADDR

#define RCERB0_ADDR			(DRR20_ADDR+15)
#define RCERB0     			*(ioport volatile unsigned int *)RCERB0_ADDR

#define XCERA0_ADDR			(DRR20_ADDR+16)
#define XCERA0     			*(ioport volatile unsigned int *)XCERA0_ADDR

#define XCERB0_ADDR			(DRR20_ADDR+17)
#define XCERB0     			*(ioport volatile unsigned int *)XCERB0_ADDR

#define PCR0_ADDR			(DRR20_ADDR+18)
#define PCR0      			*(ioport volatile unsigned int *)PCR0_ADDR

#define RCERC0_ADDR			(DRR20_ADDR+19)
#define RCERC0     			*(ioport volatile unsigned int *)RCERC0_ADDR

#define RCERD0_ADDR			(DRR20_ADDR+20)
#define RCERD0     			*(ioport volatile unsigned int *)RCERD0_ADDR

#define XCERC0_ADDR			(DRR20_ADDR+21)
#define XCERC0     			*(ioport volatile unsigned int *)XCERC0_ADDR

#define XCERD0_ADDR			(DRR20_ADDR+22)
#define XCERD0     			*(ioport volatile unsigned int *)XCERD0_ADDR

#define RCERE0_ADDR			(DRR20_ADDR+23)
#define RCERE0     			*(ioport volatile unsigned int *)RCERE0_ADDR

#define RCERF0_ADDR			(DRR20_ADDR+24)
#define RCERF0     			*(ioport volatile unsigned int *)RCERF0_ADDR

#define XCERE0_ADDR			(DRR20_ADDR+25)
#define XCERE0     			*(ioport volatile unsigned int *)XCERE0_ADDR

#define XCERF0_ADDR			(DRR20_ADDR+26)
#define XCERF0     			*(ioport volatile unsigned int *)XCERF0_ADDR

#define RCERG0_ADDR			(DRR20_ADDR+27)
#define RCERG0     			*(ioport volatile unsigned int *)RCERG0_ADDR

#define RCERH0_ADDR			(DRR20_ADDR+28)
#define RCERH0    			*(ioport volatile unsigned int *)RCERH0_ADDR

#define XCERG0_ADDR			(DRR20_ADDR+29)
#define XCERG0     			*(ioport volatile unsigned int *)XCERG0_ADDR

#define XCERH0_ADDR			(DRR20_ADDR+30)
#define XCERH0     			*(ioport volatile unsigned int *)XCERH0_ADDR
*/

/*********************************************************************/
/* MCBSP 1                  										 */
/*********************************************************************/
/*
#define DRR21_ADDR 			0x2800
#define DRR21 	      		*(ioport volatile unsigned int *)DRR21_ADDR

#define DRR11_ADDR			(DRR21_ADDR+1)
#define DRR11       		*(ioport volatile unsigned int *)DRR11_ADDR

#define DXR21_ADDR			(DRR21_ADDR+2)
#define DXR21       		*(ioport volatile unsigned int *)DXR21_ADDR

#define DXR11_ADDR			(DRR21_ADDR+3)
#define DXR11      			*(ioport volatile unsigned int *)DXR11_ADDR

#define SPCR21_ADDR			(DRR21_ADDR+4)
#define SPCR21      		*(ioport volatile unsigned int *)SPCR21_ADDR

#define SPCR11_ADDR			(DRR21_ADDR+5)
#define SPCR11      		*(ioport volatile unsigned int *)SPCR11_ADDR

#define RCR21_ADDR			(DRR21_ADDR+6)
#define RCR21      			*(ioport volatile unsigned int *)RCR11_ADDR

#define RCR11_ADDR			(DRR21_ADDR+7)
#define RCR11      			*(ioport volatile unsigned int *)RCR21_ADDR

#define XCR21_ADDR			(DRR21_ADDR+8)
#define XCR21      			*(ioport volatile unsigned int *)XCR21_ADDR

#define XCR11_ADDR			(DRR21_ADDR+9)
#define XCR11      			*(ioport volatile unsigned int *)XCR11_ADDR

#define SRGR21_ADDR			(DRR21_ADDR+10)
#define SRGR21      		*(ioport volatile unsigned int *)SRGR21_ADDR

#define SRGR11_ADDR			(DRR21_ADDR+11)
#define SRGR11      		*(ioport volatile unsigned int *)SRGR11_ADDR

#define MCR21_ADDR			(DRR21_ADDR+12)
#define MCR21      			*(ioport volatile unsigned int *)MCR21_ADDR

#define MCR11_ADDR			(DRR21_ADDR+13)
#define MCR11      			*(ioport volatile unsigned int *)MCR11_ADDR

#define RCERA1_ADDR			(DRR21_ADDR+14)
#define RCERA1     			*(ioport volatile unsigned int *)RCERA1_ADDR

#define RCERB1_ADDR			(DRR21_ADDR+15)
#define RCERB1     			*(ioport volatile unsigned int *)RCERB1_ADDR

#define XCERA1_ADDR			(DRR21_ADDR+16)
#define XCERA1     			*(ioport volatile unsigned int *)XCERA1_ADDR

#define XCERB1_ADDR			(DRR21_ADDR+17)
#define XCERB1     			*(ioport volatile unsigned int *)XCERB1_ADDR

#define PCR1_ADDR			(DRR21_ADDR+18)
#define PCR1      			*(ioport volatile unsigned int *)PCR1_ADDR

#define RCERC1_ADDR			(DRR21_ADDR+19)
#define RCERC1     			*(ioport volatile unsigned int *)RCERC1_ADDR

#define RCERD1_ADDR			(DRR21_ADDR+20)
#define RCERD1     			*(ioport volatile unsigned int *)RCERD1_ADDR

#define XCERC1_ADDR			(DRR21_ADDR+21)
#define XCERC1     			*(ioport volatile unsigned int *)XCERC1_ADDR

#define XCERD1_ADDR			(DRR21_ADDR+22)
#define XCERD1     			*(ioport volatile unsigned int *)XCERD1_ADDR

#define RCERE1_ADDR			(DRR21_ADDR+23)
#define RCERE1     			*(ioport volatile unsigned int *)RCERE1_ADDR

#define RCERF1_ADDR			(DRR21_ADDR+24)
#define RCERF1     			*(ioport volatile unsigned int *)RCERF1_ADDR

#define XCERE1_ADDR			(DRR21_ADDR+25)
#define XCERE1     			*(ioport volatile unsigned int *)XCERE1_ADDR

#define XCERF1_ADDR			(DRR21_ADDR+26)
#define XCERF1     			*(ioport volatile unsigned int *)XCERF1_ADDR

#define RCERG1_ADDR			(DRR21_ADDR+27)
#define RCERG1     			*(ioport volatile unsigned int *)RCERG1_ADDR

#define RCERH1_ADDR			(DRR21_ADDR+28)
#define RCERH1    			*(ioport volatile unsigned int *)RCERH1_ADDR

#define XCERG1_ADDR			(DRR21_ADDR+29)
#define XCERG1     			*(ioport volatile unsigned int *)XCERG1_ADDR

#define XCERH1_ADDR			(DRR21_ADDR+30)
#define XCERH1     			*(ioport volatile unsigned int *)XCERH1_ADDR
*/

/*********************************************************************/
/* MCBSP 2                  										 */
/*********************************************************************/
/*
#define DRR22_ADDR 			0x2800
#define DRR22 	      		*(ioport volatile unsigned int *)DRR22_ADDR

#define DRR12_ADDR			(DRR22_ADDR+1)
#define DRR12       		*(ioport volatile unsigned int *)DRR12_ADDR

#define DXR22_ADDR			(DRR22_ADDR+2)
#define DXR22       		*(ioport volatile unsigned int *)DXR22_ADDR

#define DXR12_ADDR			(DRR22_ADDR+3)
#define DXR12      			*(ioport volatile unsigned int *)DXR12_ADDR

#define SPCR22_ADDR			(DRR22_ADDR+4)
#define SPCR22      		*(ioport volatile unsigned int *)SPCR22_ADDR

#define SPCR12_ADDR			(DRR22_ADDR+5)
#define SPCR12      		*(ioport volatile unsigned int *)SPCR12_ADDR

#define RCR22_ADDR			(DRR22_ADDR+6)
#define RCR22      			*(ioport volatile unsigned int *)RCR12_ADDR

#define RCR12_ADDR			(DRR22_ADDR+7)
#define RCR12      			*(ioport volatile unsigned int *)RCR22_ADDR

#define XCR22_ADDR			(DRR22_ADDR+8)
#define XCR22      			*(ioport volatile unsigned int *)XCR22_ADDR

#define XCR12_ADDR			(DRR22_ADDR+9)
#define XCR12      			*(ioport volatile unsigned int *)XCR12_ADDR

#define SRGR22_ADDR			(DRR22_ADDR+10)
#define SRGR22      		*(ioport volatile unsigned int *)SRGR22_ADDR

#define SRGR12_ADDR			(DRR22_ADDR+11)
#define SRGR12      		*(ioport volatile unsigned int *)SRGR12_ADDR

#define MCR22_ADDR			(DRR22_ADDR+12)
#define MCR22      			*(ioport volatile unsigned int *)MCR22_ADDR

#define MCR12_ADDR			(DRR22_ADDR+13)
#define MCR12      			*(ioport volatile unsigned int *)MCR12_ADDR

#define RCERA2_ADDR			(DRR22_ADDR+14)
#define RCERA2     			*(ioport volatile unsigned int *)RCERA2_ADDR

#define RCERB2_ADDR			(DRR22_ADDR+15)
#define RCERB2     			*(ioport volatile unsigned int *)RCERB2_ADDR

#define XCERA2_ADDR			(DRR22_ADDR+16)
#define XCERA2     			*(ioport volatile unsigned int *)XCERA2_ADDR

#define XCERB2_ADDR			(DRR22_ADDR+17)
#define XCERB2     			*(ioport volatile unsigned int *)XCERB2_ADDR

#define PCR2_ADDR			(DRR22_ADDR+18)
#define PCR2      			*(ioport volatile unsigned int *)PCR2_ADDR

#define RCERC2_ADDR			(DRR22_ADDR+19)
#define RCERC2     			*(ioport volatile unsigned int *)RCERC2_ADDR

#define RCERD2_ADDR			(DRR22_ADDR+20)
#define RCERD2     			*(ioport volatile unsigned int *)RCERD2_ADDR

#define XCERC2_ADDR			(DRR22_ADDR+21)
#define XCERC2     			*(ioport volatile unsigned int *)XCERC2_ADDR

#define XCERD2_ADDR			(DRR22_ADDR+22)
#define XCERD2     			*(ioport volatile unsigned int *)XCERD2_ADDR

#define RCERE2_ADDR			(DRR22_ADDR+23)
#define RCERE2     			*(ioport volatile unsigned int *)RCERE2_ADDR

#define RCERF2_ADDR			(DRR22_ADDR+24)
#define RCERF2     			*(ioport volatile unsigned int *)RCERF2_ADDR

#define XCERE2_ADDR			(DRR22_ADDR+25)
#define XCERE2     			*(ioport volatile unsigned int *)XCERE2_ADDR

#define XCERF2_ADDR			(DRR22_ADDR+26)
#define XCERF2     			*(ioport volatile unsigned int *)XCERF2_ADDR

#define RCERG2_ADDR			(DRR22_ADDR+27)
#define RCERG2     			*(ioport volatile unsigned int *)RCERG2_ADDR

#define RCERH2_ADDR			(DRR22_ADDR+28)
#define RCERH2    			*(ioport volatile unsigned int *)RCERH2_ADDR

#define XCERG2_ADDR			(DRR22_ADDR+29)
#define XCERG2     			*(ioport volatile unsigned int *)XCERG2_ADDR

#define XCERH2_ADDR			(DRR22_ADDR+30)
#define XCERH2     			*(ioport volatile unsigned int *)XCERH2_ADDR
*/

/*********************************************************************/
/* Define bit fields for Serial Port Control Registers 1 and 2       */
/*********************************************************************/
#define DLB				15
#define DLB_SZ			1

#define RJUST			13
#define RJUST_SZ	    2

#define CLKSTP			11
#define CLKSTP_SZ	    2

#define DXENA			7
#define DXENA_SZ	    1

#define ABIS			6
#define ABIS_SZ			1

#define RINTM			4
#define RINTM_SZ	    2

#define RSYNCERR	    3
#define RSYNCERR_SZ		1

#define RFULL			2
#define RFULL_SZ	    1

#define RRDY 			1
#define RRDY_SZ			1

#define RRST			0
#define RRST_SZ			1

#define MCBSP_FREE		9
#define MCBSP_FREE_SZ	1

#define SOFT			8
#define SOFT_SZ			1

#define FRST			7
#define FRST_SZ			1

#define GRST			6
#define GRST_SZ			1

#define XINTM			4
#define XINTM_SZ	    2

#define XSYNCERR	    3
#define XSYNCERR_SZ		1

#define XEMPTY			2
#define XEMPTY_SZ	    1

#define XRDY			1
#define XRDY_SZ			1

#define XRST			0
#define XRST_SZ 	    1

/*********************************************************************/
/* Define bit fields for Receive Control Registers 1 and 2           */
/*********************************************************************/
#define RFRLEN1			8
#define RFRLEN1_SZ		7

#define RWDLEN1			5
#define RWDLEN1_SZ		3

#define RPHASE			15
#define RPHASE_SZ	    1

#define RFRLEN2			8
#define RFRLEN2_SZ		7

#define RWDLEN2			5
#define RWDLEN2_SZ		3

#define RCOMPAND	    3
#define RCOMPAND_SZ		2

#define RFIG			2
#define RFIG_SZ			1

#define RDATDLY			0
#define RDATDLY_SZ		2

/*********************************************************************/
/* Define bit fields for Transmit Control Registers 1 and 2          */
/*********************************************************************/
#define XFRLEN1			8
#define XFRLEN1_SZ		7

#define XWDLEN1			5
#define XWDLEN1_SZ		2

#define XPHASE			15
#define XPHASE_SZ	    1

#define XFRLEN2			8
#define XFRLEN2_SZ		7

#define XWDLEN2			5
#define XWDLEN2_SZ		3

#define XCOMPAND	    3
#define XCOMPAND_SZ		2

#define XFIG			2
#define XFIG_SZ  	    1

#define XDATDLY			0
#define XDATDLY_SZ      2

/*********************************************************************/
/* Define bit fields for Sample Rate Generator Registers 1 and 2     */
/*********************************************************************/
#define FWID			8
#define FWID_SZ			8

#define CLKGDV			0
#define CLKGDV_SZ	    8

#define GSYNC			15
#define GSYNC_SZ	    1

#define CLKSP			14 
#define CLKSP_SZ	    1

#define CLKSM			13 
#define CLKSM_SZ	    1

#define FSGM			12 
#define FSGM_SZ			1

#define FPER			0
#define FPER_SZ			12

/*********************************************************************/
/* Define bit fields for Multi-Channel Control Registers 1 and 2     */
/*********************************************************************/
#define RMCME			9
#define RMCME_SZ	    1

#define RPBBLK			7
#define RPBBLK_SZ	    2

#define RPABLK			5
#define RPABLK_SZ	    2

#define RCBLK			2
#define RCBLK_SZ	    3

#define RMCM			0
#define RMCM_SZ			1

#define XMCME			9
#define XMCME_SZ	    1

#define XPBBLK			7
#define XPBBLK_SZ	    2

#define XPABLK			5
#define XPABLK_SZ	    2

#define XCBLK			2
#define XCBLK_SZ	    3

#define XMCM			0
#define XMCM_SZ			2

/***********************************************************************/
/* Define bit fields for Receive Channel Enable Register Partition A-H */
/***********************************************************************/
#define RCE15			15
#define RCE15_SZ	    1

#define RCE14			14
#define RCE14_SZ	    1

#define RCE13			13 
#define RCE13_SZ	    1

#define RCE12			12 
#define RCE12_SZ	    1
   
#define RCE11			11 
#define RCE11_SZ	    1

#define RCE10			10
#define RCE10_SZ	    1

#define RCE9			9
#define RCE9_SZ			1

#define RCE8			8
#define RCE8_SZ			1

#define RCE7			7
#define RCE7_SZ			1

#define RCE6			6
#define RCE6_SZ			1

#define RCE5			5
#define RCE5_SZ			1

#define RCE4			4
#define RCE4_SZ			1

#define RCE3			3
#define RCE3_SZ			1

#define RCE2			2
#define RCE2_SZ			1

#define RCE1			1
#define RCE1_SZ			1

#define RCE0			0
#define RCE0_SZ			1

/*********************************************************************/
/* Define bit fields for Transmit Channel Enable Register Partition A*/
/*********************************************************************/
#define XCE15			15
#define XCE15_SZ	    1

#define XCE14			14
#define XCE14_SZ	    1

#define XCE13			13 
#define XCE13_SZ	    1

#define XCE12			12 
#define XCE12_SZ	    1

#define XCE11			11 
#define XCE11_SZ	    1

#define XCE10			10
#define XCE10_SZ	    1

#define XCE9			9
#define XCE9_SZ			1

#define XCE8			8
#define XCE8_SZ			1

#define XCE7			7
#define XCE7_SZ			1

#define XCE6			6
#define XCE6_SZ			1

#define XCE5			5
#define XCE5_SZ			1

#define XCE4			4
#define XCE4_SZ			1

#define XCE3			3
#define XCE3_SZ			1

#define XCE2			2
#define XCE2_SZ			1

#define XCE1			1
#define XCE1_SZ			1

#define XCE0			0
#define XCE0_SZ			1

/*********************************************************************/
/* Define bit fields for Pin Control Register		               */
/*********************************************************************/
#define XIOEN			13
#define XIOEN_SZ	    1

#define RIOEN			12
#define RIOEN_SZ	    1

#define FSXM			11
#define FSXM_SZ 	    1

#define FSRM			10 
#define FSRM_SZ			1

#define CLKXM			9
#define CLKXM_SZ	    1

#define CLKRM			8
#define CLKRM_SZ	    1

#define SCLKME			7
#define SCLKME_SZ	    1

#define CLKS_STAT		6
#define CLKS_STAT_SZ	1

#define DX_STAT			5
#define DX_STAT_SZ		1

#define DR_STAT			4
#define DR_STAT_SZ		1

#define FSXP			3
#define FSXP_SZ			1

#define FSRP			2
#define FSRP_SZ			1

#define CLKXP			1
#define CLKXP_SZ	    1

#define CLKRP			0
#define CLKRP_SZ	    1

/*********************************************************************/
/* CONFIGURATION REGISTER BIT and BITFIELD values                    */
/*********************************************************************/
#define MCBSP_RX     1
#define MCBSP_TX     2
#define MCBSP_BOTH   3 

//Serial Port Control Register SPCR1 
#define DLB_ENABLE          0x01	//Enable Digital Loopback Mode          
#define DLB_DISABLE         0x00	//Disable Digital Loopback Mode         

#define RXJUST_RJZF         0x00	//Receive Right Justify Zero Fill             
#define RXJUST_RJSE         0x01	//Receive Right Justify Sign Extend     
#define RXJUST_LJZF         0x02	//Receive Left Justify Zero Fill        
                                                                              
#define CLK_STOP_DISABLED	0x00	//Normal clocking for non-SPI mode       
#define CLK_START_WO_DELAY  0x02	//Clock starts without delay            
#define CLK_START_W_DELAY	0x03	//Clock starts with delay               

#define DX_ENABLE_OFF		0x00	//no extra delay for turn-on time       
#define DX_ENABLE_ON		0x01	//enable extra delay for turn-on time   

#define ABIS_DISABLE		0x00	//A-bis mode is disabled                
#define ABIS_ENABLE			0x01		//A-bis mode is enabled                 


//Serial Port Control Registers SPCR1 and SPCR2 
#define INTM_RDY            0x00     //R/X INT driven by R/X RDY             
#define INTM_BLOCK          0x01     //R/X INT driven by new multichannel blk
#define INTM_FRAME          0x02     //R/X INT driven by new frame sync      
#define INTM_SYNCERR        0x03     //R/X INT generated by R/X SYNCERR      

#define RX_RESET			0x00	 //R or X in reset 
#define RX_ENABLE			0x01	 //R or X enabled 


//Serial Port Control Register SPCR2 
#define SP_FREE_OFF			0x00     //Free running mode is diabled          
#define SP_FREE_ON			0x01     //Free running mode is enabled          

#define SOFT_DISABLE		0x00     //SOFT mode is disabled                 
#define SOFT_ENABLE			0x01     //SOFT mode is enabled                  

#define FRAME_GEN_RESET		0x00     //Frame Synchronization logic is reset  
#define FRAME_GEN_ENABLE	0x01     //Frame sync signal FSG is generated    

#define SRG_RESET			0x00     //Sample Rate Generator is reset        
#define SRG_ENABLE			0x01     //Sample Rate Generator is enabled      

//Pin Control Register PCR 
#define IO_DISABLE			0x00     //No General Purpose I/O Mode           
#define IO_ENABLE			0x01     //General Purpose I/0 Mode enabled      

#define CLKR_POL_RISING     0x01     //R Data Sampled on Rising Edge of CLKR 
#define CLKR_POL_FALLING    0x00     //R Data Sampled on Falling Edge of CLKR
#define CLKX_POL_RISING     0x00     //X Data Sent on Rising Edge of CLKX    
#define CLKX_POL_FALLING    0x01     //X Data Sent on Falling Edge of CLKX   
#define FSYNC_POL_HIGH      0x00     //Frame Sync Pulse Active High          
#define FSYNC_POL_LOW       0x01     //Frame Sync Pulse Active Low           

#define CLK_MODE_EXT        0x00     //Clock derived from external source    
#define CLK_MODE_INT        0x01     //Clock derived from internal source    

#define FSYNC_MODE_EXT      0x00     //Frame Sync derived from external src  
#define FSYNC_MODE_INT      0x01     //Frame Sync dervived from internal src 

#define IDLE_ENABLE			0x01     //Stop all McBsp clocks when in IDLE mode        
#define IDLE_DISABLE		0x00     //Do not stop all McBsp clocks when in IDLE mode        

//Transmit Receive Control Register XCR/RCR 

#define SINGLE_PHASE        0x00     //Selects single phase frames           
#define DUAL_PHASE          0x01     //Selects dual phase frames             

#define MAX_FRAME_LENGTH    0x7f     //maximum number of words per frame     

#define WORD_LENGTH_8       0x00     //8 bit word length (requires filling)  
#define WORD_LENGTH_12      0x01     //12 bit word length       ""           
#define WORD_LENGTH_16      0x02     //16 bit word length       ""           
#define WORD_LENGTH_20      0x03     //20 bit word length       ""           
#define WORD_LENGTH_24      0x04     //24 bit word length       ""           
#define WORD_LENGTH_32      0x05     //32 bit word length (matches DRR DXR sz

#define MAX_WORD_LENGTH     0x20     //maximum number of bits per word       

#define NO_COMPAND_MSB_1ST  0x00     //No Companding, Data XFER starts w/MSb 
#define NO_COMPAND_LSB_1ST  0x01     //No Companding, Data XFER starts w/LSb 
#define COMPAND_ULAW        0x02     //Compand ULAW, 8 bit word length only  
#define COMPAND_ALAW        0x03     //Compand ALAW, 8 bit word length only  

#define FRAME_IGNORE        0x01     //Ignore frame sync pulses after 1st    
#define NO_FRAME_IGNORE     0x00     //Utilize frame sync pulses             

#define DATA_DELAY0         0x00     //1st bit in same clk period as fsync   
#define DATA_DELAY1         0x01     //1st bit 1 clk period after fsync      
#define DATA_DELAY2         0x02     //1st bit 2 clk periods after fsync     
  
//Sample Rate Generator Register SRGR 

//Clock mode (ext. / int.) see PCR 
#define MAX_SRG_CLK_DIV     0xff     //max value to divide Sample Rate Gen Cl
#define MAX_FRAME_WIDTH     0xff     //maximum FSG width in CLKG periods     
#define MAX_FRAME_PERIOD    0x0fff   //FSG period in CLKG periods            

#define FSX_DXR_TO_XSR      0x00     //Transmit FSX due to DXR to XSR copy   
#define FSX_FSG             0x01     //Transmit FSX due to FSG               

#define CLKS_POL_FALLING    0x00     //falling edge generates CLKG and FSG   
#define CLKS_POL_RISING     0x01     //rising edge generates CLKG and FSG    

#define GSYNC_OFF           0x00     //CLKG always running                   
#define GSYNC_ON            0x01     //CLKG and FSG synch'ed to FSR           

//Multi-channel Control Register 1 and 2 MCR1/2 
#define RMCM_CHANNEL_ENABLE		0x00 	//all 128 channels enabled              
#define RMCM_CHANNEL_DISABLE	0x01 	//all channels disabled, selected by    
						 				//enabling RP(A-H)BLK, RCER(A-H)        

#define XMCM_CHANNEL_DX_DRIVEN	0x00	//transmit data over DX pin for as many 
										//number of words as required           
#define XMCM_XCER_CHAN_TO_DXR	0x01 	//selected channels written to DXR      
#define XMCM_ALL_WORDS_TO_DXR	0x02 	//all words copied to DXR(1/2),         
										//DX only driven for selected words     
#define XMCM_CHANNEL_SYM_R/X	0x03 	//symmetric transmit and receive        
										//operation                             
     
#define MCM_128CHANNEL_DISABLE	0x01	//Normal mode 32 channels enabled
#define MCM_128CHANNEL_ENABLE	0x01	//Enable all 128 channels

/********* Macro Definitions **************************************/
/******************************************************************/
/******************************************************************/
/* MCBSP_ENABLE(unsigned short port, unsigned short type) -       */
/*            starts serial port receive and/or transmit          */
/*            type= 1 rx, type= 2 tx, type= 3 both                */
/******************************************************************/
#define MCBSP_ENABLE(port,mode) \
   {SPCR1(port) |= (mode & 1); \
	SPCR2(port) |= ((mode >> 1) & 1);}

/******************************************************************/
/* MCBSP_TX_RESET() - reset transmit side of serial port          */
/*                                                                */
/******************************************************************/
#define MCBSP_TX_RESET(port) \
	SPCR2(port) &= ~(1<<XRST)
  

/******************************************************************/
/* MCBSP_RX_RESET() - reset receive side of serial port           */
/*                                                                */
/******************************************************************/
#define MCBSP_RX_RESET(port) \
	SPCR1(port) &= ~(1<<RRST)
  
/******************************************************************/
/* MCBSP_IO_ENABLE() - place port in general purpose I/O mode     */
/******************************************************************/
#define MCBSP_IO_ENABLE(port) \
        { MCBSP_TX_RESET(port); MCBSP_RX_RESET(port); \
          PCR(port) |= (0x0003 << RIOEN);} 


/******************************************************************/
/* MCBSP_IO_DISABLE() - take port out of general purpose I/O mode */
/******************************************************************/
#define MCBSP_IO_DISABLE(port) \
          PCR(port) &= ~(0x0003 << RIOEN)

/******************************************************************/
/* MCBSP_FRAME_SYNC_ENABLE - sets FRST bit in SPCR                */
/******************************************************************/
#define MCBSP_FRAME_SYNC_ENABLE(port) \
		SPCR2(port) |= (1<<FRST)

/******************************************************************/
/* MCBSP_FRAME_SYNC_RESET - clrs FRST bit in SPCR                 */
/******************************************************************/
#define MCBSP_FRAME_SYNC_RESET(port) \
		SPCR2(port) &= ~(1<<FRST)

/******************************************************************/
/* MCBSP_SAMPLE_RATE_ENABLE - sets GRST bit in SPCR               */
/******************************************************************/
#define MCBSP_SAMPLE_RATE_ENABLE(port) \
		SPCR2(port) |= (1<<GRST)

/******************************************************************/
/* MCBSP_SAMPLE_RATE_RESET - clrs GRST bit in SPCR                */
/******************************************************************/
#define MCBSP_SAMPLE_RATE_RESET(port) \
		SPCR2(port) &= ~(1<<GRST)

/******************************************************************/
/* MCBSP_RRDY - returns selected ports RRDY                       */
/******************************************************************/
#define MCBSP_RRDY(port) \
		((SPCR1(port) >> RRDY) & 0x1)

/******************************************************************/
/* MCBSP_XRDY - returns selected ports XRDY                       */
/******************************************************************/
#define MCBSP_XRDY(port) \
		((SPCR2(port) >> XRDY) & 0x1)


/******************************************************************/
/* MCBSP_LOOPBACK_ENABLE - places selected port in loopback       */
/******************************************************************/
#define MCBSP_LOOPBACK_ENABLE(port) \
		SPCR1(port) |= (1<<DLB)

/******************************************************************/
/* MCBSP_LOOPBACK_DISABLE - takes port out of DLB                 */
/******************************************************************/
#define MCBSP_LOOPBACK_DISABLE(port) \
		SPCR1(port) &= ~(1<<DLB)

/******************************************************************/
/* Structure definitions                                          */
/******************************************************************/
typedef struct _McBspConfig
{
	unsigned int  port;
	unsigned int  spcr1;
    unsigned int  spcr2;
    unsigned int  rcr1;
    unsigned int  rcr2;
    unsigned int  xcr1;
    unsigned int  xcr2;
    unsigned int  srgr1;
    unsigned int  srgr2;
    unsigned int  mcr1;
    unsigned int  mcr2;
    unsigned int  pcr;
    unsigned int  rcera;
    unsigned int  xcera;
    unsigned int  rcerb;
    unsigned int  xcerb;
    unsigned int  rcerc;
    unsigned int  xcerc;
    unsigned int  rcerd;
    unsigned int  xcerd;
    unsigned int  rcere;
    unsigned int  xcere;
    unsigned int  rcerf;
    unsigned int  xcerf;
    unsigned int  rcerg;
    unsigned int  xcerg;
    unsigned int  rcerh;
    unsigned int  xcerh;
} McBspConfig, *PMcBspConfig;

/****************************************************************************/
/* FUNCTION DEFINITIONS                                                     */
/****************************************************************************/
void mcbsp_init(PMcBspConfig pBsp);

#endif //_MCBSP55X_H_
