/******************************************************************************/
/*  sig.h - Tone generator for 5510 EVM                                       */
/*                                                                            */
/*  Uses a table look-up method to generate tones of varying frequencies      */
/*  Only supports frequencies up to 4000Hz                                    */
/******************************************************************************/
#define SIG_MAX_FREQ    4000 //Maximum supported frequency is 4 kHz
#define SIG_MAX_SRATE   8000 //Maximum supported sample rate is 8 kHz

/*****************************************************************************/
/* typedefs & enums                                                          */
/*****************************************************************************/
typedef enum
{
   LEFT = 0,
   RIGHT = 1,
   BOTH = 2
} SigCh, *PSigCh;

/*****************************************************************************/
// functions
/*****************************************************************************/


/*****************************************************************************/
/* int sig_init(unsigned int freq_, unsigned int srate_)                     */
/*										                                     */
/* This functions sets the frquency and the sample rate.                     */
/*																			 */
/* Parameters:																 */
/*		unsigned int freq_													 */
/*		unsigned int srate_													 */
/*																			 */
/* Return:																	 */
/*		- OK	success														 */
/*		- ERROR	failure														 */
/*																			 */
/*****************************************************************************/
int sig_init(unsigned int freq_, unsigned int srate_);


/*****************************************************************************/
/* void sig_reset()                                                          */
/*																			 */
/* This function calculates the points at which the sinusoidal               */
/* is to be sampled.                                                         */
/*																			 */
/* Parameters:	none														 */
/*																			 */
/* Return:		none														 */
/*																			 */
/*****************************************************************************/
void sig_reset();


/*****************************************************************************/
/* void sig(int *pBuf, unsigned int size, unsigned int num_ch, SigCh ch)     */
/*																			 */
/* This function generates a buffer full of tone data. It approximates       */
/* by using the look-up table.												 */
/*																			 */
/* Parameters:																 */
/*	pBuf - Pointer to buffer to store tone data								 */
/*	num_ch - Specifies either a single channel or 2 channels. For a single   */
/*           channel consecutive samples in the buffer differ where as for   */
/*           the 2 channel case identical LEFT and right tone samples are    */
/*           placed in the buffer.                                           */
/*	ch - Specifies the channel to store the data: LEFT, RIGHT, or BOTH       */
/*																			 */
/* Return:	none															 */
/*																			 */
/*****************************************************************************/
void sig(int *pBuf, unsigned int size, unsigned int num_ch, SigCh ch);
