/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... CSL - chip support library service layer interface
* FILENAME...... csldata.h
* DATE CREATED.. Fri 06/11/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED: 02/04/2000 
*   LAST MODIFIED: 06/19/2000  incorporate cpluplus compatability
*------------------------------------------------------------------------------
* DESCRIPTION:  (Global/Static Data Table to Support ROMability of CSL modules)
*
*
*
\******************************************************************************/
#ifndef _CSL_CSLDATA_H_
#define _CSL_CSLDATA_H_

#include <csl_cslhal.h>
#include <csl_datasz.h>

/****************************************\
* CSL scope and inline control macros
\****************************************/
#ifdef __cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CSL_MOD_
  #define IDECL CSLAPI
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif


/*============================================================*/
/*============= Defines ======================================*/
/*============================================================*/
#define CSL_SYSDATAINIT\
   {      /* CSL Global System Data Initialization       */\
       (0x00000000ul),            /* Reserved Word                      */\
       (0x00000000ul),            /* CSL Data Ptr                       */\
       (0x00000000ul),            /* Ptr to DSPBIOS Dispatch Table      */\
       (0x0000u),                 /* Char Ptr to CSL Version            */\
       (0x0000u),                 /* Char Ptr to CSL Time/Date Stamp    */\
       (0x0000u),                 /* DSPBIOS present flag               */\
       (0x0000u),                 /* DMA Channel Allocation Mask        */\
       (0x0000u),                 /* DMA Global Regs Alocation Mask     */\
       (0x0000u),                 /* DMA Global Regs Used Mask          */\
       (0x0000u),                 /* Dat Alloc Mask                     */\
       (0x0000u),                 /* CSL DAT Module Open flag           */\
       (0x0000u),                 /* CSL DAT Module Submit Mask         */\
       (0x0000u),                 /* DAT Module Submit Request Priority */\
       (0x0000u),                 /* MCBSP Module Port Allocation Mask  */\
       (0x0000u),                 /* MMC Port Allocation Mask           */\
       (0x0000u),                 /* TIMER Allocation Mask              */\
       (0x0000u),                 /* PLL Allocation Mask                */\
       (0x0000u),                 /* Error Count                        */\
       (0x00000000ul)             /* Error Handler                      */\
   }

/*****************************************************************************\
* Macro to declare symbols
\*****************************************************************************/


/*============================================================*/
/*============= Structure Definitions ========================*/
/*============================================================*/
typedef struct {
	Uint32 Reserved;
      Uint32 DataPtr;
      Uint32 DispatchTablePtr;
      char * Version;
      char * DateStamp;
      Uint16 BiosPresent;
      Uint16 DmaAllocMask;
      Uint16 DmaGblAllocMask;
      Uint16 DmaGblRegMask;
      Uint16 DatAllocMask;
      Uint16 DatOpenFlag;
      Uint16 DatSubmitMask;
      Uint16 DatChaPriority;
      Uint16 McbspPortAllocMask;
      Uint16 MmcAllocMask;
      Uint16 TimerAllocMask;
      Uint16 PllAllocMask;
      Uint16 ErrCnt;
      Uint32 ErrFunc;
} CSL_SysDataObj;

typedef struct {
      CSL_SysDataObj    CSL_SysData;
      CSL_IcacheDataObj CSL_IcacheData;
      CSL_ErrDataObj    CSL_ErrData;
      CSL_IrqDataObj    CSL_IrqData;
      CSL_EmifDataObj   CSL_EmifData;
      CSL_ChipDataObj   CSL_ChipData;
      CSL_DmaDataObj    CSL_DmaData;
      CSL_DatDataObj    CSL_DatData;
      CSL_GpioDataObj   CSL_GpioData;
      CSL_McbspDataObj  CSL_McbspData;
      CSL_TimerDataObj  CSL_TimerData;
      CSL_MmcDataObj    CSL_MmcData;
      CSL_WdtimDataObj  CSL_WdtimData;
      CSL_RtcDataObj    CSL_RtcData;
      CSL_I2cDataObj    CSL_I2cData;
} _CSL_SysStatusObj;

typedef _CSL_SysStatusObj * _CSL_SysStatusPtr;
extern _CSL_SysStatusObj _CSL_DataObj;

/******************************************************************************\
* Table of contents for Global/Static data array
\******************************************************************************/
#define _CSL_DATA             (*(_CSL_SysStatusPtr *)CSL_DATA_PTR)
#define CSL_SYS_DATA          (_CSL_DATA->CSL_SysData)
#define CSL_ICACHE_DATA       (_CSL_DATA->CSL_SysData)
#define CSL_IRQ_DATA          (_CSL_DATA->CSL_IrqData)
#define CSL_EMIF_DATA         (_CSL_DATA->CSL_EmifData)
#define CSL_CHIP_DATA         (_CSL_DATA->CSL_ChipData)
#define CSL_DMA_DATA          (_CSL_DATA->CSL_DmaData)
#define CSL_DAT_DATA          (_CSL_DATA->CSL_DatData)
#define CSL_GPIO_DATA         (_CSL_DATA->CSL_GpioData)
#define CSL_MCBSP_DATA        (_CSL_DATA->CSL_McbspData)
#define CSL_ERR_DATA          (_CSL_DATA->CSL_ErrData)
#define CSL_TIMER_DATA        (_CSL_DATA->CSL_TimerData)
#define CSL_PWR_DATA          (_CSL_DATA->CSL_PwrData)
#define CSL_PLL_DATA          (_CSL_DATA->CSL_PllData)
#define CSL_MMC_DATA          (_CSL_DATA->CSL_MmcData)
#define CSL_WDTIM_DATA        (_CSL_DATA->CSL_WdtimData)
#define CSL_RTC_DATA          (_CSL_DATA->CSL_RtcData)
#define CSL_I2C_DATA          (_CSL_DATA->CSL_I2cData)



#endif /* _CSL_CSLDATA_H_ */
/******************************************************************************\
* End of csl_csldata.h
\******************************************************************************/

