/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... PWR
* FILENAME...... csl_pwrhal.h
* DATE CREATED.. Thu 11/11/1999 
* PROJECT....... CSL - Chip Support Library
* COMPONENT..... CSL HAL
* PREREQUISITS..
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:       11/11/1999 Created
*   MODIFIED:      11/29/1999 modified for TMS320C54xx
*   MODIFIED:      07/18/2000 modified for TMS320C55xx
*   LAST MODIFIED: 04/16/2001 updated header comments
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the PWR module)
*
* Registers Covered:
*   (RW) _PWR_ICR  -  Idle configuration register
*
\******************************************************************************/
#ifndef _PWRHAL_H_
#define _PWRHAL_H_

#include <csl_chiphal.h>   
 
#if (_PWR_SUPPORT)

/****************************************\
* _PWR scope and inline control macros
\****************************************/
#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#define IDECL static inline
#define USEDEFS
#define IDEF  static inline


 #define _PWR_IDLE_PERIPHERALS_ACTIVE	(0x0001u)
 #define _PWR_IDLE_PERIPHERALS_INACTIVE   (0x0002u)
 #define _PWR_IDLE_PLL_DISABLED           (0x0003u)


/*============================================================================*\
* _PWR_ICR:  Idle Configuration Register
\*============================================================================*/
#define _PWR_ICR_ADDR			       (0x0001u)
#define _PWR_ICR                           PREG16(_PWR_ICR_ADDR)
#define _ICR                               _PWR_ICR

#define _PWR_ISTR_ADDR			      (0x0002u)
#define _PWR_ISTR	                         PREG16(_PWR_ISTR_ADDR)
#define _ISTR                              _PWR_ISTR

/*============================================================================*\
* Generic PWR register/field get/set macros
\*============================================================================*/
#define PWR_ADDR(Reg)              _PWR_##Reg##_ADDR
#define PWR_RGET(Reg)              _PREG_GET(PWR_ADDR(##Reg))
#define PWR_RSET(Reg,Val)          _PREG_SET(PWR_ADDR(##Reg),Val)
#define PWR_RAOI(Reg,AND,OR,INV)   _PREG_AOI(PWR_ADDR(##Reg),AND,OR,INV)
#define PWR_FGET(Reg,Field)        _PFIELD_GET(PWR_ADDR(##Reg),_PWR_##Reg##_##Field)
#define PWR_FSET(Reg,Field,Val)    _PFIELD_SET(PWR_ADDR(##Reg),_PWR_##Reg##_##Field,Val)
#define PWR_FSETS(Reg,Field,Sym)   PWR_FSET(##Reg,##Field,PWR_##Reg##_##Field##_##Sym)
#define PWR_FMK(Reg,Field,Val)     _PWR_##Reg##_##Field##_MK(Val)
#define PWR_FMKS(Reg,Field,Sym)    PWR_FMK(##Reg,##Field,PWR_##Reg##_##Field##_##Sym)

#define PWR_FAOI(Reg,Field,AND,OR,INV)\
  _PFIELD_AOI(PWR_ADDR(##Reg),_PWR_##Reg##_##Field,AND,OR,INV)

/*============================================================================*\
* _PWR_ICR_GET and _PWR_ICR_SET
\*============================================================================*/
#define _PWR_ICR_GET(RegAddr)		      HPREG_GET(RegAddr)
#define _PWR_ICR_SET(RegAddr,Val)		HPREG_SET(RegAddr, Val)

/*============================================================================*\
* _PWR_ISTR_GET 
\*============================================================================*/
#define _PWR_ISTR_GET(RegAddr)            HPREG_GET(RegAddr)


/*===========================================================================*\
* _PWR_ICR    - Idle Configuration Register
*
* Fields:
*  (RW) _PWR_ICR_EMIFI
*  (RW) _PWR_ICR_CLKGENI
*  (RW) _PWR_ICR_PERI
*  (RW) _PWR_ICR_CACHEI
*  (RW) _PWR_ICR_DMAI
*  (RW) _PWR_ICR_CPUI
*
\*==========================================================================*/

/*==========================================================================*\
* (RW) _PWR_ICR_EMIFI
\*--------------------------------------------------------------------------*/
#define _PWR_ICR_EMIFI_SHIFT		  (0x0000)
#define _PWR_ICR_EMIFI_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ICR_EMIFI_SHIFT)
#define _PWR_ICR_EMIFI_MASK            (_PWR_ICR_EMIFI_MK(1))
#define _PWR_ICR_EMIFI_CLR             (~(_PWR_ICR_EMIFI_MK(1)))

#define _PWR_ICR_EMIFI_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ICR_EMIFI)

#define _PWR_ICR_EMIFI_SET(RegAddr,Val) \
	HPFIELD_SET(RegAddr,_PWR_ICR_EMIFI,Val)


/*==========================================================================*\
* (RW) _PWR_ICR_CLKGENI
\*--------------------------------------------------------------------------*/
#define _PWR_ICR_CLKGENI_SHIFT		  (0x0001)
#define _PWR_ICR_CLKGENI_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ICR_CLKGENI_SHIFT)
#define _PWR_ICR_CLKGENI_MASK            (_PWR_ICR_CLKGENI_MK(1))
#define _PWR_ICR_CLKGENI_CLR             (~(_PWR_ICR_CLKGENI_MK(1)))

#define _PWR_ICR_CLKGENI_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ICR_CLKGENI)

#define _PWR_ICR_CLKGENI_SET(RegAddr,Val) \
	HPFIELD_SET(RegAddr,_PWR_ICR_CLKGENI,Val)


/*==========================================================================*\
* (RW)
\*--------------------------------------------------------------------------*/
#define _PWR_ICR_PERI_SHIFT		  (0x0002)
#define _PWR_ICR_PERI_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ICR_PERI_SHIFT)
#define _PWR_ICR_PERI_MASK            (_PWR_ICR_PERI_MK(1))
#define _PWR_ICR_PERI_CLR             (~(_PWR_ICR_PERI_MK(1)))

#define _PWR_ICR_PERI_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ICR_PERI)

#define _PWR_ICR_PERI_SET(RegAddr,Val) \
	HPFIELD_SET(RegAddr,_PWR_ICR_PERI,Val)


/*==========================================================================*\
* (RW) _PWR_ICR_CACHEI
\*--------------------------------------------------------------------------*/
#define _PWR_ICR_CACHEI_SHIFT		  (0x0003)
#define _PWR_ICR_CACHEI_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ICR_CACHEI_SHIFT)
#define _PWR_ICR_CACHEI_MASK            (_PWR_ICR_CACHEI_MK(1))
#define _PWR_ICR_CACHEI_CLR             (~(_PWR_ICR_CACHEI_MK(1)))

#define _PWR_ICR_CACHEI_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ICR_CACHEI)

#define _PWR_ICR_CACHEI_SET(RegAddr,Val) \
	HPFIELD_SET(RegAddr,_PWR_ICR_CACHEI,Val)

/*==========================================================================*\
* (RW) _PWR_ICR_DMAI
\*--------------------------------------------------------------------------*/
#define _PWR_ICR_DMAI_SHIFT		  (0x0004)
#define _PWR_ICR_DMAI_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ICR_DMAI_SHIFT)
#define _PWR_ICR_DMAI_MASK            (_PWR_ICR_DMAI_MK(1))
#define _PWR_ICR_DMAI_CLR             (~(_PWR_ICR_DMAI_MK(1)))

#define _PWR_ICR_DMAI_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ICR_DMAI)

#define _PWR_ICR_DMAI_SET(RegAddr,Val) \
	HPFIELD_SET(RegAddr,_PWR_ICR_DMAI,Val)


/*==========================================================================*\
* (RW) _PWR_ICR_CPUI
\*--------------------------------------------------------------------------*/
#define _PWR_ICR_CPUI_SHIFT		  (0x0005)
#define _PWR_ICR_CPUI_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ICR_CPUI_SHIFT)
#define _PWR_ICR_CPUI_MASK            (_PWR_ICR_CPUI_MK(1))
#define _PWR_ICR_CPUI_CLR             (~(_PWR_ICR_CPUI_MK(1)))

#define _PWR_ICR_CPUI_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ICR_CPUI)

#define _PWR_ICR_CPUI_SET(RegAddr,Val) \
	HPFIELD_SET(RegAddr,_PWR_ICR_CPUI,Val)


/*===========================================================================*\
* _PWR_ISTR    - Idle Status Register
*
* Fields:
*  (R) _PWR_ISTR_EMIFIS
*  (R) _PWR_ISTR_CLKGENIS
*  (R) _PWR_ISTR_PERIS
*  (R) _PWR_ISTR_CACHEIS
*  (R) _PWR_ISTR_DMAIS
*  (R) _PWR_ISTR_CPUIS
*
\*==========================================================================*/


/*==========================================================================*\
* (R) _PWR_ISTR_EMIFIS
\*--------------------------------------------------------------------------*/
#define _PWR_ISTR_EMIFIS_SHIFT		  (0x0000)
#define _PWR_ISTR_EMIFIS_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ISTR_EMIFIS_SHIFT)
#define _PWR_ISTR_EMIFIS_MASK            (_PWR_ISTR_EMIFIS_MK(1))
#define _PWR_ISTR_EMIFIS_CLR             (~(_PWR_ISTR_EMIFIS_MK(1)))

#define _PWR_ISTR_EMIFIS_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ISTR_EMIFIS)


/*==========================================================================*\
* (R) _PWR_ISTR_CLKGENIS
\*--------------------------------------------------------------------------*/
#define _PWR_ISTR_CLKGENIS_SHIFT		  (0x0001)
#define _PWR_ISTR_CLKGENIS_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ISTR_CLKGENIS_SHIFT)
#define _PWR_ISTR_CLKGENIS_MASK            (_PWR_ISTR_CLKGENIS_MK(1))
#define _PWR_ISTR_CLKGENIS_CLR             (~(_PWR_ISTR_CLKGENIS_MK(1)))

#define _PWR_ISTR_CLKGENIS_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ISTR_CLKGENIS)


/*==========================================================================*\
* (R)  _PWR_ISTR_PERIS
\*--------------------------------------------------------------------------*/
#define _PWR_ISTR_PERIS_SHIFT		  (0x0002)
#define _PWR_ISTR_PERIS_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ISTR_PERIS_SHIFT)
#define _PWR_ISTR_PERIS_MASK            (_PWR_ISTR_PERIS_MK(1))
#define _PWR_ISTR_PERIS_CLR             (~(_PWR_ISTR_PERIS_MK(1)))

#define _PWR_ISTR_PERIS_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ISTR_PERIS)


/*==========================================================================*\
* (R) _PWR_ISTR_CACHEIS
\*--------------------------------------------------------------------------*/
#define _PWR_ISTR_CACHEIS_SHIFT		  (0x0003)
#define _PWR_ISTR_CACHEIS_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ISTR_CACHEIS_SHIFT)
#define _PWR_ISTR_CACHEIS_MASK            (_PWR_ISTR_CACHEIS_MK(1))
#define _PWR_ISTR_CACHEIS_CLR             (~(_PWR_ISTR_CACHEIS_MK(1)))

#define _PWR_ISTR_CACHEIS_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ISTR_CACHEIS)


/*==========================================================================*\
* (R) _PWR_ISTR_DMAIS
\*--------------------------------------------------------------------------*/
#define _PWR_ISTR_DMAIS_SHIFT		  (0x0004)
#define _PWR_ISTR_DMAIS_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ISTR_DMAIS_SHIFT)
#define _PWR_ISTR_DMAIS_MASK            (_PWR_ISTR_DMAIS_MK(1))
#define _PWR_ISTR_DMAIS_CLR             (~(_PWR_ISTR_DMAIS_MK(1)))

#define _PWR_ISTR_DMAIS_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ISTR_DMAIS)


/*==========================================================================*\
* (RW) _PWR_ISTR_CPUIS
\*--------------------------------------------------------------------------*/
#define _PWR_ISTR_CPUIS_SHIFT		  (0x0005)
#define _PWR_ISTR_CPUIS_MK(n)           (((Uint16)(n) & 0x0001u) << _PWR_ISTR_CPUIS_SHIFT)
#define _PWR_ISTR_CPUIS_MASK            (_PWR_ISTR_CPUIS_MK(1))
#define _PWR_ISTR_CPUIS_CLR             (~(_PWR_ISTR_CPUIS_MK(1)))

#define _PWR_ISTR_CPUIS_GET(RegAddr) \
	HPFIELD_GET(RegAddr,_PWR_ISTR_CPUIS)


/*----------------------------------------------------------------------------*/

#endif /* PWR_SUPPORT */
#endif /* _PWRHAL_H_ */
/******************************************************************************\
* End of pwrhal.h
\******************************************************************************/

