/****************************************************************************/
/*     File:   evm55xdll.h                                                  */
/*                                                                          */
/*     Purpose: This is the public header file for the C55x EVM DLL         */
/*                                                                          */
/*     Copyright (c) 1998, DNA Enterprises, Inc.                            */
/****************************************************************************/
#ifndef _PCI2040_DLL_H_
#define _PCI2040_DLL_H_

/****************************************************************************/
/* defines                                                                  */
/****************************************************************************/
#define NO_FIFO_TIMEOUT			0

#define PCI_INVALID_REV_ID      0xFFFFFFFFul

#define	C5510_HPI_BOOT_ADDR		0x8000ul   //Word address. Reset entry.
#define	C5510_ROM_BOOT_ADDR		0x200000ul //Word address. Start of CE1 space

#define MAX_PCI2040_DSPS		4
#define HPI_REG_OFFSET			0x800u
#define HPI_SPACE_SIZE			(HPI_REG_OFFSET * 4)

//Memory map for 5510 EVM (word addresses)
#define INTMEM_START_ADDR		0x00000	
#define INTMEM_END_ADDR			0x27FFF
#define EXTMEM_START_ADDR		0x28000

#define DARAM_SIZE  			0x8000
#define DARAM_START_ADDR		INTMEM_START_ADDR
#define DARAM_END_ADDR			((INTMEM_START_ADDR+DARAM_SIZE) - 1)

#define SARAM_SIZE      		0x20000
#define SARAM_START_ADDR		0x8000
#define SARAM_END_ADDR			((SARAM_START_ADDR+SARAM_SIZE) - 1)

#define SBSRAM_SIZE			    0x80000
#define SBSRAM_START_ADDR		0x28000
#define SBSRAM_END_ADDR			((SBSRAM_START_ADDR+SBSRAM_SIZE) - 1)

#define FLASH_SIZE			    0x80000
#define FLASH_START_ADDR		0x200000
#define FLASH_END_ADDR			((FLASH_START_ADDR+FLASH_SIZE) - 1)

#define DB_SIZE					0x200000
#define DB_START_ADDR			0x400000
#define DB_END_ADDR				((DB_START_ADDR+DB_SIZE) - 1)

#define CPLD_SIZE				4
#define CPLD_START_ADDR			0x600000	      //8bytes, CE3 	
#define CPLD_END_ADDR			((CPLD_START_ADDR+CPLD_SIZE) - 1)

#define PDROM_START_ADDR		0x7FC000	      //32KB, CE3

#define CE0_START_ADDR			0x028000	
#define CE1_START_ADDR			0x200000	
#define CE2_START_ADDR			0x400000	
#define CE3_START_ADDR			0x600000	

#define EXTMEM_HPI_START_ADDR   0x28000
#define EXTMEM_HPI_END_ADDR     0xFFFFF
#define EXTMEM_HPI_SIZE			((EXTMEM_HPI_END_ADDR-EXTMEM_HPI_START_ADDR) + 1)

#define HPI_END_ADDR			0xFFFFF           

/***********************************************************************/
/*     DEFINE TBC REGISTERS INDICES                                    */
/***********************************************************************/
#define TBC_REG_CNTL0       (0x00>>2)
#define TBC_REG_CNTL1       (0x04>>2)
#define TBC_REG_CNTL2       (0x08>>2)
#define TBC_REG_CNTL3       (0x0C>>2)
#define TBC_REG_CNTL4       (0x10>>2)
#define TBC_REG_CNTL5       (0x14>>2)
#define TBC_REG_CNTL6       (0x18>>2)
#define TBC_REG_CNTL7       (0x1C>>2)
#define TBC_REG_CNTL8       (0x20>>2)
#define TBC_REG_CNTL9       (0x24>>2)
#define TBC_REG_MINOR_CMD   (0x28>>2)
#define TBC_REG_MAJOR_CMD   (0x2C>>2)
#define TBC_REG_CNT1_LOW    (0x30>>2)
#define TBC_REG_CNT1_HIGH   (0x34>>2)
#define TBC_REG_CNT2_LOW    (0x38>>2)
#define TBC_REG_CNT2_HIGH   (0x3C>>2)
#define TBC_REG_STATUS0     (0x40>>2)
#define TBC_REG_STATUS1     (0x44>>2)
#define TBC_REG_STATUS2     (0x48>>2)
#define TBC_REG_STATUS3     (0x4C>>2)
#define TBC_REG_CAPT_LOW    (0x50>>2)
#define TBC_REG_CAPT_HIGH   (0x54>>2)
#define TBC_REG_SERIAL_RD   (0x58>>2)
#define TBC_REG_SERIAL_WR   (0x5C>>2)

/***********************************************************************/
/*     DEFINE CPLD REGISTERS INDICES                                   */
/***********************************************************************/
#define CPLD_CTRL_OFFSET    0x00
#define CPLD_STAT1_OFFSET   0x04
#define CPLD_STAT2_OFFSET   0x08
#define CPLD_REV_OFFSET     0x0c
#define CPLD_SEM0_OFFSET    0x10
#define CPLD_SEM1_OFFSET    0x14


/***********************************************************************/
/*     DEFINE CPLD REGISTERS BIT MASKS                                 */
/***********************************************************************/
#define CPLD_BOARD_RESET    0x10
#define CPLD_BOARD_UNRESET  0xEF
#define CPLD_DSP_RESET      0x8
#define CPLD_DSP_UNRESET    0xF7
#define CPLD_TBC_RESET      0x4
#define CPLD_TBC_UNRESET    0xFB
#define CPLD_NMI_ENABLE     0x2
#define CPLD_NMI_DISABLE    0xFD
#define CPLD_INT_ENABLE     0x1
#define CPLD_INT_DISABLE    0xFE

/***********************************************************************/
/*     DEFINE HPI REGISTERS INDICES                                    */
/***********************************************************************/
/* fixup True/False defines */
#undef FALSE
#undef TRUE 
#define FALSE   ((BOOLEAN)0)
#define TRUE    ((BOOLEAN)1)

#define PCI2040_GLOBAL_EVENT_BASE_NAME "Pci2040MsgEventDev"

#ifndef INTDSP0
#define INTDSP0  (1<<0)     // Bit set if an interrupt has been generated by a device connected
#endif                     // to the HPI[0] interface. Software can set this bit for diagnostics.

#ifndef INTDSP1
#define INTDSP1  (1<<1)     // Bit set if an interrupt has been generated by a device connected
#endif                      // to the HPI[1] interface. Software can set this bit for diagnostics.

#ifndef INTDSP2
#define INTDSP2  (1<<2)     // Bit set if an interrupt has been generated by a device connected
#endif                      // to the HPI[2] interface. Software can set this bit for diagnostics.

#ifndef INTDSP3
#define INTDSP3  (1<<3)     // Bit set if an interrupt has been generated by a device connected
#endif                      // to the HPI[3] interface. Software can set this bit for diagnostics.

#ifndef GPINT
#define GPINT    (1<<26)    // Bit set if an interrupt has been generated by a device connected
#endif                      // to the GPINT# interface. Software can set this bit for diagnostics.

#ifndef INTGPIO2
#define INTGPIO2 (1<<27)    // Set when GPIO2Pin selects GPIO2 as an interrupt event input, and the
#endif                      // event type selected by the GPIO Interrupt Event Type Register occurs.

#ifndef INTGPIO3
#define INTGPIO3 (1<<28)    // Set when GPIO3Pin selects GPIO3 as an interrupt event input, and the
#endif                      // event type selected by the GPIO Interrupt Event Type Register occurs.

#ifndef GPERROR
#define GPERROR  (1<<29)    // Bit set upon serious error conditions on the GP interface, and
#endif                      // allows software to gracefully terminate communication with a GP device.
                            
#ifndef HPIERROR
#define HPIERROR (1<<30)    // Bit set upon serious error conditions on the HPI interface, and allows
#endif                      // software to gracefully terminate communication with an HPI device.
                            // This bit is the OR combination of the HPI errors in the HPI Error Report
                            // Register.

/****************************************************************************/
/* Structure used to get HPI mapped addresses                               */
/****************************************************************************/
typedef struct _Reg {
    ULONG Regoff;     // Register to read/write
    ULONG DataVal;    // Data to read/write
} Register, *PRegister;

// Structure used to access the PCI configuration
typedef struct _PCI2040_CONFIG_DATA {
    USHORT  VendorID;       // Vendor ID
    USHORT  DeviceID;       // Device ID
    USHORT  Command;        // Command
    USHORT  Status;         // Status
    UCHAR   RevisionID;     // Revision ID
    UCHAR   ProgIf;         // Prog
    UCHAR   SubClass;       // Sub-class
    UCHAR   BaseClass;      // Base-class
    UCHAR   CacheLineSize;  // Cache Line Size
    UCHAR   LatencyTimer;   // Latency Timer
    UCHAR   HeaderType;     // Header Type
    UCHAR   BIST;           // BIST
    ULONG   HPICSRBar;      // HPI CSR Memory Base Addrress
    ULONG   CSpaceBar;      // Control Space Base Address
    ULONG   GPBBar;         // GPBus Base Address
    ULONG   Reserve0[4];    // Reserved
    USHORT  SubVendorID;    // Subsystem Vendor ID
    USHORT  SubSysID;       // Subsystem ID
    ULONG   Reserve1;       // Reserved
    UCHAR   CapPointer;     // Capability Pointer
    UCHAR   Reserve2[3];    // Reserved
    ULONG   Reserve3;       // Reserved
    UCHAR   IRQLine;        // Interrupt Line
    UCHAR   IRQPin;         // Interrupt Pin
    UCHAR   MinGnt;         // Min Grant
    UCHAR   MaxLat;         // Max latency
    USHORT  Reserve4[2];    // Reserved
    UCHAR   GPBSelect;      // GPIO Select
    UCHAR   GPBInData;      // GPIO Input Data
    UCHAR   GPBDataDir;     // GPIO Direction Control
    UCHAR   GPBOutData;     // GPIO Output Data
    UCHAR   GPBIntType;     // GPIO Interrupt Type
    UCHAR   Reserve5[3];    // Reserved
    USHORT  MiscControl;    // Misc Control
    UCHAR   Reserve14;      // Reserved
    UCHAR   Diag;           // Diagnostic
    UCHAR   PMCapID;        // PM Capability ID
    UCHAR   PMNext;         // PM Next-Item Pointer
    USHORT  PMCap;          // Power Management Capabilities
    USHORT  PMCntlStat;     // PM Control / Status
    USHORT  Reserve6;       // Reserved
    ULONG   HPICSRIOBar;    // HPI CSR I/O Base Address
    UCHAR   HSCapID;        // HS Capability ID
    UCHAR   HSNext;         // HS Next-Item Pointer
    UCHAR   HSCSR;          // HS_CSR
    UCHAR   Reserve7[5];    // Reserved
} PCI2040_CONFIG_DATA, *PPCI2040_CONFIG_DATA;

typedef struct _PCI2040_INIT_DATA {
    PCI2040_CONFIG_DATA pci_regs;
} PCI2040DLL_INIT_DATA, *PPCI2040DLL_INIT_DATA;


/****************************************************************************/
/* Enums                                                                    */
/****************************************************************************/
//DSP board type definition
typedef enum {
    TYPE_UNKNOWN = 0,
    TYPE_PCI2040_C5510_EVM
} EVM55X_BOARD_TYPE, *PEVM55X_BOARD_TYPE;

typedef enum {
    ERASE_ALL = -1,
} EVM55X_FLASH_CONTROL, *PEVM55X_FLASH_CONTROL;

//DSP-to-HOST events
typedef enum {
    DSP0_INT = 0,
    DSP1_INT,
    DSP2_INT,
    DSP3_INT,
    GP_INT,
    GPIO2_INT,
    GPIO3_INT,
    HPIERROR_INT,
    HPIERROR0_INT,
    HPIERROR1_INT,
    HPIERROR2_INT,
    HPIERROR3_INT
} PCI2040_HOST_EVENT, *PPCI2040_HOST_EVENT;

//HOST-to-DSP events
typedef enum {
    NMI_INT = 0,   // NMI
    DSP_INT,       // HPIC DSPINT
    DSP_INT5       // EXT INT 5
} PCI2040_DSP_EVENT, *PPCI2040_DSP_EVENT;

typedef enum {
    PCI2040_SEM0,
    PCI2040_SEM1
} PCI2040_SEM, PPCI2040_SEM;

typedef enum {
   CSR_BAR = 0,
   HPI_BAR,
   TBC_BAR,
   CPLD_BAR
} PCI2040_BAR, *PPCI2040_BAR;

typedef enum {
   C55X_HPIC			= 0x00,
   C55X_HPIA			= 0x02,
   C55X_HPID_AUTOINC	= 0x01,
   C55X_HPID_NOAUTOINC	= 0x03
} PCI2040_HPI_REG, *PPCI2040_HPI_REG;


/****************************************************************************/
/* typedefs                                                                 */
/****************************************************************************/
/* "printf" redirection function definition */
typedef void (PCI2040_PRINTF_FUNC)(char *);
typedef PCI2040_PRINTF_FUNC  *PPCI2040_PRINTF_FUNC;

typedef void (PCI2040_INPUT_FUNC)(char *);
typedef PCI2040_INPUT_FUNC  *PPCI2040_INPUT_FUNC;

typedef void (*FileIOFunc)(LPVOID hDevice, ULONG dspNum);

#undef DLL32_ENTRY
#ifdef evm55xdll_c
    // export function, for building DLL
#define DLL32_ENTRY  __declspec(dllexport)
#else
    // import function, for using DLL
#define DLL32_ENTRY  __declspec(dllimport)
#endif

#ifdef __cplusplus

extern "C" {

#endif
    
/****************************************************************************/
/* all DLL function definitions                                             */
/****************************************************************************/

/*****************************************************************************
*  evm55x_open()
*
*	 Description: 
*		Opens the board devices. Some functions included in the API requires an 
*		exclusive open so be sure to pass in a 1 for the exclusive flag.
*
*  Parameters:
*		board_index - corresponds to the board number for which the handle is 
*                 requested.
*		exclusive_flag - indicates exclusive ownership of the board.
*
*  Return:
*		A handle to the board.
*
*******************************************************************************/
DLL32_ENTRY HANDLE evm55x_open(int board_index, BOOL exclusive_flag);

/*****************************************************************************
*  evm55x_init()
*
*	 Description: 
*		Initializes the board, specifically the montana device.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*                 requested.
*		pInitData - pointer to a PPCI2040DLL_INIT_DATA objects which has the 
*		configuration information. This can be a NULL, in which case the default 
*		configuration is used.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_pci_init(HANDLE hDevice, PPCI2040DLL_INIT_DATA pInitData);

/*****************************************************************************
*  evm55x_close()
*
*	 Description: 
*		Closes the handle to the board. No communication with the board is possible 
*		after a call to this routine.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_close(HANDLE hDevice);

/*****************************************************************************
*  evm55x_reset_board()
*
*	 Description: 
*		Resets the board to a known state.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_reset_board(HANDLE hDevice);

/*****************************************************************************
*  evm55x_reset_dsp()
*
*	 Description: 
*		Holds the DSP device in reset.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		dspNum - specifies the DSP devioe. Up to 4 DSPs may be supported on the board.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_reset_dsp(HANDLE hDevice, ULONG dspNum);

/*****************************************************************************
*  evm55x_unreset_dsp()
*
*	 Description: 
*		Removes the DSP device from reset. The DSP will begin executing code if a 
*		COFF file is loaded.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		dspNum - specifies the DSP devioe. Up to 4 DSPs may be supported on the board.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_unreset_dsp(HANDLE hDevice, ULONG dspNum);

/****************************************************************************
evm55x_run_dsp()                                                      

  The evm55x_run_dsp function releases the DSP core from the halted state
  invoked by the DSP being reset when the EHPIENA input is high.  
  This function should only be used after a evm55x_unreset_dsp call is made.

  The return value indicates the success of the function call.
  The hDevice parameter is the handle returned from a successful
  exclusive evm55x_open call.
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_run_dsp(HANDLE hDevice, ULONG dspNum);


/*****************************************************************************
*  evm55x_board_info()
*
*	 Description: 
*		Retrieves the board type and revision id.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		pBoardType - The board type.
*		pRevId - The revision identifier
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_board_info(HANDLE hDevice,
                                      PEVM55X_BOARD_TYPE pBoardType, 
                                      PULONG pRevId);

/*****************************************************************************
*  evm55x_get_configuration()
*
*	 Description: 
*		Retrieves the PCI configuration information.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		pPciConfig - A pointer to a PPCI2040_CONFIG_DATA object which contains
*		the PCI information.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_get_pci_configuration(HANDLE hDevice,
												 PPCI2040_CONFIG_DATA pReg);

/****************************************************************************
evm55x_store_pci_configuration()                                                       

  The evm55x_store_pci_configuration function writes the PCI configuration 
  information from the Montana device.
  
    The function returns a FALSE upon failure and TRUE on success
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_store_pci_configuration(HANDLE hDevice,
												   PPCI2040_CONFIG_DATA pReg);

/*****************************************************************************
*  evm55x_coff_load()
*
*	 Description: 
*		Loads a COFF file onto the board.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		lp_hpi - A pointer to the HPI map object returned from the call to 
*   evm55x_hpi_open().
*		filename - The name of the COFF file.
*		verboseFlag - Display basic COFF file information via the standard output stream.
*   clear_bss_flag - Initialize all bss section variable to zero.
*   dump - Display all data via the standard output stream.
*   dspNum - Specifies the DSP to load the COFF file into.
*
*  Return:
*		TRUE - success.
*       FALSE - failure
*
*  Note: Ensure that flash access is disable when loading to on-chip RAM or 
*        external SRAM. You do this by invoking evm55x_flash_access(TRUE).
*
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_coff_load(HANDLE hDevice, 
                                   LPVOID lp_hpi,
                                   char *filename, 
                                   BOOL verboseFlag,
                                   BOOL clear_bss_flag, 
                                   BOOL dump_flag,
                                   ULONG dspNum);

/*****************************************************************************
*  evm55x_coff_display()
*
*	 Description: 
*		Displays only the COFF information for a file
*
*  Parameters:
*		filename - The name of the COFF file.
*   clear_bss_flag - Initialize all bss section variable to zero.
*   dump - Display all data via the standard output stream.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_coff_display(char *filename,
                                      BOOL clear_bss_flag, 
                                      BOOL dump_flag);

/*****************************************************************************
*  evm55x_hpi_open()
*
*	 Description: 
*		Opens the host port interface (HPI) to the DSPs and guarantees mutual 
*		exclusion to the DSPs HPI as well as memory.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY LPVOID evm55x_hpi_open(HANDLE hDevice);

/*****************************************************************************
*  evm55x_hpi_close()
*
*	 Description: 
*		Closes the host port interface (HPI) to the DSPs.
*
*  Parameters:
* h_hpi_map - Hpi_map handle returned from the call to
* *				evm55x_hpi_open.
*
*  Return:
*		TRUE - success.
*		FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_hpi_close(LPVOID h_hpi_map);

/*****************************************************************************
*  evm55x_hpi_read()
*
*	 Description: 
*		Reads data from the DSP memory.
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*		p_buffer - Pointer to the buffer to read data into.
*		p_length - Number of 16 -bit words to read.
*		src_addr - DSP memory address to read from.
*   dspNum - Specifies the DSP.
*
*  Return:
*		TRUE - success.
*		FALSE - failure
*
*  Note: 
*
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_hpi_read(LPVOID h_hpi_map, 
                                  PULONG p_buffer,
                                  PULONG p_length, 
                                  ULONG src_addr,
                                  ULONG dspNum);

/*****************************************************************************
*  evm55x_hpi_read_single()
*
*	 Description: 
*		Reads a single 16-bit value from the DSP memory.
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*		p_data - Pointer to the buffer to read data into.
*		src_addr - DSP memory address to read from.
*		dspNum - Specifies the DSP.
*
*  Return:
*		TRUE - success.
*       FALSE - failure
*
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_hpi_read_single(LPVOID h_hpi_map, 
                                  PULONG p_data,
                                  ULONG src_addr,
                                  ULONG dspNum);

/*****************************************************************************
*  evm55x_hpi_write()
*
*	 Description: 
*		Writes data to the DSP memory.
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*		p_buffer - Pointer to the buffer to read data into.
*		p_length - Number of 16 -bit words to write.
*		src_addr - DSP memory address to read from.
*		dspNum - Specifies the DSP
*
*  Return:
*		TRUE - success.
*       FALSE - failure
*
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_hpi_write(LPVOID h_hpi_map, 
                                   PULONG p_buffer,
                                   PULONG p_length, 
                                   ULONG dest_addr,
                                   ULONG dspNum);

/*****************************************************************************
*  evm55x_hpi_write_single()
*
*	 Description: 
*		Writes a single 16-bit value to the DSP memory.
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*		p_data - Pointer to the buffer to read data into.
*		dest_addr - DSP memory address to write to.
*		dspNum - Specifies the DSP.
*
*  Return:
*		TRUE - success.
*       FALSE - failure
*
*  Note: 
*
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_hpi_write_single(LPVOID h_hpi_map, 
                                           PULONG p_data,
                                           ULONG dest_addr,
                                           ULONG dspNum);
                                
/*****************************************************************************
*  evm55x_hpi_fill()
*
*	 Description: 
*		Fills DSP memory with a single value.
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*		fill_value - 16-bit value to fill DSP memory with.
*		p_length - Number of 16 -bit words to write.
*		src_addr - DSP memory address to read from.
*       dspNum - Specifies the DSP.
*
*  Return:
*		TRUE - success.
*       FALSE - failure
*
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_hpi_fill(LPVOID h_hpi_map, 
                                  USHORT fill_value,
                                  PULONG p_length, 
                                  ULONG dest_addr,
                                  ULONG dspNum);

/*****************************************************************************
*  evm55x_fifo_read()
*
*	 Description: 
*		Reads data from the fifo stream.
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*		p_buffer - Pointer to the buffer to read data into.
*		p_length - Number of 16-bit words to read.
*   dspNum - Specifies the DSP.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_fifo_read(LPVOID h_hpi_map, 
                                  PULONG p_buffer,
                                  PULONG p_length, 
                                  ULONG dspNum);

/*****************************************************************************
*  evm55x_fifo_write()
*
*	 Description: 
*		Writes data to the fifo stream.
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*		p_buffer - Pointer to the buffer to write data from.
*		p_length - Number of 16-bit words to write.
*           dspNum - Specifies the DSP.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_fifo_write(LPVOID h_hpi_map, 
                                    PULONG p_buffer,
                                    PULONG p_length, 
                                    ULONG dspNum);

/*****************************************************************************
*  evm55x_generate_int()
*
*	 Description: 
*		Interrupts the DSP device using either the CPLD or HPI depending on the 
*     desired interrupt..
*
*  Parameters:
*		h_hpi_map - A void pointer corresponding to the HPI map object.
*     dspNum - Specifies the DSP.
*     intr - The type of interrupt to generate to the DSP
* 
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_generate_int(LPVOID h_hpi_map, PCI2040_DSP_EVENT intr, ULONG dspNum);

/*****************************************************************************
*  evm55x_enable_int()
*
*	 Description: 
*		Enables the specified interrupt to the host from the board.
*
*  Parameters:
*		intMask - Mask for the interrupt.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_enable_int(LPVOID h_hpi_map, ULONG intMask);

/*****************************************************************************
*  evm55x_disable_int()
*
*	 Description: 
*		disables the specified interrupt to the host from the board.
*
*  Parameters:
*		intMask - Mask for the interrupt.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_disable_int(LPVOID h_hpi_map, ULONG intMask);

/*****************************************************************************
*  evm55x_printf_control()
*
*	 Description: 
*		Sets the function to be used for printf.
*
*  Parameters:
*		enable - Enables printf (1 - enable , 0 - disbale).
*		func - printf function
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_printf_control(BOOL enable,
                                        PPCI2040_PRINTF_FUNC func);

/*****************************************************************************
*  evm55x_input_control()
*
*	 Description: 
*		Sets the function to be used for input.
*
*  Parameters:
*		func - input function
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_input_control(PPCI2040_INPUT_FUNC func);

/*****************************************************************************
*  evm55x_dll_revision()
*
*	 Description: 
*		Sets the dll revision
*
*  Parameters:
*		pRevMajor - The revison major number.
*		pRevMinor - The revison minor number.
*		pBuildNum - The buil number.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_dll_revision(PULONG pRevMajor,
                                      PULONG pRevMinor,
                                      PULONG pBuildNum);

/*****************************************************************************
*  evm55x_read_reg()
*
*	 Description: 
*		Modifies a Montana device (The PCI controller) register.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		preg - Pointer to the PCI20404_REG  object containing the new register value.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_read_pci_reg(HANDLE hDevice, PRegister  pReg);

/*****************************************************************************
*  evm55x_write_reg()
*
*	 Description: 
*		Reads a Montana device (The PCI controller) register.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		preg - Pointer to the PCI20404_REG object to hold the read register value.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_write_pci_reg(HANDLE hDevice, PRegister  pReg);

/*****************************************************************************
*  evm55x_dsp_present()
*
*	 Description: 
*		Determines if the specified DSP is present.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		dspNum - Specifies the DSP.
*
*  Return:
*		TRUE - success.
*   FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_dsp_present(HANDLE hDevice, ULONG dspNum);

/*****************************************************************************
*  evm55x_cpld_read_all()
*
*	 Description: 
*		Gets a dump of the CPLD registers.
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		regs - Pointer to array of shorts to hold register values.
*  Return:
*		TRUE - success.
*     FALSE - failure
*******************************************************************************/
DLL32_ENTRY BOOL evm55x_cpld_read_all(HANDLE hDevice, PUSHORT regs);


/*****************************************************************************
*  evm55x_get_event_handle()
*
*	 Description: 
*		Returns the handle to the requested event
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		eventNUM - Event that monitoring is to be terminated.
*  Return:
*		event HANDLE - success.
*     NULL - failure
*******************************************************************************/
DLL32_ENTRY HANDLE evm55x_get_event_handle(HANDLE hDevice, 
                                              PCI2040_HOST_EVENT eventNum);

/****************************************************************************
*evm55x_read_cpld_reg()
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		pReg - pointer to a PCI2040_REG that holds the read value.
*  The evm55x_read_cpld_reg function reads a value from the CPLD register
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_read_cpld_reg(HANDLE hDevice, PRegister  pReg);

/****************************************************************************
*evm55x_write_cpld_reg()
*
*  The evm55x_write_cpld_reg function writes a value to the CPLD register
*  
*		hDevice - Board handle returned from the call to evm55x_open.
*		pReg - pointer to a PCI2040_REG that holds the value to write
*
*    Returns TRUE on succes
*    FALSE on failure.
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_write_cpld_reg(HANDLE hDevice, PRegister  pReg);

/****************************************************************************/
/*                                                                          */
/* evm55x_user_semaphore_get() - This function tries to acquire the        */
/*    specified user semaphore.                                             */
/*   sem will be filled with the semaphore state                           */
/*    Returns TRUE if acquired                                              */
/*            FALSE if semaphore is not acquired                            */
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_user_semaphore_get(HANDLE hDevice, PCI2040_SEM sem);

/****************************************************************************/
/*                                                                          */
/* evm55x_user_semaphore_release() - This function releases the previously */
/*    acquired semaphore specified by sem.                                  */
/*                                                                          */
/*   returns FALSE if the semaphore has already been released.             */
/*            TRUE if operation is successful                               */
/*                                                                          */
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_user_semaphore_release(HANDLE hDevice, PCI2040_SEM sem);

/****************************************************************************/
/*                                                                          */
/* evm55x_user_semaphore_wait() - This function waits indefinitely to      */
/*    acquire the semaphore specified by sem.                               */
/*                                                                          */
/*   returns FALSE if opreation fails                                      */
/*            TRUE if successful                                            */
/*                                                                          */
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_user_semaphore_wait(HANDLE hDevice, PCI2040_SEM sem);

/****************************************************************************/
/*                                                                          */
/* evm55x_get_base_address() - This function returns the specified base    */
/*    address                               .                               */
/*                                                                          */
/*   returns FALSE if opreation fails                                      */
/*            TRUE if successful                                            */
/*                                                                          */
/****************************************************************************/
DLL32_ENTRY PULONG evm55x_get_base_address(HANDLE hDevice, PCI2040_BAR bar_num);

/****************************************************************************/
/*                                                                          */
/* evm55x_set_timeout() - The evm55x_set_timeout function sets the          */
/* timeout for the FIFO. FIFO access calls return with an error whenever    */
/* they block for a multiple of the specified timeout value.                */
/*                                                                          */
/*   returns FALSE if opreation fails                                      */
/*            TRUE if successful                                            */
/*                                                                          */
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_set_timeout(HANDLE hDevice, ULONG timeout);

/****************************************************************************/
/*                                                                          */
/* evm55x_tbc_reset() - The evm55x_tbc_reset function pulses the TBC  */
/*                       reset to reset the Test Bus Controller.            */
/*                                                                          */
/*   returns FALSE if opreation fails                                      */
/*            TRUE if successful                                            */
/*                                                                          */
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_tbc_reset(HANDLE hDevice);

/****************************************************************************
evm55x_tbc_unreset()

  The evm55x_tbc_unreset function removes the TBC from the reset state
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_tbc_unreset(HANDLE hDevice);

/****************************************************************************
evm55x_read_tbc_reg()

  The evm55x_read_reg function reads a value from the TBC device 
  register specified by the pointer pReg
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_read_tbc_reg(HANDLE hDevice, PRegister  pReg);

/****************************************************************************
evm55x_write_tbc_reg()

  The evm55x_write_tbc_reg function writes a value to the TBC device 
  register specified by the pointer pReg
  
    Returns TRUE on succes
    FALSE on failure.
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_write_tbc_reg(HANDLE hDevice, PRegister  pReg);

/****************************************************************************
evm55x_read_hpi_reg()

  The evm55x_read_hpi_reg function writes a value to the HPI register
  specified by the reg.
  
    Returns TRUE on succes
    FALSE on failure.
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_read_hpi_reg(LPVOID pBd_, PRegister pReg, ULONG dspNum);

/****************************************************************************
evm55x_write_hpi_reg()

  The evm55x_write_hpi_reg function writes a value to the HPI register
  specified by the reg.
  
    Returns TRUE on succes
    FALSE on failure.
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_write_hpi_reg(LPVOID pBd_, PRegister pReg, ULONG dspNum);

/****************************************************************************
*evm55x_read_cpld_reg()
*
*  Parameters:
*		hDevice - Board handle returned from the call to evm55x_open.
*		pReg - pointer to a PCI2040_REG that holds the read value.
*  The evm55x_read_cpld_reg function reads a value from the CPLD register
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_read_cpld_reg(HANDLE hDevice, PRegister  pReg);

/****************************************************************************
*evm55x_write_cpld_reg()
*
*  The evm55x_write_cpld_reg function writes a value to the CPLD register
*  
*		hDevice - Board handle returned from the call to evm55x_open.
*		pReg - pointer to a PCI2040_REG that holds the value to write
*
*    Returns TRUE on succes
*    FALSE on failure.
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_write_cpld_reg(HANDLE hDevice, PRegister  pReg);

/****************************************************************************
*evm55x_erase_flash(HANDLE hDevice, int area)
*
*  The evm55x_erase_flash erases a portion of Flash memory
*  will be to flash memory.
*  
*		hDevice - Board handle returned from the call to evm55x_open.
*		sector - specifies block of flash to erase (0-10 or -1 for entire chip
*
*    Returns TRUE on succes
*    FALSE on failure.
/****************************************************************************/
DLL32_ENTRY BOOL evm55x_erase_flash(HANDLE hDevice, int area);

/****************************************************************************
evm55x_program_flash()

/****************************************************************************/
DLL32_ENTRY BOOL evm55x_program_flash(HANDLE hDevice, char *hexFile, ULONG dspNum);

/****************************************************************************
evm55x_reset_flash()

/****************************************************************************/
DLL32_ENTRY BOOL evm55x_reset_flash(HANDLE hDevice);

#ifdef __cplusplus
}
#endif

#endif // _PCI2040_DLL_H_
