#!/bin/sh
#
## NAME
##      UmountAll.sh - Remove mount points for all drives
##
## SYNOPSIS
##      UmountAll.sh [-n] [-k] [Savelist]
##
## PURPOSE
##      Clean up the mount table created by SNiFF+.
##      With switch -n (no-execute), just print what UmountAll would do.
##      With switch -k (keep), actually execute the Umount but
##      keep mount points listed in the following [Savelist] intact.
##
## EXAMPLE
##      UmountAll.sh -k /bin
##
## AUTHOR
##      Martin Oberhuber, (c) 1999 TakeFive Software GmbH
##
## SEE ALSO
##      MountAll.sh
##

if [ "$SNIFF_DIR" = "" ]; then
    echo "UmountAll.sh: Error: you must set \$SNIFF_DIR before executing!"
    exit 1
fi 

if [ $# = 0 -o x$1 = x-h ]; then
    $SNIFF_DIR/bin/grep "^##" $0 | $SNIFF_DIR/bin/cut -c4-
    exit 0
fi

case $1 in
  -k) DOIT=1 ; shift ;;
  -n) PRINTIT=1 ; shift ;;
  *) echo "UmountAll.sh: Unknown switch $1, type Umountall.sh -h for help"
     exit 1
     ;;
esac

# Mount points from this list won't be processed
SAVELIST=$*

ROOTDIR=`$SNIFF_DIR/bin/mount | $SNIFF_DIR/bin/grep "/ " | $SNIFF_DIR/bin/cut -d" " -f1 | $SNIFF_DIR/bin/sed -e 's/\\\\/\//g'`
if [ ! -d $ROOTDIR ]; then
	echo "Error invalid Rootdir found: $ROOTDIR -- exiting..."
	exit 1
fi

echo "UmountAll.sh: Unmounting Windows drives from $ROOTDIR"
echo "UmountAll.sh: Use MountAll.sh to re-create your mounts."

for i in C D E F G H I J K L M N O P Q R S T U V W X Y Z bin / # tmp
do
    # The rootdir is special because the / is here
    test x$i = x/ && i=""
 
    # Find out whether this mount point should be saved 
    SAVEIT=0
    for j in $SAVELIST
    do
        test x$j = x/$i && SAVEIT=1
    done
    test "$SAVEIT" = "1"  && continue

    # Only do something if the mount point is REALLY currently mounted
    LINE=`$SNIFF_DIR/bin/mount | $SNIFF_DIR/bin/grep " /$i "`
    test "$LINE" = "" && continue

    # Print the message - we rmdir only if it's not the ROOTDIR
    if [ "$i" != "" ]; then
        echo "umount /$i ; rmdir $ROOTDIR/$i"
    else
        echo "umount /"
    fi

    # Unmount it
    test "$DOIT" = "1" && $SNIFF_DIR/bin/umount /$i 2> /dev/null
    # Remove the directory only if it's not the ROOTDIR. 
    test "$DOIT" = "1" -a "$i" != "" && $SNIFF_DIR/bin/rmdir $ROOTDIR/$i
done

test "$PRINTIT"="1" && exit 0

echo ""
echo "UmountAll done. Warning: due to the Umount, your path may no longer work"
echo "correctly. If you have problems accessing your commands, please start"
echo "a new bash process to have a correct path again."
