#!/bin/sh
#
# postinstall file for SNiFF+ TornadoII integration
#
# This file is sourced from the generic install.sh
# What we have at this point:
# *) System specifics:
#    - $SYSTEM is set to "Windows" or "UNIX"
#    - $CYGPATH is set to the cygpath.exe executable if System is "Windows"
#    - $DIFF is set to a diff program that works with cygwin paths
#    - $READ_REGISTRY_VALUE points to the ReadRegistryValue.exe program on Win
#    - $PREFERRED_SHELL is set to the shell program we should use
# *) General Switches
#    - $DEBUG is set to "echo" if debug mode is on (or empty otherwise)
#    - $CONFIG_ONLY is set to 1 if no copying should be made
#    - $UNINSTALL is set to 1 if we should make an uninstall (1 otherwise)
# *) Directories:
#    - $StartFromDir is from where the install.sh was started
#    - $mydir is where this install.sh is located
#    - $installdir is at the installation source
#    - $target_dirs has a list of targets where to install to
#    - $logfile exists and is ready for logging
#    - $save tells us whether to backup or not
#    - $bakdir is the target where to backup files, it exists and is writable
# *) Common switches
#    - $integration_name is the adaptor name to install
#    - $is_external tells us whether we are installing from "outside" the SNiFF Tree
# *) Special cases handled
#    - $SNIFF_DIR is the installation target: correctly set, exists and is writable
#    - $WIND_BASE is correctly set and writable, if it is needed
#
# ACTIONS:
# *) install SiteMenus.TornadoII.sniff
# *) install FactoryPrefs.[UNIX|win].sniff
# *) install SitePrefs.[UNIX|win].sniff
# *) remove unnecessary SNiFF+ Project templates
# *) remove unnecessary SNiFF+ Platform files
# *) generate SNiFF+ Platform files for all installed Tornado Platforms
# *) create customized sniff.bat/.profile/.cshrc in $WIND_BASE and $SNIFF_DIR
# *) Create sniff.lnk on the User's Desktop / Program Group
# *) Modify workingenvs according to the real platforms installed
#
#
# TODO:
# *) restore old $WIND_BASE/host/resource/tcl/gdb.tcl in case of version clash
# *) ask for the user's default Platform; set it in WorkingEnvs / SitePrefs.sniff
# *) ask for the user's CM system; set it in *.ptmpl and SitePrefs.sniff
# *) Patch the 01SNiFF.win32.tcl for running SNiFF+ from Tornado via Batchfile
# *) (?) Set a Default Working Env (?)
# *) Nicer Logging to logfile
# *) Remove unnecessary entries from Workingenvs file

echo ""
echo "" >> "$logfile"
if [ "$UNINSTALL" = "1" ]; then
  echo "Uninstalling local configurations..."
  CREATING_REMOVING="Removing"
else
  echo "install.sh is now configuring your system..."
  CREATING_REMOVING="Creating"
fi

if [ "$UNINSTALL" != "1" ]; then
# install SiteMenus.TornadoII.sniff
cd "$SNIFF_DIR/config"
theFile=\$"SNIFF_DIR/config/SiteMenus.sniff"
if $DIFF SiteMenus.TornadoII.sniff SiteMenus.sniff >/dev/null 2>&1 ; then
  echo "(no need to copy, up-to-date) $theFile"
else
  if [ "$save" = "1" ]; then
    BAK="$bakdir/SNIFF_DIR/config"
    test -d "$BAK" || $DEBUG mkdir -p "$BAK"
    $DEBUG cp -f "$SNIFF_DIR/config/SiteMenus.sniff" "$BAK"
    msg="(backup) copying $theFile"
  else
    msg="copying $theFile"
  fi
  echo "$msg"
  echo "$msg" >> "$logfile"
  $DEBUG rm -f "$SNIFF_DIR/config/SiteMenus.sniff"
  $DEBUG cp -f "$SNIFF_DIR/config/SiteMenus.TornadoII.sniff" "$SNIFF_DIR/config/SiteMenus.sniff"
fi
 
# install FactoryPrefs.sniff
cd "$SNIFF_DIR/config/misc"
theFile=\$"SNIFF_DIR/config/misc/FactoryPrefs.sniff"
if $DIFF FactoryPrefs.sniff FactoryPrefs.$SYSTEM.sniff >/dev/null 2>&1 ; then
  echo "(no need to copy, up-to-date) $theFile"
else
  if [ "$save" = "1" ]; then
    BAK="$bakdir/SNIFF_DIR/config/misc"
    test -d "$BAK" || $DEBUG mkdir -p "$BAK"
    $DEBUG cp -f "$SNIFF_DIR/config/misc/FactoryPrefs.sniff" "$BAK"
    msg="(backup) copying $theFile"
  else
    msg="copying $theFile"
  fi
  echo "$msg"
  echo "$msg" >> "$logfile"
  $DEBUG rm -f "$SNIFF_DIR/config/misc/FactoryPrefs.sniff"
  $DEBUG cp "$SNIFF_DIR/config/misc/FactoryPrefs.$SYSTEM.sniff" "$SNIFF_DIR/config/misc/FactoryPrefs.sniff"
fi
 
# install SitePrefs.sniff
cd "$SNIFF_DIR/integrations/TornadoII/adm"
theFile=\$"SNIFF_DIR/SitePrefs.sniff"
if $DIFF SitePrefs.$SYSTEM.sniff ../../../SitePrefs.sniff >/dev/null 2>&1 ; then
  echo "(no need to copy, up-to-date) $theFile"
else
  if [ "$save" = "1" ]; then
    # BAK must exist at this point!
    $DEBUG cp -f "$SNIFF_DIR/SitePrefs.sniff" "$bakdir/SNIFF_DIR"
    msg="(backup) copying $theFile"
  else
    msg="copying $theFile"
  fi
  echo "$msg"
  echo "$msg" >> "$logfile"
  $DEBUG rm -f "$SNIFF_DIR/SitePrefs.sniff"
  $DEBUG cp -f "$SNIFF_DIR/integrations/TornadoII/adm/SitePrefs.$SYSTEM.sniff" "$SNIFF_DIR/SitePrefs.sniff"
fi
# remove unnecessary SNiFF+ Project templates: create filelist to be removed
if [ -d "$SNIFF_DIR/config/project" ]; then
  cd "$SNIFF_DIR/config/project"
  PLATFORM="i386-unknown-win32"  # will be overridden by UNIX
  FILELIST=""
  if [ "$SYSTEM" = "Windows" ]; then
    if [ ! -f "$SNIFF_DIR/bin/sniffada.exe" ]; then
      FILELIST="$FILELIST Ada-Project.ptmpl"
    fi
    if [ ! -f "$SNIFF_DIR/bin/sniff_fortran.exe" ]; then
      FILELIST="$FILELIST Fortran_Fixed-Project.ptmpl Fortran_Free-Project.ptmpl"
    fi
    if [ ! -f "$SNIFF_DIR/bin/sniffidl.exe" ]; then
      FILELIST="$FILELIST IDL_C++_Client-Project.ptmpl IDL_C++_Server-Project.ptmpl IDL_Java-Project.ptmpl"
    fi
  else
    PLATFORM=`$SNIFF_DIR/bin/sniff_arch`
    if [ ! -f "$SNIFF_DIR/bin/bin.$PLATFORM/sniffada" ]; then
      FILELIST="$FILELIST Ada-Project.ptmpl"
    fi
    if [ ! -f "$SNIFF_DIR/bin/bin.$PLATFORM/sniff_fortran" ]; then
      FILELIST="$FILELIST Fortran_Fixed-Project.ptmpl Fortran_Free-Project.ptmpl"
    fi
    if [ ! -f "$SNIFF_DIR/bin/bin.$PLATFORM/sniffidl" ]; then
      FILELIST="$FILELIST IDL_C++_Client-Project.ptmpl IDL_C++_Server-Project.ptmpl IDL_Java-Project.ptmpl"
    fi
  fi
  # keep the C, Java and MFC Project Templates
  # make sure that the files to be removed really exist
  newFileList=""
  for curFile in $FILELIST
  do
    if [ -f "$curFile" ]; then
      newFileList="$newFileList $curFile"
    fi
  done
  FILELIST="$newFileList"
else
  FILELIST=""
fi
# remove unnecessary project templates: remove them from filelist
if [ "$FILELIST" != "" ]; then
  echo ""
  echo "The following SNiFF+ Project Templates seem to be unnecessary on your System:"
  count=1
  for curFile in $FILELIST
  do
    echo "($count) $curFile"
    count=`expr "$count" + 1`
  done
  echo ""
  echo "It is recommended to remove these Project Templates for better usability."
  echo "Note: You can also later remove these Project Templates by deleting the"
  echo "corresponding files from your "\$"SNIFF_DIR/config/project directory."
  if [ "$save" = "1" ]; then
    BAK="$bakdir/SNIFF_DIR/config/project"
    BAK_W="$BAK"
    if [ "$SYSTEM" = "Windows" ]; then
      BAK_W=`"$CYGPATH" -w "$BAK" | sed 's,[\],/,g' `
    fi
    echo ""
    echo "You can also restore these Project Templates later by copying the"
    echo "corresponding file from your backup directory,"
    echo "    $BAK_W".
  fi
  echo ""
  printf "Remove unnecessary Project Templates now? [Y/n] Y\b"
  read sel
  case $sel in
    n*|N*) ;;
    *) if [ "$save" = "1" ]; then
         test -d "$BAK" || $DEBUG mkdir -p "$BAK"
         echo "(backup) removing $FILELIST" >> "$logfile"
         $DEBUG cp -f $FILELIST "$BAK"
       else
         echo "removing $FILELIST" >> "$logfile"
       fi
       $DEBUG rm -f $FILELIST
       ;;
  esac
else
  echo ""
  echo "SNiFF+ TornadoII SETUP could not detect any unnecesary project templates."
  echo "You may want to remove unnecessary Project Templates later by deleting the"
  echo "corresponding file from the "\$"SNIFF_DIR/config/project directory."
fi

# generate SNiFF+ Platform Descriptions for Tornado Platforms
torMake="$WIND_BASE/target/h/make"
torMake_W="$WIND_BASE_W/target/h/make"
newTorMake_W="$torMake_W"
if [ -d "$torMake" ]; then
  cd "$torMake"
  torFiles=`ls make.* 2>/dev/null`
else
  torFiles=""
fi
while [ "$torFiles" = "" ];
do
  echo ""
  echo "Auto-generating SNiFF+ Platform Descriptions for Tornado:"
  echo "ERROR: Cannot find Tornado Makefiles in $torMake_W"
  printf "Correct Directory or [i] to ignore: "
  read newTorMake_W
  case $newTorMake_W in
    i|I) torFiles="_ignore_" ;;
    *) newTorMake="$newTorMake_W"
       test "$SYSTEM" = "Windows" && newTorMake=`"$CYGPATH" -u "$newTorMake_W"`
       if [ -d "$newTorMake" ]; then
         cd "$newTorMake"
         torFiles=`ls make.* 2>dev/null`
       else
         torFiles=""
       fi
       ;;
  esac
done
if [ "$torFiles" != "_ignore_" ]; then
  torMake="$newTorMake"
  torMake_W="$newTorMake_W"
else
  torFiles=""
fi

# backup those files that have not yet been backed up and will
# be overwritten by the Platform Generation Script
if [ "$save" = "1" ]; then
  echo ""
  echo "Creating temporary backup of existing Tornado Platforms..."
  BAK="$bakdir/SNIFF_DIR/Preferences/Platforms"
  test -d "$BAK" || $DEBUG mkdir -p "$BAK"
  cd "$SNIFF_DIR/Preferences/Platforms"
  for curFile in `ls *.sniff | grep 'tor[^HS][^I]'` ;
  do
    test -f "$BAK/$curFile" || $DEBUG cp -f "$curFile" "$BAK"
  done
  BAK="$bakdir/SNIFF_DIR/make_support"
  test -d "$BAK" || $DEBUG mkdir -p "$BAK"
  cd "$SNIFF_DIR/make_support"
  for curFile in `ls *.mk | grep 'tor[^HS][^I]'` ;
  do
    test -f "$BAK/$curFile" || $DEBUG cp -f "$curFile" "$BAK"
  done
fi

# Auto-generate SNiFF+ Platforms for all Tornado Platforms
if [ "$torFiles" != "" ]; then
  cd "$installdir"
  if [ "$DEBUG" = "echo" ]; then
    dbgSwitch="-d"
  else
    dbgSwitch=""
  fi
  $DEBUG $PREFERRED_SHELL $installdir/install.SNIFF_DIR/bin/sniffMakeTorPlatforms.sh \
    $dbgSwitch \
    "$torMake_W" \
    "$SNIFF_DIR_W/Preferences/Platforms" \
    "$installdir_W/install.SNIFF_DIR/Preferences/Platforms/torSIMNTgnu.sniff" \
    "$SNIFF_DIR_W/make_support" \
    "$installdir_W/install.SNIFF_DIR/make_support/torSIMNTgnu.mk" \
    "$logfile"
fi

# customize the WorkingEnvData.sniff file to accomodate the User's
# REAL SIMULATOR / REAL TARGET Platforms instead of SIMNTgnu / PENTIUMgnu
SED_SIM=""
case $PLATFORM in
  pa_risc-hp*) SED_SIM="-e 's,SIMNT,SIMHPPA,g'"
    ;;
  sparc-sun*)  SED_SIM="-e 's,SIMNT,SIMSPARCSOLARIS,g'"
    ;;
esac
RealTargets=`echo "$torFiles" | sed \
  -e 's,make.default,,g' \
  -e 's,make.SIM[a-zA-Z0-9_]*,,g' \
  -e 's,make.,,g'`
test "$DEBUG" = "echo" && echo "RealTargets: $RealTargets"
for curTarget in $RealTargets __dummy__ ; do
  FirstReal="$curTarget"
  break
done
test "$DEBUG" = "echo" && echo "Chosen RealTarget $FirstReal"
if [ "$FirstReal" != "__dummy__" ]; then
  SED_REAL="-e 's,PENTIUMgnu,$FirstReal,g'"
else
  SED_REAL=""
fi

# Create a modified WorkingEnvData.TornadoII.sniff with sed:
# but only if this is not a DEV kit!
if [ ! -f "$installdir/install.SNIFF_DIR/workingenvs/WorkingEnvData.sniff" ]; then
  echo ""
  TGT="$SNIFF_DIR/workingenvs/WorkingEnvData.TornadoII.sniff"
  if  [ -f "$TGT" ]; then
    $DEBUG rm -f "$TGT" 2>/dev/null
  fi
  test -d "$SNIFF_DIR/workingenvs" || $DEBUG mkdir -p "$SNIFF_DIR/workingenvs"
  if [ "$SED_SIM" = "" -a "$SED_REAL" = "" ]; then
    $DEBUG cp "$installdir/adm/WorkingEnvData.sniff" "$TGT"
  else
    evalstr="sed $SED_SIM $SED_REAL \"$installdir/adm/WorkingEnvData.sniff\" > \"$TGT\""
    if [ "$DEBUG" = "echo" ]; then
      echo "$evalstr"
    fi
    eval "$evalstr"
  fi
  msg=\$"SNIFF_DIR/workingenvs/WorkingEnvData.sniff"

  # Move the modified WorkingEnvData.sniff into place
  if $DIFF "$TGT" "$SNIFF_DIR/workingenvs/WorkingEnvData.sniff" >/dev/null 2>&1 ; then
    echo "(no need to copy, up-to-date) $msg"
  else
    if [ "$save" = "1" ]; then
      msg="(backup) copying $msg"
      test -d "$bakdir/SNIFF_DIR/workingenvs" || $DEBUG mkdir -p "$bakdir/SNIFF_DIR/workingenvs"
      $DEBUG cp -f "$SNIFF_DIR/workingenvs/WorkingEnvData.sniff" "$bakdir/SNIFF_DIR/workingenvs"
    else
      msg="(override) copying $msg"
      $DEBUG rm -f "$SNIFF_DIR/workingenvs/WorkingEnvData.sniff"
    fi
    echo "$msg"
    echo "$msg" >> "$logfile"
    $DEBUG cp -f "$SNIFF_DIR/workingenvs/WorkingEnvData.TornadoII.sniff" "$SNIFF_DIR/workingenvs/WorkingEnvData.sniff"
  fi    
fi

# remove unnecessary SNiFF+ Platform files: replace the old files with the
# new ones, which separate between GNU and NATIVE. Only keep Linux ;-)
echo ""
echo "Checking for unnecessary SNiFF+ Platforms..."
FILELIST="AIX.sniff
  DecAlpha.sniff
  HP-UX.sniff
  Irix.sniff
  Linux-glibc.sniff
  SCO.sniff
  Sinix.sniff
  Solaris.sniff
  SunOS.sniff
  Unixware.sniff
  Windows.sniff"
FILELIST_HP="HP-UX_20gnu.sniff
  HP-UX_20hp.sniff
  torHOSTHPPAgnu.sniff
  torHOSTHPPAhp.sniff
  torSIMHPPAhp.sniff
  torSIMHPPAgnu.sniff"
FILELIST_SOL="Solaris_20SPARCworks.sniff
  Solaris_20gnu.sniff
  torHOSTSPARCSOLARISgnu.sniff
  torHOSTSPARCSOLARISsun.sniff
  torSIMSPARCSOLARISgnu.sniff"
FILELIST_SUNOS="SunOS_20gnu.sniff
  SunOS_20native.sniff"
FILELIST_UNIX="Java-UNIX.sniff
  torHOSTUNIXgnu.sniff
  UNIX-Autodetect_20gnu.sniff"
FILELIST_WIN="Java-Windows.sniff
  torHOSTWINDOWSgnu.sniff
  torHOSTWINDOWSvc.sniff
  torSIMNTvc.sniff
  Windows_20MSDEV.sniff
  Windows_20gnu.sniff"
# keep torSIMNTgnu and torPENTIUMgnu in case it is needed by Workingenvs
if [ "$SED_SIM" != "" ]; then
  FILELIST_WIN="$FILELIST_WIN torSIMNTgnu.sniff"
fi
if [ "$SED_REAL" != "" ]; then
  FILELIST_WIN="$FILELIST_WIN torPENTIUMgnu.sniff"
fi

cd "$SNIFF_DIR/Preferences/Platforms"
# don't ask the user about those platforms that we have installed
# ourselves: On Windows, the torHOST(Unix) Platforms make no sense!
# If the user had had these Platforms they are already in the Backup dir.
case $PLATFORM in
  i386-unknown-win*)
    badfiles="$FILELIST_HP $FILELIST_SOL $FILELIST_SUNOS $FILELIST_UNIX"
    FILELIST=`echo "$FILELIST UNIX.sniff" | sed 's,Windows.sniff,,g'`
    ;;
  sparc-sun-solaris*)
    badfiles="$FILELIST_HP $FILELIST_SUNOS $FILELIST_WIN"
    FILELIST=`echo "$FILELIST" | sed 's,Solaris.sniff,,g'`
    ;;
  sparc-sun-sunos*)
    badfiles="$FILELIST_HP $FILELIST_WIN"
    FILELIST=`echo "$FILELIST" | sed 's,SunOS.sniff,,g'`
    ;;
  pa_risc*)
    badfiles="$FILELIST_SOL $FILELIST_SUNOS $FILELIST_WIN"
    FILELIST=`echo "$FILELIST" | sed 's,HP-UX.sniff,,g'`
    ;;
  rs6000*)
    badfiles="$FILELIST_HP $FILELIST_SOL $FILELIST_SUNOS $FILELIST_WIN"
    FILELIST=`echo "$FILELIST" | sed 's,AIX.sniff,,g'`
    ;;
  *-linux*)
    badfiles="$FILELIST_HP $FILELIST_SOL $FILELIST_SUNOS $FILELIST_WIN"
    FILELIST=`echo "$FILELIST" | sed 's,Linux-glibc.sniff,,g'`
    ;;
esac
# "badfiles" are those that are installed by the Tornado integration itself
# and may thus be considered obsolete without asking the user.
# backup the "badfiles" so they can be easily retrieved later
# Remove files only if this is NOT a DEVkit!
if [ ! -f "$installdir/install.SNIFF_DIR/workingenvs/WorkingEnvData.sniff" ]; then
  newFileList=""
  if [ "$save" = "1" ]; then
    BAK="$bakdir/SNIFF_DIR/Preferences/Platforms"
    test -d "$BAK" || $DEBUG mkdir -p "$BAK"
    BAK_W="$BAK"
    if [ "$SYSTEM" = "Windows" ]; then
      BAK_W=`"$CYGPATH" -w "$BAK" | sed 's,[\],/,g' `
    fi
  fi
  cd "$SNIFF_DIR/Preferences/Platforms"
  for curFile in __dummy__ $badfiles ;
  do
    if [ "$curFile" = "__dummy__" ]; then
      continue
    fi
    if [ -f "$curFile" ]; then
      if [ "$save" = "1" ]; then
        if [ ! -f "$BAK/$curFile" ]; then
          $DEBUG cp -f "$curFile" "$BAK/$curFile"
          # remove the "badfiles" without asking the user
          ##ALTERNATIVE for asking the user about these files as well:
          # newFileList="$newFileList $curFile"
          echo "Removing unnecessary "\$"SNIFF_DIR/Preferences/Platforms/$curFile" >> "$logfile"
          $DEBUG rm -f "$curFile"
        # else
          # backup exists: must have been user-modified and can thus not be
          # considered obsolete! Don't remove it and don't put it into the
          # FILELIST.
        fi
      else
        # we don't make backups at all -- just remove the files.
        echo "Removing unnecessary "\$"SNIFF_DIR/Preferences/Platforms/$curFile" >> "$logfile"
        $DEBUG rm -f "$curFile"
      fi
    fi
  done
fi

# restrict the FILELIST to those platforms that are really there.
for curFile in $FILELIST ;
do
  if [ -f "$curFile" ]; then
    newFileList="$newFileList $curFile"
  fi
done

# sort the FILELIST
FILELIST=""
for curFile in __dummy__ `echo "$newFileList" | sort ` ;
do
  if [ "$curFile" = "__dummy__" ]; then
    continue
  fi
  FILELIST="$FILELIST $curFile"
done
if [ "$FILELIST" != "" ]; then
  doAgain=1
  while [ "$FILELIST" != "" -a "$doAgain" = "1" ];
  do
    echo ""
    echo "The following SNiFF+ Platform Descriptions seem to be unnecessary:"
    count=1
    for curFile in $FILELIST ;
    do
      echo "($count) $curFile"
      count=`expr "$count" + 1`
    done
    echo ""
    echo "The SNiFF+ Platform Descriptions listed above seem to be unnecessary"
    echo "on your System. We recommend to remove these files to allow for easier"
    echo "handling and better overview in SNiFF+."
    echo ""
    echo "Note: you can remove any Platforms later in the SNiFF+ Preferences Dialog."
    if [ "$save" = "1" ]; then
      echo "You can also restore these Platforms later by copying the corresponding"
      echo "File from your backup directory,"
      echo "    $BAK_W".
    fi
    echo ""
    echo "Enter the numbers of any Platforms you would like to keep."
    printf "Enter numbers, [R] to remove all, or [A] to keep all shown [0-9/R/a] : R\b"
    # printf "or [C] to continue :"
    read sel
    if [ "$sel" = "" ]; then
      doAgain=0
      continue
    fi
    remList=""
    for curSel in $sel ;
    do
      if [ "$FILELIST" = "" ]; then
        doAgain=0
        continue
      fi
      case $curSel in
      a|A) FILELIST="" ; doAgain=0 ;;
      r|R) doAgain=0 ;;
      1*|2*|3*|4*|5*|6*|7*|8*|9*) # number entered
        count=1
        for curFile in $FILELIST ; do
          if [ $count -eq $curSel ]; then
            remList="$remList $curFile"
            break
          fi
          count=`expr "$count" + 1`
        done
        ;;
      *) continue ;;
      esac
    done # for curSel
    for curRem in _dummy_ $remList ; do
      FILELIST=`echo $FILELIST | sed "s,$curRem,,g"`
    done
  done # while doAgain
  # now, really remove the stuff!
  if [ "$FILELIST" != "" ]; then
    cd "$SNIFF_DIR/Preferences/Platforms"
    for curFile in $FILELIST ; do
      if [ "$save" = "1" ]; then
        msg="(backup) "
        if [ ! -f "$BAK/$curFile" ]; then
          $DEBUG cp "$curFile" "$BAK/$curFile"
        fi
      else
        msg=""
      fi
      echo "${msg}removing unnecessary "\$"SNIFF_DIR/Preferences/Platforms/$curFile" >> "$logfile"
      $DEBUG rm -f "$curFile"
    done
  fi # empty FILELIST after postprocessing
# else # empty filelist from beginning
  # echo ""
  # echo "SNiFF+ TornadoII SETUP could not detect your system type."
  # echo "You may want to remove unnecessary Platforms later in the SNiFF+"
  # echo "Preferences / Platforms Dialog."
fi # empty FILELIST from beginning

# remove unnecessary entries from Platforms Backup Directory
if [ "$save" = "1" ]; then
  echo ""
  echo "Removing unnecessary temporary backups..."
  cd "$bakdir/SNIFF_DIR/Preferences/Platforms"
  for curFile in `ls *.sniff 2>/dev/null` ;
  do
    if [ -f "$SNIFF_DIR/Preferences/Platforms/$curFile" ]; then
      if $DIFF "$curFile" "$SNIFF_DIR_W/Preferences/Platforms/$curFile" >/dev/null ; then
        $DEBUG rm -f "$curFile"
      fi
    fi
  done
  rest=`ls 2>/dev/null`
  if [ "$rest" = "" ]; then
    cd ..
    rmdir Platforms
    rest=`ls 2>/dev/null`
    if [ "$rest" = "" ]; then
      cd ..
      rmdir Preferences
    fi
  fi
  cd "$bakdir/SNIFF_DIR/make_support"
  for curFile in `ls *.mk 2>/dev/null` ;
  do
    if $DIFF "$curFile" "$SNIFF_DIR_W/make_support/$curFile" >/dev/null ; then
      $DEBUG rm -f $curFile
    fi
  done
  rest=`ls 2>/dev/null`
  if [ "$rest" = "" ]; then
    cd ..
    rmdir make_support
  fi
fi

# Tornado 1: create missing defs.project
if [ ! -f "$WIND_BASE/target/h/make/defs.project" ]; then
  echo "Creating missing "\$"WIND_BASE/target/h/make/defs.project"
  test -d "$WIND_BASE/target/h/make" || mkdir -p "$WIND_BASE/target/h/make"
  f="$WIND_BASE/target/h/make/defs.project"
  echo 'include $(TGT_DIR)/h/make/defs.$(WIND_HOST_TYPE)' > "$f"
  echo 'include $(TGT_DIR)/h/make/defs.bsp' >> "$f"
  echo 'include $(TGT_DIR)/h/make/make.$(CPU)$(TOOL)' >> "$f"
fi

fi # NOT UNINSTALL

# create customized sniff.bat / sniff.cshrc / sniff.profile in $SNIFF_DIR
# and $WIND_BASE
echo ""
echo "" >> "$logfile"
TGT="WIND_BASE" ; TGT_DIR="$WIND_BASE"
PERM_ERR=`touch "$TGT_DIR/sniff.bat" 2>&1 `
if [ "$PERM_ERR" != "" ]; then
  echo "${CREATING_REMOVING} Startup file: No write permission on $TGT_DIR"
  TGT=SNIFF_DIR ; TGT_DIR="$SNIFF_DIR"
  PERM_ERR=`touch "$TGT_DIR/sniff.bat" 2>&1 `
  if [ "$PERM_ERR" != "" ]; then
    echo "${CREATING_REMOVING} Startup file: No write permission on $TGT_DIR"
    TGT="WIND_BASE" ; TGT_DIR=/tmp
  fi
fi
SNIFF_VERSION="SNiFF+ Version ???"
test -f "$SNIFF_DIR/Version" && SNIFF_VERSION=`cat "$SNIFF_DIR/Version"`
SNIFF_TOR_VERSION=`cat "$installdir/Version.txt"`
case $PLATFORM in
  i386-unknown-win*)
    # Windows: Must use WIN-Form of pathnames, with backslashes.
    # SNiFF+ Requires that the drive letter be in uppercase!
    WB_B=`"$CYGPATH" -w "$WIND_BASE" `
    WB_B1=`echo "$WB_B" | cut -c1 | tr 'a-z' 'A-Z'`
    WB_BR=`echo "$WB_B" | cut -c2-`
    WB_B="${WB_B1}${WB_BR}"
    SD_B=`"$CYGPATH" -w "$SNIFF_DIR" `
    SD_B1=`echo "$SD_B" | cut -c1 | tr 'a-z' 'A-Z'`
    SD_BR=`echo "$SD_B" | cut -c2-`
    SD_B="${SD_B1}${SD_BR}"
    TGT_DIR_B=`"$CYGPATH" -w "$TGT_DIR" `
    msg="${CREATING_REMOVING} Startup $TGT_DIR_B\\sniff.bat"
    if [ "$UNINSTALL" = "1" ]; then
      $DEBUG rm -f "$TGT_DIR/sniff.bat"
    else
      if [ -f "$TGT_DIR/sniff.bat" ]; then
        if [ "$save" = "1" ]; then
          msg="(backup) $msg"
          test -d "$bakdir/$TGT" || $DEBUG mkdir -p "$bakdir/$TGT"
          $DEBUG cp -f "$TGT_DIR/sniff.bat" "$bakdir/$TGT/sniff.bat"
        else
          msg="(override) $msg"
        fi
        $DEBUG rm -f "$TGT_DIR/sniff.bat"
      fi
      echo "$msg"
      echo "$msg" >> "$logfile"
      if [ "$WIND_REGISTRY" = "" ]; then
        WIND_REGISTRY=`"$READ_REGISTRY_VALUE" \
          "HKEY_CURRENT_USER" \
          "Software\\Wind River Systems\\Tornado 2.0" \
          "WIND_REGISTRY" \
          "REG_SZ" `
        if [ "$WIND_REGISTRY" = "" ]; then
          WIND_REGISTRY=localhost
        fi
      fi
      echo "@ECHO OFF" > $TGT_DIR/sniff.bat
      echo "REM Batchfile for starting SNiFF+ / $SNIFF_TOR_VERSION" >> "$TGT_DIR/sniff.bat"
      echo "" >> "$TGT_DIR/sniff.bat"
      echo "REM IF \"%WIND_REGISTRY%\" == \"\" SET WIND_REGISTRY=$WIND_REGISTRY" >> "$TGT_DIR/sniff.bat"
      echo "IF EXIST host\\x86-win32\\bin\\torVars.bat CALL host\\x86-win32\\bin\\torVars.bat" >> "$TGT_DIR/sniff.bat"
      echo "IF \"%WIND_BASE%\" == \"\" SET WIND_BASE=$WB_B" >> "$TGT_DIR/sniff.bat"
      if [ "$TORNADO_VERSION" != "" ]; then
        echo "SET TORNADO_VERSION=$TORNADO_VERSION" >> "$TGT_DIR/sniff.bat"
      fi
      echo "SET SNIFF_DIR=$SD_B" >> "$TGT_DIR/sniff.bat"
      echo "" >> "$TGT_DIR/sniff.bat"
      echo "REM SET WIND_TARGET_BASE=%WIND_BASE%\\target" >> "$TGT_DIR/sniff.bat"
      echo "REM SET SNIFF_EXAMPLE_ROOT=%HOMEDRIVE%%HOMEPATH%\\Sniff_WS\\example" >> "$TGT_DIR/sniff.bat"
      echo "REM SET SNIFF_PDF_GEN_ROOT=%HOMEDRIVE%%HOMEPATH%\\Sniff_WS\\PDFs\\dot.sniffdirs" >> "$TGT_DIR/sniff.bat"
      echo "REM SET SNIFF_USE_SLICKEDIT=1" >> "$TGT_DIR/sniff.bat"
      echo "" >> "$TGT_DIR/sniff.bat"
      echo "CALL \"%SNIFF_DIR%\\integrations\\TornadoII\\adm\\sniff.bat\" %1 %2 %3 %4 %5 %6 %7" >> "$TGT_DIR/sniff.bat"
    fi

    # create SYMLINK on the Desktop
    LinkName="SNiFF+ for Tornado"
    BashName="Bash for Tornado"
    if [ "$TORNADO_VERSION" != "" ]; then
      LinkName="$LinkName $TORNADO_VERSION"
      BashName="$BashName $TORNADO_VERSION"
    fi
    if [ "$TORNADO_ARCH" != "" ]; then
      LinkName="$LinkName $TORNADO_ARCH"
      BashName="$BashName $TORNADO_ARCH"
    fi
    lnkFile="${LinkName}.lnk"
    bashFile="${BashName}.lnk"
    msg="${CREATING_REMOVING} Shortcut \"$lnkFile\" in $TGT_DIR_B"
    if [ -f "$TGT_DIR/$lnkFile" ]; then
      if [ "$save" = "1" ]; then
        msg="(backup) $msg"
        test -d "$bakdir/$TGT" || $DEBUG mkdir -p "$bakdir/$TGT"
        $DEBUG cp -f "$TGT_DIR/$lnkFile" "$bakdir/$TGT/$lnkFile"
      else
        msg="(override) $msg"
      fi
      $DEBUG rm -f "$TGT_DIR/$lnkFile"
    fi
    echo "$msg"
    echo "$msg" >> "$logfile"
    if [ "$UNINSTALL" != "1" ]; then
      $DEBUG "$installdir/adm/shortcut.exe" -f -n "$TGT_DIR_B\\$lnkFile" -t "$TGT_DIR_B\\sniff.bat" -i "$SD_B\\bin\\sniff.exe" -d "$TGT_DIR_B"
    fi

    msg="${CREATING_REMOVING} Shortcut \"$bashFile\" in $TGT_DIR_B"
    if [ -f "$TGT_DIR/$bashFile" ]; then
      if [ "$save" = "1" ]; then
        msg="(backup) $msg"
        test -d "$bakdir/$TGT" || $DEBUG mkdir -p "$bakdir/$TGT"
        $DEBUG cp -f "$TGT_DIR/$bashFile" "$bakdir/$TGT/$bashFile"
      else
        msg="(override) $msg"
      fi
      $DEBUG rm -f "$TGT_DIR/$bashFile"
    fi
    echo "$msg"
    echo "$msg" >> "$logfile"
    if [ "$UNINSTALL" != "1" ]; then
      $DEBUG "$installdir/adm/shortcut.exe" -f -n "$TGT_DIR_B\\$bashFile" -t "$TGT_DIR_B\\sniff.bat" -a "bash" -i "$SD_B\\bin\\sniff.exe" -x 6 -d "$TGT_DIR_B"
    fi

    UserDesktop=`"$READ_REGISTRY_VALUE" \
      "HKEY_CURRENT_USER" \
      "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders" \
      "Desktop" \
      "REG_EXPAND_SZ" | sed -e 's,[\],/,g' -e 's,/*$,,g' `
    if [ "$?" != "0" ]; then
      echo "WARNING ${CREATING_REMOVING} Shortcut: cannot find User Desktop Folder"
      UserDesktop="$SYSTEMROOT/Profiles/$USERNAME/Desktop"
    fi
    UserProgramsFolder=`"$READ_REGISTRY_VALUE" \
      "HKEY_CURRENT_USER" \
      "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders" \
      "Programs" \
      "REG_EXPAND_SZ" | sed -e 's,[\],/,g' -e 's,/*$,,g' `
    if [ "$?" != "0" ]; then
      echo "WARNING ${CREATING_REMOVING} Shortcut: cannot find User Programs Group in the Start Menu"
      UserStartupFolder="$SYSTEMROOT/Profiles/$USERNAME/Start Menu/Programs"
    fi
    CommonProgramsFolder=`"$READ_REGISTRY_VALUE" \
      "HKEY_LOCAL_MACHINE" \
      "SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders" \
      "Common Programs" \
      "REG_EXPAND_SZ" | sed -e 's,[\],/,g' -e 's,/*$,,g' `
    if [ "$?" != "0" ]; then
      echo "WARNING ${CREATING_REMOVING} Shortcut: cannot find Common Programs Group in the Start Menu"
      CommonStartupFolder="$SYSTEMROOT/Profiles/All Users/Start Menu/Programs"
    fi
 
    # $DEBUG cp -f "$WIND_BASE/$lnkFile" "$SNIFF_DIR/$lnkFile"
    for curDir in \
      "${UserDesktop}" \
      "${UserProgramsFolder}/Tornado2" \
      "${UserProgramsFolder}/SNiFF+ for Windows" \
      "${CommonProgramsFolder}/Tornado2" \
      "${CommonProgramsFolder}/SNiFF+ for Windows" ;
    do
      msg="copying shortcuts to $curDir"
      # substitute special characters (including spaces!) with ?
      ALIEN_CHARS=`echo "$curDir" | sed 's,[^a-zA-Z0-9_()~!,.:/+=-],?,g'`
      if [ "$ALIEN_CHARS" != "$curDir" ]; then
        curDir=`ls -d $ALIEN_CHARS 2>/dev/null`
      fi
      if [ -d "$curDir" ]; then
        # don't warn about missing write permissions
        if [ -f "${curDir}/$lnkFile" ]; then
          msg="(override) $msg"
          rm -f "${curDir}/$lnkFile"
          rm -f "${curDir}/$bashFile" 2>/dev/null
        fi
        if [ "$UNINSTALL" = "1" ]; then
          msg="${CREATING_REMOVING} Shortcut in $curDir"
          echo "$msg"
          echo "$msg" >> "$logfile"
        else
          $DEBUG cp -f "$TGT_DIR/$lnkFile" "$curDir" 2>/dev/null
          $DEBUG cp -f "$TGT_DIR/$bashFile" "$curDir" 2>/dev/null
          if [ "$?" != "0" ]; then
            echo "NOT $msg"
          else
            echo "$msg"
            echo "$msg" >> "$logfile"
          fi
        fi
      else
        echo "NOT $msg"
      fi
    done
    ;;
  *) #UNIX: create symbolic links for the programs installed
    if [ "$UNINSTALL" != "1" ]; then
      CREATING="Creating"
      if [ ! -x "$SNIFF_DIR/bin/sniff_wrapper" ]; then
        msg="ERROR: "\$"SNIFF_DIR/bin/sniff_wrapper does not exist or is not executable!"
        echo "$msg"
        echo "$msg" >> "$logfile"
        CREATING="Not creating"
      fi
      msg="${CREATING} symbolic link for "
      for curLink in sniffasm_windriver sniffmakeparser ; do
        xmsg="$msg"\$"SNIFF_DIR/bin/$curLink"
        if [ "$CREATING" = "Creating" ]; then
          if [ -f "$SNIFF_DIR/bin/$curLink" ]; then
            if [ "$save" = "1" ]; then
              xmsg="(backup) $xmsg"
              test -d "$bakdir/SNIFF_DIR/bin" || $DEBUG mkdir -p "$bakdir/SNIFF_DIR/bin"
              $DEBUG cp -f "$SNIFF_DIR/bin/$curLink" "$bakdir/SNIFF_DIR/bin"
            fi
          fi
          echo "$xmsg"
          echo "$xmsg" >> "$logfile"
          $DEBUG rm -f "$SNIFF_DIR/bin/$curLink"
          $DEBUG ln -s sniff_wrapper "$SNIFF_DIR/bin/$curLink"
        fi
      done
    fi
    # remove rest from Windows installation
    rm -f "$TGT_DIR/sniff.bat" >/dev/null 2>&1
    msg="${CREATING_REMOVING} $TGT_DIR/sniff.cshrc"
    if [ -f "$TGT_DIR/sniff.cshrc" ]; then
      if [ "$save" = "1" ]; then
        msg="(backup) $msg"
        test -d "$bakdir/$TGT" || $DEBUG mkdir -p "$bakdir/$TGT"
        $DEBUG cp -f "$TGT_DIR/sniff.cshrc" "$bakdir/$TGT/sniff.cshrc"
      else
        msg="(override) $msg"
      fi
      $DEBUG rm -f "$TGT_DIR/sniff.cshrc"
    fi
    echo "$msg"
    echo "$msg" >> "$logfile"
    if [ "$UNINSTALL" != "1" ]; then
      echo "# Set Environment for SNiFF+ / $SNIFF_TOR_VERSION" > "$TGT_DIR/sniff.cshrc"
      echo "" >> "$TGT_DIR/sniff.cshrc"
      echo "setenv SNIFF_DIR $SNIFF_DIR" >> "$TGT_DIR/sniff.cshrc"
      echo "" >> "$TGT_DIR/sniff.cshrc"
      echo "setenv WIND_BASE $WIND_BASE" >> "$TGT_DIR/sniff.cshrc"
      echo 'setenv WIND_HOST_TYPE `$WIND_BASE/host/resource/wind_host_type`' >> "$TGT_DIR/sniff.cshrc"
      echo 'source $WIND_BASE/host/$WIND_HOST_TYPE/bin/torVars.csh' >> "$TGT_DIR/sniff.cshrc"
      if [ "$TORNADO_VERSION" != "" ]; then
        echo "setenv TORNADO_VERSION \"$TORNADO_VERSION\"" >> "$TGT_DIR/sniff.cshrc"
      fi
      echo "" >> "$TGT_DIR/sniff.cshrc"
      echo "#setenv WIND_TARGET_BASE "\$"{WIND_BASE}/target" >> "$TGT_DIR/sniff.cshrc"
      echo "setenv SNIFF_EXAMPLE_ROOT "\$"HOME/Sniff_WS/example" >> "$TGT_DIR/sniff.cshrc"
      echo "setenv SNIFF_PDF_GEN_ROOT "\$"HOME/Sniff_WS/PDFs/dot.sniffdirs" >> "$TGT_DIR/sniff.cshrc"
      echo "" >> "$TGT_DIR/sniff.cshrc"
      echo "source $SNIFF_DIR/integrations/TornadoII/adm/sniff.cshrc" >> "$TGT_DIR/sniff.cshrc"
    fi

    msg="${CREATING_REMOVING} $TGT_DIR/sniff.profile"
    if [ -f "$TGT_DIR/sniff.profile" ]; then
      if [ "$save" = "1" ]; then
        msg="(backup) $msg"
        $DEBUG cp -f "$TGT_DIR/sniff.profile" "$bakdir/$TGT/sniff.profile"
      else
        msg="(override) $msg"
      fi
      $DEBUG rm -f "$TGT_DIR/sniff.profile"
    fi
    echo "$msg"
    echo "$msg" >> "$logfile"
    if [ "$UNINSTALL" != "1" ]; then
      echo "# Set Environment for SNiFF+ / $SNIFF_TOR_VERSION" > "$TGT_DIR/sniff.profile"
      echo "" >> "$TGT_DIR/sniff.profile"
      echo "SNIFF_DIR=$SNIFF_DIR" >> "$TGT_DIR/sniff.profile"
      echo "export SNIFF_DIR" >> "$TGT_DIR/sniff.profile"
      echo "" >> "$TGT_DIR/sniff.profile"
      echo "WIND_BASE=$WIND_BASE" >> "$TGT_DIR/sniff.profile"
      echo 'WIND_HOST_TYPE=`$WIND_BASE/host/resource/wind_host_type`' >> "$TGT_DIR/sniff.profile"
      echo '. $WIND_BASE/host/$WIND_HOST_TYPE/bin/torVars.sh' >> "$TGT_DIR/sniff.profile"
      if [ "$TORNADO_VERSION" != "" ]; then
        echo "TORNADO_VERSION=\"$TORNADO_VERSION\" ; export TORNADO_VERSION" >> "$TGT_DIR/sniff.profile"
      fi
      echo "" >> "$TGT_DIR/sniff.profile"
      echo "#setenv WIND_TARGET_BASE "\$"WIND_BASE/target ; export WIND_TARGET_BASE" >> "$TGT_DIR/sniff.profile"
      echo "SNIFF_EXAMPLE_ROOT="\$"HOME/Sniff_WS/example" >> "$TGT_DIR/sniff.profile"
      echo "export SNIFF_EXAMPLE_ROOT" >> "$TGT_DIR/sniff.profile"
      echo "SNIFF_PDF_GEN_ROOT="\$"HOME/Sniff_WS/PDFs/dot.sniffdirs" >> "$TGT_DIR/sniff.profile"
      echo "export SNIFF_PDF_GEN_ROOT" >> "$TGT_DIR/sniff.profile"
      echo "" >> "$TGT_DIR/sniff.profile"
      echo ". $SNIFF_DIR/integrations/TornadoII/adm/sniff.profile" >> "$TGT_DIR/sniff.profile"
    fi
    ;;
esac
 
# Remove unnecessary backups of startup files
if [ "$save" = "1" ]; then
  cd "$bakdir"
  for curFile in `ls SNIFF_DIR/sniff.* WIND_BASE/sniff.* 2>/dev/null` ;
  do
    # SNIFF_DIR and WIND_BASE are known to be the same!
    curName=`basename $curFile`
    if [ -f "$SNIFF_DIR/$curName" ]; then
      if $DIFF "$curFile" "$SNIFF_DIR_W/$curName" >/dev/null ; then
        $DEBUG rm -f "$curFile"
      fi
    fi
  done
fi

if [ "$UNINSTALL" != "1" ]; then
  # HOTFIXES for the SSWE:
  # - Make the SSWE Read-only: Necessary on Windows!
  # - Add a directory for target/h/make
  cd "$SNIFF_DIR/example/Tornado/2_Gizmo/SSWE"
  chmod 444 `find . -type f`
  test -d "$SNIFF_DIR/example/Tornado/2_Gizmo/SSWE/h/make" || mkdir -p "$SNIFF_DIR/example/Tornado/2_Gizmo/SSWE/h/make"

  # HOTFIX for Tornado 1.0.1: restore vital files
  if [ "$UNKNOWN_TORNADO_VERSION" = "1" ]; then
    cd "$WIND_BASE"
    for curFile in $PATCHED_TORNADO_FILES ; do
      if [ -f "$curFile" ]; then
        cp -f "$curFile" "$curFile.sniff_new"
      fi
      if [ -f "$curFile.sniff_orig" ]; then
        cp -f "$curFile.sniff_orig" "$curFile"
      fi
    done
  fi
fi

echo ""
echo "TornadoII PostInstall finished!"
echo ""
echo "Install has created backup files in SitePrefs.sniff.tor_orig,"
echo "workingenvs.tor_orig and config/SiteMenus.sniff.tor_orig."
echo "If you should be missing anything from your old SNiFF+ installation, you"
echo "may want to consider merging your changes back from these backup files."
# do *not* exit 0 here because this is sourced from install.sh
