#!/bin/sh
#
# precopy.sh file for SNiFF+ TornadoII integration
#
# This file is sourced from the generic install.sh before copying files.
# What we have at this point:
# *) System specifics:
#    - $SYSTEM is set to "Windows" or "UNIX"
#    - $CYGPATH is set to the cygpath.exe executable if System is "Windows"
#    - $DIFF is set to a diff program that works with cygwin paths
#    - $READ_REGISTRY_VALUE points to the ReadRegistryValue.exe program on Win
#    - $PREFERRED_SHELL is set to the shell program we should use
# *) General Switches
#    - $DEBUG is set to "echo" if debug mode is on (or empty otherwise)
#    - $CONFIG_ONLY is set to 1 if no copying should be made
#    - $UNINSTALL is set to 1 if we should make an uninstall (1 otherwise)
# *) Directories:
#    - $StartFromDir is from where the install.sh was started
#    - $mydir is where this install.sh is located
#    - $installdir is at the installation source
#    - $target_dirs has a list of targets where to install to
#    - $logfile exists and is ready for logging
#    - $save tells us whether to backup or not
#    - $bakdir is the target where to backup files, it exists and is writable
# *) Common switches
#    - $integration_name is the adaptor name to install
#    - $is_external tells us whether we are installing from "outside" the SNiFF Tree
# *) Special cases handled
#    - $SNIFF_DIR is the installation target: correctly set, exists and is writable
#    - $WIND_BASE is correctly set and writable, if it is needed
#
# Make sure that $WIND_BASE/host/resource/tcl/gdb.tcl is backed up und all
# circumstances, because we don't know whether overwriting this file is legal!
#

echo ""
echo "Preparing to copy..."
TORNADO_VERSION=""
TORNADO_ARCH=""
UNKNOWN_TORNADO_VERSION=0
# files that are patched by installing the SNiFF+ Tornado integration
PATCHED_TORNADO_FILES="host/resource/tcl/gdb.tcl \
      host/resource/tcl/CrossWind.tcl \
      host/resource/app-defaults/Launch-color"
PATCHED_SNIFF_FILES="SitePrefs.sniff \
      config/SiteMenus.sniff"
 
# Save possibly user-modified files to their backups
cd "$SNIFF_DIR"
for curFile in $PATCHED_SNIFF_FILES ; do
  if [ -f "$curFile" ]; then
    if [ -f "$curFile.tor_orig" ]; then
      rm -f "$curFile.tor_orig"
    fi
    cp -f "$curFile" "$curFile.tor_orig"
  fi
done
if [ -f "workingenvs/WorkingEnvData.sniff" ]; then
  if [ -d "workingenvs.tor_orig" ]; then
    rm -rf "workingenvs.tor_orig"
  fi
  mv "workingenvs" "workingenvs.tor_orig"
  mkdir "workingenvs"
  cp workingenvs.tor_orig/WorkingEnv*.sniff workingenvs
fi

# Find out Tornado Version
tmpFile="/tmp/wtxTsVersionGet.$$.tcl"
if [ "$SYSTEM" = "Windows" ]; then
  WIND_HOST_TYPE=x86-win32
  tmpFile_WB=`"$CYGPATH" -w "$tmpFile"`
else
  tmpFile_WB="$tmpFile"
  if [ "$WIND_HOST_TYPE" = "" ]; then
    if [ -x "$WIND_BASE/host/resource/wind_host_type" ]; then
      WIND_HOST_TYPE=`sh $WIND_BASE/host/resource/wind_host_type`
      export WIND_HOST_TYPE
    fi
  fi
fi
test "$DEBUG" = "echo" && echo "Getting Tornado Version from $WIND_BASE/host/$WIND_HOST_TYPE/bin/wtxtcl"
if [ -x "$WIND_BASE/host/$WIND_HOST_TYPE/bin/wtxtcl" ]; then
  rm -f "$tmpFile"
  echo "puts [wtxTsVersionGet]" > "$tmpFile"
  TORNADO_VERSION=`$WIND_BASE/host/$WIND_HOST_TYPE/bin/wtxtcl "$tmpFile_WB" \
    | sed 's,[^0-9a-zA-Z._-],,g' `
  test "$DEBUG" = "echo" && echo "TORNADO_VERSION: $TORNADO_VERSION"
  rm -f "$tmpFile"
fi
if [ -d "$WIND_BASE/target/h/arch" ]; then
  cd "$WIND_BASE/target/h/arch"
  TORNADO_ARCH=`ls | grep -v -i '^sim' | head -1 | tr 'a-z' 'A-Z'`
fi

if [ "$UNINSTALL" != "1" ]; then
  # Save patched Tornado Files under ALL CIRCUMSTANCES!
  cd "$WIND_BASE"
  for curFile in $PATCHED_TORNADO_FILES ; do
    if [ ! -f "$curFile.sniff_orig" ]; then
      if [ -f "$curFile" ]; then
        cp -f "$curFile" "$curFile.sniff_orig"
      fi
    fi
  done

  dir="host/resource/tcl"
  file=gdb.tcl
  ERROR=0
  if [ ! -f "$WIND_BASE/$dir/$file" ]; then
    echo "ERROR: Installing into unknown Tornado Version!"
    echo ""
    echo \$"WIND_BASE/$dir/$file was not found."
    ERROR=1
  else
    diff_lines=`$DIFF \
      "$WIND_BASE_W/$dir/$file" \
      "$installdir_W/install.WIND_BASE/$dir/$file" \
      2>/dev/null \
      | wc | cut -c-8`
    if [ $diff_lines -gt 10 ]; then
      # this is an UNKNOWN gdb.tcl!
      BAK="$bakdir/WIND_BASE/$dir/$file"
      if [ "$SYSTEM" = "Windows" ]; then
        BAK_W=`"$CYGPATH" -w "$BAK" | sed 's,[\],/,g'`
      else
        BAK_W="$BAK"
      fi
      #msg="WARNING: Upgrading UNKNOWN $file -- Saving Backup to"
      #echo "$msg"
      #echo "$msg" >> "$logfile"
      #echo "  $BAK_W"
      #echo "  $BAK_W" >> "$logfile"
      #test -d "$BAK/$dir" || mkdir -p "$BAK/$dir"
      #cp -f "$WIND_BASE/$dir/$file" "$BAK/$dir/$file"
      echo "ERROR: Installing into unknown Tornado Version!"
      echo ""
      echo \$"WIND_BASE/$dir/$file has $diff_lines lines of difference!"
      ERROR=1
    fi
  fi
  if [ "$ERROR" = "1" ]; then
    UNKNOWN_TORNADO_VERSION=1
    echo "Note that this integration currently does not support"
    echo "Tornado 1.0.1 and Tornado 3."
    echo ""
    echo "If you continue installation, you may break your Tornado!"
    echo "Answer [i] for ignore only if you know what you are doing!"
    echo ""
    printf "Quit installation ? Y\b"
    read sel
    case x$sel in
    xi*|xI*) ERROR=0 #and continue
             ;;
    *) RESULT=$exit_wrong_version
       finish
       ;;
    esac
  fi
else
  # uninstall
  if [ -d "$SNIFF_DIR" ]; then
    msg="Removing Tornado additions in "\$"SNIFF_DIR:"
    cd "$SNIFF_DIR"
    FILES=`ls config/editor/InitTornado*.py 2>/dev/null`
    if [ "$FILES" != "" ]; then
      echo "$msg"
      echo "$msg" >> "$logfile"
      echo "  $FILES"
      echo "  $FILES" >> "$logfile"
      $DEBUG rm -f $FILES
    fi
  fi
  if [ -d "$WIND_BASE/host/resource/tcl" ]; then
    msg="Removing Tornado additions in "\$"WIND_BASE:"
    cd "$WIND_BASE/host/resource/tcl"
    FILES="app-config/Launch/01ProjSNiFF.tcl \
    app-config/CrossWind/01SNiFF.tcl \
    app-config/Tornado/01SNiFF.win32.tcl"
    FILES=`ls $FILES 2>/dev/null`
    if [ "$FILES" != "" ]; then
      echo "$msg"
      echo "$msg" >> "$logfile"
      echo "  $FILES"
      echo "  $FILES"
      $DEBUG rm -f $FILES
    fi
  fi
fi
