#!/bin/sh
#
# preinstall file for SNiFF+ TornadoII integration
#
# This file is sourced from the generic install.sh and may be used to
# guess environment variables or prepare other things before the actual
# copying.
#
# What we have at this point:
# *) System specifics:
#    - $SYSTEM is set to "Windows" or "UNIX"
#    - $CYGPATH is set to the cygpath.exe executable if System is "Windows"
#    - $DIFF is set to a diff program that works with cygwin paths
#    - $READ_REGISTRY_VALUE points to the ReadRegistryValue.exe program on Win
#    - $PREFERRED_SHELL is set to the shell program we should use
# *) General Switches
#    - $DEBUG is set to "echo" if debug mode is on (or empty otherwise)
#    - $CONFIG_ONLY is set to 1 if no copying should be made
#    - $UNINSTALL is set to 1 if we should make an uninstall (1 otherwise)
# *) Directories:
#    - $StartFromDir is from where the install.sh was started
#    - $mydir is where this install.sh is located
#    - $installdir is at the installation source
#    - $target_dirs has a list of targets where to install to
#
# *) $SNIFF_DIR is guessed but not yet accepted by the user
#
# What we don't yet have at this point:
# *) $SNIFF_DIR, $integration_name, $logfile, $is_external, $bakdir, $save
#    all do not exist yet.
#
# Guess the WIND_BASE environment variable unless it's already set
#

cd "$installdir"
if [ "$SNIFF_DIR" = "" ]; then
  if [ "$SYSTEM" = "Windows" ]; then
    # Guess SNIFF_DIR from Registry
    SNIFF_DIR=`"$READ_REGISTRY_VALUE" \
      "HKEY_CURRENT_USER" \
      "Software\\TakeFive Software\\SNiFF+ for Windows\\3.000\\Directories" \
      "ProductDir" \
      "REG_EXPAND_SZ"`
    if [ "$?" != "0" ]; then
      SNIFF_DIR=""
      test "$DEBUG" = "echo" && echo "ReadRegistryValue: ERROR Reading User SNIFF_DIR"
    fi
    test "$DEBUG" = "echo" && echo "ReadRegistryValue: User SNIFF_DIR=${SNIFF_DIR}<--"
    if [ "$SNIFF_DIR" = "" ]; then
      SNIFF_DIR=`"$READ_REGISTRY_VALUE" \
        "HKEY_LOCAL_MACHINE" \
        "Software\\TakeFive Software\\SNiFF+ for Windows\\3.000\\Directories" \
        "ProductDir" \
        "REG_EXPAND_SZ"`
      if [ "$?" != "0" ]; then
        SNIFF_DIR=""
        test "$DEBUG" = "echo" && echo "ReadRegistryValue: ERROR Reading Machine SNIFF_DIR"
      fi
      test "$DEBUG" = "echo" && echo "ReadRegistryValue: Machine SNIFF_DIR=${SNIFF_DIR}<--"
    fi
  fi
fi

if [ "$WIND_BASE" = "" ]; then
  if [ -d "$SNIFF_DIR/../host/resource/tcl" ]; then
    cd "$SNIFF_DIR/.."
    WIND_BASE=`pwd`
  else
    if [ "$SYSTEM" = "Windows" ]; then
      # WINDOWS: Try to get WIND_BASE from the Registry
      WIND_BASE=`"$READ_REGISTRY_VALUE" \
        "HKEY_CURRENT_USER" \
        "Software\\Wind River Systems" \
        "WIND_BASE" \
        "REG_EXPAND_SZ"`
      if [ "$?" != "0" ]; then
        WIND_BASE=""
        test "$DEBUG" = "echo" && echo "ReadRegistryValue: ERROR Reading User WIND_BASE"
      fi
      test "$DEBUG" = "echo" && echo "ReadRegistryValue: User WIND_BASE=${WIND_BASE}<--"
      if [ "$WIND_BASE" = "" ]; then
        WIND_BASE=`"$READ_REGISTRY_VALUE" \
          "HKEY_LOCAL_MACHINE" \
          "SOFTWARE\\Wind River Systems" \
          "WIND_BASE" \
          "REG_EXPAND_SZ"`
        if [ "$?" != "0" ]; then
          WIND_BASE=""
          test "$DEBUG" = "echo" && echo "ReadRegistryValue: ERROR Reading Machine WIND_BASE"
        fi
        test "$DEBUG" = "echo" && echo "ReadRegistryValue: Machine WIND_BASE=${WIND_BASE}<--"
      fi # WIND_BASE still empty
    fi # SYSTEM=Windows
  fi # ../host/resource/tcl don't exist
fi # WIND_BASE empty

# do *not* exit 0 here because this gets sourced from install.sh
