@ECHO OFF
REM
REM sniff.bat - Batch File for starting SNiFF+ tools in managed environment
REM
REM Usage: sniff.bat [bash (or) RegSniff (or) vim]
REM
REM Without parameter, it will set the necessary environment and start SNiFF+.
REM With parameter, it will set environment and call the corresponding app.
REM
REM !!! PLEASE CUSTOMIZE THIS FILE TO YOUR NEEDS, BELOW !!!
REM
REM Description:
REM This file contains all fixed settings for a particular SNiFF+ / Tornado
REM installation. This enables you to run SNiFF+ / Tornado on any workstation
REM without having to set local Variables in the Control Panel. Moreover, it
REM allows you to run multiple different versions of SNiFF+ in parallel by
REM providing different startup batch files.
REM All the User needs to do to start a SNiFF+ tool is call the Batch file,
REM which may in turn be stored on a server.
REM
REM Many Variables can be overridden by a particular Workstation User by
REM Setting them in his Control Panel; here, the IF... clause makes these
REM Variables to have precedence over the site-level sttings fixed in this
REM Batch file.
REM
REM Note: If you are on Windows 95/98 you might need to modify your
REM C:\CONFIG.SYS file to add a line like
REM SHELL=C:\WINDOWS\COMMAND.COM /P /E:8192
REM To provide enough environment space for all variables.
REM
REM (c) WindRiver (R) 2000
REM Author: Martin Oberhuber
REM

REM ----- User Configuration -- Modify to set your personal environment HERE:

REM --- The directory root under which Tornado is installed
REM --- In a standard installation, just having this setting right is enough!
IF "%WIND_BASE%" == "" SET WIND_BASE=C:\Tornado
IF EXIST "%WIND_BASE%\host\x86-win32\bin\tornado.exe" GOTO WIND_BASE_OK
ECHO.
ECHO ERROR setting up environment for Tornado and SNiFF+:
ECHO Cannot find %%WIND_BASE%%\host\x86-win32\bin\tornado.exe
ECHO WIND_BASE is set to %WIND_BASE%
ECHO Please check your WIND_BASE environment variable and try again.
ECHO.
PAUSE
EXIT

:WIND_BASE_OK
IF "%WIND_HOST_TYPE%" == ""  SET WIND_HOST_TYPE=x86-win32
REM IF "%WIND_REGISTRY%" == ""   SET WIND_REGISTRY=localhost

REM --- This is where the VxWorks target files are located, and where the
REM --- Root of the SNiFF+ SSWE for the target is. Overriding this setting
REM --- Allows to use one installation of Tornado Host tools with multiple
REM --- different installations of Tornado Target tools.
IF "%WIND_TARGET_BASE%" == "" SET WIND_TARGET_BASE=%WIND_BASE%\target

REM --- The directory root under which SNiFF+ is installed
IF "%SNIFF_DIR%" == "" SET SNIFF_DIR=%WIND_BASE%\Sniff
IF EXIST "%SNIFF_DIR%\bin\sniff_arch" GOTO SNIFF_DIR_OK
ECHO.
ECHO ERROR setting up environment for Tornado and SNiFF+:
ECHO Cannot find %%SNIFF_DIR%%\bin\sniff_arch
ECHO SNIFF_DIR is set to %SNIFF_DIR%
ECHO Please check your SNIFF_DIR environment variable and try again.
ECHO.
PAUSE
EXIT

:SNIFF_DIR_OK

REM --- SNiFF NEEDS a HOME Environment Variable for the RCS Tools and for BASH!
IF "%HOME%" == "" SET HOME=%HOMEDRIVE%%HOMEPATH%

REM --- The directory where you will store your SNiFF+ User Preferences
REM IF "%SNiFF_RESOURCE_DIR%" == "" SET SNiFF_RESOURCE_DIR=%HOMEDRIVE%%HOMEPATH%\.sniffrc-t2
IF "%SNiFF_RESOURCE_DIR%" == "" SET SNiFF_RESOURCE_DIR=%SNIFF_DIR%\Profiles\%USERNAME%
REM Make sure we get the SN[iI]FF problem with bash on Windows right!
SET SNIFF_RESOURCE_DIR=%SNiFF_RESOURCE_DIR%

REM --- SNiFF+ License file to use: if empty, %SNIFF_DIR%\license.dat is used
REM --- The setting can be port@host or a path to a license file (see example)
REM SET LM_LICENSE_FILE=G:\Server\Licenses\license_combined.dat
REM SET LM_LICENSE_FILE=7594@gkar

REM --- Start up the Slickedit DDE client, yes or no?
REM SET SNIFF_USE_SLICKEDIT=1

REM --- The Editor to be called from Tornado: choose one to use, or
REM --- comment out all of them to use only the Tornado-internal editor
REM --- There are SNiFF integrations for all three editors, so you may
REM --- use any of them and still use SNiFF browsing tools from the Editor
REM SET EDITOR=%SLICK_ROOT%\bin\vslick.exe  REM Visual SlickEdit
REM SET EDITOR=%SNIFF_DIR%\bin\vim.exe      REM VI-Improved, comes with SNiFF
REM SET EDITOR=gnuclientw.exe               REM Emacs -- my personal favorite
REM Call sniffaccess through a shellscript to use the sniff-internal editor
SET EDITOR=%SNIFF_DIR%\bin\sh.exe %SNIFF_DIR%\bin\SniffEditFile.sh

REM --- ONLY if SniffEditFile.sh is used to call SNiFF editor via sniffaccess:
REM --- configure an alternate editor in case SNiFF is not responding
REM SET SNIFF_ALTERNATE_EDITOR=vim.exe
SET SNIFF_ALTERNATE_EDITOR=write.exe

REM --- This is where absolute projects for SNiFF+ are stored. You can move this
REM --- to one common place for all SNiFF+ users and put more than only Tornado parts in here.
IF "%SNIFF_PDF_ROOT%" == "" SET SNIFF_PDF_ROOT=%SNIFF_DIR%\PDFs
IF "%SNIFF_PDF_GEN_ROOT%" == "" SET SNIFF_PDF_GEN_ROOT=%SNIFF_PDF_ROOT%\dot.sniffdirs
IF EXIST "%SNIFF_PDF_ROOT%" GOTO PDF_ROOT_Done
  IF EXIST "%SNIFF_DIR%\PDFs" GOTO PDF_SRC_Done
    ECHO WARNING: SNIFF_PDF_ROOT set to non-existing Directory.
  GOTO PDF_ROOT_Done
:PDF_SRC_Done
IF "%SNIFF_DIR%\PDFs" == "%SNIFF_PDF_ROOT%" GOTO PDF_ROOT_Done
  ECHO Copying SNiFF+ Project Descriptions to your local Workspace.
  ECHO This needs to be done only once unless you remove the target directory.
  ECHO xcopy /s "%SNIFF_DIR%\PDFs" "%SNIFF_PDF_ROOT%\"
  xcopy /s /q "%SNIFF_DIR%\PDFs" "%SNIFF_PDF_ROOT%\"
:PDF_ROOT_Done

REM --- This is where the SNiFF+ Example files reside. On Windows, this is
REM --- typically inside the SNiFF+ Installation.
IF "%SNIFF_EXAMPLE_ROOT%" == "" SET SNIFF_EXAMPLE_ROOT=%SNIFF_DIR%\example
IF EXIST "%SNIFF_EXAMPLE_ROOT%\Tornado" GOTO Exam_ROOT_Done
  IF EXIST "%SNIFF_DIR%\example\Tornado" GOTO Exam_SRC_Done
    ECHO WARNING: SNIFF_EXAMPLE_ROOT set to non-existing Directory.
    GOTO :Exam_ROOT_Done
:Exam_SRC_Done
  ECHO Copying SNiFF+ Example Files to your local Workspace.
  ECHO This needs to be done only once unless you remove the target directory.
  ECHO xcopy /s /q "%SNIFF_DIR%\example\Tornado" "%SNIFF_EXAMPLE_ROOT%\"
  xcopy /s /q "%SNIFF_DIR%\example\Tornado" "%SNIFF_EXAMPLE_ROOT%\"
:Exam_ROOT_Done
IF "%SNIFF_EXAMPLE_RWE%" == ""   SET SNIFF_EXAMPLE_RWE=%SNIFF_EXAMPLE_ROOT%\Tornado\2_Gizmo\RWE


REM --- Settings that influence a running SNiFF+ but are usually disabled.
REM --- ask mailto:sniff-support@takefive.com for info
REM SET CLASSPATH=
REM SET VCSDEBUG=1
REM SET SNiFF_USE_CACHE=1
REM SET SNiFF_FILES_NEEDED=1
REM SET SNiFF_ALLDEPS_NEEDED=1
REM SET SNIFFCONSOLE=2

REM ----- User Configuration ENDS -- no modifications below this line

:GeneralConfig
REM ----------------------------------------------------------
REM Tornado General Settings
REM ----------------------------------------------------------
SET PATH=%WIND_BASE%\host\%WIND_HOST_TYPE%\bin;%PATH%
REM ----------------------------------------------------------
REM SNiFF+ General Settings
REM ----------------------------------------------------------
IF "%PLATFORM%" == ""            SET PLATFORM=i386-unknown-win32
REM Unset MKS environment variables -- not needed for SNiFF+ 3.1 and above
REM SET ROOTDIR=
REM BASH is faster
REM SET SHELL=%SNIFF_DIR%\bin\bash.exe
SET SHELL=%SNIFF_DIR%\bin\sh.exe
SET ENV=%SNIFF_DIR%\config\environ.ksh
SET PATH=%SNIFF_DIR%\bin;%PATH%
SET VIM=%SNIFF_DIR%\config\vim
REM This setting is only needed by SNiFF+ Tornado Make bridge to get access
REM to SNiFF+ host specific rules even if $PLATFORM is modified to reflect
REM the target platform
SET SNIFF_HOST_TYPE=%PLATFORM%
REM ----------------------------------------------------------
REM End of Configuration setting -- SNiFF+ tool startup begins

echo Starting %1 ....
echo SNIFF_DIR is set to %SNIFF_DIR%
echo.
echo PATH is set to %PATH%
echo.
IF "%1" == "RegSniff" Goto RegSniff
IF "%1" == "bash" Goto Bash
IF "%1" == "vim" Goto Vim
IF "%1" == "Tornado" Goto Tornado
IF "%1" == "EnvOnly" Goto End
IF "%1" == "EnvironOnly" Goto End

REM SNIFF_DIR is now set -- start SNiFF

IF "%SNIFF_USE_SLICKEDIT%" == "1" start "%SNIFF_DIR%\bin\SniffToSlickedit.exe"

echo SNiFF+ is now starting. Once you see the LaunchPad, you can close
echo this startup window. Note: To automate closing the Window, you can
echo also configure your Windows Shortcut to this file as "close on exit".

REM Start SNiFF on Windows NT
REM PATH is already set: if we have spaces in dirnames, this is the only
REM way to start a program in background!
REM IF "%OS%"=="Windows_NT" start /wait Sniff.exe %1 %2 %3 %4 %5 %6 %7 %8 %9
IF "%OS%"=="Windows_NT" start Sniff.exe %1 %2 %3 %4 %5 %6 %7 %8 %9

REM Start SNiFF on Windows 95
REM IF "%OS%"=="" start -w Sniff.exe %1 %2 %3 %4 %5 %6 %7 %8 %9
IF "%OS%"=="" start Sniff.exe %1 %2 %3 %4 %5 %6 %7 %8 %9

GOTO End

:RegSniff
"%SNIFF_DIR%\bin\RegSniff.exe" %2 %3 %4 %5 %6 %7 %8 %9
GOTO End

:Bash
"%SNIFF_DIR%\bin\bash.exe" --posix -i %2 %3 %4 %5 %6 %7 %8 %9
GOTO End

:Vim
start "%SNIFF_DIR%\bin\vim.exe" %2 %3 %4 %5 %6 %7 %8 %9
GOTO End

:Tornado
start "%WIND_BASE%\host\%WIND_HOST_TYPE%\bin\Tornado.exe" %2 %3 %4 %5 %6 %7
GOTO End

:End
