#
# sample cshrc to run SNiFF+ together with Tornado for csh/tcsh users.
# 
# Customize this file to your needs and either
# - merge it with your $HOME/.cshrc to to allow running SNiFF+ from startup or
# - source this file before starting SNiFF+ or Tornado.
#

######################################################
# Begin of User Customization Section

##### Tornado Default Settings
if ( ! $?WIND_BASE )      setenv WIND_BASE /opt/wind
if ( ! -f ${WIND_BASE}/host/resource/wind_host_type ) then
    echo ""
    echo "ERROR setting up environment for Tornado and SNiFF+:"
    echo 'Cannot find $WIND_BASE/host/resource/wind_host_type'
    echo "WIND_BASE is set to ${WIND_BASE}"
    echo 'Please check your $WIND_BASE environment variable and try again!'
    exit 1
endif

if ( ! $?WIND_HOST_TYPE ) setenv WIND_HOST_TYPE `${WIND_BASE}/host/resource/wind_host_type`
if ( ! $?WIND_REGISTRY )  setenv WIND_REGISTRY localhost

# This is where the VxWorks target files are located, and where the
# Root of the SNiFF+ SSWE for the target is. Overriding this setting
# Allows to use one installation of Tornado Host tools with multiple
# different installations of Tornado Target tools.
if ( ! $?WIND_TARGET_BASE ) setenv WIND_TARGET_BASE ${WIND_BASE}/target

##### SNiFF+ Settings
if ( ! $?SNIFF_DIR )      setenv SNIFF_DIR ${WIND_BASE}/sniff
if ( ! -f ${SNIFF_DIR}/bin/sniff_arch ) then
    echo ""
    echo "ERROR setting up environment for Tornado and SNiFF+:"
    echo 'Cannot find $SNIFF_DIR/bin/sniff_arch'
    echo "SNIFF_DIR is set to ${SNIFF_DIR}"
    echo 'Please check your $SNIFF_DIR environment variable and try again!'
endif

# Explicitly set SNiFF_RESOURCE_DIR to have T2 separate from regular sniff
if ( ! $?SNiFF_RESOURCE_DIR ) then
    #setenv SNiFF_RESOURCE_DIR "${HOME}/.sniffrc-t2"
    setenv SNiFF_RESOURCE_DIR "${HOME}/.sniffrc"
endif
setenv SNIFF_RESOURCE_DIR "${SNiFF_RESOURCE_DIR}"

# Set sniffaccess / edit_file as the main editor
setenv EDITOR "${SNIFF_DIR}/bin/SniffEditFile.sh"

# The Editor to be called if sniffaccess doesn't work
setenv SNIFF_ALTERNATE_EDITOR vi

# End of User Customization Section
######################################################

## Tornado Automatic Settings
setenv LD_LIBRARY_PATH ${WIND_BASE}/host/${WIND_HOST_TYPE}/lib
setenv PATH ${WIND_BASE}/host/${WIND_HOST_TYPE}/bin:${PATH}

## SNiFF+ Automatic Settings
if ( ! $?PLATFORM )       setenv PLATFORM `${SNIFF_DIR}/bin/sniff_arch`
setenv PATH ${SNIFF_DIR}/bin:${PATH}

## Integration stuff
# We build via the sniffmake alias in order to call SNiFF gmake on Windows
# but Tornado make on UNIX
alias sniffmake '${WIND_BASE}/host/${WIND_HOST_TYPE}/bin/make'
alias sm 'sniffmake -fMakefile_sniff'
alias smd 'sniffmake -fMakefile_sniff DEBUG=1'

# The SNIFF_HOST_TYPE is used for host-specific precompilers on all targets
setenv SNIFF_HOST_TYPE ${PLATFORM}

# This is where absolute projects for SNiFF+ are stored. You can move this
# to one common place for all SNiFF+ users and put more than only Tornado parts in here.
if ( ! $?SNIFF_PDF_ROOT )     setenv SNIFF_PDF_ROOT ${SNIFF_DIR}/PDFs
if ( ! $?SNIFF_PDF_GEN_ROOT ) setenv SNIFF_PDF_GEN_ROOT ${SNIFF_PDF_ROOT}/dot.sniffdirs
if ( ! -d "${SNIFF_PDF_ROOT}" ) then
  if ( -d "${SNIFF_DIR}/PDFs" ) then
    echo "Copying SNiFF+ Project Descriptions to your local Workspace."
    echo "This needs to be done only once unless you remove the target directory."
    echo "mkdir -p ${SNIFF_PDF_ROOT}"
    mkdir -p "${SNIFF_PDF_ROOT}"
    echo "cp -R ${SNIFF_DIR}/PDFs/* ${SNIFF_PDF_ROOT}"
    cp -R ${SNIFF_DIR}/PDFs/* "${SNIFF_PDF_ROOT}"
  else
    echo "WARNING: SNIFF_PDF_ROOT set to non-existing Directory!"
  endif
endif
 
if ( ! $?SNIFF_EXAMPLE_ROOT ) setenv SNIFF_EXAMPLE_ROOT ${SNIFF_DIR}/example
if ( ! -d "${SNIFF_EXAMPLE_ROOT}/Tornado" ) then
  if ( -d "${SNIFF_DIR}/example/Tornado" ) then
    echo "Copying SNiFF+ Example Files to your local Workspace."
    echo "This needs to be done only once unless you remove the target directory."
    if ( ! -d "${SNIFF_EXAMPLE_ROOT}" ) then
        echo "mkdir -p ${SNIFF_EXAMPLE_ROOT}"
        mkdir -p "${SNIFF_EXAMPLE_ROOT}"
    endif
    echo "cp -R ${SNIFF_DIR}/example/Tornado ${SNIFF_EXAMPLE_ROOT}"
    cp -R "${SNIFF_DIR}/example/Tornado" "${SNIFF_EXAMPLE_ROOT}"
  else
    echo "WARNING: SNIFF_EXAMPLE_ROOT set to non-existing Directory."
  endif
endif

# This is where the Repository for Example projects is found
if ( ! $?SNIFF_EXAMPLE_RWE ) then
    setenv SNIFF_EXAMPLE_RWE ${SNIFF_EXAMPLE_ROOT}/Tornado/2_Gizmo/RWE
endif

