#
# sample script to run SNiFF+ together with Tornado for sh/ksh/bash/zsh users.
#
# Customize this file to your needs and either
# - Merge it into your $HOME/.profile to allow running SNiFF+ from startup or
# - source ( . sample.profile ) before starting SNiFF+ or Tornado.
#

######################################################
# Begin of User Customization Section

##### Tornado Settings
if [ "$WIND_BASE" = "" ]; then
    WIND_BASE=/opt/wind
fi
if [ ! -f "$WIND_BASE/host/resource/wind_host_type" ]; then
    echo ""
    echo "ERROR setting up environment for Tornado and SNiFF+:"
    echo 'Cannot find $WIND_BASE/host/resource/wind_host_type'
    echo "WIND_BASE is set to $WIND_BASE"
    echo 'Please check your $WIND_BASE environment variable and try again!'
    exit 1
fi
if [ "$WIND_HOST_TYPE" = "" ]; then
    WIND_HOST_TYPE=`$WIND_BASE/host/resource/wind_host_type`
fi
if [ "$WIND_REGISTRY" = "" ]; then
    WIND_REGISTRY=localhost
fi
# This is where the VxWorks target files are located, and where the
# Root of the SNiFF+ SSWE for the target is. Overriding this setting
# Allows to use one installation of Tornado Host tools with multiple
# different installations of Tornado Target tools.
if [ "$WIND_TARGET_BASE" = "" ]; then
    WIND_TARGET_BASE=$WIND_BASE/target
fi

export WIND_BASE WIND_HOST_TYPE WIND_REGISTRY WIND_TARGET_BASE

##### SNiFF+ Settings
if [ "$SNIFF_DIR" = "" ]; then
    SNIFF_DIR=$WIND_BASE/sniff
fi
if [ ! -f "$SNIFF_DIR/bin/sniff_arch" ]; then
    echo ""
    echo "ERROR setting up environment for Tornado and SNiFF+:"
    echo 'Cannot find $SNIFF_DIR/bin/sniff_arch'
    echo "SNIFF_DIR is set to $SNIFF_DIR"
    echo 'Please check your $SNIFF_DIR environment variable and try again!'
fi

# Explicitly set SNiFF_RESOURCE_DIR to have T2 separate from regular sniff
if [ "$SNiFF_RESOURCE_DIR" = "" ]; then
  #SNiFF_RESOURCE_DIR=$HOME/.sniffrc-t2
  SNiFF_RESOURCE_DIR=$HOME/.sniffrc
fi
SNIFF_RESOURCE_DIR=$SNiFF_RESOURCE_DIR
export SNIFF_DIR SNiFF_RESOURCE_DIR SNIFF_RESOURCE_DIR 

# Set sniffaccess / edit_file as the main editor
EDITOR="$SNIFF_DIR/bin/SniffEditFile.sh"
# The Editor to be called if sniffaccess doesn't work
SNIFF_ALTERNATE_EDITOR=vi
export EDITOR SNIFF_ALTERNATE_EDITOR

# End of User Customization Section
######################################################

## Tornado Automatic Settings
LD_LIBRARY_PATH=$WIND_BASE/host/$WIND_HOST_TYPE/lib
PATH=$WIND_BASE/host/$WIND_HOST_TYPE/bin:$PATH
export LD_LIBRARY_PATH PATH

## SNiFF+ Automatic Settings
if [ "$PLATFORM" = "" ]; then
    PLATFORM=`$SNIFF_DIR/bin/sniff_arch`
fi
PATH=$SNIFF_DIR/bin:$PATH
export PLATFORM PATH

## Integration stuff
# We build via the sniffmake alias in order to call SNiFF gmake on Windows
# but Tornado make on UNIX
alias sniffmake='$WIND_BASE/host/$WIND_HOST_TYPE/bin/make'
alias sm='sniffmake -fMakefile_sniff'
alias smd='sniffmake -fMakefile_sniff DEBUG=1'

# The SNIFF_HOST_TYPE is used for host-specific precompilers on all targets
SNIFF_HOST_TYPE=$PLATFORM

# This is where absolute projects for SNiFF+ are stored. You can move this
# to one common place for all SNiFF+ users and put more than only Tornado parts in here.
if [ "$SNIFF_PDF_ROOT"="" ]; then
    SNIFF_PDF_ROOT=$SNIFF_DIR/PDFs
fi
if [ "$SNIFF_PDF_GEN_ROOT"="" ]; then
    SNIFF_PDF_GEN_ROOT=$SNIFF_PDF_ROOT/dot.sniffdirs
fi
if [ ! -d "$SNIFF_PDF_ROOT" ]; then
  if [ -d "$SNIFF_DIR/PDFs" ]; then
    echo "Copying SNiFF+ Project Descriptions to your local Workspace."
    echo "This needs to be done only once unless you remove the target directory."
    echo "mkdir -p $SNIFF_PDF_ROOT"
    mkdir -p "$SNIFF_PDF_ROOT"
    echo "cp -R $SNIFF_DIR/PDFs/* $SNIFF_PDF_ROOT"
    cp -R $SNIFF_DIR/PDFs/* "$SNIFF_PDF_ROOT"
  else
    echo "WARNING: SNIFF_PDF_ROOT set to non-existing Directory."
  fi
fi

if [ "$SNIFF_EXAMPLE_ROOT" = "" ]; then
    SNIFF_EXAMPLE_ROOT="$SNIFF_DIR/example"
fi
if [ ! -d "$SNIFF_EXAMPLE_ROOT/Tornado" ]; then
  if [ -d "$SNIFF_DIR/example/Tornado" ]; then
    echo "Copying SNiFF+ Example Files to your local Workspace."
    echo "This needs to be done only once unless you remove the target directory."
    if [ ! -d "$SNIFF_EXAMPLE_ROOT" ]; then
      echo "mkdir -p $SNIFF_EXAMPLE_ROOT"
      mkdir -p "$SNIFF_EXAMPLE_ROOT"
    fi
    echo "cp -R $SNIFF_DIR/example/Tornado $SNIFF_EXAMPLE_ROOT"
    cp -R "$SNIFF_DIR/example/Tornado" "$SNIFF_EXAMPLE_ROOT"
  else
    echo "WARNING: SNIFF_EXAMPLE_ROOT set to non-existing Directory."
  fi
fi

# This is where the Repository for Example projects is found
if [ "$SNIFF_EXAMPLE_RWE" = "" ]; then
    SNIFF_EXAMPLE_RWE="$SNIFF_EXAMPLE_ROOT/Tornado/2_Gizmo/RWE"
fi

export SNIFF_HOST_TYPE SNIFF_PDF_ROOT SNIFF_PDF_GEN_ROOT 
export SNIFF_EXAMPLE_ROOT SNIFF_EXAMPLE_RWE
