#!/bin/sh
#
## NAME
##      CleanSniff - Clean up a linked (Project-Level) SNiFF+ installation
##
## SYNOPSIS
##      CleanSniff.sh [-l] <sniff_dir>
##
## DESCRIPTION
##      This command will remove any symbolic links and intermediate files
##      of a SNiFF+ installation.
##      After cleaning up, you can easily tar the rest of the files to
##      create a snapshot of the local changes made in your SNiFF installation
##      (see also PackSniffChanges for how to do this in a live SNiFF workspace
##      without having to remove stuff).
##      You can use LinkSniffOver to to re-create symbolic links.
##
## PARAMETERS
##      <sniff_dir>  Absolute or relative path pointing to the SNiFF+
##                   installation directory you want to clean up.
##
## OPTIONS
##      -l           If given, clean symbolic links as well; else, leave
##                   symbolic links intact
##
## AUTHOR
##      Martin Oberhuber, (c) 1999 TakeFive Software GmbH
##
## SEE ALSO
##      LinkSniffOver, PackSniffChanges
##

if [ $# -lt 1 -o "$1" = "-h" ]; then
    # Print Usage information
    grep '^##' $0 | cut -c4-
    exit 0
fi

if [ "$1" = "-l" ]; then
	DoCleanLinks=1
	shift
fi
theDir=${1:?"Error, Directory missing"}

curDir=`pwd`
cd $theDir
if [ "$DoCleanLinks" = "1" ]; then
	echo "Cleaning symbolic links (this may take a while) ..."
	# With -exec it is slower, but we won't get over-full command line
	find . -type l -exec rm {} \;
else
	echo "NOT cleaning symbolic links: use switch "-l" to clean symLinks, too"
fi

echo "Cleaning .sniffdirs ..."
rm -f `find . -name '.[sS]niff*' -o -name .ProjectCache -o -name .RetrieverIndex`
echo "Cleaning Python Objects and Backup Files ..."
rm -f `find . -name '*.py[oc]' -o -name '*[%~]'`

echo "Cleaning empty directories ..."
for d in `find . -type d`
do
	case $d in
	.)  # don't do anything in toplevel directory
	    continue
		;;
	*)  if [ ! -d $d ]; then
			# it was already removed through rm -rf before
			continue;
		fi
		theFiles=`find $d -type f | wc | cut -c-8`
		if [ $theFiles = 0 ]; then
			# echo "theFiles: $theFiles"
		    echo "rm -rf $d"
		    rm -rf $d
		fi
		;;
	esac
done	   
echo "Done."

cd $curDir
exit 0
