#!/bin/sh
#
## NAME
##      PackSniffChanges - Pack changes to a SNiFF installation into a tarfile
##
## SYNOPSIS
##      PackSniffChanges.sh <sniff_dir> <tarfile>
##
## DESCRIPTION
##      This command will create a tar archive of all files in a local SNiFF+
##      installation which are known not to be intermediate or backup files,
##      and which are newer than the file "install.date" in the SNiFF+
##      installation root directory.
##
##      If the file "install.date" does not exist, all regular files which
##      are not intermediate or backup files will be packed into the tarball.
##
##      You can use "LinkSniffOver" to re-create a linked SNiFF installation
##      from the tarball.
##
## PARAMETERS
##      <sniff_dir>  Absolute or relative path pointing to the SNiFF+
##                   installation directory you want to pack
##      <tarfile>    Absolute or relative path to the destination tarfile
##
## AUTHOR
##      Martin Oberhuber, (c) 1999 TakeFive Software GmbH
##
## SEE ALSO
##      CleanSniff, LinkSniffOver
##

if [ $# != 2 -o "$1" = "-h" ]; then
    # Print Usage information
    grep '^##' $0 | cut -c4-
    exit 0
fi

sniffDir=${1:?"Error, missing sniff_dir"}
tarFile=${2:?"Error, missing tarfile"}
curDir=`pwd`

case $tarFile in
 /*) ;;
 *)  tarFile=$curDir/$tarFile ;;
esac
 
cd $sniffDir

if [ -f install.date ]; then
	findParm="-type f -newer install.date"
else
	findParm="-type f"
fi
fileList=`find . $findParm -print \
	| grep -v '/\.[sS]niff' \
    | grep -v '/\.ProjectCache' | grep -v '/\.RetrieverIndex' \
    | grep -v '[%~]$' | grep -v '\.py[oc]$' \
    | grep -v '/filebrowser/filebrowser$' | grep -v '\.[oa]$' `

echo $fileList
tar cfv $tarFile $fileList

cd $curDir
exit 0
