from etgui import *
#import CmdNo,string
import regex
from PageLayout import *
from ListEditor import AbstrListEditor

class ListBox(AbstrListEditor):
	"""A class for displaying a list of strings"""
	def __init__(self):
		self.items=[]
		AbstrListEditor.__init__(self)
	def ListChanged(self):
		pass
	def DoSetItems(self,items):
		self.items=items
		return items
	def DoGetItems(self):
		return self.items
	def DoMakeItem(self,v):
		return TextItem(str(v))
	def DoInsert(self,i,v):
		self.items.insert(i,v)
		self.ListChanged()
		return i

class FilteredListBox(ListBox):
	"""Listbox with an additional Regex Filter to limit display.
	The Regex Filter is applied anew with every character that is typed.
	This gives reasonable Performance up to listboxes with ~2000 elements."""
	def __init__(self,model,FilterSlot="ListBoxFilter"):
		self.model=model
		self.FilterSlot=FilterSlot
		self.items=[]
		self.filteredItems=[]
		self.model.SetValue(self.FilterSlot,"")
		self.model.AddModelObserver(self.Observe,self.FilterSlot)
		ListBox.__init__(self)
	def Observe(self,model,path):
		if path==self.FilterSlot:
			self.ObserveFilterChange(model,path)
	def ObserveFilterChange(self,model,path):
#		print 'Observe',self._GetCollView().IsOpen(), `path`
		self.SetItems(self.items)
		self.ListChanged()
	def DoSetItems(self,items):
		self.items=items
		theFilter=self.model.GetValue(self.FilterSlot)
		if not theFilter:
			self.filteredItems=self.items
		else:
			try:
				patt=regex.compile(theFilter, regex.casefold)
			except:
				# premature end or illegal regex: return same filtered items as before
				return self.filteredItems
			self.filteredItems=[]
			for i in self.items:
				if patt.search(i)>=0:
					self.filteredItems.append(i)
#			print "filter: ",theFilter,": ",self.filteredItems
#		print "filterLen: ",len(self.filteredItems)
		return self.filteredItems
	def GetSelection(self):
		try:
			return self.filteredItems[self.GetSelected()]
		except:
			return None
	def MakeCollView(self,scrollersize=None):
		return VBox(
			align=eVObjHExpand|eVObjVExpand,
			items=[
				MakeSectionLayout(
					Form(
						items=[
							"Filter", PotTextField(self.FilterSlot,1)
						]
					)
				),
				ListBox.MakeCollView(self,scrollersize)
			]
		)

def ListBoxDialog(theText, theItems, theHeader="Selection", useFilter=1, theDefault=-1):
	model = PotGuiModel()
	if useFilter:
		lb = FilteredListBox(model)
	else:
		lb = ListBox()
	lb.SetItems(theItems)
	if theDefault >= 0:
		lb.Select(theDefault)
	dialog=PotGuiDialog(
		model,
		MakeDialogWithButtons(
			MakeSectionLayout(
				MultilineTextItem(theText),
				lb.MakeCollView()
			),
			#ActionButton(CmdNo.cIdOk,"OK",default=1),
			ActionButton(CmdNo.cIdOk,"OK"),
			ActionButton(CmdNo.cIdCancel,"Cancel"),
		),
		theHeader,
		#eWinDefault
		eWinBlock
	)
	res=dialog.ShowUnderMouse()
	if res==CmdNo.cIdOk:
		return lb.GetSelection()
	else:
		return None

if __name__=="__main__":
	items=[
		"-I.",
		"Michael",
		"-I..",
		"Test",
		"-Test",
		"AHA",
	]
	for i in range(8):
		items = items + items
	rv = ListBoxDialog("\nMake your Selection:\n",items)
	print "rv=",rv
