##################################################################
# SNiFF+ and Tornado Integration Project
# basic support routines
#
# File Version:
# $Id: torBaseServices.py,v 1.17 2000/04/21 15:31:50 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Adapter History:
# - 0.01 file creation-  02/02/2000
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import os, sys, string

# import some SNiFF+ services
import vcs
import etgui
import searchPathLib

# import basic constants
import torConstants
from torConstants import false, true

# **** create a default instance of the torDataServiceHandler ****
defaultTorPrefsFileHandler = None

# **** create a default instance of the torTgtSvrHandler ****
defaultTorTgtSvrHandler = None

# message box wrapper
import torMessageBox

# import Windows Registry methods
import torWinRegistryInterface

# **** common helper functions ****

def getHostName():
	return vcs.getoutput("hostname")

# function returns the default handler of the
# integration preferences file
def getDefaultPrefsFileHandler():
	global defaultTorPrefsFileHandler
	if defaultTorPrefsFileHandler == None:
		# persistent data module
		import torDataServices
		defaultTorPrefsFileHandler = torDataServices.torDataServiceHandler()
	if defaultTorPrefsFileHandler != None:
		if sys.platform == "win32":
			# write the WIND_REGISTRY setting to the torIntPrefs.sniff File
			regInterface = torWinRegistryInterface.getWinRegistryInterfaceHandle()
			rc, windRegistryValue = regInterface.ReadRegistryValue("HKEY_CURRENT_USER", r"Software\Wind River Systems\Tornado 2.0", "WIND_REGISTRY", "REG_EXPAND_SZ")
			if rc == 0 and windRegistryValue != None:
				defaultTorPrefsFileHandler.setWindRegistrySlot(windRegistryValue)
			else:
				defaultTorPrefsFileHandler.setWindRegistrySlot("")
		else:
			# set it empty on Unix
			defaultTorPrefsFileHandler.setWindRegistrySlot("")
	return defaultTorPrefsFileHandler

# function returns the default handler of the
# Tornado Target Server Handler
def getDefaultTgtSvrHandler():
	global defaultTorTgtSvrHandler
	if defaultTorTgtSvrHandler == None:
		# target server module
		import torTgtSvrServices
		defaultTorTgtSvrHandler = torTgtSvrServices.torTgtSvrHandler()
	return defaultTorTgtSvrHandler

def doSniffAccess(*args):
	# call sniffaccess using the python interface
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x DoSniffAccess@B" % __name__
	try:
		stringArgs = string.join(map(str, args), " ")
		if torConstants.DEBUG:
			print "(%s)    @B\tstringArgs = %s" % (__name__, torConstants.filterUnprintable(stringArgs))
		result = etgui.Sniffaccess(stringArgs)
	except etgui.SniffAccessError, result:
		print "(%s)    @Bsniffaccess call @rfailed@x !@B result was: '%s'" % (__name__, result)
		#torMessageBox.messageBox("sniffaccess call failed ! Open the log window to see further details !", "Sniffaccess failure", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x DoSniffAccess@B" % __name__
	return result

# **** Tornado Integration Helper fucntions ****

# function returns the host type for ths machine
# we are on
#	on Unix .... $WIND_BASE/host/resource/wind_host_type is used
#   on Windows ... x86-win32 is returned
def getWindHostType():
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x getWindHostType@B" % __name__
	wind_host_type = "x86-win32"
	if os.environ.has_key("WIND_HOST_TYPE"):
		wind_host_type = os.environ["WIND_HOST_TYPE"]
	else:
		if sys.platform != "win32":
			# seems we are on Unix
			import torLaunchServices
			rc, _out = torLaunchServices.AbstractToolLauncher().startProcess("%s" % vcs.joinpath(os.environ["WIND_BASE"], "host", "resource", "wind_host_type"))
			if rc == 0:
				wind_host_type = _out
			else:
				wind_host_type = "invalid"
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x getWindHostType@B" % __name__
	return string.strip(wind_host_type)

# function calculates the default simulator image path
def getDefaultSimulatorImagePath():
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x getDefaultSimulatorImagePath@B" % __name__
	ImagePath=""
	if sys.platform == "win32":
		# Windows 95/98/NT
		ImagePath=os.path.normpath(os.path.join(os.environ["WIND_BASE"], "target", "config", "simpc", "VxWorks.exe"))
	else:
		# Unix
		thePlatform="UNIX"
		try:
			HOST_TYPE=getWindHostType()
			if HOST_TYPE == "sun4-sunos4":
				thePlatform="sunos"
			elif HOST_TYPE[:11] == "parisc-hpux":
				thePlatform="hpux"
			elif HOST_TYPE == "sun4-solaris2":
				thePlatform="solaris"
			else:
				if torConstants.DEBUG:
					print "(%s)    ERROR: unknown WIND_HOST_TYPE '%s'" % (__name__, HOST_TYPE)
		except:
			if torConstants.DEBUG:
				print "(%s)    Exception determining HOST_TYPE" % __name__
		ImagePath = os.path.normpath(os.path.join(os.environ["WIND_BASE"], "target", "config", thePlatform, "vxWorks"))
	st = vcs.get_stat(ImagePath)
	if not vcs.test_exists(st):
		torMessageBox.messageBox("No vxWorks simulator found in '%s' !" % ImagePath, "Simulator Not Found ERROR:", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
	if torConstants.DEBUG:
		print "(%s)    returned ImagePath: %s" % (__name__, ImagePath)
		print "(%s)@B@r<<<@x getDefaultSimulatorImagePath@B" % __name__
	return ImagePath

# function returns the last simulator image path used
#	- use "$WIND_BASE/.wind/.vxsim_last_stared" on Unix
def getLastSimulatorImagePath():
	#	- use registry simulator lastImageLaunched if available
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x getLastSimulatorImagePath@B" % __name__
	ImagePath=""
	if sys.platform == "win32":
		# Windows 95/98/NT
		# read the registry
		regInterface = torWinRegistryInterface.getWinRegistryInterfaceHandle()
		rc, ImagePath = regInterface.ReadRegistryValue("HKEY_CURRENT_USER", r"Software\Wind River Systems\Tornado 2.0\Tornado\Simulator", "lastImageLaunched", "REG_EXPAND_SZ")
		if ImagePath == None:
			ImagePath = ""
	else:
		# Unix
		ImagePath = ""
		try:
			ImagePath=vcs.normpath(string.strip(open(vcs.joinpath(os.environ["HOME"],".wind",".vxsim_last_started")).read()))
			if ImagePath == None:
				ImagePath = ""
		except:
			pass
	if torConstants.DEBUG:
		print "(%s)    returned ImagePath: %s" % (__name__, ImagePath)
		print "(%s)@B@r<<<@x getLastSimulatorImagePath@B" % __name__
	return ImagePath

# function returns if the given ImagePath is the default Image
# rc = true ... is the default simulator
# rc = false ... is not the default simulator
def simIsDefault(imagePath):
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x simIsDefault@B" % __name__
	rc = false
	defaultImagePath = getDefaultSimulatorImagePath()
	if string.lower(string.strip(vcs.normpath(imagePath))) == string.lower(string.strip(vcs.normpath(defaultImagePath))):
		rc = true
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x isFullSimInstalled (rc = %d)@B" % (__name__, rc)
	return rc

# function returns the availability of the full VxWorks simulator
# rc = false ... no full simulator
# rc = true ... full simulator
def isFullSimInstalled():
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x isFullSimInstalled@B" % __name__
	rc = false
	# the file $(WIND_BASE)/target/config/simpc/fullSimInstalled.flag must exist
	filePath=os.path.normpath(os.path.join(os.environ["WIND_BASE"], "target", "config", "simpc", "fullSimInstalled.flag"))
	if os.path.isfile(filePath) and os.path.exists(filePath):
		rc = true
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x isFullSimInstalled (rc = %d)@B" % (__name__, rc)
	return rc

# function tries to locate a given file in the SNiFF+ 
def locateFile(fileName, relativeDirectory = ""):
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x locateFile@B" % __name__
		print "(%s)    fileName: %s" % (__name__, fileName)
		print "(%s)    relativeDirectory: %s" % (__name__, relativeDirectory)
	realFileLocation = None
	testPath = vcs.joinpath(searchPathLib.getUsersProfileDir(), relativeDirectory, fileName)
	if os.path.exists(testPath):
		realFileLocation = testPath
	else:
		testPath = vcs.joinpath(searchPathLib.getSniffDir(), relativeDirectory, fileName)
		if os.path.exists(testPath):
			realFileLocation = testPath
	if torConstants.DEBUG:
		print "(%s)    realFileLocation: " % __name__, realFileLocation
		print "(%s)@B@r<<<@x locateFile@B" % __name__
	return realFileLocation

