##################################################################
# SNiFF+ and Tornado Integration Project
# services routines for storing and reading static and
# dynamic integration config files
#
# File Version:
# $Id: torDataServices.py,v 1.11 2000/04/21 15:36:56 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Adapter History:
# - 0.01 file creation-  02/04/2000
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string
from stat import *

# import SNiFF+ GUI interface
from etgui import *
from PageLayout import *
import vcs
import searchPathLib

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Services

# import Tornado integration helper
import torMessageBox

class torDataServiceHandler:
	# class privates
	# model storage
	__currentUserPrefsModel = None
	__currentUserPrefsModelMTime = 0
	
	# prefs file name strorage
	__prefsFileDir = None
	__prefsFileBaseName = None

	# **** constructors and common helper methods ****
	
	# constructor
	# default location is SNiFF+ User Profile Dir
	# default base name is torConstants.prefsFileBaseName
	def __init__(self, prefsFileDir = searchPathLib.getUsersProfileDir(), prefsFileBaseName = torConstants.prefsFileBaseName):
		self.__prefsFileDir = prefsFileDir
		self.__prefsFileBaseName = prefsFileBaseName

	# method returns the absolute pathname for the
	# preferences file encapsulated in this Handler
	def __getFullPrefsFileName(self):
		return vcs.joinpath(self.__prefsFileDir, self.__prefsFileBaseName)

	# **** basic data service methods ****

	# method dumps the given data model and writes the result
	# to the given integration preferences file
	# method is PRIVATE
	def __writeConfigFile(self, fileName, dataModel, titleComment = "//Any:AnyPrettyIO\n"):
		rc = true
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __writeConfigFile@B" % __name__
		# check, if the file itself exits
		if os.path.isfile(fileName) and os.path.exists(fileName):
			# remove the file for safety
			# some file attribute combinations can
			# lead to a permission error in the following open operation
			vcs.rm_fr(fileName)
		# open file for writing
		configFile = open(fileName, "w")
		if configFile != None:
			# Ok, we got the file Object
			configFile.write(titleComment)
			if dataModel != None:
				dataDump = dataModel.DumpModel()
				configFile.write(dataDump)
			configFile.close()
		else:
			rc = false
			if torConstants.DEBUG:
				print "(%s)    config file @B'%s'@B could not opened !" % fileName
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __writeConfigFile@B" % __name__
		return rc

	# method reads the given integration prefs file and
	# undump the model stored in that file
	# method is PRIVATE
	def __readConfigFile(self, fileName):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __readConfigFile@B" % __name__
		rc = false
		dataModel = None
		if os.path.exists(fileName):
			configFile = open(fileName, "r")
			if configFile != None:
				dataDump = configFile.read()
				configFile.close()
				dataModel = PotGuiModel()
				dataModel.UnDumpModel(dataDump)
				rc = true
			else:
				if torConstants.DEBUG:
					print "(%s)    config file @B'%s'@B could not opened !" % fileName
		else:
			if torConstants.DEBUG:
				print "(%s)    config file @B'%s'@B could not read !" % fileName
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __readConfigFile@B" % __name__
		return rc, dataModel

	# **** methods to manage the global integration preferences model ****

	# method returns the current integration prefs data model
	# it checks the memory data model timestamp against the 
	# integration prefs file timestamp and reloads the model if
	# necessary
	# method is PUBLIC
	def torGetPrefsModel(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x torGetPrefsModel@B" % __name__
		prefsModel = None
		fullPrefsFileName = self.__getFullPrefsFileName()
		if os.path.exists(fullPrefsFileName):
			# Preferences file is available, try to get the data inside
			# check modification time
			if self.__currentUserPrefsModelMTime < os.stat(fullPrefsFileName)[ST_MTIME]:
				# we must reload the preferences file
				self.__currentUserPrefsModelMTime = os.stat(fullPrefsFileName)[ST_MTIME]
				rc, prefsModel = self.__readConfigFile(fullPrefsFileName)
				if torConstants.DEBUG:
					print "(%s)    @B@bTornado Integration Config File reloaded !@x@B" % __name__
				if rc == false:
					if torConstants.DEBUG:
						print "(%s)    @B@rReload of Tornado Integration Config File failed !@x@B" % __name__
				else:
					# reload successfully
					pass
			else:
				# __currentUserPrefsModel is up to date
				prefsModel = self.__currentUserPrefsModel
		else:
			# Preferences file doesn't exists, return new PotGuiModel
			if self.__currentUserPrefsModel == None:
				prefsModel = PotGuiModel()
				if torConstants.DEBUG:
					print "(%s)    New Tornado Integration Prefs Model generated !" % __name__
			else:
				# use the existing model
				prefsModel = self.__currentUserPrefsModel
		# update the preferences if necessary
		if self.__currentUserPrefsModel != prefsModel:
			# TODO: here is something wrong ???
			self.__torUpdatePrefsModel(prefsModel)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x torGetPrefsModel@B" % __name__
		return prefsModel

	# method stores the given data model to the
	# Integration Preferences File
	# method is PRIVATE
	def __torUpdatePrefsModel(self, newPrefsModel):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x torUpdatePrefsModel@B" % __name__
			print "(%s)    newPrefsModel = " % __name__, newPrefsModel
		rc = true
		fullPrefsFileName = self.__getFullPrefsFileName()
		rc = self.__writeConfigFile(fullPrefsFileName, newPrefsModel)
		if rc == false:
			if torConstants.DEBUG:
				print "(%s)    @B@rWriting Tornado Integration Config File failed !@x@B" % __name__
		# update memory hold model evertime
		self.__currentUserPrefsModel = newPrefsModel
		self.__currentUserPrefsModelMTime = os.stat(fullPrefsFileName)[ST_MTIME]
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x torUpdatePrefsModel@B" % __name__
		return rc

	# **** basic data read and write methods ****

	# method returns the stored data from the
	# given data path
	# method is PUBLIC
	def getDataFromModel(self, dataPath):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getDataFromModel@B" % __name__
			print "(%s)    dataPath = '%s'" % (__name__, dataPath)
		dataValue = None
		model = self.torGetPrefsModel()
		dataValue = model.GetValue(dataPath)
		if torConstants.DEBUG:
			if dataValue != None and type(dataValue) == type("") and string.find(dataValue, r"@") != -1:
				print "(%s)    dataValue = %s" % (__name__, torConstants.filterUnprintable(dataValue))
			else:
				print "(%s)    dataValue = " % __name__, dataValue
			print "(%s)@B@r<<<@x getDataFromModel@B" % __name__
		return dataValue

	# method stores the given data to 
	# the given data path in the integration preferences model
	# method is PUBLIC
	def setDataInModel(self, dataPath, dataValue):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x setDataInModel@B" % __name__
			print "(%s)    dataPath = %s" % (__name__, dataPath)
			if dataValue != None and type(dataValue) == type("") and string.find(dataValue, r"@") != -1:
				print "(%s)    dataValue = %s" % (__name__, torConstants.filterUnprintable(dataValue))
			else:
				print "(%s)    dataValue = " % __name__, dataValue
		model = self.torGetPrefsModel()
		model.SetValue(dataPath, dataValue)
		self.__torUpdatePrefsModel(model)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x setDataInModel@B" % __name__
		return

	# *** specialized data store and read methods ****

	# **** store and read selected target server name ****
	def getTgtSvrName(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getTgtSvrName@B" % __name__
		targetServerName = self.getDataFromModel("targetServerName")
		if torConstants.DEBUG:
			if targetServerName != None:
				print "(%s)    targetServerName = '%s'" % (__name__, torConstants.filterUnprintable(targetServerName))
			else:
				print "(%s)    targetServerName = " % __name__, targetServerName
			print "(%s)@B@r<<<@x getTgtSvrName@B" % __name__
		return targetServerName

	def setTgtSvrName(self, targetServerName):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x setTgtSvrName@B" % __name__
		if targetServerName != self.getTgtSvrName():
			self.setDataInModel("targetServerName", targetServerName)
		# save the current target server name to file
		fullTgtSvrFileName = vcs.joinpath(searchPathLib.getUsersProfileDir(), torConstants.tgtSvrFileName)
		if torConstants.DEBUG:
			print "(%s)    fullTgtSvrFileName: %s" % (__name__, fullTgtSvrFileName)
		# check, if the file itself exits
		if os.path.isfile(fullTgtSvrFileName) and os.path.exists(fullTgtSvrFileName):
			# remove the file for safety
			# some file attribute combinations can
			# lead to a permission error in the following open operation
			vcs.rm_fr(fullTgtSvrFileName)
		if targetServerName != None and string.strip(targetServerName) != "":
			tgtSvrFile = open(fullTgtSvrFileName, "w")
			if tgtSvrFile != None:
				tgtSvrFile.write(targetServerName)
				tgtSvrFile.write(vcs.NL)
				tgtSvrFile.close()
			else:
				if torConstanst.DEBUG:
					print "(%s)    can't write %s" % (__name__, fullTgtSvrFileName)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x setTgtSvrName@B" % __name__
		return

	# **** store and read target server dialog Switch ****
	def getTgtSvrSwitch(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getTgtSvrSwitch@B" % __name__
		tgtSvrSwitch = self.getDataFromModel("tgtSvrDialogSwitch")
		if torConstants.DEBUG:
			if tgtSvrSwitch != None:
				print "(%s)    tgtSvrSwitch = '%d'" % (__name__, tgtSvrSwitch)
			else:
				print "(%s)    tgtSvrSwitch = " % __name__, tgtSvrSwitch
			print "(%s)@B@r<<<@x getTgtSvrSwitch@B" % __name__
		return tgtSvrSwitch

	def setTgtSvrSwitch(self, tgtSvrSwitch):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x setTgtSvrSwitch@B" % __name__
		if tgtSvrSwitch != self.getTgtSvrSwitch():
			self.setDataInModel("tgtSvrDialogSwitch", tgtSvrSwitch)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x setTgtSvrName@B" % __name__
		return

	# store and read the current WIND_REGISTRY setting
	def getWindRegistrySlot(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getWindRegistrySlot@B" % __name__
		windRegistryValue = self.getDataFromModel("WIND_REGISTRY")
		if torConstants.DEBUG:
			if windRegistryValue != None:
				print "(%s)    windRegistryValue = '%s'" % (__name__, windRegistryValue)
			else:
				print "(%s)    windRegistryValue = " % __name__, windRegistryValue
			print "(%s)@B@r<<<@x getWindRegistrySlot@B" % __name__
		return windRegistryValue

	def setWindRegistrySlot(self, windRegistryValue):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x setWindRegistrySlot@B" % __name__
		self.setDataInModel("WIND_REGISTRY", windRegistryValue)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x setWindRegistrySlot@B" % __name__
		return
