##################################################################
# SNiFF+ and Tornado Integration Project
# support routines for launching the CrossWind Debugger on the target
#
# File Version:
# $Id: torLaunchCrossWind.py,v 1.7 2000/02/18 15:44:13 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string

# import SNiFF+ GUI interface
from etgui import *
from PageLayout import *
import vcs
import searchPathLib

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Base Services
import torBaseServices
import torLaunchServices
from torLaunchServices import BasicToolLauncher, TornadoToolLauncher

# import Tornado integration helper
import torMessageBox

# defines the CrossWind Tool class
class CrossWindTool(TornadoToolLauncher):
	# class privates
	__startupFileName = None

	# constructor
	def __init__(self):
		# initialize TornadoToolLauncher depend of the platform we
		# are running on
		if sys.platform == "win32":
			# WindView Tool currently not available on Windows
			pass
		else:
			thePath = os.path.join(os.environ["WIND_BASE"], "host", torBaseServices.getWindHostType(), "bin", "crosswind")
			TornadoToolLauncher.__init__(self, thePath,
										"",
										torLaunchServices.BACKGROUND,
										true		# show tgtSvrSelectionDialog
									)
		self.setStartupFileName(None)
		return

	# method saves the current startupFileName
	def setStartupFileName(self, fileName):
		self.__startupFileName = fileName
		return

	# method returns the current startupFileName
	def getStartupFileName(self):
		return self.__startupFileName

	# method builds the command to be executed
	# overrides TornadoToolLauncher.buildCommandToExecute
	def buildCommandToExecute(self):
		return "%s %s -x %s" % (self.getCommandToExecute(), self.getCommandParams(), self.getStartupFileName())

	# override preExecuteSteps method
	def preExecuteSteps(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x preExecuteSteps@B" % __name__
		# call the preExecuteSteps of the base class
		rc = TornadoToolLauncher.preExecuteSteps(self)
		if rc == true:
			# write the crosswind startup file
			startupFileName = searchPathLib.getTempFile("crosswind_start_")
			if startupFileName != None:
				self.setStartupFileName(startupFileName)
				startupFile = open(self.getStartupFileName(), "w")
				if startupFile != None:
					startupFile.write("set wtx-tool-name crosswind" + vcs.NL)
					startupFile.write("target wtx %s" % self.getTgtSvrNameToUse())
					startupFile.write(vcs.NL)
					startupFile.write("tcl exec rm %s" % self.getStartupFileName())
					startupFile.write(vcs.NL)
					startupFile.close()
				else:
					torMessageBox.messageBox("Can't open crosswind startup file '%s' !" % startupFileName, torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
					rc = false
			else:
				torMessageBox.messageBox("Can't get temporary crosswind startup file name !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
				rc = false
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x preExecuteSteps (rc = %d)@B" % (__name__, rc)
		return rc

	# method runWithAdditionalParams not available in crosswind tool
	def runWithAdditionalParams(self, additionalParams, useCallSemantic = None):
		if torConstants.DEBUG:
			print "(%s)@B@b runWithAdditionalParams@x@B" % __name__
			print "(%s)    @B@rNot available method for CrossWindTool !@x@B" % __name__
		return

# function launches tornado CrossWind Debugger on the target
def startCrossWind():
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x startCrossWind@B" % __name__
	if sys.platform == "win32":
		torMessageBox.messageBox("To launch the CrossWind debugger on Windows, please use the Tornado IDE !", "Start CrossWind debugger ...", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
	else:
		# we are on Unix
		try:
			tgtSvrHandler = torBaseServices.getDefaultTgtSvrHandler()
			currentTgtSvrName = tgtSvrHandler.getCurrentTgtSvrName()
			if tgtSvrHandler.isTgtSvrActive(currentTgtSvrName):
				# get the target architecture
				tgtSvrArchitecture = tgtSvrHandler.getTgtSvrArchitecture(currentTgtSvrName)
				if tgtSvrArchitecture != None:
					# ok, we have now all information to start the debugger
					crossWind = CrossWindTool()
					crossWind.setCommandParams("-t %s" % tgtSvrArchitecture)
					crossWind.run()
				else:
					torMessageBox.messageBox("Can't get target architecture for '%s' ! Can't start CrossWind !" % currentTgtSvrName, torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
			else:
				torMessageBox.messageBox("Selected Target Server '%s' not running ! Start the target server first !" % currentTgtSvrName, torMessageBox.MB_OK | torMessageBox.MB_ICONINFORMATION)
		except torConstants.InvalidTgtSvrException:
			pass
		except torConstants.TgtSvrNotRunningException:
			torMessageBox.messageBox("Selected Target Server not running !", "Error", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x startCrossWind@B" % __name__
	return
