##################################################################
# SNiFF+ and Tornado Integration Project
# services routines for launching external tools and commands
#
# File Version:
# $Id: torLaunchServices.py,v 1.10 2000/04/20 12:52:32 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string
from stat import *

# import SNiFF+ GUI interface
import etgui
import vcs

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Services
import torBaseServices

# import Tornado integration helper
import torMessageBox

# define calling semantic constants
NORMAL		=	0		# returns rc and _out
BACKGROUND	=	1		# no returns
SHELL		=	2		# returns rc and _out
SYSTEM		=	3		# returns rc

# basic class in the Tools Launch Hierarchy
# this class provides only the launch interface methods
class AbstractToolLauncher:
	# method starts a given command in the background
	# no returns
	def startBackProcess(self, cmd):
		if torConstants.DEBUG:
			print "(%s)@B@b startBackProcess@x@B" % __name__
			print "(%s)    cmd: %s" % (__name__, torConstants.filterUnprintable(cmd))
		return etgui.gSystem.RunProgAsynch(cmd)

	# method starts a given command in the foreground
	# and waits for termination
	# returns return code of command and output of command
	def startProcess(self, cmd):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x startProcess@B" % __name__
			print "(%s)    cmd: %s" % (__name__, torConstants.filterUnprintable(cmd))
		rc, _out = vcs.syscmd(cmd)
		if torConstants.DEBUG:
			print "(%s)    rc: %d" % (__name__, rc)
			print "(%s)    _out: %s" % (__name__, torConstants.filterUnprintable(_out[:2000]))
			print "(%s)@B@r<<<@x startProcess@B" % __name__
		return rc, _out

	# method starts a given command in the foreground
	# and waits for termination
	# returns return code of command
	def system(self, cmd):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x system@B" % __name__
			print "(%s)    cmd: %s" % (__name__, torConstants.filterUnprintable(cmd))
		rc, _out = self.startProcess(cmd)
		if torConstants.DEBUG:
			print "(%s)    rc: %d" % (__name__, rc)
			print "(%s)@B@r<<<@x system@B" % __name__
		return rc

	# methods starts a given command in the foreground
	# and in a Unix subshell, waits for termination
	# returns return code of command and output of command
	def startShellProcess(self, cmd):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x startShellProcess@B" % __name__
			print "(%s)    cmd: %s" % (__name__, torConstants.filterUnprintable(cmd))
		shellCmd = 'sh -c \'%s\'' % cmd
		rc, _out = self.startProcess(shellCmd)
		if torConstants.DEBUG:
			print "(%s)    rc: %d" % (__name__, rc)
			print "(%s)    _out: %s" % (__name__, torConstants.filterUnprintable(_out[:2000]))
			print "(%s)@B@r<<<@x startShellProcess@B" % __name__
		return rc, _out

# class to launch basic tools/commands just as defined
# in this class
# commandToExecute and commandParams are given through the constructor
# methods available: run and runWithAdditionalParams
class BasicToolLauncher(AbstractToolLauncher):
	# class privates
	__commandToExecute = None
	__commandParams = None
	__defaultCallSemantic = None
	
	# constructor
	def __init__(self, commandToExecute, commandParams = "", defaultCallSemantic = NORMAL):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __init__@B" % __name__
		if commandToExecute != None:
			self.__commandToExecute = commandToExecute
			self.__commandParams = commandParams
			self.__defaultCallSemantic = defaultCallSemantic
			if torConstants.DEBUG:
				print "(%s)    commandToExecute: %s" % (__name__, self.__commandToExecute)
				print "(%s)    commandParams: %s" % (__name__, self.__commandParams)
				print "(%s)    defaultCallSemantic: %d" % (__name__, self.__defaultCallSemantic)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __init__@B" % __name__
		return

	# methods change the default calling semantic
	def setDefaultCallSemantic(self, useCallSemantic = NORMAL):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x setDefaultCallSemantic@B" % __name__
		self.__defaultCallSemantic = useCallSemantic
		if torConstants.DEBUG:
			print "(%s)    new defaultCallSemantic: %d" % (__name__, self.getDefaultCallSemantic())
			print "(%s)@B@r<<<@x setDefaultCallSemantic@B" % __name__
		return

	# method returns default calling semantic
	def getDefaultCallSemantic(self):
		return self.__defaultCallSemantic

	# method can be used to change the predefined command line parameters
	def setCommandParams(self, newCommandParams):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x setCommandParams@B" % __name__
		self.__commandParams = newCommandParams
		if torConstants.DEBUG:
			print "(%s)    new commandParams: %s" % (__name__, torConstants.filterUnprintable(self.getCommandParams()))
			print "(%s)@B@r<<<@x setCommandParams@B" % __name__
		return

	# method returns current command line params
	def getCommandParams(self):
		return self.__commandParams

	# method builds the command to be executed
	def buildCommandToExecute(self):
		return "%s %s" % (self.getCommandToExecute(), self.getCommandParams())

	# method returns command to be executed
	def getCommandToExecute(self):
		return self.__commandToExecute

	# method executes command which should be done BEFORE calling the command
	def preExecuteSteps(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x preExecuteSteps@B" % __name__
		rc = true
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x preExecuteSteps (rc = %d)@B" % (__name__, rc)
		return rc

	# method executes command which should be done After calling the command
	def postExecuteSteps(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x postExecuteSteps@B" % __name__
		rc = true
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x postExecuteSteps (rc = %d)@B" % (__name__, rc)
		return rc

	# method to run the command
	def run(self, useCallSemantic = None):
		if useCallSemantic == None:
			useCallSemantic = self.getDefaultCallSemantic()
		if torConstants.DEBUG:
			print "(%s)@B@b run@x@B" % __name__
			print "(%s)    useCallSemantic: %d" % (__name__, useCallSemantic)
		try:
			preExecuteState = self.preExecuteSteps()
			# run the command, if there is one and if the preExecuteStep finished successfully
			if self.getCommandToExecute() != None and len(self.getCommandToExecute()) > 0 and preExecuteState == true:
				# ok, there is a command we can try to start
				fullCommandToExecute = self.buildCommandToExecute()
				if useCallSemantic == NORMAL:
					rc, _out = self.startProcess(fullCommandToExecute)
					postExecuteState = self.postExecuteSteps()
					return rc, _out
				if useCallSemantic == BACKGROUND:
					self.startBackProcess(fullCommandToExecute)
					postExecuteState = self.postExecuteSteps()
					return
				if useCallSemantic == SHELL:
					rc, _out = self.startShellProcess(fullCommandToExecute)
					postExecuteState = self.postExecuteSteps()
					return rc, _out
				if useCallSemantic == SYSTEM:
					rc = self.system(fullCommandToExecute)
					postExecuteState = self.postExecuteSteps()
					return rc
		except:
			if torConstants.DEBUG:
				print "(%s)@B     execution of run failed !@B" % __name__
				import traceback
				traceback.print_exc()
			else:
				torMessageBox.messageBox("The command @B'%s'@B could not be executed !" % self.getCommandToExecute(), "Execution failure", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
			return

	# method put the additionalParams at the right place
	def concatAdditionalParams(self, additionalParams):
		return "%s %s" % (self.getCommandParams(), additionalParams)

	# method to run the command with additional params
	def runWithAdditionalParams(self, additionalParams, useCallSemantic = None):
		if useCallSemantic == None:
			useCallSemantic = self.getDefaultCallSemantic()
		if torConstants.DEBUG:
			print "(%s)@B@b runWithAdditionalParams@x@B" % __name__
			print "(%s)    useCallSemantic: %d" % (__name__, useCallSemantic)
			print "(%s)    additionalParams: %s" % (__name__, additionalParams)
		# save the original command params
		orgParams = self.getCommandParams()
		self.setCommandParams(self.concatAdditionalParams(additionalParams))
		if useCallSemantic == NORMAL:
			rc, _out = BasicToolLauncher.run(self, useCallSemantic)
			# restore original parameters
			self.setCommandParams(orgParams)
			return rc, _out
		if useCallSemantic == SHELL:
			rc, _out = BasicToolLauncher.run(self, useCallSemantic)
			# restore original parameters
			self.setCommandParams(orgParams)
			return rc, _out
		if useCallSemantic == SYSTEM:
			rc = BasicToolLauncher.run(self, useCallSemantic)
			# restore original parameters
			self.setCommandParams(orgParams)
			return rc
		if useCallSemantic == BACKGROUND:
			BasicToolLauncher.run(self, useCallSemantic)
			# restore original parameters
			self.setCommandParams(orgParams)
			return

# class to launch Tornado Based Tools
# Tornado based Tools check for a running Target Server
# and can present a target server selection dialog
class TornadoToolLauncher(BasicToolLauncher):
	# class privates
	__isShowTgtSvrSelectionDialog = false
	__tgtSvrNameToUse = None
	
	# constructor
	def __init__(self, commandToExecute, commandParams = "", defaultCallSemantic = NORMAL, tgtSvrSelectionDialogVisibility = false):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __init__@B" % __name__
		BasicToolLauncher.__init__(self, commandToExecute, commandParams, defaultCallSemantic)
		self.setDialogVisibility(tgtSvrSelectionDialogVisibility)
		self.setTgtSvrNameToUse(None)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __init__@B" % __name__
		return

	# method returns the state if we should show the
	# target server selection dialog
	def getDialogVisibility(self):
		return self.__isShowTgtSvrSelectionDialog

	def setDialogVisibility(self, visible):
		self.__isShowTgtSvrSelectionDialog = visible
		return

	# method returns the target server name we should connet
	def getTgtSvrNameToUse(self):
		return self.__tgtSvrNameToUse

	# methods sets the target server name we shoudl connect
	def setTgtSvrNameToUse(self, tgtSvrName):
		self.__tgtSvrNameToUse = tgtSvrName
		return

	# shows the Target Server Selection Dialog and returns
	# a target server name
	def showTgtSvrSelectionDialog(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x showTgtSvrSelectionDialog@B" % __name__
		tgtSvrSelectionDialogVisibility = self.getDialogVisibility()
		selectedTgtSvrName = None
		tgtSvrHandler = torBaseServices.getDefaultTgtSvrHandler()
		# check, if the user has switched off the showing of the dialog
		# using the select target server dialog switch
		tgtSvrSwitch = torBaseServices.getDefaultPrefsFileHandler().getTgtSvrSwitch()
		if tgtSvrSwitch != None:
			if tgtSvrSwitch == 0:
				# user decided to switch off target server selection dialog
				# the user has the last decision !!! It will override forceTgtSvrSelection Dialog as well !!!
				tgtSvrSelectionDialogVisibility = false
				# return preselected targetServerName, if this tool
				# does not store a valid target server name itself
				if selectedTgtSvrName == None:
					selectedTgtSvrName = tgtSvrHandler.getCurrentTgtSvrName()
		
		# show the target server selection dialog
		if tgtSvrSelectionDialogVisibility == true:
			selectedTgtSvrName = tgtSvrHandler.showTgtSvrSelectionDialog()
		if torConstants.DEBUG:
			print "(%s)    returned target server name: " % __name__, selectedTgtSvrName
			print "(%s)@B@r<<<@x showTgtSvrSelectionDialog@B" % __name__
		return selectedTgtSvrName

	# method builds the command to be executed
	# overrides BasicToolLauncher.buildCommandToExecute
	def buildCommandToExecute(self):
		return "%s %s %s" % (self.getCommandToExecute(), self.getCommandParams(), self.getTgtSvrNameToUse())

	# method executes command which should be done BEFORE calling the command
	def preExecuteSteps(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x preExecuteSteps@B" % __name__
		# call the preExecuteSteps of the base class
		rc = BasicToolLauncher.preExecuteSteps(self)
		if rc == true:
			tgtSvrNameToUse = self.showTgtSvrSelectionDialog()
			if tgtSvrNameToUse == None:
				rc = false
				raise torConstants.InvalidTgtSvrException
			else:
				self.setTgtSvrNameToUse(tgtSvrNameToUse)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x preExecuteSteps (rc = %d)@B" % (__name__, rc)
		return rc

