##################################################################
# SNiFF+ and Tornado Integration Project
# support routines for launching the standard VxWorks simulator
#
# File Version:
# $Id: torLaunchSim.py,v 1.18 2000/04/20 14:24:46 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string

# import SNiFF+ GUI interface
from etgui import *
from PageLayout import *
import vcs

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Services
import torBaseServices
import torLaunchServices
import torWtxTclTool

# import Tornado integration helper
import torMessageBox

# import the Windows Registry Interface
import torWinRegistryInterface

# defines the Simulator start dialog model
class SimDialogModel(DictPyModel):
	def DoSetValue(self, path, value):
		if path == "simSelection":
			if value == 1:
				# custom build simulator selected
				self.SetValue("ImageFieldEnabler", 1)
				lastSimPath = os.path.normpath(torBaseServices.getLastSimulatorImagePath())
				if lastSimPath != None and string.strip(lastSimPath) != "":
					self.SetValue("VxWorksImage", lastSimPath)
			else:
				# standard simulator selected
				self.SetValue("ImageFieldEnabler", 0)
				self.SetValue("VxWorksImage", torBaseServices.getDefaultSimulatorImagePath())
		return DictPyModel.DoSetValue(self, path, value)

# define the Start Dialog for the Simulator
def ShowLaunchSimDialog():
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x ShowLaunchSimDialog@B" % __name__
	model = SimDialogModel()
	# initialize Model
	model.SetValue("simSelection", 0)
	model.SetValue("ImageFieldEnabler", 0)
	model.SetValue("VxWorksImage", torBaseServices.getDefaultSimulatorImagePath())
	model.SetValue("LaunchOptionsEnabler", 0)
	if sys.platform != "win32":
		# on Unix we can enable the Launch Options
		model.SetValue("LaunchOptionsEnabler", 1)
	model.SetValue("ProcessorNo", 0)
	# prepare the radiobuttons
	simSelection = PotGuiOneOf("simSelection")
	simSelection.AddItem("Standard Simulator", 0)
	simSelection.AddItem("Custom-built simulator", 1)
	# set the VxSim description Text
	if torBaseServices.isFullSimInstalled() == true:
		descriptionText = MultilineTextItem("VxSim includes a fully-operational version of WindView.\nWindView support for additional targets is available separately.")
		# enable the Launch Options
		model.SetValue("LaunchOptionsEnabler", 1)
		VxSimInfoTextItem = TextItem("")
	else:
		descriptionText = MultilineTextItem("The VxSim-Lite Simulator is installed, including a fully-operational version of WindView\nfor VxSim-Lite. A complete version of VxSim which adds networking capabilities is\navailable separately, as is WindView support for additional targets.")
		VxSimInfoTextItem = TextItem("(Not configurable for VxSim-Lite)")
	# check, if we show Standard or Custom Build Simulator
	lastSimImageStarted = torBaseServices.getLastSimulatorImagePath()
	if lastSimImageStarted != None and string.strip(lastSimImageStarted) != "" and torBaseServices.simIsDefault(lastSimImageStarted) == false:
		model.SetValue("ImageFieldEnabler", 1)
		model.SetValue("simSelection", 1)
	retVal=ShowSubDialog("VxSim-Lite Launch: Select Image and Options",
		model,
		MakeSectionLayout(
			MakeBorderedSectionLayout("VxWorks Image",
				Form(
					items=[
						VBox(align=eVObjHLeft,
							items=[
								VBox(align=eVObjHExpand|eVObjVFixed|eVObjHLeft,
									items=[
										descriptionText,
										Filler(gPoint10),
									] # items
								), # VBox
								VBox(align=eVObjHLeft,
									items=[
										"Select the executable VxWorks image to be launched:",
										simSelection,
										PotGuiEnabler("ImageFieldEnabler",
											HBox(
												items=[
													"Image:",
													PotGuiFileSelector("VxWorksImage", 2*gTextFieldLen, "Select VxWorks Image")
												] # items
											) # HBox
										) # PotGuiEnabler
									] # items
								) # VBox
							] # items
						) # VBox
					] # items
				) # Form
			), # MakeBorderedSectionLayout
			MakeBorderedSectionLayout("Launch Options",
				Form(
					items=[
						HBox(
							items=[
								PotGuiEnabler("LaunchOptionsEnabler",
									HBox(
										items=[
											"Processor no.: (0-9) ",
											PotGuiIntField("ProcessorNo", IntField(-1, 0, 0, 9))
										] # items
									) # HBox
								), # PotGuiEnable
								VxSimInfoTextItem
							] # items
						) # HBox
					] # items
				) # Form
			) # MakeBorderedSectionLayout
		) # MakeSectionLayout
	) # end ShowSubDialog
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x ShowLaunchSimDialog (retVal = %d)@B" % (__name__, retVal)
	if retVal:
		return model
	else:
		return None

# entry point for starting Simulator
def startSimulator():
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x startSimulator@B" % __name__
	model = ShowLaunchSimDialog()
	if model != None:
		# check if a simulator already running
		processorNumber = model.GetValue("ProcessorNo")
		tgtSvrHandler = torBaseServices.getDefaultTgtSvrHandler()
		defaultTargetServerName = tgtSvrHandler.getDefaultSimTgtSvrName("vxsim", processorNumber)
		if tgtSvrHandler.isTgtSvrActive(defaultTargetServerName) == true:
			# a Simulator for selected target name already running
			if torBaseServices.isFullSimInstalled() == true:
				message="A VxWorks simulator with processor number %d is already running on this machine. Click on OK to connect to this simulator or click on Cancel to make another selection." % processorNumber
			else:
				message="A VxWorks simulator is already running on this machine. Click on OK to connect to this simulator or click on Cancel to make another selection."
			retVal = torMessageBox.messageBox(message, "Information", torMessageBox.MB_OKCANCEL | torMessageBox.MB_ICONINFORMATION)
			print retVal
		else:
			# we can do something
			simImagePath = vcs.normpath(os.path.expandvars(model.GetValue("VxWorksImage")))
			simulatorStarted = false
			tgtSvrStarted = false
			if os.path.exists(simImagePath):
				# Ok, we can start the simulator
				doLaunchSimulator(simImagePath, processorNumber)
				simulatorStarted = true
				# checks the target server
				torBaseServices.getDefaultTgtSvrHandler().doLaunchTgtSvr(defaultTargetServerName)
				tgtSvrStarted = true
				# save target server name
				torBaseServices.getDefaultPrefsFileHandler().setTgtSvrName(defaultTargetServerName)
			else:
				torMessageBox.messageBox("Simulator Image '%s' does not exist !" % simImagePath, "VxWorks Image Not found", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x startSimulator@B" % __name__
	return

# functions saves the ImagePath to the last started Simulator
def saveLastSimulatorStarted(ImagePath):
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x saveLastSimulatorStarted@B" % __name__
	if sys.platform == "win32":
		# on Windows we are using the Windows Registry
		regInterface = torWinRegistryInterface.getWinRegistryInterfaceHandle()
		rc = regInterface.WriteRegistryValue("HKEY_CURRENT_USER", r"Software\Wind River Systems\Tornado 2.0\Tornado\Simulator", "lastImageLaunched", "REG_EXPAND_SZ", "%s" % ImagePath)
	else:
		# on Unix we save the ImagePath to $WIND_BASE/.wind/.vxsim_last_started
		# !!WIND_BASE not writable on UNIX installations! -- mober
		# configDir = vcs.joinpath(os.environ["WIND_BASE"], ".wind")
		configDir = vcs.joinpath(os.environ["HOME"], ".wind")
		if not os.path.exists(configDir):
			# create the directory
			vcs.mkdir_p(configDir)
		if os.path.exists(configDir) and os.path.isdir(configDir):
			# remove the file ".vxsim_last_started" if it should be exists
			saveFile = vcs.joinpath(configDir, ".vxsim_last_started")
			if os.path.exists(saveFile):
				# remove the file
				vcs.rm_fr(saveFile)
			if not os.path.exists(saveFile):
				# write the file finally
				try:
					fileHandle = open(saveFile, "w")
				except:
					fileHandle=None
				if fileHandle != None:
					fileHandle.write(ImagePath)
					fileHandle.write("\n");
					fileHandle.close()
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x saveLastSimulatorStarted@B" % __name__
	return

# function launchs the simulator Image
def doLaunchSimulator(ImagePath, ProcessorNumber = 0):
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x doLaunchSimulator@B" % __name__
	# start the given image as background process
	# use startBackProcess to start process
	if sys.platform == "win32":
		torLaunchServices.AbstractToolLauncher().startBackProcess('%s "%s"' % (ImagePath, ""))
	else:
		(dir, file) = os.path.split(ImagePath)
		scriptFilePath = vcs.normpath("$WIND_BASE/host/resource/tcl/app-config/all/hostUtils.tcl")
		command="""cd %s ; source %s ; runTerminal "Vxsim %s" 1 ./%s -p %s""" % (dir, scriptFilePath, ProcessorNumber, file, ProcessorNumber)
		# send through wtxtcl
		torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
		try:
			torWtxTclTool.getWtxTclToolHandle().runScript(torLaunchServices.BACKGROUND)
		except torConstants.ScriptExecutionFailure:
			pass
	saveLastSimulatorStarted(ImagePath)
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x doLaunchSimulator@B" % __name__
	return

