##################################################################
# SNiFF+ and Tornado Integration Project
# support routines for launching the windsh on the target
#
# File Version:
# $Id: torLaunchWindSh.py,v 1.20 2000/04/20 19:09:40 mober Exp $
#
# Authors:
# - Uwe Stieber
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string

# import SNiFF+ GUI interface
from etgui import *
from PageLayout import *
import vcs

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Base Services
import torBaseServices
import torLaunchServices
from torLaunchServices import TornadoToolLauncher
import torWtxTclTool

# import Tornado integration helper
import torMessageBox

# defines the WindSh Tool class
class WindShTool(TornadoToolLauncher):
	# constructor
	def __init__(self):
		# initialize TornadoToolLauncher depend of the latform we
		# are running on
		if sys.platform == "win32":
			TornadoToolLauncher.__init__(self, "rxvt",
										"-fn 'Courier-medium-12' -e windsh",
										torLaunchServices.BACKGROUND,
										true		# show tgtSvrSelectionDialog
									)
		else:
			TornadoToolLauncher.__init__(self, "windsh",
										"",
										torLaunchServices.BACKGROUND,
										true
									)
		return

	# method to run the command
	def run(self, useCallSemantic = None):
		if sys.platform == "win32":
			# run normal
			return TornadoToolLauncher.run(self, useCallSemantic)
		else:
			# send through wtxtcl
			tgtSvrNameToUse = self.showTgtSvrSelectionDialog()
			if tgtSvrNameToUse != None:
				scriptFilePath = vcs.normpath("$WIND_BASE/host/resource/tcl/app-config/all/hostUtils.tcl")
				torWtxTclTool.getWtxTclToolHandle().setCommandParams("source %s ; runTerminal Windsh 1 windsh %s" % (scriptFilePath, tgtSvrNameToUse))
				try:
					return torWtxTclTool.getWtxTclToolHandle().runScript(torLaunchServices.BACKGROUND)
				except torConstants.ScriptExecutionFailure:
					pass

# function launches the windsh on the target
def startWindSh(SniffAccessProject = "", fileName=""):
	if torConstants.DEBUG:
		print "(%s)@B@g>>>@x startWindSh@B" % __name__
	dir=""
	if fileName:
		try:
			(dir,file)=os.path.split(fileName)
			os.chdir(dir)
		except:
			if torConstants.DEBUG:
				import traceback ; traceback.print_exc()
	try:
		if not SniffAccessProject:
			WindShTool().run()
		else:
			# start the windsh in the SNiFF+ shell environment
			currentTgtSvrName = torBaseServices.getDefaultTgtSvrHandler().getCurrentTgtSvrName()
			if currentTgtSvrName != None and len(string.strip(currentTgtSvrName)) > 0:
				if dir:
					command = '\'cd "%s"; windsh "%s"\'' % (dir, currentTgtSvrName)
				else:
					command =  '\'windsh "%s"\'' % currentTgtSvrName
				torBaseServices.doSniffAccess("shell", SniffAccessProject, command)
			else:
				torMessageBox.messageBox("No target server selected ! Start and/or select a target server first !", "Error", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
	except torConstants.InvalidTgtSvrException:
		pass
	except torConstants.TgtSvrNotRunningException:
		torMessageBox.messageBox("Selected Target Server not running !", "Error", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
	if torConstants.DEBUG:
		print "(%s)@B@r<<<@x startWindSh@B" % __name__
	return
