##################################################################
# SNiFF+ and Tornado Integration Project
# maps the messageBox function to the native available ones
#
# File Version:
# $Id: torMessageBox.py,v 1.11 2000/04/20 14:32:46 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Adapter History:
# - 0.01 file creation-  02/03/2000
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string

# import SNiFF+ interfaces
import vcs
import etgui
import PyDialog
import CmdNo
import PageLayout

# define all necessary constants
MB_OK 				= 0x0L
MB_OKCANCEL 		= 0x1L
MB_ABORTRETRYIGNORE = 0x2L
MB_YESNOCANCEL		= 0x3L
MB_YESNO			= 0x4L
MB_RETRYCANCEL		= 0x5L

MB_ICONHAND			= 0x10L
MB_ICONQUESTION		= 0x20L
MB_ICONEXCLAMATION	= 0x30L
MB_ICONASTERISK		= 0x40L
MB_USERICON			= 0x80L
MB_ICONWARNING		= MB_ICONEXCLAMATION
MB_ICONERROR		= MB_ICONHAND
MB_ICONINFORMATION	= MB_ICONASTERISK
MB_ICONSTOP			= MB_ICONHAND

MB_DEFBUTTON1		= 0x00000000L
MB_DEFBUTTON2		= 0x00000100L
MB_DEFBUTTON3		= 0x00000200L
MB_DEFBUTTON4		= 0x00000300L

MB_APPLMODAL		= 0x00000000L
MB_SYSTEMMODAL		= 0x00001000L
MB_TASKMODAL		= 0x00002000L
MB_HELP				= 0x00004000L # Help Button

MB_NOFOCUS			= 0x00008000L
MB_SETFOREGROUND	= 0x00010000L
MB_DEFAULT_DESKTOP_ONLY = 0x00020000L

IDOK		= 1
IDCANCEL	= 2
IDABORT		= 3
IDRETRY		= 4
IDIGNORE	= 5
IDYES		= 6
IDNO		= 7
IDCLOSE		= 8
IDHELP		= 9

# define additional ET++ ShowAlert types
eAlertOkCancelNote = 10
eAlertRetryCancelNote = 11

# reimplement missing Windows Dialog Types
class OkCancelDialog(PyDialog.PyDialog):
	wflags = etgui.eWinBlock	# modal dialog
	title = 'Ok or Cancel'
	def __init__(self, title, str=''):
		self.title = title
		# limit the width of the dialog
		newText = ""
		textList = string.split(str)
		wordCount = 0
		for aWord in textList:
			newText = newText + aWord + " "
			wordCount = wordCount + 1
			# every tenth word a NL
			if wordCount == 10:
				newText = newText + vcs.NL
				wordCount = 0
		self.text = etgui.MultilineTextItem(newText + vcs.NL)
		self.answer = None
	def SetString(self, str):
		self.text.SetString(str)
	def ShowUnderMouse(self):
		self.impl.ShowUnderMouse()
	def MakeContent(self):
		return PageLayout.MakeDialogWithButtons(
			self.text,
			etgui.ActionButton(CmdNo.cIdOk, 'OK', default=1),
			etgui.ActionButton(CmdNo.cIdCancel, 'Cancel')
		)
	def Ok(self):
		self.answer = 1
	def Cancel(self):
		self.answer = 4
	def Answer(self):
		return self.answer
	def Control(self, id, part, val):
		if id == CmdNo.cIdOk:
			self.answer = 1
			return 0
		elif id == CmdNo.cIdCancel:
			self.answer = 4
			return 0
		return 0

class RetryCancelDialog(PyDialog.PyDialog):
	wflags = etgui.eWinBlock	# modal dialog
	title = 'Retry or Cancel'
	def __init__(self, title, str=''):
		self.title = title
		# limit the width of the dialog
		newText = ""
		textList = string.split(str)
		wordCount = 0
		for aWord in textList:
			newText = newText + aWord + " "
			wordCount = wordCount + 1
			# every tenth word a NL
			if wordCount == 10:
				newText = newText + vcs.NL
				wordCount = 0
		self.text = etgui.MultilineTextItem(newText + vcs.NL)
		self.answer = None
	def SetString(self, str):
		self.text.SetString(str)
	def ShowUnderMouse(self):
		self.impl.ShowUnderMouse()
	def MakeContent(self):
		return PageLayout.MakeDialogWithButtons(
			self.text,
			etgui.ActionButton(CmdNo.cIdOk, 'Retry', default=1),
			etgui.ActionButton(CmdNo.cIdCancel, 'Cancel')
		)
	def Retry(self):
		self.answer = 12
	def Cancel(self):
		self.answer = 4
	def Answer(self):
		return self.answer
	def Control(self, id, part, val):
		if id == CmdNo.cIdOk:
			self.answer = 12
			return 0
		elif id == CmdNo.cIdCancel:
			self.answer = 4
			return 0
		return 0

def messageBox(message, title, flags):
	rc = 0
	if sys.platform == "win32":
		import re
		# make "@@" unpossible character sequenz
		message = re.sub(r"@@", "@%", message)
		# ok, we must filter the input stream for possible formating string
		# characters for ET++
		message = re.sub(r"@[brgxBI]+", r"", message)
		# and we must unmask the ET++ dialogs difficult characters
		message = re.sub(r"@%", r"@", message)
		rc, _out = vcs.syscmd('showNativeMessageBox "%s" "%s" %d' % (message, title, flags))
	else:
		# filter the ET++ Alert type out of the Windows flags
		testFlags = flags & 0xf
		etAlertType = etgui.eAlertNote
		if testFlags == MB_ABORTRETRYIGNORE:
			# use eAlertError dialog
			etAlertType = etgui.eAlertError
		else:
			if testFlags == MB_YESNOCANCEL:
				etAlertType = etgui.eAlertCaution
				# decide which icon
				if (flags & 0xf0) == MB_ICONSTOP:
					# use stop icon
					etAlertType = etgui.eAlertStop
			else:
				if testFlags == MB_YESNO:
					etAlertType = etgui.eAlertQuestion
				else:
					if testFlags == MB_OKCANCEL:
						# use eAltertOkCancelNote
						etAlertType = eAlertOkCancelNote
					else:
						if testFlags == MB_RETRYCANCEL:
							# use eAltertRetryCancelNote
							etAlertType = eAlertRetryCancelNote
		if etAlertType != eAlertOkCancelNote and etAlertType != eAlertRetryCancelNote:
			rc = etgui.ShowAlert(etAlertType, message)
		else:
			if etAlertType == eAlertOkCancelNote:
				dlg = OkCancelDialog(title, message)
				etgui.ShowDialog(dlg)
				rc = dlg.Answer()
			if etAlertType == eAlertRetryCancelNote:
				dlg = RetryCancelDialog(title, message)
				etgui.ShowDialog(dlg)
				rc = dlg.Answer()
		# map the ET++ return codes to the correct Windows ones
		if rc == 2:
			# correct to IDYES
			rc = IDYES
		else:
			if rc == 3:
				# correct to IDNO
				rc = IDNO
			else:
				if rc == 4:
					# correct to IDCANCEL
					rc = IDCANCEL
				else:
					if rc == 10:
						# correct to IDIGNORE
						rc = IDIGNORE
					else:
						if rc == 11:
							# correct to IDABORT
							rc = IDABORT
						else:
							if rc == 12:
								# correct to IDRETRY
								rc = IDRETRY
	return rc
