##################################################################
# SNiFF+ and Tornado Integration Project
# dialog definitions for configure and managing Target Servers
#
# File Version:
# $Id: torTgtSvrDialogs.py,v 1.9 2000/04/20 13:58:00 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string
from stat import *

# import SNiFF+ GUI interface
from etgui import *
from PageLayout import *
from ListBox import *
import vcs
import searchPathLib

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Services
import torBaseServices

# import Tornado integration helper
import torMessageBox

# define some constants
notAvailableMessage = "No available Target Server"

# defines the Target Server Selection Dialog
class TgtSvrSelectionDialog:
	# class privates
	__targetServerHandler = None
	__model = None
	
	# inner classes
	# Target Server Selection Dialog model
	class TgtSvrDialogModel(DictPyModel):
		def DoSetValue(self, path, value):
			if path == "selectedTgtSvr":
				if value != None:
					x=string.lower(string.strip(value))
					y=string.lower(string.strip(notAvailableMessage))
					if x != y:
						# Target server operations ON
						self.SetValue("tgtSvrOperationsEnabler", 1)
					else:
						# Target server operation OFF
						self.SetValue("tgtSvrOperationsEnabler", 0)
				else:
					# Target server operation OFF
					self.SetValue("tgtSvrOperationsEnabler", 0)
			return DictPyModel.DoSetValue(self, path, value)

	# special version of ListBox for Target Server Selection Dialog
	# target server names list and changed selection handler
	#class TgtSvrListBox(FilteredListBox):
	class TgtSvrListBox(ListBox):
		# class privates
		__tgtSvrHandler = None
		__modelReference = None
		__dataSlot1 = None
		__dataSlot2 = None

		# constructor
		def __init__(self, tgtSvrHandler, model, dataSlot1, dataSlot2):
			#FilteredListBox.__init__(self, model)
			ListBox.__init__(self)
			self.__tgtSvrHandler = tgtSvrHandler
			self.__modelReference = model
			self.__dataSlot1 = dataSlot1
			self.__dataSlot2 = dataSlot2
		def DoSelect(self, i):
			# list selection has changed
			ListBox.DoSelect(self, i)
			# check the length of the Items List
			if len(self.GetItems()) > 0:
				value = self.GetItems()[i]
				# change the model
				self.__modelReference.SetValue(self.__dataSlot1, value)
				# only read the info for real target server
				if string.lower(value) != string.lower(notAvailableMessage):
					self.__modelReference.SetValue(self.__dataSlot2, self.__tgtSvrHandler.getTgtSvrInfo(value))
				else:
					self.__modelReference.SetValue(self.__dataSlot2, "(not available)")
				if torConstants.DEBUG:
					print "(%s)    ListBox Selection changed to %s" % (__name__, torConstants.filterUnprintable(value))
					print "(%s)    new target server information: %s" % (__name__, torConstants.filterUnprintable(self.__modelReference.GetValue(self.__dataSlot2)))
			else:
				# create a dummy entry
				dummyList = [ notAvailableMessage ]
				self.SetItems(dummyList)

	# special version of ListBox for Target Server Selection Dialog
	# target server information read only list box
	class TgtSvrInfoListBox(ListBox):
		# class privates
		__model = None
		__dataSlot = None
		__targetServerNames = None		# only used for snychronisation purpose
										# out of __KillActionPerformed
		
		# constructor
		def __init__(self, model, dataSlot):
			ListBox.__init__(self)
			self.__model = model
			self.__dataSlot = dataSlot
			self.__model.AddModelObserver(self.Observe, self.__dataSlot)
		def DoMakeItem(self,v):
			return TextItem(str(v),font=gFixedFont)
		def Observe(self, model, slot):
			if slot == self.__dataSlot:
				self.ObserveTgtSvrInfoChanged(model, slot)
		def ObserveTgtSvrInfoChanged(self, model, slot):
			# do it only, if real target server available
			newTgtSvrInfoList = string.split(self.__model.GetValue(self.__dataSlot), "\n")
			self.SetItems(newTgtSvrInfoList)
			self.ListChanged()

	# constructor
	def __init__(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __init__@B" % __name__
		self.__targetServerHandler = torBaseServices.getDefaultTgtSvrHandler()
		self.__model = self.TgtSvrDialogModel()
		self.__targetServerNames = None
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __init__@B" % __name__
		return

	# target server operation wrapper methods
	def __ReserveActionPerformed(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __ReserveActionPerformed@B" % __name__
		if self.__model != None:
			selectedTgtSvr = self.__model.GetValue("selectedTgtSvr")
			if selectedTgtSvr != None:
				# do the operation
				rc = self.__targetServerHandler.ReserveTgtSvr(selectedTgtSvr)
				if rc == 0:
					# we have to reread the target server information
					targetServerList = self.__targetServerNames.GetItems()
					self.__selectTargetServerNameInList(targetServerList, selectedTgtSvr, true)
			else:
				if torConstants.DEBUG:
					print "(%s)\tOperation not performed because of no selected target server !" % __name__
		else:
			if torConstants.DEBUG:
				print "(%s)\tOperation not performed because of not available model !" % __name__
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __ReserveActionPerformed@B" % __name__
		return

	def __UnreserveActionPerformed(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __UnreserveActionPerformed@B" % __name__
		if self.__model != None:
			selectedTgtSvr = self.__model.GetValue("selectedTgtSvr")
			if selectedTgtSvr != None:
				# do the operation
				rc = self.__targetServerHandler.UnreserveTgtSvr(selectedTgtSvr)
				if rc == 0:
					# we have to reread the target server information
					targetServerList = self.__targetServerNames.GetItems()
					self.__selectTargetServerNameInList(targetServerList, selectedTgtSvr, true)
			else:
				if torConstants.DEBUG:
					print "(%s)\tOperation not performed because of no selected target server !" % __name__
		else:
			if torConstants.DEBUG:
				print "(%s)\tOperation not performed because of not available model !" % __name__
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __UnreserveActionPerformed@B" % __name__
		return

	def __UnregisterActionPerformed(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __UnregisterActionPerformed@B" % __name__
		if self.__model != None:
			selectedTgtSvr = self.__model.GetValue("selectedTgtSvr")
			if selectedTgtSvr != None:
				# do the operation
				rc = self.__targetServerHandler.UnregisterTgtSvr(selectedTgtSvr)
				if rc == 0:
					# operation successfully, we have to refresh the
					# target server list
					newTargetServerList = string.split(self.__targetServerHandler.getTgtSvrList())
					if len(newTargetServerList) == 0:
						# write dummy list
						newTargetServerList = [ notAvailableMessage ]
					self.__fillTargetServerNameList(newTargetServerList)
			else:
				if torConstants.DEBUG:
					print "(%s)\tOperation not performed because of no selected target server !" % __name__
		else:
			if torConstants.DEBUG:
				print "(%s)\tOperation not performed because of not available model !" % __name__
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __UnregisterActionPerformed@B" % __name__
		return

	def __KillActionPerformed(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __KillActionPerformed@B" % __name__
		if self.__model != None:
			selectedTgtSvr = self.__model.GetValue("selectedTgtSvr")
			if selectedTgtSvr != None:
				# do the operation
				rc = self.__targetServerHandler.KillTgtSvr(selectedTgtSvr)
				if rc == 0:
					# operation successfully, we have to refresh the
					# target server list
					newTargetServerList = string.split(self.__targetServerHandler.getTgtSvrList())
					if len(newTargetServerList) == 0:
						# write dummy list
						newTargetServerList = [ notAvailableMessage ]
					self.__fillTargetServerNameList(newTargetServerList)
			else:
				if torConstants.DEBUG:
					print "(%s)\tOperation not performed because of no selected target server !" % __name__
		else:
			if torConstants.DEBUG:
				print "(%s)\tOperation not performed because of not available model !" % __name__
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __KillActionPerformed@B" % __name__
		return

	def __RebootActionPerformed(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __RebootActionPerformed@B" % __name__
		if self.__model != None:
			selectedTgtSvr = self.__model.GetValue("selectedTgtSvr")
			if selectedTgtSvr != None:
				# do the operation
				rc = self.__targetServerHandler.RebootTgtSvr(selectedTgtSvr)
			else:
				if torConstants.DEBUG:
					print "(%s)\tOperation not performed because of no selected target server !" % __name__
		else:
			if torConstants.DEBUG:
				print "(%s)\tOperation not performed because of not available model !" % __name__
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __RebootActionPerformed@B" % __name__
		return

	def __fillTargetServerNameList(self, targetServerList, currentTargetServerName = None, doTargetServerPreSelect = true):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __fillTargetServerNameList@B" % __name__
		if self.__targetServerNames != None and targetServerList != None:
			realTgtSvrList = []
			for aTgtSvrName in targetServerList:
				# filter out REGISTRY_NAME_NOT_FOUND
				if string.upper(string.strip(aTgtSvrName)) != "REGISTRY_NAME_NOT_FOUND":
					realTgtSvrList.append(aTgtSvrName)
			if len(realTgtSvrList) == 0:
				realTgtSvrList = [ notAvailableMessage ]
			self.__targetServerNames.SetItems(realTgtSvrList)
			if (doTargetServerPreSelect == true and currentTargetServerName != None):
				self.__selectTargetServerNameInList(realTgtSvrList, currentTargetServerName, doTargetServerPreSelect)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __fillTargetServerNameList@B" % __name__
		return

	def __selectTargetServerNameInList(self, targetServerList, currentTargetServerName, doTargetServerPreSelect = true):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __selectTargetServerNameInList@B" % __name__
		if self.__targetServerNames != None and targetServerList != None:
			if (doTargetServerPreSelect == true and currentTargetServerName != None):
				if currentTargetServerName in targetServerList:
					index = 0
					for aTgtSvrName in targetServerList:
						if aTgtSvrName == currentTargetServerName:
							self.__model.SetValue("selectedTgtSvr", currentTargetServerName)
							self.__targetServerNames.Select(index)
							break
						else:
							index = index + 1
				else:
					self.__model.SetValue("selectedTgtSvr", targetServerList[0])
					self.__targetServerNames.Select(0)
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x __selectTargetServerNameInList@B" % __name__
		return

	# method shows the target server selection dialog
	# and returns the selected target server name or None
	def showTgtSvrSelectionDialog(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x showTgtSvrSelectionDialog@B" % __name__
		targetServerName = None
		targetServerList = string.split(self.__targetServerHandler.getTgtSvrList())
		currentTargetServerName = self.__targetServerHandler.getCurrentTgtSvrName()
		self.__model.SetValue("selectedTgtSvr", "")
		self.__model.SetValue("selectedTgtSvrInfo", "")
		self.__model.SetValue("tgtSvrInfoViewEnabler", 1)
		self.__model.SetValue("tgtSvrOperationsEnabler", 0)
		tgtSvrSwitch = torBaseServices.getDefaultPrefsFileHandler().getTgtSvrSwitch()
		if tgtSvrSwitch != None:
			self.__model.SetValue("tgtSvrDialogSwitch", tgtSvrSwitch)
		else:
			self.__model.SetValue("tgtSvrDialogSwitch", 1)
		# create target server selection listbox
		targetServerNames = self.TgtSvrListBox(self.__targetServerHandler, self.__model, "selectedTgtSvr", "selectedTgtSvrInfo")
		self.__targetServerNames = targetServerNames
		self.__fillTargetServerNameList(targetServerList, currentTargetServerName)
		#targetServerNameView = targetServerNames.MakeCollView(Point(100,271))
		targetServerNameView = targetServerNames.MakeCollView(Point(100,300))
		if self.__model.GetValue("selectedTgtSvr") == notAvailableMessage:
			self.__model.SetValue("selectedTgtSvrInfo", "(not available)")
		else:
			self.__model.SetValue("selectedTgtSvrInfo", self.__targetServerHandler.getTgtSvrInfo(self.__model.GetValue("selectedTgtSvr")))
		# prepare tgtSvrInfoView
		tgtSvrInfoList = string.split(self.__model.GetValue("selectedTgtSvrInfo"), "\n")
		#tgtSvrInfoView = MultilineTextItem(torConstants.filterUnprintable(self.__model.GetValue("selectedTgtSvrInfo")), -1, gFixedFont)
		tgtSvrInfo = self.TgtSvrInfoListBox(self.__model, "selectedTgtSvrInfo")
		tgtSvrInfo.SetItems(tgtSvrInfoList)
		tgtSvrInfoView = tgtSvrInfo.MakeCollView(Point(300, 300))
		# Build the ActionButton Panel
		buttonPanel = AlignBox(
						eVObjHCenter,
						flags=eVObjVFixed,
						inner = HBox(
									align=eVObjHExpand | eVObjVBase | eVObjHEqual,
									items=[
										ActionButton("Reserve", action=self.__ReserveActionPerformed),
										ActionButton("Unreserve", action=self.__UnreserveActionPerformed),
										ActionButton("Unregister", action=self.__UnregisterActionPerformed),
										ActionButton("Kill", action=self.__KillActionPerformed),
										ActionButton("Reboot", action=self.__RebootActionPerformed)
									] # items
								) # HBox
							) # AlignBox
		# Show the final dialog
		retVal = ShowSubDialog("Select Target Server",
			self.__model,
			MakePageLayout(eVObjVExpand | eVObjHExpand,
				VBox(
					align=eVObjVExpand | eVObjHFixed,
					items=[
						HBox(
							align=eVObjVFixed | eVObjHExpand,
							items=[
								MakeBorderedSectionLayout("Available Target Server",
									Form(
										items=[
											targetServerNameView
										] # items
									) # Form
								), # MakeSectionLayour
								MakeBorderedSectionLayout("Target Server Info",
									VBox(
										align=eVObjVFixed | eVObjHExpand,
										items=[
											PotGuiEnabler("tgtSvrInfoViewEnabler",
												tgtSvrInfoView
											) # PotGuiEnabler
										] # items
									) # VBox
								) # MakeBorderedSectionLayour
							] # items
						), # HBox
						PotGuiToggleButton("tgtSvrDialogSwitch", "Show before every tool start"),
					] # items
				), # VBox
				PotGuiEnabler("tgtSvrOperationsEnabler",
					buttonPanel
				) # PotGuiEnabler
			) # MakePageLayout
		) # ShowSubDialog
		if retVal and len(targetServerList) > 0:
			targetServerName =  self.__model.GetValue("selectedTgtSvr")
			if string.lower(targetServerName) == string.lower(notAvailableMessage):
				# return None
				targetServerName = None
			# save the Target Server Dialog Switch
			torBaseServices.getDefaultPrefsFileHandler().setTgtSvrSwitch(self.__model.GetValue("tgtSvrDialogSwitch"))
		else:
			targetServerName = None
		if torConstants.DEBUG:
			if targetServerName != None:
				print "(%s)@B@r<<<@x showTgtSvrSelectionDialog (targetServerName = '%s')@B" % (__name__, torConstants.filterUnprintable(targetServerName))
			else:
				print "(%s)@B@r<<<@x showTgtSvrSelectionDialog (targetServerName = 'None')@B" % __name__
		return targetServerName

	def showStandaloneTgtSvrDialog(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x showStandaloneTgtSvrDialog@B" % __name__
		selectedTgtSvrName = self.showTgtSvrSelectionDialog()
		if selectedTgtSvrName != None:
			# save the returned target server name
			torBaseServices.getDefaultPrefsFileHandler().setTgtSvrName(selectedTgtSvrName)
		if torConstants.DEBUG:
			if selectedTgtSvrName != None:
				print "(%s)    selected target server name: %s" % (__name__, torConstants.filterUnprintable(selectedTgtSvrName))
			else:
				print "(%s)    selected target server name: " % __name__, selectedTgtSvrName
			print "(%s)@B@r<<<@x showStandaloneTgtSvrDialog@B" % __name__
		return
