##################################################################
# SNiFF+ and Tornado Integration Project
# services routines for configure and managing Target Servers
#
# File Version:
# $Id: torTgtSvrServices.py,v 1.18 2000/04/20 15:12:01 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string
from stat import *
import time

# import SNiFF+ GUI interface
import vcs
import searchPathLib

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Services
import torBaseServices
import torLaunchServices
import torWtxTclTool

# import Tornado integration helper
import torMessageBox

# class defines the interface for working with and on target servers
class torTgtSvrHandler:
	# class privates
	tgtSvrSelectionDialog = None
	# Target Server Info Cache
	__previousSelectedTgtSvr = None
	__previousTgtSvrInfo = None
	__lastAccess = 0
	__cacheUsed = 0
	__allowedDelay = 5		# inbetween 5 sec. --> use the cache
	
	# function returns the list of all registered target server
	def getTgtSvrList(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getTgtSvrList@B" % __name__
		if sys.platform == "win32":
			# on Windows we use WTX C API programs, because of problems
			# with wtxtcl
			binaryScriptFile = torBaseServices.locateFile("getTgtSvrList.exe", "bin")
			rc, targetServerList = torLaunchServices.AbstractToolLauncher().startProcess(binaryScriptFile)
		else:
			# on Unix we use TCL Scripts
			scriptFilePath = torBaseServices.locateFile("SniffTgtSvrList.tcl", "integrations/TornadoII/tcl")
			if scriptFilePath != None:
				torWtxTclTool.getWtxTclToolHandle().setCommandParams(scriptFilePath)
				rc, targetServerList = torWtxTclTool.getWtxTclToolHandle().run()
			else:
				torMessageBox.messageBox("Can't locate script file 'SniffTgtSvrList.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		if torConstants.DEBUG:
			print "(%s)    returned Target Server List: %s" % (__name__, torConstants.filterUnprintable(targetServerList))
			print "(%s)@B@r<<<@x getTgtSvrList@B" % __name__
		return string.strip(targetServerList)

	# functions checks, if a simulator for a given target server
	def isTgtSvrActive(self, targetServerName):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x isTgtSvrActive@B" % __name__
		simState = false
		targetServerList = string.split(self.getTgtSvrList())
		for aTargetServer in targetServerList:
			if string.lower(aTargetServer) == string.lower(targetServerName):
				simState = true
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x isTgtSvrActive (simState = %d)@B" % (__name__, simState)
		return simState

	# method return currently selected target server name
	def getCurrentTgtSvrName(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getCurrentTgtSvrName@B" % __name__
		torPrefsFileHandler = torBaseServices.getDefaultPrefsFileHandler()
		tgtSvrName = torPrefsFileHandler.getTgtSvrName()
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x getCurrentTgtSvrName (tgtSvrName = '%s')@B" % (__name__, torConstants.filterUnprintable(tgtSvrName))
		return tgtSvrName

	# method returns default simulator target server name
	def getDefaultSimTgtSvrName(self, targetBaseName = "vxsim", processorNumber = 0):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getDefaultSimTgtSvrName@B" % __name__
		hostName = torBaseServices.getHostName()
		if sys.platform == "win32":
			fullSimTargetServerName = string.strip("%s%d@%s" % (targetBaseName, processorNumber, hostName))
			stdSimTargetServerName = string.strip("%s@%s" % (targetBaseName, hostName))		
		else:
			if os.environ.has_key("USER"):
				fullSimTargetServerName = string.strip("%s-%s-%d@%s" % (targetBaseName, os.environ["USER"], processorNumber, hostName))
			else:
				fullSimTargetServerName = string.strip("%s%d@%s" % (targetBaseName, processorNumber, hostName))
			stdSimTargetServerName = fullSimTargetServerName
		if torBaseServices.isFullSimInstalled() == true:
			targetServerName = fullSimTargetServerName
		else:
			targetServerName = stdSimTargetServerName
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x getDefaultSimTgtSvrName (targetServerName = '%s')@B" % (__name__, torConstants.filterUnprintable(targetServerName))
		return targetServerName

	def __doGetTgtSvrInfo(self, targetServerName):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x __doGetTgtSvrInfo@B" % __name__
		scriptFilePath = torBaseServices.locateFile("SniffTsInfoGet.tcl", "integrations/TornadoII/tcl")
		if scriptFilePath != None:
			command="source %s ; SniffTsInfoGet %s" % (scriptFilePath, targetServerName)
			torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
			try:
				rc, targetServerInfo = torWtxTclTool.getWtxTclToolHandle().runScript()
			except torConstants.ScriptExecutionFailure:
				pass
		else:
			torMessageBox.messageBox("Can't locate script file 'SniffTsInfoGet.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		if torConstants.DEBUG:
			print "(%s)    returned Target Server Info: %s" % (__name__, torConstants.filterUnprintable(targetServerInfo))
			print "(%s)@B@r<<<@x __doGetTgtSvrInfo@B" % __name__
		return string.strip(targetServerInfo)

	# method returns information about the given target server as string
	def getTgtSvrInfo(self, targetServerName):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getTgtSvrInfo@B" % __name__
		# check the cache before
		timeStamp = time.time()
		self.__cacheUsed = 0
		if ((timeStamp - self.__lastAccess) <= self.__allowedDelay):
			# try to use the cache
			if (self.__previousSelectedTgtSvr == targetServerName):
				# cache can be used !
				if torConstants.DEBUG:
					print "(%s)@B@g CACHE HIT !@x@B" % __name__
				self.__cacheUsed = 1
			else:
				if torConstants.DEBUG:
					print "(%s)@B@r CACHE FAILED !@x@B" % __name__
		else:
			if torConstants.DEBUG:
				print "(%s)@B@b To much CACHE difference@x@B" % __name__
		if self.__cacheUsed == 0:
			# read the target server information
			tgtSvrInfo = self.__doGetTgtSvrInfo(targetServerName)
			# and save it to the cache
			self.__previousSelectedTgtSvr = targetServerName
			self.__previousTgtSvrInfo = tgtSvrInfo
		else:
			# use the cached information
			tgtSvrInfo = self.__previousTgtSvrInfo
		# update the last access time
		self.__lastAccess = time.time()
		if torConstants.DEBUG:
			print "(%s)    returned Target Server Info: %s" % (__name__, torConstants.filterUnprintable(tgtSvrInfo))
			print "(%s)@B@r<<<@x getTgtSvrInfo@B" % __name__
		return string.strip(tgtSvrInfo)

	# method returns the target server architecture for the given target server
	def getTgtSvrArchitecture(self, tgtSvrName = None):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x getTgtSvrArchitecture@B" % __name__
			print "(%s)    tgtSvrName: " % __name__, tgtSvrName
		tgtSvrArchitecture = None
		if tgtSvrName != None:
			# ask for the info
			scriptFilePath = torBaseServices.locateFile("SniffCpuInfoGet.tcl", "integrations/TornadoII/tcl")
			if scriptFilePath != None:
				command="source %s ; SniffCpuInfoGet %s" % (scriptFilePath, tgtSvrName)
				torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
				try:
					rc, tgtSvrArchitecture = torWtxTclTool.getWtxTclToolHandle().runScript()
				except torConstants.ScriptExecutionFailure:
					pass
			else:
				torMessageBox.messageBox("Can't locate script file 'SniffTsInfoGet.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		if torConstants.DEBUG:
			print "(%s)    tgtSvrArchitecture: " % __name__, tgtSvrArchitecture
			print "(%s)@B@r<<<@x getTgtSvrArchitecture@B" % __name__
		return string.strip(tgtSvrArchitecture)

	# wrapper method to show the target server selection dialog
	def showTgtSvrSelectionDialog(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x showTgtSvrSelectionDialog@B" % __name__
		if self.tgtSvrSelectionDialog == None:
			# import Target Server Dialogs
			import torTgtSvrDialogs
			self.tgtSvrSelectionDialog = torTgtSvrDialogs.TgtSvrSelectionDialog()
		tgtSvrName = self.tgtSvrSelectionDialog.showTgtSvrSelectionDialog()
		if torConstants.DEBUG:
			if tgtSvrName != None:
				print "(%s)@B@r<<<@x showTgtSvrSelectionDialog (tgtSvrName = '%s')@B" % (__name__, torConstants.filterUnprintable(tgtSvrName))
			else:
				print "(%s)@B@r<<<@x showTgtSvrSelectionDialog (tgtSvrName = 'None')@B" % __name__
		return tgtSvrName

	# wrapper method to shwo the target server selection dialog standalone
	def showStandaloneTgtSvrDialog(self):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x showStandaloneTgtSvrDialog@B" % __name__
		if self.tgtSvrSelectionDialog == None:
			# import Target Server Dialogs
			import torTgtSvrDialogs
			self.tgtSvrSelectionDialog = torTgtSvrDialogs.TgtSvrSelectionDialog()
		self.tgtSvrSelectionDialog.showStandaloneTgtSvrDialog()
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x showStandaloneTgtSvrDialog@B" % __name__
		return
	
	# method launchs a given the target server
	def doLaunchTgtSvr(self, fullTargetServerName):
		if torConstants.DEBUG:
			print "(%s)@B@g>>>@x doLaunchTgtSvr@B" % __name__
		# build target server options
		# start the target server as background process
		tsfsRoot = searchPathLib.getTempDir()
		tsfsRoot = vcs.joinpath(tsfsRoot, "tsfs")
		defaultTgtSvrOptions = "-B wdbpipe -R %s -RW" % tsfsRoot

		# to fix tgtsvr bug
		if not os.environ.has_key("WIND_UID"):
			os.environ["WIND_UID"] = "0"

		# remove hostname from target server name
		targetServerName = fullTargetServerName
		try:
			index = string.rindex(fullTargetServerName, "@")
			targetServerName = fullTargetServerName[:index]
		except ValueError:
			pass

		# calculate arguments
		args = "%s %s" % (defaultTgtSvrOptions, targetServerName)

		# start the target server process in the background
		torLaunchServices.AbstractToolLauncher().startBackProcess('%s %s' % ("tgtsvr", args))
		if torConstants.DEBUG:
			print "(%s)@B@r<<<@x doLaunchTgtSvr@B" % __name__
		return
	
	# target server operations
	def ReserveTgtSvr(self, tgtSvrToOperate):
		# reserve the Target Server (wtxTsLock)
		# assume that we fail
		rc_dialog = 1
		scriptFilePath = torBaseServices.locateFile("SniffTsOperations.tcl", "integrations/TornadoII/tcl")
		if scriptFilePath != None:
			command="source %s ; SniffTsReserve %s" % (scriptFilePath, tgtSvrToOperate)
			torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
			try:
				rc, errMsg = torWtxTclTool.getWtxTclToolHandle().runScript()
				if torConstants.DEBUG:
					print "(%s)\trc = %d" % (__name__, rc)
					print "(%s)\terrorMessage:\n" % __name__, errMsg
				if rc == 0:
					##torMessageBox.messageBox("Target server @B'%s'@B reservation successfully !" % torConstants.filterUnprintable(tgtSvrToOperate), "Target Server Reserve", torMessageBox.MB_OK | torMessageBox.MB_ICONINFORMATION)
					# everything ok
					rc_dialog = 0
				else:
					torMessageBox.messageBox("Target server @B'%s'@B reservation failed with following error message !\n\n%s" % (torConstants.filterUnprintable(tgtSvrToOperate), errMsg), "Target Server Reserve", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
			except torConstants.ScriptExecutionFailure:
				pass
		else:
			torMessageBox.messageBox("Can't locate script file 'SniffTsOperations.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		return rc_dialog

	def UnreserveTgtSvr(self, tgtSvrToOperate):
		# unreserve the Target Server (wtxTsUnlock)
		# assume that we fail
		rc_dialog = 1
		scriptFilePath = torBaseServices.locateFile("SniffTsOperations.tcl", "integrations/TornadoII/tcl")
		if scriptFilePath != None:
			command="source %s ; SniffTsUnreserve %s" % (scriptFilePath, tgtSvrToOperate)
			torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
			try:
				rc, errMsg = torWtxTclTool.getWtxTclToolHandle().runScript()
				if torConstants.DEBUG:
					print "(%s)\trc = %d" % (__name__, rc)
					print "(%s)\terrorMessage:\n" % __name__, errMsg
				if rc == 0:
					##torMessageBox.messageBox("Target server @B'%s'@B unreservation successfully !" % torConstants.filterUnprintable(tgtSvrToOperate), "Target Server Unreserve", torMessageBox.MB_OK | torMessageBox.MB_ICONINFORMATION)
					# everything ok
					rc_dialog = 0
				else:
					torMessageBox.messageBox("Target server @B'%s'@B unreservation failed with following error message !\n\n%s" % (torConstants.filterUnprintable(tgtSvrToOperate), errMsg), "Target Server Unreserve", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
			except torConstants.ScriptExecutionFailure:
				pass
		else:
			torMessageBox.messageBox("Can't locate script file 'SniffTsOperations.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		return rc_dialog

	def UnregisterTgtSvr(self, tgtSvrToOperate):
		# unregister the Target Server (wtxUnregister $ts)
		# assume that we fail
		rc_dialog = 1
		scriptFilePath = torBaseServices.locateFile("SniffTsOperations.tcl", "integrations/TornadoII/tcl")
		if scriptFilePath != None:
			command="source %s ; SniffTsUnregister %s" % (scriptFilePath, tgtSvrToOperate)
			torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
			try:
				rc, errMsg = torWtxTclTool.getWtxTclToolHandle().runScript()
				if torConstants.DEBUG:
					print "(%s)\trc = %d" % (__name__, rc)
					print "(%s)\terrorMessage:\n" % __name__, errMsg
				if rc == 0:
					##torMessageBox.messageBox("Target server @B'%s'@B unregistration successfully !" % torConstants.filterUnprintable(tgtSvrToOperate), "Target Server Unregister", torMessageBox.MB_OK | torMessageBox.MB_ICONINFORMATION)
					# everything ok
					rc_dialog = 0
				else:
					torMessageBox.messageBox("Target server @B'%s'@B unregistration failed with following error message !\n\n%s" % (torConstants.filterUnprintable(tgtSvrToOperate), errMsg), "Target Server Unregister", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
			except torConstants.ScriptExecutionFailure:
				pass
		else:
			torMessageBox.messageBox("Can't locate script file 'SniffTsOperations.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		return rc_dialog

	def KillTgtSvr(self, tgtSvrToOperate):
		answer = torMessageBox.messageBox("Do you really want to kill the target server @B'%s'@B ?\n\nPlease close all connected applications before killing the Target Server if there are any !" % torConstants.filterUnprintable(tgtSvrToOperate), "Target Server Operation", torMessageBox.MB_YESNO | torMessageBox.MB_ICONQUESTION)
		# the return status to the calling dialog
		rc_dialog = 2	# means, that the user answered with "NO"
		if answer == torMessageBox.IDYES:
			# kill the target server (wtxTsKill "destroy")
			# assume that we fail
			rc_dialog = 1
			scriptFilePath = torBaseServices.locateFile("SniffTsOperations.tcl", "integrations/TornadoII/tcl")
			if scriptFilePath != None:
				command="source %s ; SniffTsKill %s" % (scriptFilePath, tgtSvrToOperate)
				torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
				try:
					rc, errMsg = torWtxTclTool.getWtxTclToolHandle().runScript()
					if torConstants.DEBUG:
						print "(%s)\trc = %d" % (__name__, rc)
						print "(%s)\terrorMessage:\n" % __name__, errMsg
					if rc == 0:
						##torMessageBox.messageBox("Kill of target server @B'%s'@B successfully !" % torConstants.filterUnprintable(tgtSvrToOperate), "Target Server Kill", torMessageBox.MB_OK | torMessageBox.MB_ICONINFORMATION)
						# everything ok
						rc_dialog = 0
					else:
						torMessageBox.messageBox("Kill of target server @B'%s'@B failed with following error message !\n\n%s" % (torConstants.filterUnprintable(tgtSvrToOperate), errMsg), "Target Server Kill", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
				except torConstants.ScriptExecutionFailure:
					pass
			else:
				torMessageBox.messageBox("Can't locate script file 'SniffTsOperations.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		return rc_dialog

	def RebootTgtSvr(self, tgtSvrToOperate):
		answer = torMessageBox.messageBox("Do you really want to reboot the target connected to @B'%s'@B ?" % torConstants.filterUnprintable(tgtSvrToOperate), "Target Reboot", torMessageBox.MB_YESNO | torMessageBox.MB_ICONQUESTION)
		rc_dialog = 2	# means, that the user answered with "NO"
		if answer == torMessageBox.IDYES:
			# reboot the target (wtxTargetReset)
			# assume that we fail
			rc_dialog = 1
			scriptFilePath = torBaseServices.locateFile("SniffTsOperations.tcl", "integrations/TornadoII/tcl")
			if scriptFilePath != None:
				command="source %s ; SniffTsReboot %s" % (scriptFilePath, tgtSvrToOperate)
				torWtxTclTool.getWtxTclToolHandle().setCommandParams(command)
				try:
					rc, errMsg = torWtxTclTool.getWtxTclToolHandle().runScript()
					if torConstants.DEBUG:
						print "(%s)\trc = %d" % (__name__, rc)
						print "(%s)\terrorMessage:\n" % __name__, errMsg
					if rc == 0:
						torMessageBox.messageBox("Reboot of target server @B'%s'@B successfully !\n\nWait for the target system until the reboot is finished !" % torConstants.filterUnprintable(tgtSvrToOperate), "Target Server Reboot", torMessageBox.MB_OK | torMessageBox.MB_ICONINFORMATION)
						# everything ok
						rc_dialog = 0
					else:
						torMessageBox.messageBox("Reboot of target server @B'%s'@B failed with following error message !\n\n%s" % (torConstants.filterUnprintable(tgtSvrToOperate), errMsg), "Target Server Reboot", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
				except torConstants.ScriptExecutionFailure:
					pass
			else:
				torMessageBox.messageBox("Can't locate script file 'SniffTsOperations.tcl' !", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
		return rc_dialog
