##################################################################
# SNiFF+ and Tornado Integration Project
# defines a helper tool to run TCL scripts through the wtxtcl binary
#
# File Version:
# $Id: torWtxTclTool.py,v 1.12 2000/02/18 08:51:07 uwe Exp $
#
# Authors:
# - Uwe Stieber
#
# Adapter History:
# - 0.01 file creation-  02/09/2000
#
# Limitation:
# - currently no limitations know
#
# Notes:
# - Please report problems to sniff-support@takefive.co.at
#
##################################################################

# import some system services
import sys, os, string

# import SNiFF+ GUI interface
from etgui import *
from PageLayout import *
import vcs
import searchPathLib

# import basic constants
import torConstants
from torConstants import false, true

# import Tornado Integration Base Services
import torLaunchServices
from torLaunchServices import BasicToolLauncher

# import Tornado integration helper
import torMessageBox

# defines the WtxTcl Tool class
class WtxTclTool(BasicToolLauncher):
	# constructor
	def __init__(self):
		# initialize BasicToolLauncher
		BasicToolLauncher.__init__(self, "wtxtcl")
		# set the default calling semantic to foreground process
		self.setDefaultCallSemantic(torLaunchServices.NORMAL)
		self._scriptMode=0   # don't pipe commands into wtxtcl by default

	# method builds the command to be executed
	def buildCommandToExecute(self):
		if sys.platform == 'win32':
			return BasicToolLauncher.buildCommandToExecute(self)
		else:
			#print "scriptMode = ",self._scriptMode
			if self._scriptMode:
				return "echo '%s' | %s" % (self.getCommandParams(), self.getCommandToExecute())
				self._scriptMode = 0
			else:
				return BasicToolLauncher.buildCommandToExecute(self)

	def run(self, useCallSemantic = None):
		self._scriptMode = 0
		#print "scriptMode = ",self._scriptMode
		return BasicToolLauncher.run(self, useCallSemantic)

	# methods writes command given by __commandParams to a
	# temporary script and execute this script instead of
	# passing __commandParams to the wtxtcl command line
	# --> the commandParams are not options or a filename for wtxtcl,
	# but rather a tcl program that should be directly executed.
	def runScript(self, useCallSemantic = None, removeScriptFile = true):
		if torConstants.DEBUG:
			print "(%s)@B@b runScript@x@B" % __name__
		if useCallSemantic == None:
			useCallSemantic = self.getDefaultCallSemantic()
		if sys.platform == "win32":
			return self.runWithTempScript(useCallSemantic, removeScriptFile)
		# UNIX: here, we can directly pipe the commands into wtxtcl.
		# this is a one-time option!!
		self._scriptMode = 1
		return BasicToolLauncher.run(self, useCallSemantic)
	
	def runWithTempScript(self, useCallSemantic = None, removeScriptFile = true):
		if torConstants.DEBUG:
			print "(%s)@B@b runWithTempScript@x@B" % __name__
		if useCallSemantic == None:
			useCallSemantic = self.getDefaultCallSemantic()
		tempFileName = searchPathLib.getTempFile("torInt_Temp_Script_",".tcl")
		if torConstants.DEBUG:
			print "(%s)    generated temp file: %s" % (__name__, tempFileName)
		# try to open the script file
		tempFile = open(tempFileName, "w")
		if tempFile:
			# ok, we can write the script
			tempFile.write(self.getCommandParams())
			tempFile.write(vcs.NL)
			tempFile.close()
		else:
			if torConstants.DEBUG:
				print "(%s)    failed to generated temp script file '%s' !" % (__name__, tempFileName)
			else:
				torMessageBox.messageBox("Can't execute '%s' !" % self.getCommandParams(), "WtxTcl Script Execution Failure", torMessageBox.MB_OK | torMessageBox.MB_ICONSTOP)
			if torConstants.DEBUG:
				print "(%s)@B@r<<<@x runWithTempScript (Script Execution failure)@B" % __name__
			raise torConstants.ScriptExecutionFailure
		# execute the temporary script
		orgParams = self.getCommandParams()
		# set script file name as command line option
		# BUGBUG better: 
		## self.setCommandParams --> Parameters for wtxtcl
		## self.setCommand --> Command to echo into wtxtcl
		self.setCommandParams(tempFileName)
		if useCallSemantic == torLaunchServices.NORMAL \
				or useCallSemantic == torLaunchServices.SHELL:
			self._scriptMode=0
			rc, _out = BasicToolLauncher.run(self, useCallSemantic)
			# restore original command line options
			self.setCommandParams(orgParams)
			# remove generated temp file
			if removeScriptFile == true:
				vcs.rm_fr(tempFileName)
			return rc, _out
		if useCallSemantic == torLaunchServices.BACKGROUND:
			self._scriptMode=0
			BasicToolLauncher.run(self, useCallSemantic)
			# restore original command line options
			self.setCommandParams(orgParams)
			# remove generated temp file
			if removeScriptFile == true:
				vcs.rm_fr(tempFileName)
			return
		if useCallSemantic == torLaunchServices.SYSTEM:
			self._scriptMode=0
			rc = BasicToolLauncher.run(self, useCallSemantic)
			# restore original command line options
			self.setCommandParams(orgParams)
			# remove generated temp file
			if removeScriptFile == true:
				vcs.rm_fr(tempFileName)
			return rc

# instance of WtxTclTool
defaultWtxTclTool = None

# call this function to get access to the WtxTclTool
def getWtxTclToolHandle():
	global defaultWtxTclTool
	if defaultWtxTclTool == None:
		defaultWtxTclTool = WtxTclTool()
	return defaultWtxTclTool

