# 01ProjSNiFF.tcl -- launch SNiFF+ from Tornado Launcher on UNIX
#
# modification history 
# -------------------- 
# 01a,16feb00,mob  written 
#*/ 
 
# Add a SNiFF activation button to bottom of the launcher 
# The associated icon is taken from "sniff" (xbm format) from
# installDir/host/resource/bitmaps/Launch/objects.  
 
objectCreate app sniff "SNiFF+" {launchSNiFF}

# Add SNiFF+ support to "Support" menu item
menuButtonCreate Support "SNiFF+..." S {supportRequest "SNiFF+" }

# Add SNiFF+ Website to "Info" menu item
menuButtonCreate Info "SNiFF+" S {sniffWebPage}

# Add a complete SNiFF Menu for open project etc.... NOT NOW!!!!

# create VxSim and WindView controls to be sure they appear BEFORE 
# the Tornado Project Control (which will thus be outside the window border).
objectCreate app vxsim VxSim {LaunchVxSim}
objectCreate app windview WindView {launchWindView}

######################################################################## 
# 
# launch SNiFF+
# TODO: check whether SNiFF is already running --> in that case, just
# do a sniffaccess browse_symbol or similar.
#
 
proc launchSNiFF {} { 
    global env
    if [ catch {set sniff_dir $env(SNIFF_DIR)}] {
        puts "ERROR: \$SNIFF_DIR not set, cannot start SNiFF+"
    } else {
        exec $sniff_dir/bin/sniff &
    }
}

########################################################################
#
# go to the SNiFF Website
#

proc sniffWebPage {} {
    set webpage "http://www.takefive.com"

    if {[info proc windHelpDisplay] == ""} {
        # Source windHelp library
        uplevel #0 source [wtxPath host resource doctools]windHelpLib.tcl
    }

    windHelpDisplay $webpage

}

########################################################################
#
# eMail a support request for the SNiFF+ integration
# attention: put all possible version numbers in here!
# TODO: get SNiFF Version number from $SNIFF_DIR/Version file
#

proc sniffSupportRequest {} {
    global env
    global tgtsvr_cpu

    if {$tgtsvr_cpu == "" } { 
        if [catch {set cpu $env(VX_CPU_FAMILY)}] {
            set cpu ""
        }
    } else {
        set cpu $tgtsvr_cpu
    }

    set host [exec uname -a]
    set integration_version "1.0_final_beta"
    set sniff_version "3.2.1"
    set torver [wtxTsVersionGet]

    supportPost "SNiFF+ $sniff_version Tornado $torver Integration" "$cpu" "$host" "BSP ?"
}
