@ECHO OFF
REM
REM Windows Batch file Wrapper for SNiFF+ Integration Installation
REM
REM USAGE: install.bat [-c] [-d] [-sd SNIFF_DIR] ...
REM
REM -c  ... Configure only: don't copy, just create Platform and startup files
REM -d  ... Debug mode: print commands only but don't execute them
REM -sd ... assume SNIFF_DIR at given dir
REM all other parameters are passed through to install.sh
REM
REM Author: Martin Oberhuber, 09-Feb-2000
REM (c) TakeFive Software GmbH
REM

REM Initialize
SET MYNAME=%0
SET CONFIG_OPT=
SET DEBUG_OPT=
SET ASSUMED_SNIFFDIR=
SET ASSUMED_SD_OPT=

IF NOT "%1" == "-sd" GOTO First_Opt_Done
SET ASSUMED_SNIFFDIR=%2
SET ASSUMED_SD_OPT=-sd %2
SHIFT
SHIFT

:First_Opt_Done
IF NOT "%1" == "-c" GOTO Config_Opt_Done
SET CONFIG_OPT=-c
SHIFT

:Config_Opt_Done
IF NOT "%1" == "-d" GOTO Debug_Opt_Done
SET DEBUG_OPT=-d
SHIFT

:Debug_Opt_Done
IF NOT "%1" == "-sd" GOTO Sniffdir_Opt_Done
SET ASSUMED_SNIFFDIR=%2
SET ASSUMED_SD_OPT=-sd %2
SHIFT
SHIFT

:Sniffdir_Opt_Done
REM Add SNiFF bin directory to path for cp and other UNIX-style programs
REM This will work only, if either $SNIFF_DIR is set or the integration
REM is started from "inside" the SNiFF+ installation.
IF NOT EXIST "..\..\SetPath.bat" GOTO External_Install
CALL ..\..\SetPath.bat
GOTO Path_OK

:External_Install
IF NOT EXIST "%ASSUMED_SNIFFDIR%\SitePrefs.sniff" GOTO Bad_Assumed_Sniffdir
SET SNIFF_DIR=%ASSUMED_SNIFFDIR%
SET PATH=%ASSUMED_SNIFFDIR%\bin;%PATH%
GOTO Path_OK

:Bad_Assumed_Sniffdir
IF "%ASSUMED_SNIFFDIR%" == "" GOTO Do_Set_SNIFF_DIR
ECHO.
ECHO WARNING:
ECHO   %ASSUMED_SNIFFDIR%
ECHO is not a valid SNIFF_DIR (missing SitePrefs.sniff). 
ECHO Perhaps your Registry contains an old setting!
IF "%SNIFF_DIR%" == "" GOTO NO_SNIFF_DIR
ECHO Trying SNIFF_DIR=%SNIFF_DIR% instead...

:Do_Set_SNIFF_DIR
IF NOT EXIST "%SNIFF_DIR%\SitePrefs.sniff" GOTO NO_SNIFF_DIR
SET PATH=%SNIFF_DIR%\bin;%PATH%
GOTO Path_OK

:NO_SNIFF_DIR
REM At this point, apparently SNIFF_DIR was not set, and the integration
REM was installed from "Outside" a SNiFF+ installation. Tell the user
REM that this mighth not work because the install.sh requires that bash.exe 
REM and mount.exe (and the other GNUWIN Tools) need to be in the PATH.
REM ECHO PATH=%PATH%
ECHO.
ECHO WARNING:
ECHO INSTALL.BAT can not determine the location of bash.exe and mount.exe,
ECHO which are required to successfully run the installation.
ECHO.
ECHO If the installation still runs, you can ignore this warning message.
ECHO In case the installation aborts with an error message, please insure
ECHO that either
ECHO    * the SNIFF_DIR environment variable is set, or
ECHO    * the %%SNIFF_DIR%%\bin directory is in your system PATH
ECHO.
ECHO then run INSTALL.BAT again.
ECHO.

:Path_OK
REM At this point, we can be sure that GNUWIN is in the Path.
REM Make sure that /tmp is mounted for Cygwin
SET theTempDir=C:\TEMP
IF NOT "%TMP%" == "" SET theTempDir=%TMP%
IF NOT "%TEMP%" == "" SET theTempDir=%TEMP%
IF NOT EXIST "%theTempDir%" mkdir "%theTempDir%"
mount -f %theTempDir% /tmp >NUL: 2>NUL:

SET INST_PROG=install.sh
IF "%MYNAME%" == "sniffinstall.bat" SET INST_PROG="%SNIFF_DIR%\bin\sniffinstall"

IF NOT "%DEBUG_OPT%" == "-d" GOTO Debug_Print_Done
  ECHO.
  ECHO CALLED: %MYNAME% %DEBUG_OPT% %CONFIG_OPT% %ASSUMED_SD_OPT% %1 %2 %3 %4 %5 %6 %7 %8 %9
  ECHO SET SNIFF_DIR=%SNIFF_DIR%
  ECHO SET PATH=%PATH%
  ECHO.
  ECHO bash.exe %INST_PROG% %DEBUG_OPT% %CONFIG_OPT% %1 %2 %3 %4 %5 %6 %7 %8 %9
:Debug_Print_Done
bash.exe %INST_PROG% %DEBUG_OPT% %CONFIG_OPT% %1 %2 %3 %4 %5 %6 %7 %8 %9

echo.
pause
