#* MRe 2000/01/19 *
#
#    updateWS.ksh  WorkingEnvironment  Project  [SSWE|SOWE|PWE]


rm -f update.log
rm -f updateSniff.log
touch update.log
touch updateSniff.log

if [ "$1" = "" -o "$2" = "" -o "$3" = "" ]
then
	echo "Usage: updateWS.ksh  WorkingEnvironment  Project  [SSWE|SOWE|PWE]";
	exit
fi

USER=${USERNAME:-$LOGNAME}

# change subdirectory if project (second command line parameter) isn't
# in the root directory of workspace
basedir=`pwd | sed -e '/\/\//s#//\([a-zA-Z]\)#\1:#g'`
cd `dirname $2`

echo "==================================================================="	>> $basedir/update.log 2>&1
echo "Start update of project $2 in the Working Environment $1"			>> $basedir/update.log 2>&1
date										>> $basedir/update.log 2>&1
echo "==================================================================="	>> $basedir/update.log 2>&1

MAKE=gmake
export MAKE

# set PLATFORM environment variable for make support
if [ -z "${PLATFORM:-}" ]
then
	PLATFORM=`sh $SNIFF_DIR/bin/sniff_arch`
	export PLATFORM
fi
echo "EnvVar PLATFORM: $PLATFORM"											 >> $basedir/update.log 2>&1

# set TMP environment variable
if [ -z "${TMP:-$TEMP}" ]
then
	TMP=c:/tmp
fi
TMP=`echo $TMP | sed -e 's#\\\\#/#g'`
export TMP
echo "EnvVar TMP: $TMP"							 >> $basedir/update.log 2>&1

# set session identifier
session=`pwd`
session="cron$3_`basename $session`"

if [ "$3" = "SOWE" ]
then
# delete symbols of SNiFF+ in the workspace (.sniffdir) recursively.
# SNiFF+ will then use shared symbols
	echo $MAKE -i sniffclean					>> $basedir/update.log 2>&1
	$MAKE -i sniffclean						>> $basedir/update.log 2>&1
fi


# start sniff and sniffaccess in Batch mode (SNIFF_BATCH=1)
SNIFF_BATCH=1
export SNIFF_BATCH

# remove old appcomm file (if there)
appFile=sniffappcomm_"$session"_$USER
rm -f "$TMP/.sniffdir2/$appFile"       		       			>> $basedir/update.log 2>&1

sniff -s $session -l $basedir/updateSniff.log & 			>> $basedir/update.log 2>&1
sleep 120

# clean old cache directory
if [ -r $basedir/.ProjectCache ]
then
	find $basedir/.ProjectCache -type f -exec rm -f {} \;  		>> $basedir/update.log 2>&1
fi

if [ -r $TMP/sniffacess_"$session"_$USER ]
then
	rm -f $TMP/sniffacess_"$session"_$USER 				>> $basedir/update.log 2>&1
fi

# open project in SNiFF+ and update the workspace and the makefiles
# update configuration information and generate xref information new
echo "set_timeout 2000          # set timeout to 2000 sec" 		>  $TMP/sniffacess_"$session"_$USER
echo set_workingenv \"$1\"						>> $TMP/sniffacess_"$session"_$USER
if [ "$3" = "SSWE" -o "$3" = "PWE" ]
then
	echo open_project \"$2\" NO_CACHE				>> $TMP/sniffacess_"$session"_$USER
else
	echo open_project \"$2\" WITHOUT_SYMBOLS NO_CACHE 		>> $TMP/sniffacess_"$session"_$USER
fi
echo "update_private_we */      # update workingenv" 			>> $TMP/sniffacess_"$session"_$USER
echo "reload_project */"						>> $TMP/sniffacess_"$session"_$USER
echo "update_makefiles */"						>> $TMP/sniffacess_"$session"_$USER
if [ "$3" != "SOWE" ]
then
	echo "update_cms_info */   # update configuration information"	>> $TMP/sniffacess_"$session"_$USER
	echo "generate_xref_info */"					>> $TMP/sniffacess_"$session"_$USER
fi
echo check_obsolete_files \"`basename $2`\"				>> $TMP/sniffacess_"$session"_$USER
echo quit								>> $TMP/sniffacess_"$session"_$USER


sniffaccess -s $session < $TMP/sniffacess_"$session"_$USER 		>> $basedir/update.log 2>&1

rm -f $TMP/sniffacess_"$session"_$USER 					>> $basedir/update.log 2>&1

if [ "$3" != "SSWE" ]
then
	if [ "$3" = "PWE" ]
	then
		# clean all targets recursively
		# make symbolic links to shared object files.
		echo $MAKE -i clean					>> $basedir/update.log 2>&1
		$MAKE -i clean						>> $basedir/update.log 2>&1
		echo $MAKE -i symbolic_links				>> $basedir/update.log 2>&1
		$MAKE -i symbolic_links					>> $basedir/update.log 2>&1
	fi
	if [ "$3" = "SOWE" ]
	then
		# make symbolic link to the shared dependencies file recursively
		# make symbolic links to shared object files.
		# Symbolic links are only needed if there are multiple shared object
		# workspaces in the working environment
		echo $MAKE -i symbolic_link_to_dependencies_file	>> $basedir/update.log 2>&1
		$MAKE -i symbolic_link_to_dependencies_file		>> $basedir/update.log 2>&1
		#$MAKE -i symbolic_links				>> $basedir/update.log 2>&1
	fi
	# start make recursively
	echo $MAKE -i CHECK_UPDATE=0					>> $basedir/update.log 2>&1
	$MAKE -i CHECK_UPDATE=0											 		>> $basedir/update.log 2>&1
	ret=$?
else
	ret=0
fi

echo "==================================================================="	>> $basedir/update.log 2>&1
echo "End of update: "														>> $basedir/update.log 2>&1
date										>> $basedir/update.log 2>&1
echo "==================================================================="	>> $basedir/update.log 2>&1

#(echo "Subject: Update in the WE '$1'"; echo To: $USER; echo ''; cat $basedir/updateSniff.log $basedir/update.log) | postmail -Htakefive.takefive.co.at -F$3 $USER
#for MKS Toolkit
#(echo "Subject: Update in the WE '$1'"; echo To: $USER; echo ''; cat $basedir/updateSniff.log $basedir/update.log) | smtpmail -h takefive.takefive.co.at -F "$3 $USER"
exit $ret
