BUILD_DATE="2000/04/14 MRe"
INTEGRATION_VERSION="2.4.4"

# set the PATH in case we are called from a freshly installed
# pRISM+ environment
PATH="$PSS_ROOT/bin/source/plugins/scripts;$PATH"

# calling this script with any first parameter
# switches debug mode on.
# Having set the variable DEBUG to != "0"
# also turns on the debugmode
if [ "X$1" != "X" ]
then
  DEBUG="1"
fi

if [ "X$DEBUG" = "X" ]
then
  DEBUG="0"
fi

if [ $DEBUG != "0" ]
then
  echo Debugmode turned on!
  echo
  CP_DBG="v"
else
  CP_DBG=""
fi

# Test whether we were started from within the
# Korn Shell for pRISM+
if [ "X$PRISM_INSTALL_DIR" = "X" ]
then
  echo Sorry!
  echo You need to start this script from within the
  echo \"Korn Shell for pRISM+\"
  echo Please try again!
  echo
  echo Installation aborted!
  echo
  echo Press the \<Enter\>-Key to terminate the installation script!
  read response_input
  echo
  exit 1
fi

PRISM_INSTALL_DIR=`VarDosToUnix PRISM_INSTALL_DIR`
# export all environment variables by default
set -a

# find out, which Target CPU family we support
if [ "X$CPU_FAMILY" = "X" ]
then
  # set the CPU_FAMILY to "ppc" since the distribution of PPC
  # is the only one that does not set this variable
  CPU_FAMILY="ppc"
fi

# since there are 3 and 4 letter replacements (mip and mips) used
CPU_FAMILY_3LETTERS=`echo $CPU_FAMILY | cut "-c 1-3" -`

# find out, Compiler we are using
# is this pRISM+ for PPC or ARM?
if [ "X$COMP_TOOL" = "X"  ]
then
  if [ $CPU_FAMILY = "ppc" ]
  then
    COMP_TOOL="diab"
  else
    # it has to be pRISM+ for ARM (at least it was in the pSOSystem V2.3.0 like this!)
    if [ "X$TOOL_VENDOR" = "X" ]
    then
      # strange, set default compiler to "arm"
      COMP_TOOL="arm"
    else
      COMP_TOOL=$TOOL_VENDOR
    fi
  fi
fi

# set the $SNIFF_VERSION to "3.2" to use generic scripts afterwards
SNIFF_VERSION="3.2"

# set the $SNIFF_DIR to the new SNiFF+ Installation directory (default value)
SNIFF_DIR="$PRISM_INSTALL_DIR/sniff${SNIFF_VERSION}"

# Generate a TempFile name
# Windows compatibility
SYS=`uname`
case "$SYS" in
    DOS|*NT|Windows*)
        DEVNULL=nul
        if [ X$TMP != "X" ]
        then
            TMP_DIR=`VarDosToUnix TMP`
        elif [ X$TEMP != "X" ]
        then
            TMP_DIR=`VarDosToUnix TEMP`
        else
            TMP_DIR="."
        fi
        mkdir -p $TMP_DIR
        ;;
    *)
        DEVNULL=/dev/null
        TMP_DIR=/tmp
        ;;
esac
USERNAME=`logname`

# Generate a Version textfile
echo "Installation of the Integration of SNiFF+ ${SNIFF_VERSION} in pRISM+ 2.0" > version.txt
echo "         this is for pRISM+ for $CPU_FAMILY on $HOST               "  >> version.txt
echo "                   Version   : $INTEGRATION_VERSION                       " >> version.txt
echo "                   Build Date: $BUILD_DATE                       " >> version.txt
echo
echo
cat version.txt
echo
echo "*------------------- Important ---------------------------*"
echo "*     Please select a windowbuffersize of 1000 in your    *"
echo "*   MKS Korn Shell Windos properties (Windos NT only!)    *"
echo "*------------------- Important ---------------------------*"
echo

# Test whether the SNiFF+ should be installed in the default locaton
TMP_NAME=`dirname $PWD`
SNIFF_DIR_NEW=`dirname $TMP_NAME`

echo
echo "Did you install the new SNiFF+ Version ${SNIFF_VERSION} here (y/[n])?"
echo "(${SNIFF_DIR_NEW})"
read response_input
response=${response_input:-"n"}

if [ $response = "y" -o  $response = "Y" ]
then
  SNIFF_DIR=$SNIFF_DIR_NEW
else
  DONE_FLAG=0
  until [ DONE_FLAG = 1 ]
    do
      echo Enter the complete path to the SNiFF+ Installation:
      echo "(Please enter the separator for directories either as"
      echo " a single slash \"/\" or"
      echo " a double backslash \"\\ \b\\\" !"
      read READ_DIR
      READ_DIR=`VarDosToUnix READ_DIR`
      if [ -d $READ_DIR ]
      then
        echo "Ist this the right directory (y/[n])?"
        echo $READ_DIR
        read response_input
        response=${response_input:-"n"}
        if [ $response = "y" -o  $response = "Y" ]
        then
         SNIFF_DIR=$READ_DIR
         DONE_FLAG=1
         break
        fi
      else
        echo This directory does not exist. Please retry
        echo
      fi
    done
fi

# Test if the SNiFF+ 3.0.2 product is installed
RESULT=`awk '/^SNiFF+/ {if ( $3 == "3.0.2" ) print 1; else print 0}' $SNIFF_DIR/Version`
if [ $RESULT =  "1" ]
then
  echo Sorry!
  echo There seem to be no SNIFF+ ${SNIFF_VERSION} in this directory!
  echo
  echo The Version found is:
  cat $SNIFF_DIR/Version
  echo
  echo Please try again!
  echo
  echo Installation aborted!
  echo
  echo Press the \<Enter\>-Key to terminate the installation script!
  read response_input
  echo
  exit 1
fi

BACKUP_EXISTS=0
# Test whether the Installation already took place
INTEGRATION_BACKUP=$PRISM_INSTALL_DIR/backup/SNiFF${SNIFF_VERSION}_integration/V${INTEGRATION_VERSION}_${CPU_FAMILY}
if [ -d $INTEGRATION_BACKUP ]
then
  BACKUP_EXISTS=1
  echo Previous installation detected!
  echo "Should the current installation be continued (y/[n])?"
  read response_input
  response=${response_input:-"n"}
  if [ $response = "y" -o  $response = "Y" ]
  then
    echo Installation will overwrite previous installation!
    echo "Should the current Backup be saved ([y]/n)?"
    read response_input
    response=${response_input:-"y"}
    if [ $response = "y" -o  $response = "Y" ]
    then
      mv -rf$CP_DBG $INTEGRATION_BACKUP ${INTEGRATION_BACKUP}_`date "+%Y%m%d_%H%M%S"`
      echo
      echo "Backup moved to:"
      echo "${INTEGRATION_BACKUP}_`date "+%Y%m%d_%H%M%S"`"
      echo
    else
      rm -rf$CP_DBG $INTEGRATION_BACKUP
    fi
  else
    echo Installation aborted!
    exit 1
  fi
fi
echo Installation starts ...
echo

# set the $SNIFF_INTEGRATION_DIR to the new SNiFF+ ${SNIFF_VERSION}
# installation's integrations/pRISM2.0 directory
SNIFF_INTEGRATION_DIR="$SNIFF_DIR/integrations/pRISM2.0"

# convert all pathnames to Unix notaion
PRISM_INSTALL_DIR=`VarDosToUnix PRISM_INSTALL_DIR`
PSS_ROOT=`VarDosToUnix PSS_ROOT`
SNIFF_DIR=`VarDosToUnix SNIFF_DIR`
SNIFF_INTEGRATION_DIR=`VarDosToUnix SNIFF_INTEGRATION_DIR`

if [ $DEBUG != 0 ]
then
  echo Generating the backup directories in
fi
mkdir -p $INTEGRATION_BACKUP/`basename $PSS_ROOT`
mkdir -p $INTEGRATION_BACKUP/sniff
if [ $DEBUG != 0 ]
then
  echo Backup directory is: $INTEGRATION_BACKUP
  echo
fi

echo You should do a backup of the directory \$PSS_ROOT which points to
echo "  \"$PSS_ROOT\""
echo "Should the backup be done now ([y]/n)?"
read response_input
response=${response_input:-"y"}
if  [ $response = "n" -o  $response = "N" ]
then
  echo Skipping the backup!
else
  echo Backing up the complete \$PSS_ROOT now ...
  cp -rf$CP_DBG $PSS_ROOT $INTEGRATION_BACKUP
  echo Backup of \$PSS_ROOT done!
fi

echo
echo Copy SNiFF+ related files ...
if [ $DEBUG != 0 ]
then
  echo
  echo Copy the file SitePrefs.pRISM20_${CPU_FAMILY}.sniff
fi
if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION} ]
then
  mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}
fi
mv -f$CP_DBG $SNIFF_DIR/SitePrefs.sniff $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/SitePrefs.pRISM20_${CPU_FAMILY}.sniff $SNIFF_DIR/SitePrefs.sniff

if [ $DEBUG != 0 ]
then
  echo Hide the shell and sed shipped with SNIFF+
fi
if [ -f $SNIFF_DIR/bin/sh.exe ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin
  fi
  cp -f$CP_DBG $SNIFF_DIR/bin/sh.exe $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin
  mv -f$CP_DBG $SNIFF_DIR/bin/sh.exe $SNIFF_DIR/bin/sh_unused_due_mks.exe
fi

if [ -f $SNIFF_DIR/bin/sed.exe ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin
  fi
  cp -f$CP_DBG $SNIFF_DIR/bin/sed.exe $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin
  mv -f$CP_DBG $SNIFF_DIR/bin/sed.exe $SNIFF_DIR/bin/sed_unused_due_mks.exe
fi

if [ $DEBUG != 0 ]
then
  echo Backup the utilities diff.exe and diff3.exe in the \$ROOTDIR
fi

if [ -f $ROOTDIR/mksnt/diff.exe ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/mksnt ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/mksnt
  fi
  cp -f$CP_DBG $ROOTDIR/mksnt/diff.exe $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/mksnt
  mv -f$CP_DBG $ROOTDIR/mksnt/diff.exe $ROOTDIR/mksnt/diff_mks.exe
fi
if [ -f $ROOTDIR/mksnt/diff3.exe ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/mksnt ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/mksnt
  fi
  cp -f$CP_DBG $ROOTDIR/mksnt/diff3.exe $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/mksnt
  mv -f$CP_DBG $ROOTDIR/mksnt/diff3.exe $ROOTDIR/mksnt/diff3_mks.exe
fi

# To avoid legal problems we decided to not ship the manual pages of the MKS-Tools
# as a bugfix for the pRISM+ installation!
#
#if [ $DEBUG != 0 ]
#then
#  echo Copy manual pages for MKS Toolkit
#fi
#
#if [ -f $ROOTDIR/etc/man.dbz ]
#then
#  if [ ! -d $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/etc ]
#  then
#    mkdir -p $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/etc
#  fi
#  mv -f$CP_DBG $ROOTDIR/etc/man.dbz $INTEGRATION_BACKUP/sniff/mks/`basename $ROOTDIR`/etc
#fi
#cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/mks/etc/man.dbz $ROOTDIR/etc

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ architecture tester
fi

if [ -f $SNIFF_DIR/bin/sniff_arch ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin
  fi
  mv -f$CP_DBG $SNIFF_DIR/bin/sniff_arch $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/bin
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/bin/sniff_arch $SNIFF_DIR/bin

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ Assembler parser
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/bin/sniffasm.exe $SNIFF_DIR/bin

if [ $DEBUG != 0 ]
then
  echo Make sure, that older projects using the FileType asm will work
  echo So copy the latest parser using the right parser-API
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/bin/sniffasm.exe $SNIFF_DIR/bin/sniff-asm.exe

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ syntax highlighting for Assembler, Linker Command, MIB and pSOSystem API
fi
if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config/editor ]
then
  mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config/editor
fi
mv -f$CP_DBG $SNIFF_DIR/config/editor/InitCXX.py $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config/editor
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/editor $SNIFF_DIR/config

if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/lib/python/Sniff ]
then
  mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/lib/python/Sniff
fi
mv -f$CP_DBG $SNIFF_DIR/lib/python/Sniff/CharStyles.py $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/lib/python/Sniff
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/lib/python/Sniff/CharStyles.py $SNIFF_DIR/lib/python/Sniff

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ Assembler Symbol mapper
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/parser/sniffasm.lsd $SNIFF_DIR/config/parser

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ template files for C-Source files adapted for pRISM+
fi
if [ -f $SNIFF_DIR/config/template.C ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config
  fi
  mv -f$CP_DBG $SNIFF_DIR/config/template.C $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/template.C $SNIFF_DIR/config

if [ -f $SNIFF_DIR/config/template.h ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config
  fi
  mv -f$CP_DBG $SNIFF_DIR/config/template.h $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/template.h $SNIFF_DIR/config

if [ -f $SNIFF_DIR/config/template.makefile ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config
  fi
  mv -f$CP_DBG $SNIFF_DIR/config/template.makefile $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/config
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/template.makefile $SNIFF_DIR/config

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ template files for pRISM+ projects
fi

if [ $DEBUG != 0 ]
then
  echo Make a difference of Objects named *.o and *.OBJ for x86
fi

if [ $CPU_FAMILY = "x86" ]
then
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/project_${CPU_FAMILY}/* $SNIFF_DIR/config/project
else
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/project $SNIFF_DIR/config
fi

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ FileTypes Icons
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/icons $SNIFF_DIR/config

if [ $DEBUG != 0 ]
then
  echo Copy the SNiFF+ make support files for pRISM+
fi
if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/make_support ]
then
  mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/make_support
fi
cp -rf$CP_DBG $SNIFF_DIR/make_support $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/make_support $SNIFF_DIR

if [ $DEBUG != 0 ]
then
  echo Copy the new SNiFF+ File Type and Platform descriptions
  echo
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/Preferences $SNIFF_DIR

if [ $DEBUG != 0 ]
then
  echo Generating the updateWS.ksh script
fi
if [ -f $SNIFF_DIR/ws_support/updateWS.sh ]
then
  if [ ! -d $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/ws_support ]
  then
    mkdir -p $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/ws_support
  fi
  cp -rf$CP_DBG $SNIFF_DIR/ws_support/updateWS.sh $INTEGRATION_BACKUP/sniff${SNIFF_VERSION}/ws_support
  rm -f$CP_DBG $SNIFF_DIR/ws_support/updateWS.sh
fi
echo "#!/bin/sh" > $SNIFF_DIR/ws_support/updateWS.ksh
echo "# generated by the integration of SNiFF+ ${SNIFF_VERSION} in pRISM+ 2.0 Version ${INTEGRATION_VERSION}" >> $SNIFF_DIR/ws_support/updateWS.ksh
echo ". \"$PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh\"" >> $SNIFF_DIR/ws_support/updateWS.ksh
cat $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/ws_support/updateWS1.ksh >> $SNIFF_DIR/ws_support/updateWS.ksh
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/ws_support/ReadMe_Windows.txt $SNIFF_DIR/ws_support
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/ws_support/Start_updateWS.bat $SNIFF_DIR/ws_support

if [ $DEBUG != 0 ]
then
  echo Copy the environment script for SNiFF+
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/SNiFF${SNIFF_VERSION}/config/environ_pRISM_for_SNiFF${SNIFF_VERSION}.ksh $SNIFF_DIR/config

if [ $DEBUG != 0 ]
then
  echo Copy the file WorkingEnvData.sniff
fi
if [ ! -d $PSS_ROOT/workingenvs/SNIFF${SNIFF_VERSION}_pRISM2.0/${CPU_FAMILY} ]
then
  mkdir -p $PSS_ROOT/workingenvs/SNIFF${SNIFF_VERSION}_pRISM2.0/${CPU_FAMILY}
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/workingenvs/SNIFF${SNIFF_VERSION}_pRISM2.0/${CPU_FAMILY}/WorkingEnvData_standard.sniff $PSS_ROOT/workingenvs/SNIFF${SNIFF_VERSION}_pRISM2.0/${CPU_FAMILY}/WorkingEnvData.sniff


echo done

# Test if the SNiFF+ Version is the GA V3.2. If yes, patch it!

RESULT=`awk '/^SNiFF+/ {if ( $3 == "3.2" ) print 1; else print 0}' $SNIFF_DIR/Version`
if [ $RESULT =  "1" ]
then
  echo
  echo "!!!!! Caution: You are using SNiFF+ 3.2 generated in November 1999     !!!!!"
  echo "!!!!!          You should update to V3.2.1 or later for proper results !!!!!"
  echo
fi

echo Copy pRISM+ related files ...
if [ $DEBUG != 0 ]
then
  echo
  echo Delete old File Types and settings
fi

if [ $DEBUG != 0 ]
then
  echo Copy all the new scripts of the integration
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/bin $PSS_ROOT

if [ $CPU_FAMILY = "x86" ]
then
  if [ -f $PSS_ROOT/bin/win32/sed.exe ]
  then
    if [ $DEBUG != 0 ]
    then
      echo Get rid of the tiny sed.exe coming with pSOSystem x86!
    fi

    if [ ! -d $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bin/win32 ]
    then
      mkdir -p $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bin/win32
    fi
    cp -rf$CP_DBG $PSS_ROOT/bin/win32/sed.exe $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bin/win32
    mv -rf$CP_DBG $PSS_ROOT/bin/win32/sed.exe $PSS_ROOT/bin/win32/sed_psos.exe
  fi
fi

if [ $DEBUG != 0 ]
then
  echo Is the make utility up to date?
fi
if [ $SNIFF_INTEGRATION_DIR/pRISM2.0/bin/win32/gnu/make.exe -nt $PSS_ROOT/win32/gnu/make.exe ]
then
  if [ $DEBUG != 0 ]
  then
    echo Copy the make utility of PPC SP1!
  fi

  if [ ! -d $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bin/win32/gnu ]
  then
    mkdir -p $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bin/win32/gnu
  fi
  mv -rf$CP_DBG $PSS_ROOT/bin/win32/gnu/make.exe $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bin/win32/gnu
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/bin/win32/gnu/make.exe $PSS_ROOT/bin/win32/gnu
fi

if [ $CPU_FAMILY = "x86" -o $CPU_FAMILY = "arm" ]
then
  if [ $DEBUG != 0 ]
  then
    echo Patch the makefile in \$PSS_ROOT/sys/os due to the new make utility!
  fi

  TMP_MAKEFILE=$TMP_DIR/makefile_sys_os_`date "+%Y%m%d_%H%M%S"`
  if [ ! -d $INTEGRATION_BACKUP/`basename $PSS_ROOT`/sys/os ]
  then
    mkdir -p $INTEGRATION_BACKUP/`basename $PSS_ROOT`/sys/os
  fi
  sed -e "s,\$(RECURSIVE_MAKE_OPT) \$(MAKEFLAGS),\$(RECURSIVE_MAKE_OPT) \$(MFLAGS),g" $PSS_ROOT/sys/os/makefile > $TMP_MAKEFILE
  if [ $? -eq 0 ]
  then
    mv -rf$CP_DBG $PSS_ROOT/sys/os/makefile $INTEGRATION_BACKUP/`basename $PSS_ROOT`/sys/os
    mv -rf$CP_DBG $TMP_MAKEFILE $PSS_ROOT/sys/os/makefile
    if [ $DEBUG != 0 ]
    then
      echo "TMP_MAKEFILE:"
      cat $TMP_MAKEFILE
      echo
    fi
    rm -f$CP_DBG $TMP_MAKEFILE
  fi
fi

if [ $CPU_FAMILY = "mips" ]
then
  if [ $DEBUG != 0 ]
  then
    echo Patch the makefile in \$PSS_ROOT/bsps/idt79465/src due to a bug!
  fi

  TMP_MAKEFILE=$TMP_DIR/makefile_bsp_`date "+%Y%m%d_%H%M%S"`
  if [ ! -d $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bsps/idt79465/src ]
  then
    mkdir -p $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bsps/idt79465/src
  fi
  sed -e "s,\$(RECURSIVE_MAKE_OPT) \$(MAKEFLAGS),\$(RECURSIVE_MAKE_OPT) \$(MFLAGS),g" $PSS_ROOT/bsps/idt79465/src/makefile > $TMP_MAKEFILE
  if [ $? -eq 0 ]
  then
    mv -rf$CP_DBG $PSS_ROOT/bsps/idt79465/src/makefile $INTEGRATION_BACKUP/`basename $PSS_ROOT`/bsps/idt79465/src
    mv -rf$CP_DBG $TMP_MAKEFILE $PSS_ROOT/bsps/idt79465/src/makefile
    if [ $DEBUG != 0 ]
    then
      echo "TMP_MAKEFILE:"
      cat $TMP_MAKEFILE
      echo
    fi
    rm -f$CP_DBG $TMP_MAKEFILE
  fi
fi

if [ $DEBUG != 0 ]
then
  echo Copy the pSOSystem Template application for SNiFF+
fi

if [ -d $PSS_ROOT/apps/snf_tmpl_${CPU_FAMILY} ]
then
  if [ ! -d $INTEGRATION_BACKUP/`basename $PSS_ROOT`/apps/snf_tmpl_$CPU_FAMILY ]
  then
    mkdir -p $INTEGRATION_BACKUP/`basename $PSS_ROOT`/apps
  fi
  mv -rf$CP_DBG $PSS_ROOT/apps/snf_tmpl_${CPU_FAMILY} $INTEGRATION_BACKUP/`basename $PSS_ROOT`/apps
fi
cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/apps/snf_tmpl_${CPU_FAMILY} $PSS_ROOT/apps

if [ $DEBUG != 0 ]
then
  echo Copy the demo application for user project
fi
mkdir -p $PSS_ROOT/contrib/user_pdemo
if [ $CPU_FAMILY = "arm" -o $CPU_FAMILY = "68k" ]
then
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/contrib/user_pdemo_230/* $PSS_ROOT/contrib/user_pdemo
else
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/contrib/user_pdemo_250/* $PSS_ROOT/contrib/user_pdemo
fi

# bugfixes for PPC
if [ $CPU_FAMILY = "ppc" ]
then
  if [ $DEBUG != 0 ]
  then
    echo Copy the file .snifffl.lst to \$PSS_ROOT/bsps/simppc/src
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/bsps/ppc/simppc/src/.snifffl.lst $PSS_ROOT/bsps/simppc/src
fi

# bugfixes for ARM
if [ $CPU_FAMILY = "arm" ]
then
  if [ ! -f $PSS_ROOT/bsps/template/.snifffl.lst ]
  then
    if [ $DEBUG != 0 ]
    then
      echo Copy the file .snifffl.lst to \$PSS_ROOT/bsps/template/src
    fi
    cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/bsps/arm/template/src/.snifffl.lst $PSS_ROOT/bsps/template/src
  fi

  if [ $DEBUG != 0 ]
  then
    echo Copy the file .snifffl.lst to \$PSS_ROOT/bsps/armul/src
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/bsps/arm/armul/src/.snifffl.lst $PSS_ROOT/bsps/armul/src

  if [ $DEBUG != 0 ]
  then
    echo Copy the file .snifffl.lst to \$PSS_ROOT/bsps/pid7t/src
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/bsps/arm/pid7t/src/.snifffl.lst $PSS_ROOT/bsps/pid7t/src

  if [ $DEBUG != 0 ]
  then
    echo Copy the file .snifffl.lst to \$PSS_ROOT/bsps/pid940t/src
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/bsps/arm/pid940t/src/.snifffl.lst $PSS_ROOT/bsps/pid940t/src

  if [ $DEBUG != 0 ]
  then
    echo Copy the file .snifffl.lst to \$PSS_ROOT/apps/pdemo
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/apps/arm/pdemo/.snifffl.lst $PSS_ROOT/apps/pdemo
fi

if [ $DEBUG != 0 ]
then
  echo Test if the files of pSOSim need to be copied
fi

if [ ! -f $PSS_ROOT/include/pna_rename.h ]
then
  if [ $DEBUG != 0 ]
  then
    echo Copy pna_rename.h to \$PSS_ROOT/include
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/include/pna_rename.h $PSS_ROOT/include
fi

if [ ! -f $PSS_ROOT/include/prepc_rename.h ]
then
  if [ $DEBUG != 0 ]
  then
    echo Copy prepc_rename.h to \$PSS_ROOT/include
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/include/prepc_rename.h $PSS_ROOT/include
fi

if [ ! -f $PSS_ROOT/include/open_rename.h ]
then
  if [ $DEBUG != 0 ]
  then
    echo Copy open_rename.h to \$PSS_ROOT/include
  fi
  cp -rf$CP_DBG $SNIFF_INTEGRATION_DIR/pRISM2.0/include/open_rename.h $PSS_ROOT/include
fi

echo done
echo
echo "Generating pRISM+ scripts ..."
# Generate the setting of the varialbe $PRISM_INSTALL_DIR
# for the env<CPU_FAMILY_3LETTERS>.ksh
if [ $DEBUG != 0 ]
then
  echo Generating the env${CPU_FAMILY_3LETTERS}.ksh script
fi
cp -rf$CP_DBG $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh $INTEGRATION_BACKUP
rm -rf$CP_DBG $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

echo "#!/bin/sh" > $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "# generated by the integration of SNiFF+ ${SNIFF_VERSION} in pRISM+ 2.0 Version ${INTEGRATION_VERSION}" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
cat $SNIFF_INTEGRATION_DIR/pRISM2.0/envxxx1.ksh >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "PRISM_INSTALL_DIR=\"$PRISM_INSTALL_DIR\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "PRISM_VERSION=\"$PRISM_VERSION\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "HOST=\"$HOST\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "CPU_FAMILY=\"$CPU_FAMILY\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "CPU_FAMILY_3LETTERS=\"$CPU_FAMILY_3LETTERS\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "COMP_TOOL=\"$COMP_TOOL\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "PLATFORM=\"${COMP_TOOL}${CPU_FAMILY}_${HOST}\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

cat $SNIFF_INTEGRATION_DIR/pRISM2.0/envxxx2.ksh >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "ISI_PROJECT_NUM=\"$ISI_PROJECT_NUM\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "PSS_ROOT=\"$PSS_ROOT\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "PSS_ROOT_FOR_SNIFF_PWE=\"\$PSS_ROOT\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

cat $SNIFF_INTEGRATION_DIR/pRISM2.0/envxxx3.ksh >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

# Test whether we have a BSP under PSS_ROOT selected
TMP_NAME1=`VarDosToUnix PSS_BSP`
TMP_NAME1=`dirname \`dirname $PSS_BSP\``
TMP_NAME1=`VarDosToUnix TMP_NAME1`
TMP_NAME2=`VarDosToUnix PSS_ROOT`
if [ $TMP_NAME1 = $TMP_NAME2 ]
then
  if [ $DEBUG != 0 ]
  then
    echo
    echo "\$PSS_BSP set to found location: "
  fi
  echo "  PSS_BSP=\"\$PSS_ROOT/bsps/`basename $PSS_BSP`\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  if [ $DEBUG != 0 ]
  then
    echo "\$PSS_ROOT/bsps/`basename $PSS_BSP`"
    echo
  fi
else
  echo
  echo "Warning:"
  echo "\$PSS_BSP set to default: "
  case $CPU_FAMILY in

    ppc)
      echo "  PSS_BSP=\"\$PSS_ROOT/bsps/mbx8xx\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "\$PSS_ROOT/bsps/mbx8xx"
      ;;
    mips)
      echo "  PSS_BSP=\"\$PSS_ROOT/bsps/idt79465\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "\$PSS_ROOT/bsps/idt79465"
      ;;
    x86)
      echo "  PSS_BSP=\"\$PSS_ROOT/bsps/pc\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "\$PSS_ROOT/bsps/pc"
      ;;
    68k)
      echo "  PSS_BSP=\"\$PSS_ROOT/bsps/m167\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "\$PSS_ROOT/bsps/m167"
      ;;
    arm)
      echo "  PSS_BSP=\"\$PSS_ROOT/bsps/pid7t\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "\$PSS_ROOT/bsps/pid7t"
      ;;
    *)
      echo "  PSS_BSP=\"\$PSS_ROOT/bsps/template\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "\$PSS_ROOT/bsps/template"
      ;;
  esac
  echo
fi
echo "fi" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

if [ $CPU_FAMILY = "arm" ]
then
  echo "# Replace the next line with the token for your BSP_TYPE" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "# Valid tokens are 32l, 32b, 16l, or 16b" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "if [ \"x\$BSP_TYPE\" = \"x\" ]" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "then" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "  BSP_TYPE=\"$BSP_TYPE\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "fi" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
fi

cat $SNIFF_INTEGRATION_DIR/pRISM2.0/envxxx4.ksh >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "# SNiFF+" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "SNIFF_VERSION=\"${SNIFF_VERSION}\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "SNIFF_DIR=\"$SNIFF_DIR\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "SNIFF_INTEGRATION_DIR=\"\$SNIFF_DIR/integrations/pRISM2.0\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "PATH=\"\$SNIFF_DIR/bin;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "SNIFF_MAKE_CMD=\"snf_gnu\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "# Compiler speciffic settings" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "# for $COMP_TOOL" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

if [ $COMP_TOOL = "diab" ]
then
  echo "# DIAB-SDS Compiler" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  # generate DIABLIB setting
  echo "DIABLIB=`VarDosToUnix DIABLIB`" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "PATH=\"`VarDosToUnix DIABLIB`/$HOST/bin;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "DIABLIB=\`VarUnixToDos DIABLIB\`" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
fi

if [ $COMP_TOOL = "arm" ]
then
  # generate ARM setting
  echo "# ARM Compiler" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "ARM=`VarDosToUnix ARM`" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "ARMLIB=`VarDosToUnix ARMLIB`" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "ARMINC=`VarDosToUnix ARMINC`" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "PATH=\"`VarDosToUnix ARM`/bin;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "ARM=\`VarUnixToDos ARM\`" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
fi

if [ $COMP_TOOL = "cadul" ]
then
  # generate CAD-UL setting
  echo "# CAD-UL Compiler" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "CC386TMP=$TMP_DIR" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "PATH=\"`VarDosToUnix PRISM_INSTALL_DIR`/cadul/bin;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  echo "PATH=\"`VarDosToUnix PRISM_INSTALL_DIR`/cadul/xdb/x364b1xx;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
fi

# if we are on PowerPC, we need to
# test if we are using the SingleStep version 7.5 or 7.4?
if [ $CPU_FAMILY = "ppc" -o $CPU_FAMILY = "mips" ]
then
  if [ "X$SDS_VERSION" != "X" ]
  then
    if [ $DEBUG != 0 ]
    then
      echo SingleStep Version 7.5 detected!
    fi
    if [ $SDS_VERSION = "7.5"]
    then
      echo "" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "# DIAB-SDS Debugger" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "SDS_VERSION=7.5" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "PATH=\"\$PRISM_INSTALL_DIR/sds75/cmd;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
    else
      echo "Unknown DIAB-SDS Debugger version found!"
      echo "Please edit env${CPU_FAMILY}.ksh to include the right \$PATH for this debugger!"
      echo "# DIAB-SDS Debugger" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "# Please add the right debugger bin directory to PATH variable!" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
      echo "# PATH=\"\$PRISM_INSTALL_DIR/sds75/cmd;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
    fi
  else
    if [ $DEBUG != 0 ]
    then
      echo No SingleStep Version 7.5 detected! Must be 7.4!
    fi
    echo "" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
    echo "# DIAB-SDS Debugger" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
    echo "PATH=\"\$PRISM_INSTALL_DIR/sds74/cmd;\$PATH\"" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
  fi
fi

echo "" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "# MKS Tools" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "ROOTDIR=$ROOTDIR" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

cat $SNIFF_INTEGRATION_DIR/pRISM2.0/envxxx5.ksh >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "# FLEXLM license manager" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh
echo "LM_LICENSE_FILE=`VarDosToUnix LM_LICENSE_FILE`" >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh

cat $SNIFF_INTEGRATION_DIR/pRISM2.0/envxxx6.ksh >> $PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh


# Generate the call of the env<CPU_FAMILY_3LETTERS>.ksh from within
# prsm<CPU_FAMILY_3LETTERS>.ksh
# use generic version for all CPU_FAMILies
if [ $DEBUG != 0 ]
then
  echo Generating the prsm${CPU_FAMILY_3LETTERS}.ksh script
fi
cp -rf$CP_DBG $PRISM_INSTALL_DIR/prsm${CPU_FAMILY_3LETTERS}.ksh $INTEGRATION_BACKUP
rm -rf$CP_DBG $PRISM_INSTALL_DIR/prsm${CPU_FAMILY_3LETTERS}.ksh
echo "#!/bin/sh" > $PRISM_INSTALL_DIR/prsm${CPU_FAMILY_3LETTERS}.ksh
echo "# generated by the integration of SNiFF+ ${SNIFF_VERSION} in pRISM+ 2.0 Version ${INTEGRATION_VERSION}" >> $PRISM_INSTALL_DIR/prsm${CPU_FAMILY_3LETTERS}.ksh
echo ". \"$PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh\"" >> $PRISM_INSTALL_DIR/prsm${CPU_FAMILY_3LETTERS}.ksh
cat $SNIFF_INTEGRATION_DIR/pRISM2.0/prsmxxx1.ksh >> $PRISM_INSTALL_DIR/prsm${CPU_FAMILY_3LETTERS}.ksh

if [ $DEBUG != 0 ]
then
  echo Generating the psos${CPU_FAMILY_3LETTERS}.ksh script
fi
cp -rf$CP_DBG $PRISM_INSTALL_DIR/psos${CPU_FAMILY_3LETTERS}.ksh $INTEGRATION_BACKUP
echo "#!/bin/sh" > $PRISM_INSTALL_DIR/psos${CPU_FAMILY_3LETTERS}.ksh
echo "# generated by the integration of SNiFF+ ${SNIFF_VERSION} in pRISM+ 2.0 Version ${INTEGRATION_VERSION}" >> $PRISM_INSTALL_DIR/psos${CPU_FAMILY_3LETTERS}.ksh
echo ". \"$PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh\"" >> $PRISM_INSTALL_DIR/psos${CPU_FAMILY_3LETTERS}.ksh
cat $SNIFF_INTEGRATION_DIR/pRISM2.0/psosxxx1.ksh >> $PRISM_INSTALL_DIR/psos${CPU_FAMILY_3LETTERS}.ksh

if [ $DEBUG != 0 ]
then
  echo Generating the sniffproj_rebuild.ksh script
fi
if [ -f $PRISM_INSTALL_DIR/sniffproj_rebuild.ksh ]
then
  cp -rf$CP_DBG $PRISM_INSTALL_DIR/sniffproj_rebuild.ksh $INTEGRATION_BACKUP
fi
echo "#!/bin/sh" > $PRISM_INSTALL_DIR/sniffproj_rebuild.ksh
echo "# generated by the integration of SNiFF+ ${SNIFF_VERSION} in pRISM+ 2.0 Version ${INTEGRATION_VERSION}" >> $PRISM_INSTALL_DIR/sniffproj_rebuild.ksh
echo ". \"$PRISM_INSTALL_DIR/env${CPU_FAMILY_3LETTERS}.ksh\"" >> $PRISM_INSTALL_DIR/sniffproj_rebuild.ksh
cat $SNIFF_INTEGRATION_DIR/pRISM2.0/sniffproj_rebuild1.ksh >> $PRISM_INSTALL_DIR/sniffproj_rebuild.ksh

# Upgrade Preferences for SNiFF+
plugins_upgrade_siteprefs

# Do the User Profiles reside in $SNIFF_DIR/Profiles?
plugins_upgrade_userprefs


echo "done"
echo ""
echo "-------------------------- Important ----------------------"
echo ""
echo "The prebuilt SNiFF+ projects for the pSOSystem part have"
echo "to be rebuilt. This might be done now automatically."
echo "This may take some time!"
echo "This script takes about 20 ( - 80) minutes on a high ( - low)"
echo "performing computer."
echo "You may want to start this rebuilding of the projects later and"
echo "start the script later by calling: \"sniffproj_rebuild.ksh\""
echo "-------------------------- Important ----------------------"
echo ""
echo "Do you want to start the rebuilding of the project now ([y]/n)?"
read response_input
response=${response_input:-"y"}
if [ $response = "y" -o  $response = "Y" ]
then
  $PRISM_INSTALL_DIR/sniffproj_rebuild.ksh
else
  echo ""
  echo "Rebuilding skipped!"
  echo ""
  echo "Call "$PRISM_INSTALL_DIR/sniffproj_rebuild.ksh" before starting pRISM+!"
  echo ""
fi
echo "Installation done"
