/* MRe 2000/01/20 */
/***********************************************************************/
/*                                                                     */
/*   MODULE:  apps/user_pdemo/data.c                                   */
/*   DATE:    2000/01/20                                               */
/*   PURPOSE: A sample application for the host debugger.              */
/*                                                                     */
/*---------------------------------------------------------------------*/
/*                                                                     */
/*           Copyright 1991 - 2000, Integrated Systems, Inc.           */
/*                      ALL RIGHTS RESERVED                            */
/*                                                                     */
/*   Permission is hereby granted to licensees of Integrated Systems,  */
/*   Inc. products to use or abstract this computer program for the    */
/*   sole purpose of implementing a product based on Integrated        */
/*   Systems, Inc. products.   No other rights to reproduce, use,      */
/*   or disseminate this computer program, whether in part or in       */
/*   whole, are granted.                                               */
/*                                                                     */
/*   Integrated Systems, Inc. makes no representation or warranties    */
/*   with respect to the performance of this computer program, and     */
/*   specifically disclaims any responsibility for any damages,        */
/*   special or consequential, connected with the use of this program. */
/*                                                                     */
/*---------------------------------------------------------------------*/
/*                                                                     */
/*   This module contains code to simulate processing of RAM disk      */
/*   data.                                                             */
/*                                                                     */
/***********************************************************************/
#include "sys_conf.h"
#include <psos.h>
#include "demo.h"

/*---------------------------------------------------------------------*/
/* Function prototypes.                                                */
/*---------------------------------------------------------------------*/
static void calc_sum(unsigned long);
static long myequate(long x);
static long cube(long x);

/***********************************************************************/
/* process_data: Simulate processing RAM disk data.                    */
/*                                                                     */
/***********************************************************************/
void process_data(char *dataptr)
{
int Index;
unsigned long date, time, ticks;
unsigned long rc;

rc = tm_get(&date, &time, &ticks);
calc_sum(ticks);

for (Index = 0; Index < BLOCK_SIZE; Index++)
    dataptr[Index] = ~dataptr[Index];

tm_wkafter(10);
}

/***********************************************************************/
/*        calc_sum:   Calculates the sum of an arbitrary function.     */
/*                                                                     */
/*        NOTE: Called from either 'IO1 ' or 'IO2 '                    */
/***********************************************************************/
static void calc_sum(unsigned long ticks)
{
long sum = 0;
long x, y;
long max_value;
long count;

#define INCREMENT 1

/*---------------------------------------------------------------------*/
/* Use ticks to determine values to plug into function.                */
/*---------------------------------------------------------------------*/

max_value = (ticks % 16) + 16;                           /* some number */
x = -max_value;

while (x < max_value)
   {
   y = myequate(x);
   sum = sum + y;
   x += INCREMENT;
   }

/*---------------------------------------------------------------------*/
/* Loop some more to simulate processing time.                         */
/*---------------------------------------------------------------------*/
count = max_value * 9000;
while (count--)
   ;;

}

/***********************************************************************/
/*  myequate: Calculate the function, y = x^3                          */
/*          given the value of x.                                      */
/*                                                                     */
/*        NOTE: Called by 'IO1 ' and 'IO2 ' tasks                      */
/***********************************************************************/
static long myequate(long x)
{
return(cube(x));
}

/***********************************************************************/
/*  cube:  Calculate the cube of a number, i.e. x times x times x      */
/*                                                                     */
/*        NOTE: Called by 'IO1 ' and 'IO2 ' tasks                      */
/***********************************************************************/
static long cube(long x)
{

return(x * x * x);
}


