/* @(#) pSOSystem MIPS/V2.5.0: apps/pdemo/demo.c (&U&) 4.13 99/02/01 13:36:39 */
/***********************************************************************/
/*                                                                     */
/*   MODULE:  apps/pdemo/demo.c                                        */
/*   DATE:    99/02/01                                                 */
/*   PURPOSE: A sample application for the host debugger.              */
/*                                                                     */
/*---------------------------------------------------------------------*/
/*                                                                     */
/*           Copyright 1991 - 1998, Integrated Systems, Inc.           */
/*                      ALL RIGHTS RESERVED                            */
/*                                                                     */
/*   Permission is hereby granted to licensees of Integrated Systems,  */
/*   Inc. products to use or abstract this computer program for the    */
/*   sole purpose of implementing a product based on Integrated        */
/*   Systems, Inc. products.   No other rights to reproduce, use,      */
/*   or disseminate this computer program, whether in part or in       */
/*   whole, are granted.                                               */
/*                                                                     */
/*   Integrated Systems, Inc. makes no representation or warranties    */
/*   with respect to the performance of this computer program, and     */
/*   specifically disclaims any responsibility for any damages,        */
/*   special or consequential, connected with the use of this program. */
/*                                                                     */
/*---------------------------------------------------------------------*/
/*                                                                     */
/*   This sample application contains the following tasks:             */
/*                                                                     */
/*   "ROOT":   Starts the other tasks, then suspends itself            */
/*   "MEM1":   Requests memory segments of various sizes               */
/*   "MEM2":   Receives memory segments from "MEM1" and frees them     */
/*   "IO1_":   Reads a block from the RAM disk                         */
/*   "IO2_":   Writes a block to the RAM disk                          */
/*   "SRCE":   Sends messages to Queue "SS__"                          */
/*   "SINK":   Consumes messages from Queue "SS__"                     */
/*   "SUDO":   pSEUDO driver demonstration task                        */
/*                                                                     */
/***********************************************************************/
#include "sys_conf.h"
#include <psos.h>
#include <probe.h>
#include <pna.h>
#include <phile.h>
#include <pmont.h>
#include <drv_intf.h>
#include <string.h>
#include <stdio.h>
#include "demo.h"
#include <bspfuncs.h>

/*---------------------------------------------------------------------*/
/* Function Prototypes                                                 */
/*---------------------------------------------------------------------*/
static void mem1(void);
static void mem2(void);
static void source(void);
static void sink(void);
static void io1(void);
static void io2(void);
static void pseudo_demo(void);
static void PrintErrMessage(char *FileName, int LineNum, unsigned long ErrCode);

/*---------------------------------------------------------------------*/
/* Global variables                                                    */
/*---------------------------------------------------------------------*/
char pbuf[LENGTH + 4];              /* buffer used by 'PTN1' partition */
static UCHAR WriteBuf[]  = "pSEUDO driver demo task output\n";
static UCHAR ReadBuf[100];
UCHAR  gPseudoDemo = 0;             /* Set this varible to non-zero to */
                                    /* enable pSEUDO demo output       */

/***********************************************************************/
/*        root: Sets up the evaluation program execution.              */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): Executes as task 'ROOT'.                               */
/*                                                                     */
/***********************************************************************/
void 
root(void)
{
unsigned long qidss, qid;
unsigned long iopb[4], ioretval;
unsigned long date, time, ticks;
unsigned long tid[10], demo_tid;
void *data_ptr;
unsigned long rc;
unsigned long ptid, nbufs;
unsigned long smid;
void *seg_ptr;
unsigned long rnid, rsize;

/*---------------------------------------------------------------------*/
/* Set date to May 1, 1995, time to 8:30 AM, and start the system      */
/* clock running.                                                      */
/*---------------------------------------------------------------------*/
date = (1995 << 16) + (5 << 8) + 1;
time = (8 << 16) + (30 << 8);
ticks = 0;
tm_set(date, time, ticks);

/*---------------------------------------------------------------------*/
/* Initialize the Timer and console device                             */
/*---------------------------------------------------------------------*/
#if !SC_AUTOINIT
if ((rc = de_init(DEV_TIMER, iopb, &ioretval, &data_ptr)) != NOERR)
    k_fatal(0x10000 + rc, 0);
    
if ((rc = de_init(CONSOLE, iopb, &ioretval, &data_ptr)) != NOERR)
    k_fatal(0x10000 + rc, 0);
#endif

/*---------------------------------------------------------------------*/
/* Now initialize the RAM disk driver.  Although this application      */
/* does not use the pHILE+ file system manager, it does read and write */
/* blocks from the "RAM disk" device.  The reading and writing of      */
/* these "disk" blocks is done  by direct calls to de_read() and       */
/* de_write().  Tasks 'IO1_' and 'IO2_' make these calls.              */
/*---------------------------------------------------------------------*/
iopb[0] = NUM_BLOCKS;
if ((rc = de_init(DEV_RAMDISK, iopb, &ioretval, &data_ptr)) != NOERR)
    k_fatal(0x10000 + rc, 0);

/*---------------------------------------------------------------------*/
/* Create the queue which will be used by SOURCE and SINK.  Also,      */
/* create the partition that will be used by IO1_ and IO2_.            */
/*---------------------------------------------------------------------*/
if ((rc = q_create("SS__", 8, Q_PRIOR | Q_LIMIT, &qidss)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = pt_create("PTN1", (void *) (((unsigned long) pbuf + 4) & 0xFFFFFFFC), 
           (void  *) 0, LENGTH, BLOCK_SIZE, PT_NODEL, &ptid, &nbufs)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

/*---------------------------------------------------------------------*/
/* Create the message queue that MEM1 & MEM2 will use for              */
/* communication.                                                      */
/*---------------------------------------------------------------------*/
if ((rc = q_create("QMEM", 0, Q_FIFO  | Q_NOLIMIT | Q_SYSBUF, &qid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

/*---------------------------------------------------------------------*/
/* Obtain a chunk of memory from region 0, and "subdivide" it by       */
/* creating a new memory region with it.  Note that we get four bytes  */
/* more than we need so that we can insure alignment on a longword     */
/* boundary, which pSOS+ requires when creating a memory region.       */
/*---------------------------------------------------------------------*/
if (( rc = rn_getseg(0, RNSIZE + 4, RN_NOWAIT, 0, &seg_ptr)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

seg_ptr = (void *)((unsigned long)((char *)seg_ptr + 3) & ~3);

if ((rc = rn_create("RMEM", seg_ptr, RNSIZE, 128, 0, &rnid, &rsize)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

/*---------------------------------------------------------------------*/
/* Create all application tasks                                        */
/*---------------------------------------------------------------------*/
if ((rc = t_create("MEM1", 48,  4096, 512, 0, &tid[0])) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_create("MEM2", 47,  4096, 512, 0, &tid[1])) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_create("IO1_", 30,  4096, 512, 0, &tid[2])) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_create("IO2_", 30,  4096, 512, 0, &tid[3])) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_create("SRCE", 128, 4096, 512, 0, &tid[4])) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_create("SINK", 80,  4096, 512, 0, &tid[5])) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_create("SUDO", 129, 4096, 512, 0, &demo_tid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

/*---------------------------------------------------------------------*/
/* Now, start all application tasks                                    */
/*---------------------------------------------------------------------*/
if ((rc = t_start(tid[0], T_USER | T_PREEMPT | T_NOTSLICE, mem1, 0)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_start(tid[1], T_USER | T_PREEMPT | T_NOTSLICE, mem2, 0)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_start(tid[2], T_USER | T_PREEMPT | T_TSLICE,   io1, 0)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_start(tid[3], T_USER | T_PREEMPT | T_TSLICE,   io2, 0)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_start(tid[4], T_SUPV | T_PREEMPT | T_NOTSLICE, source,0)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_start(tid[5], T_SUPV | T_PREEMPT | T_NOTSLICE, sink,  0)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_start(demo_tid, T_USER | T_PREEMPT | T_TSLICE, pseudo_demo, 0)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

t_suspend(0L);
}

/***********************************************************************/
/*        mem1: Obtains memory segments and sends their addresses to   */
/*              'MEM2' via message queue 'QMEM'.                       */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): Executes as task 'MEM1'.                               */
/*                                                                     */
/***********************************************************************/
static void 
mem1(void)
{
unsigned long size, rc, qid, rnid;
unsigned long date, time, ticks;
MEMMSG *current_msg;
MEMMSG msgarray[MAX_MSG];
void *seg_ptr;
static int i;
unsigned long ntimes = 0;

/*---------------------------------------------------------------------*/
/* Create a circular linked list to store messages.                    */
/*---------------------------------------------------------------------*/
for (i = 0; i < (MAX_MSG - 1); i++) 
    msgarray[i].next = &msgarray[i+1];

msgarray[MAX_MSG-1].next = &msgarray[0]; /* Wrap around the buffer list*/
current_msg = msgarray;

/*---------------------------------------------------------------------*/
/* Get the QMEM and RMEM idents                                        */
/*---------------------------------------------------------------------*/
if ((rc = q_ident("QMEM", 0, &qid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = rn_ident("RMEM", &rnid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

while(1) {


    /*----------------------------------------------------------------*/
    /* Request memory segments.  For each segment, send a message to  */
    /* queue 'QMEM' which contains its address, size, and region.  If */
    /* a segment cannot be allocated, wait for 5 ticks.               */
    /*----------------------------------------------------------------*/
    tm_get(&date, &time, &ticks);
    ticks = (ticks & 7) + 1;            /* Random number from 1 to 8  */
    size = ticks * 128;                 /* Sizes from 128 to 1K bytes */

    if ((rc = rn_getseg(rnid, size, RN_NOWAIT, 0, &seg_ptr)) != NOERR)
        tm_wkafter(5);                  /* Ran out of memory.  Sleep. */
    else {
        /*------------------------------------------------------------*/
        /* Load the current message with the information and send it  */
        /* to the queue. Move on to the next message.                 */
        /*------------------------------------------------------------*/
        ntimes++;                     /* number of times in this loop */
        current_msg->address = (unsigned long)seg_ptr;   
        current_msg->size = size;                     
        current_msg->seq_num = ntimes;
        current_msg->unused = 0;

        if ((rc = q_send(qid, (unsigned long *)current_msg)) != NOERR)
            PrintErrMessage(__FILE__, __LINE__, rc);
        current_msg = current_msg->next;
        }
    }
}

/***********************************************************************/
/*        mem2: Grabs segments from 'MEM1' and frees them.             */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): Executes as task 'MEM2'.  Zeros each segment before    */
/*              freeing it to simulate use of the segment.             */
/*                                                                     */
/***********************************************************************/
static void 
mem2(void)
{
unsigned long qid, rnid;
MEMMSG message;
unsigned char *mem_ptr;
unsigned long seg_size, rc;

if ((rc = q_ident("QMEM", 0, &qid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = rn_ident("RMEM", &rnid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

/*---------------------------------------------------------------------*/
/* Infinite loop to grab messages from the queue, and from the message */
/* received retreives the address and size information of the segment. */
/* Later the memory segment is accessed using the address and size     */
/* fields of the message and freed.                                    */
/*---------------------------------------------------------------------*/
while (1) {

    if ((rc = q_receive(qid, Q_WAIT, 0, (unsigned long *) &message)) == NOERR)
    {
        mem_ptr = (unsigned char *) (message.address); 
        seg_size = message.size;

        while (message.size--)	      /* Zero out the memory locations */
            *mem_ptr++ = 0;

        /* Return seg back to RMEM */
        if ((rc = rn_retseg(rnid, (void *)(message.address))) != NOERR)
            PrintErrMessage(__FILE__, __LINE__, rc);
    }
    else
        tm_wkafter(5);
    }
}

/***********************************************************************/
/*      source: Sends messages to queue 'SS__'.                        */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): This code executes as task 'SRCE' and sends messages   */
/*              to queue 'SS__'.  If the queue becomes full, the task  */
/*              suspends itself.                                       */
/*                                                                     */
/*     Format of the message is as follows:                            */
/*                                                                     */
/*              ------------------------------------                   */
/*             |   0    |    0   |  Message ID      |                  */
/*              ------------------------------------                   */
/*             |   0    |    0   |    0    |    0   |                  */
/*              ------------------------------------                   */
/*             |   0    |    0   |    0    |    0   |                  */
/*              ------------------------------------                   */
/*             |   0    |    0   |    0    |    0   |                  */
/*              ------------------------------------                   */
/*                                                                     */
/***********************************************************************/
static void 
source(void)
{
unsigned long qid, rc;
unsigned long msg[MSGLEN];	            /* Message, four long words */
unsigned long msgid = 0;

if ((rc = q_ident("SS__", 0, &qid)) != NOERR)       /* Get the queue ID */
    PrintErrMessage(__FILE__, __LINE__, rc);

while (1)
    {
    msg[0] = (msgid++ & 0x0000FFFF);  /* first 2 bytes of msg are zero; */
                                      /* next 2 bytes contain msg ID    */
    msg[1] = 0;
    msg[2] = 0;
    msg[3] = 0;

    if ((rc = q_send(qid, msg)) != NOERR) 
        t_suspend(0L);            /* If queue full or if no more buffers*/
                                  /* give up.                           */
    }
}

/***********************************************************************/
/*        sink: Take messages from queue 'SS__'                        */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): This code executes as task 'SINK'.  It repeatedly re-  */
/*              quests messages from queue 'SS__'.  When none are      */
/*              available, it resumes 'SRCE', then pauses for a while. */
/*                                                                     */
/*     Format of the message is as follows:                            */
/*                                                                     */
/*              ------------------------------------                   */
/*             |   0    |    0   |  Message ID      |                  */
/*              ------------------------------------                   */
/*             |   0    |    0   |    0    |    0   |                  */
/*              ------------------------------------                   */
/*             |   0    |    0   |    0    |    0   |                  */
/*              ------------------------------------                   */
/*             |   0    |    0   |    0    |    0   |                  */
/*              ------------------------------------                   */
/*                                                                     */
/***********************************************************************/
static void 
sink(void)
{
unsigned long qidss, tidsrce, rc;
unsigned long date, time, ticks;
unsigned long msg[MSGLEN];

if ((rc = q_ident("SS__", 0, &qidss)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

if ((rc = t_ident("SRCE", 0, &tidsrce)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

while (1)
    {
    if ((rc = q_receive(qidss, Q_NOWAIT, 0, msg)) == ERR_NOMSG)
    {
        t_resume(tidsrce);              /* No more messages at   */
        tm_get(&date, &time, &ticks);   /* the queue.  Resume    */
        ticks = ticks & 0xF;            /* SRCE and sleep for a  */
        tm_wkafter(ticks);              /* random amount of time.*/
    }
    /*
     * Log a "User Event" into pMONT so that this event can be
     * viewed by the Esp tool.
     */
    else if (rc == NOERR)
        log_event(1, msg[0]);

    else if (rc == ERR_OBJID) 
        tm_wkafter(5);
    }
}

/***********************************************************************/
/*         io1: Repeatedly read from the "RAM disk" device.            */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): This code runs as task 'IO1_' and competes with task   */
/*              'IO2_' for access to the "RAM disk" device.            */
/*                                                                     */
/***********************************************************************/
static void 
io1(void)
{
unsigned long ioretval;             /* I/O device return value */
struct buffer_header iopb;          /* I/O parameter block */
unsigned long ptid, Index;
unsigned long rc;
char *bufaddr;

if ((rc = pt_ident("PTN1", 0, &ptid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

while (1)
    {
    iopb.b_blockno = 0;             /* read from block 0 */
    iopb.b_bcount = 1;              /* read 1 block */
    iopb.b_blksize = FC_LOGBSIZE;   /* Logical block size */

    do {
       if ((rc = pt_getbuf(ptid, (void **) &bufaddr)) == NOERR)
       {
           iopb.b_bufptr = bufaddr;        /* addr of data block */
           process_data(bufaddr);

           if ((rc = de_read(DEV_RAMDISK, &iopb, &ioretval)) != NOERR)
               PrintErrMessage(__FILE__, __LINE__, rc);

           pt_retbuf(ptid, bufaddr);
       }
       else
           tm_wkafter(5);

       } while (rc != NOERR);    /* Error occured, repeat the loop again */
    }
}

/***********************************************************************/
/*         io2: Repeatedly write to the "RAM disk" device.             */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): This code runs as task 'IO2_' and competes with task   */
/*              'IO1_' for access to the "RAM disk" device.            */
/*                                                                     */
/***********************************************************************/
static void 
io2(void)
{
unsigned long ioretval;             /* I/O device return value */
struct buffer_header iopb;          /* I/O parameter block */
unsigned long ptid, Index;
unsigned long rc;
char *bufaddr;

if ((rc = pt_ident("PTN1", 0, &ptid)) != NOERR)
    PrintErrMessage(__FILE__, __LINE__, rc);

while (1)
    {
    iopb.b_blockno = 0;             /* write to block 0 */
    iopb.b_bcount = 1;              /* write 1 block */
    iopb.b_blksize = FC_LOGBSIZE;   /* Logical block size */

    do {
       if ((rc = pt_getbuf(ptid, (void **) &bufaddr)) == NOERR)
       {
           iopb.b_bufptr = bufaddr;  /* addr of data block */
           process_data(bufaddr);
  
           if ((rc = de_write(DEV_RAMDISK, &iopb, &ioretval)) != NOERR)
               PrintErrMessage(__FILE__, __LINE__, rc);

           pt_retbuf(ptid, bufaddr);
       }
       else 
           tm_wkafter(5);          /* sleep and try again for buffer   */

       } while (rc != NOERR);
    }
}

/***********************************************************************/
/* pseudo_demo: Task to demonstrate the pSEUDO driver capabilities     */
/*                                                                     */
/*      INPUTS: None                                                   */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S):                                                        */
/*                                                                     */
/***********************************************************************/
static void 
pseudo_demo(void)
{
ULONG rc, ioretval, tid;
PssCharCtrlIOPB ioctl_pb;
MAPIO_INFO mapio_info[3];

    if ((rc = t_ident("SUDO", 0, &tid)) != NOERR)
        PrintErrMessage(__FILE__, __LINE__, rc);

    /*-----------------------------------------------------------------*/
    /* Set the STDIN to DEV_MEMLOG (Memory Log Driver)                 */
    /*-----------------------------------------------------------------*/
    mapio_info[STDIN_DEV].target = DEV_MEMLOG;
    mapio_info[STDIN_DEV].type   = MAPIO_DEVICE;

    /*-----------------------------------------------------------------*/
    /* Set the STDOUT to DEV_MEMLOG (Memory Log Driver)                */
    /*-----------------------------------------------------------------*/
    mapio_info[STDOUT_DEV].target = DEV_MEMLOG;
    mapio_info[STDOUT_DEV].type   = MAPIO_DEVICE;

    /*-----------------------------------------------------------------*/
    /* Set the STDERR to DEV_RDIO (Remote Debugger).                   */
    /*-----------------------------------------------------------------*/
    mapio_info[STDERR_DEV].target = DEV_RDIO;
    mapio_info[STDERR_DEV].type   = MAPIO_DEVICE;

    if ((rc = PssRedirectStdioChans (tid, mapio_info)) != NOERR)
        PrintErrMessage(__FILE__, __LINE__, rc);

/*---------------------------------------------------------------------*/
/* Loop to write and read from Memlog driver and later output to stderr*/
/*---------------------------------------------------------------------*/
    while (1) {

        /*-------------------------------------------------------------*/
        /* By Default, the output to stderr is disabled, to enable the */
        /* printing to stderr (Serial Console or Host Debugger), set   */
        /* "gPseudoDemo" flag to "non-zero".                           */
        /*-------------------------------------------------------------*/
        if (gPseudoDemo) {
            fputs(WriteBuf, stdout);
            fgets(ReadBuf, sizeof(ReadBuf), stdin);
            fputs(ReadBuf, stderr);
        }
        tm_wkafter(360);
    }
}

/***********************************************************************/
/* process_data: Simulate processing of input data                     */
/*                                                                     */
/*      INPUTS: Buffer address                                         */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S): This function just simulates processing of data.       */
/*                                                                     */
/***********************************************************************/
static void
process_data(char *Buf)
{
    int Index;

    /*-----------------------------------------------------------------*/
    /* Process the data, just complement it                            */
    /*-----------------------------------------------------------------*/
    for (Index = 0; Index < BLOCK_SIZE; Index++)
        Buf[Index] = ~Buf[Index];
}


/***********************************************************************/
/* PrintErrMessage: Local function to interpret the error message      */
/*                                                                     */
/*      INPUTS: File name, Line number and error code                  */
/*                                                                     */
/*     RETURNS:                                                        */
/*     OUTPUTS:                                                        */
/*     NOTE(S):                                                        */
/*                                                                     */
/***********************************************************************/
static void
PrintErrMessage(char *FileName, int LineNum, unsigned long ErrCode)
{

printf("\nFILE:%s: LINE:%d: The Error is %d", FileName, LineNum, ErrCode);
k_fatal(0x10000 + ErrCode, 0);

}
