#
# PVCSConstants.py
#
# this file defines some global constants and functions
# for the PVCS integration
#
# Author: Uwe Stieber
# Copyright (c) 1998, 1999 TakeFive Software, Salzburg
#

# import common modules
import os, string

# import SNiFF+ interface modules
import vcs

# import Helper modules
import searchPathLib
import PVCSCommonHelp

# set Preferences File
PVCSPrefsFileName = os.path.normpath(os.path.join(searchPathLib.getUsersProfileDir(), "PvcsPrefs.sniff"))

# global debug variables
TEST = int(PVCSCommonHelp.readValueFromPrefsFile(PVCSPrefsFileName, "PVCSDebug"))
VLOGTEST = int(PVCSCommonHelp.readValueFromPrefsFile(PVCSPrefsFileName, "VLOGDebug"))

# adapter specific subdirectory
AdapterSpecificSubDir = PVCSCommonHelp.readValueFromPrefsFile(PVCSPrefsFileName, "AdapterSubDir")

# find out the PVCS Version we are using
# we assume PVCS 6.5 per default
PVCSVersion = vcs.getoutput("vcs 2>&1 | grep -i \"PVCS Version Manager\"")
# version number is on position 5 !!
try:
	PVCSVersion = string.split(PVCSVersion)[4]
	# remove leading 'v' and the trailing '.[0-9][0-9]'
	PVCSVersion = PVCSVersion[1:-3]
except:
	PVCSVersion = "" 
PVCSVersion = string.strip(PVCSVersion)
if PVCSVersion == "":
	PVCSVersion = "6.5"

if TEST:
	print "(PVCS Constants) TEST = '%d'" % TEST
	print "(PVCS Constants) VLOGTEST = '%d'" % VLOGTEST
	print "(PVCS Constants) PVCSVersion = %s" % PVCSVersion

# initialize Call Interface
import CommonCallWrapper
usedCallingInterface = CommonCallWrapper.LOCAL
callWrapper = None
if os.environ.has_key("SNiFF_CMVC_USE_CALL_INTERFACE"):
	usedCallingInterface = int(os.environ["SNiFF_CMVC_USE_CALL_INTERFACE"])
try:
	callWrapper = CommonCallWrapper.CommonCallWrapper("Pvcs", usedCallingInterface)
except CommonCallWrapper.CommonCallWrapperInitFailed:
	usedCallingInterface = CommonCallWrapper.LOCAL
except CommonCallWrapper.CommonCallWrapperInterfaceImportFailed:
	usedCallingInterface = CommonCallWrapper.LOCAL

# the boolean values, use the definitions of vcs.py
# if available
vcs_module_imported = 1
try:
	reload(vcs)
	
	true = vcs.TRUE
	false = vcs.FALSE
	if not os.environ.has_key("VCSDEBUG"):
		if PVCSCommonHelp.readValueFromPrefsFile(PVCSPrefsFileName, "VCSDebug") == "1":
			vcs.TEST = '1'
		else:
			vcs.TEST = ''
	if TEST:
		if vcs.TEST:
			print "(PVCS Constants) vcs.TEST = 'on'"
		else:
			print "(PVCS Constants) vcs.TEST = 'off'"

	# define a extended unixpath
	def unixpath(path):
		if not path: return path
		import os
		path = os.path.normpath(path)
		import string
		path = string.translate(path, vcs.BACKSLASH2SLASH)
		if path[-1]=='/':
			return path[:-1]
		return path
except ImportError:
	# vcs.py module not available
	# define it by ourself
	true = 1
	false = 0
	vcs_module_imported = 0

# a different split function, DON'T use string.split !
def split(s, sep=None, maxsplit=0):
	"""split(str [,sep [,maxsplit]]) -> list of strings

	Return a list of the words in the string s, using sep as the
	delimiter string.  If maxsplit is nonzero, splits into at most
	maxsplit words If sep is not specified, any whitespace string
	is a separator.  Maxsplit defaults to 0.
	"""
	import string
	if sep is None: sep = string.whitespace
	res = []
	i, n = 0, len(s)
	if maxsplit <= 0: maxsplit = n
	count = 0
	while i < n:
		while i < n and s[i] in sep: i = i+1
		if i == n: break
		if count >= maxsplit:
			res.append(s[i:])
			break
		j = i
		while j < n and s[j] not in sep: j = j+1
		count = count + 1
		res.append(s[i:j])
		i = j
	return res

# this function translate the PVCS meta notation
# into regular expressions
def makeRegEx(aCoreString):
	aRegExString = r""
	for aCharIndex in range(len(aCoreString)):
		if aCoreString[aCharIndex] == '.':
			# translate '.' to '\.'
			aRegExString = aRegExString + r"\."
		else:
			if aCoreString[aCharIndex] == '?':
				# translate '?' to '.'
				aRegExString = aRegExString + r"."
			else:
				if aCoreString[aCharIndex] == '*':
					# translate '*' to '[0-9]*'
					aRegExString = aRegExString + r"[0-9]*"
				else:
					# append the normal character
					aRegExString = aRegExString + aCoreString[aCharIndex]
	return aRegExString + r"$"

# the exception class definitions
import exceptions
class PVCSConfigFileSyntaxError(exceptions.StandardError):
	pass

class PVCSNoSuffixRule(exceptions.StandardError):
	pass

class PVCSErrorWritingConfigFile(exceptions.StandardError):
	pass
