#
# Filename: PvcsRemote.py
# $Id: PvcsRemote.py,v 1.9 1999/11/26 14:27:37 uwe Exp $
#
# defines the real call functions for the Pvcs Remote interface
#
# Author: Uwe Stieber
# Copyright (c) 1998, 1999 TakeFive Software, Salzburg
#

# import the necessary modules
import os
import sys
import string
import PVCSConstants
import vcs

# put something in front of the called Pvcs command
RemoteCommandPrefix = ""
# example of usage
# RemoteCommandPrefix = "export PVCS_BINDIR=/tools/pvcs-6.0; cd /tmp; /tools/pvcs-6.0/"
 
# command to be called for mkdir
MkdirCommand = "mkdir -p"
# example of usage, if a 'su version' of mkdir is to be used
# MkdirCommand = "umask 02; %spvcs_mkdir -p" % RemoteCommandPrefix

# remote shell command
RemoteHost = "dummy"
if os.environ.has_key("PVCS_REMOTE_HOST"):
	RemoteHost = os.environ["PVCS_REMOTE_HOST"]
if not os.environ.has_key("SNiFF_CMVC_REMOTE_USER"):
	RemoteShellCommand = "%s\\System32\\rsh.exe %s " % (os.environ["SystemRoot"], RemoteHost)
else:
	RemoteShellCommand = "%s\\System32\\rsh.exe %s -l %s " % (os.environ["SystemRoot"], RemoteHost, os.environ["SNiFF_CMVC_REMOTE_USER"])

# remote pvcs path mapping: environment variables on the remote side 
# can only work correctly, if for the corresponding working environments
# also the "remote Root" is set up in the SNiFF working environments tool.
PathMap = {
			#### examples of usage
			# "$WORKSPACE":	"/usr/users/BZ2000",
			# "$PRIWORKSPACE":	"$HOME/BZ2000"
			# "M:":		"/usr/users/BZ2000",
			# "L:":	"$HOME"
			"G:":	"/Users/uwe"
		}

def translatePathnames(aString):
	convertedString = aString
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x translatePathnames" % __name__
	for aPathToConvert in PathMap.keys():
		if vcs.TEST:
			print "(@B@I%s@I@B)\t%s --> %s" % (__name__, aPathToConvert, PathMap[aPathToConvert])
		convertedString = string.replace(convertedString, vcs.normpath(os.path.expandvars(aPathToConvert)), PathMap[aPathToConvert])
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x translatePathnames" % __name__
	if convertedString == aString:
		print "(@B@I%s@I@B)@B@r<<<@x translatePathnames: nothing converted for %s" % (__name__, aString)
	return convertedString

# call the put command
def put(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x put" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %sput %s" % (__name__, RemoteShellCommand, RemoteCommandPrefix, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''%sput %s''" % (RemoteShellCommand, RemoteCommandPrefix, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x put (%d)" % (__name__, rc)
	return rc

# call the get command
def get(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x get" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %sget %s" % (__name__, RemoteShellCommand, RemoteCommandPrefix, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''%sget %s''" % (RemoteShellCommand, RemoteCommandPrefix, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x get (%d)" % (__name__, rc)
	return rc

# call the vcs_command command
def vcs_command(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x vcs_command" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %svcs %s" % (__name__, RemoteShellCommand, RemoteCommandPrefix, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''%svcs %s''" % (RemoteShellCommand, RemoteCommandPrefix, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x vcs_command (%d)" % (__name__, rc)
	return rc

# call some sh command and grep the output
def sh_getoutput(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x sh_getoutput" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %s" % (__name__, RemoteShellCommand, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''$SHELL -c %s''" % (RemoteShellCommand, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x sh_getoutput" % __name__
	return _out

# call the vlog_command command
def vlog_command(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x vlog_command" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %svlog %s" % (__name__, RemoteShellCommand, RemoteCommandPrefix, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''%svlog %s''" % (RemoteShellCommand, RemoteCommandPrefix, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x vlog_command" % __name__
	return _out

# call the vlog_command command and returns a StringStream
def vlog_popen(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x vlog_popen" % __name__
	cmd = ""
	file = ""
	# convert argument tuple to string
	seq = arguments[0]
	cmd = translatePathnames(string.replace(seq[0], r'"', r"\""))
	file = seq[1]
	if file:
		file = string.join(map(vcs.normpath, string.split(file)))
	file = translatePathnames(file)
	if vcs.TEST:
		print "(@B@I%s@I@B)\texecute command: %s %s%s %s" % (__name__, RemoteShellCommand, RemoteCommandPrefix, cmd, file)
	try:
		rc, _out = vcs.syscmd("%s ''%s%s %s''" % (RemoteShellCommand, RemoteCommandPrefix, cmd, file))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x vlog_popen" % __name__
	return vcs.StringStream(_out)

# call the vdel command
def vdel(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x vdel" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %svdel %s" % (__name__, RemoteShellCommand, RemoteCommandPrefix, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''%svdel %s''" % (RemoteShellCommand, RemoteCommandPrefix, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x vdel (%d)" % (__name__, rc)
	return rc

# call the vdiff command
def vdiff(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x vdiff" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %svdiff %s" % (__name__, RemoteShellCommand, RemoteCommandPrefix, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''%svdiff %s''" % (RemoteShellCommand, RemoteCommandPrefix, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x vdiff (%d)" % (__name__, rc)
	return rc

# call the diff command
def diff(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x diff" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s diff %s" % (__name__, RemoteShellCommand, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''diff %s''" % (RemoteShellCommand, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x diff" % __name__
	return _out

# call the rm -f command
def rm_f(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x rm_f" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s rm -f %s" % (__name__, RemoteShellCommand, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''rm -f %s''" % (RemoteShellCommand, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x rm_f (%d)" % (__name__, rc)
	return rc
 
# call the mkdir -p  command. Done in here to make sure we can call a
# setuid version of mkdir for creating the repository dir.
def mkdir_p(*arguments):
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@g>>>@x mkdir_p" % __name__
	argumentString = ""
	# convert argument tuple to string
	for seq in arguments:
		for aArgument in seq:
			argumentString = "%s %s" % (argumentString, string.replace(aArgument, r'"', r"\""))
	# translate Pathnames
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
	argumentString = translatePathnames(argumentString)
	if vcs.TEST:
		print "(@B@I%s@I@B)\targumentString = %s" % (__name__, argumentString)
		print "(@B@I%s@I@B)\texecute command: %s %s %s" % (__name__, RemoteShellCommand, MkdirCommand, argumentString)
	try:
		rc, _out = vcs.syscmd("%s ''%s %s''" % (RemoteShellCommand, MkdirCommand, argumentString))
	except:
		import traceback
		traceback.print_exc()
	if vcs.TEST:
		print "(@B@I%s@I@B)\trc = %d" % (__name__, rc)
		print "(@B@I%s@I@B)\t_out = %s" % (__name__, _out)
	if vcs.TEST:
		print "(@B@I%s@I@B)@B@r<<<@x mkdir_p (%d)" % (__name__, rc)
	return rc
