from etgui import *
from PageLayout import *
import vcs,string,os,marshal

class FileListView(MultiCollView):
	def __init__(self,model):
		MultiCollView.__init__(self)
		self.model=model
	def UpdateFileList(self,dir='.'):
		# build a list of item from which we can select
		items=[]
		for file in os.listdir(dir):
			if file not in ('.','..'):
				items.append(TextItem(file))
		self.ReplaceItems(items)
	def SelectionChanged(self):
		# collect the names of the selected items
		selection=[]
		for item in self.GetSelectedItems():
			selection.append(item.AsString())
		# set the values in our model
		self.model.SetSelectedFiles(selection)


def MakeView(model):
		"""Create the GUI elements"""
		# The Popup changes the value "ChoiceValue" in
		# the model
		popup=PotGuiPopupButton("ShellCommand")
		# AddItem(display_name,value_in_model)
		# the value_in_model could also be an integer
		popup.AddItem("ls","ls")
		popup.AddItem("wc","wc")
		updatebutton=ActionButton("Update",action=model.UpdateDateOutput)
		filelist=FileListView(model)
		filelist.UpdateFileList('.')
		view=MakePageLayout(
			eVObjHExpand|eVObjVExpand, # how to align the items on the page
			VBox(
				align=eVObjVExpand|eVObjHExpand,
				# the items are pairs of label,gui-element
				items=[
					HBox(
						align=eVObjVBase|eVObjHExpand,
						items=[
							"Date Output",
							PotTextField("DateOutput"), # edit "DateOutput" in model
							updatebutton
						]
					),
					ActionButton("Update File List",action=filelist.UpdateFileList),
					Scroller(filelist,Point(500,300)),
					BorderItem("Flags",
						ManyOfCluster(
							PotGuiToggleButton("-l", "-l (long format)"),
							PotGuiToggleButton("-t", "-t (sort on date)"),
							HBox(align=eVObjVBase|eVObjHExpand,
								items= [
									PotGuiToggleButton("-W", "Use Wildcard"),
									PotTextField("Wildcard"),
								]
							)
						)
					),
					PotGuiTextView("ShellOutput",TextView(),Point(200)),
				]
			),
		)
		return view
# important: keep one copy of the dialog
gDialog=None
gModel=None
class MyModel(DictPyModel):
	def __init__(self,filename):
		DictPyModel.__init__(self)
		self.filename=filename
	def DoApply(self):
		flags=''
		if self.GetValue("-l"):
			flags=flags+' -l'
		if self.GetValue('-t'):
			flags=flags+' -t'
		command="ls"+flags
		if self.filelist:
			files=string.join(self.filelist," ")
			command=command+' '+files
		output=self.RunShellCommand(command)
		self.SetValue("ShellOutput",output)
		self.Save() # remember the state
	def DoSetValue(self,path,value):
		if path=="-W":
			self.NotifyValueChange("Wildcard") # then DoIsValueChangable will be called
		
		return DictPyModel.DoSetValue(self,path,value)
	def DoIsValueChangable(self,path):
		if path=="Wildcard":
			return self.GetValue("-W") # enable only if -W is set
		return 1
	# new methods
	def UpdateDateOutput(self):
		"""Calledn when the Update button next to the 'date output field# is pressed"""
		self.SetValue("DateOutput",self.RunShellCommand("date"))
	def RunShellCommand(self,command):
		pipe=vcs.popen(command)    # opens the shell command
		output=pipe.read()         # reads the shell output
		output=string.strip(output)# remove leading and trailing whitespace
		return output
	#-- IO --------------------------
	def GetFileName(self):
		# show file dialog?
		return self.filename
	def Save(self):
		file=open(self.GetFileName(),"wb") # write binary
		marshal.dump(self.dict,file)
		file.close()
	def Load(self):
		try:
			file=open(self.GetFileName(),"rb") # read binary
			self.dict=marshal.load(file)
			file.close()
			self.AllValuesChanged()
		except IOError:
			pass # no file
	########################
	filelist=[] # empty file list as defaut
	def SetSelectedFiles(self,files):
		"""Called from the FileListView"""
		self.filelist=files
	
def Show():
		global gDialog,gModel
		if not gDialog:
				# create the dialog once!
				gModel=MyModel('/tmp/dialogstatus')
				gDialog=MakeOkCancelDialog(
					"My Dialog",        # the title of the dialog
					gModel,
					MakeView(gModel),  
					ActionButton(CmdNo.cIdOk,"OK",default=1), # make OK button the default, calls Apply implicilely
					ActionButton("Apply",action=gModel.Apply),# tricky action is gModel.Apply
					ActionButton("Load",action=gModel.Load),
					ActionButton("Save",action=gModel.Save),
					ActionButton(CmdNo.cIdCancel,"Cancel")    # calls Cancel implicilely
				)
				# set this value only the first time and
				# remember when dialog is opened next time
				gModel.SetValue("Text1","bla")
		# get the dialogs model
		# set the following values each time the dialog is shown
		gModel.Load()
		gDialog.ShowUnderMouse()
if __name__=="__main__":
	Show()

