#
#	general.java.mk
#
#	SNiFF+ V3.2.1
#
#	Common make rules for java compiler.
#
#	Copyright (C) 1999 TakeFive Software GmbH
#	Salzburg, Austria (e-mail: sniff@TakeFive.co.at)
#
#	Authors: Walter Brunauer, Johann Draschwandtner

MAKEFILE = Makefile

# The following macros should be used as command line parameters of the make command
#
#        Set default values of the command line parameters
DEBUG = 0

#        Make Session macros
SESSION = 0
SESSIONFILE=.Sniff_LastMake

PARENT = ./

#        Java compiler
JAVAC = javac
#        All Java compiler flags
ALL_JFLAGS = -g
#        Java compiler command with using of generate dir parameter
JAVAC_CMD = $(JAVAC) $(ALL_JFLAGS) -d $(SNIFF_JAVA_GENDIR_ROOT)
 
#        Java compiler wrapper command, which checks dependency internally and then calls the Java compiler recursively
#        targets are all, recursive or a specific Java file
#        optional: -c cmdlinelen: use the command line for passing the files to compile to javac
#        cmdlinelen is the maximal length of the command line, depending on the platform used
#        if the option -c is not chosen, a file list is generated and passed to javac via the file "@filelist"
#        CAUTION! JDK versions older than 1.2 will not work without setting the option -c!
# SNIFFJMAKE_CMD =  $(SNIFF_DIR)/bin/sniffjmake -p $(SNIFF_PROJECT_DIR) -f $(SNIFF_MAKEDIR)/.sniffjmake
SNIFFJMAKE_DEBUG = $(DEBUG:1=-D)
SNIFFJMAKE_DEBUG := $(SNIFFJMAKE_DEBUG:0=)
#		 Using the jdk 1.2 compiler calling convention (@filelist, which means not using the -c option 
#        in the  SNIFFJMAKE_CMD) in a jdk 1.2.x project leads to an impressive speed improvement 
#        (factor 27). For example, the jdk can be compiled in 11 minutes, instead of 5,5 hours.
SNIFFJMAKE_CMD = $(SNIFF_DIR)/bin/sniffjmake $(SNIFFJMAKE_DEBUG) -p . -f $(SNIFF_MAKEDIR)/.sniffjmake -c 1024
# SNIFFJMAKE_CMD = $(SNIFF_DIR)/bin/sniffjmake -p . -f $(SNIFF_MAKEDIR)/.sniffjmake

### ----- JNI ----- ###
# JNI_SUPPORT = 1
#        JNI rule
JNI_RULE = $(JNI_SUPPORT:1=_jni_all)
JNI_RULE := $(JNI_RULE:0=)
#        Java native code generator
JAVAH = javah
#        All Java native code generator flags
# ALL_JNIFLAGS = $(OTHER_JNIFLAGS) $(COMMON_JNIFLAGS) $(OS_JNIFLAGS) $(JNIFLAGS)
ALL_JNIFLAGS =
#        Java native code generator command with using of generate dir parameter
JAVAH_CMD = $(JAVAH) $(ALL_JNIFLAGS) -d $(SNIFF_JAVA_GENDIR_ROOT)
### ----- JNI ----- ###

### ----- RMI ----- ###
# RMI_SUPPORT = 1
#        RMI rule
RMI_RULE = $(RMI_SUPPORT:1=_rmi_all)
RMI_RULE := $(RMI_RULE:0=)
#        Java RMI compiler
RMIC = rmic
#        All Java RMI compiler flags
# ALL_RMIFLAGS = $(OTHER_RMIFLAGS) $(COMMON_RMIFLAGS) $(OS_RMIFLAGS) $(RMIFLAGS)
ALL_RMIFLAGS = -g
#        Java RMI compiler command with using of generate dir parameter
RMIC_CMD =  $(RMIC) $(ALL_RMIFLAGS) -d $(SNIFF_JAVA_GENDIR_ROOT)
#        Java RMI compiler definitions of stubs and skeletons
RMI_STUB_FILES = $(SNIFF_JAVA_RMI_FILES:.java=_Stub.class)
RMI_SKEL_FILES = $(SNIFF_JAVA_RMI_FILES:.java=_Skel.class)
RMI_CLASS_FILES = $(RMI_STUB_FILES) $(RMI_SKEL_FILES)
### ----- RMI ----- ###

### ----- IDL ----- ###
# IDLJ_SUPPORT = 1
#        OrbixWeb IDL to Java compiler
IDLJ = idlj
#        All OrbixWeb IDL to Java compiler flags
# ALL_IDLJFLAGS = $(OTHER_IDLJFLAGS) $(COMMON_IDLJFLAGS) $(OS_IDLJFLAGS) $(IDLJFLAGS)
ALL_IDLJFLAGS = -jO
#        OrbixWeb IDL to Java compiler command with using of generate dir parameter
IDLJ_CMD =  $(IDLJ) $(ALL_IDLJFLAGS) $(SNIFF_JAVA_GENDIR_ROOT)
### ----- IDL ----- ###
 
#        Java archive
JAR = jar
#        All Java archive flags
# ALL_JARFLAGS = $(OTHER_JARFLAGS) $(COMMON_JARFLAGS) $(OS_JARFLAGS) $(JARFLAGS)
ALL_JARFLAGS = -cv0f
#        Java archive command
# JAR_CMD = $(JAR) $(ALL_JARFLAGS) "$@" $(SNIFF_JAVA_CLASS_FILES)
JAR_CMD = $(JAR) $(ALL_JARFLAGS)

#        Java interpreter
JAVA_INTERPRETER = java

#        Java applet viewer
JAVA_APPLET_VIEWER = appletviewer

#        Java CLASSPATH environment variable, changes the delimiter to $(CLASSPATH_DELIMITER)
SNIFF_CLASSPATH = `echo '$(SNIFF_JAVA_CLASSPATH)' | sed -e 's/;/$(CLASSPATH_DELIMITER)/g'`

########################################################################
# rule for make default target recursively
########################################################################
all :: main_all targets_all
# comment out line above and uncomment following line to build pre-targets recursively first (esp for IDL)
#all :: all_pre_targets main_all targets_all

#     Java compiler rule
$(SNIFF_JAVA_GENDIR_ROOT)/$(SNIFF_JAVA_PACKAGE_DIR)/%.class : %.java
	@ echo "Making class $@";\
	if [ "$(COMPILER_WRAPPER)" != "1" ]; then\
		CP="$(SNIFF_CLASSPATH)$(CLASSPATH_DELIMITER)$$CLASSPATH";\
		if [ $(DEBUG) != 0 ]; then\
			echo "CLASSPATH=$$CP";\
			echo "$(JAVAC_CMD) $<";\
		fi;\
	else\
		JAVAC=$(JAVAC);\
		export JAVAC;\
		ALL_JFLAGS="$(ALL_JFLAGS)";\
		export ALL_JFLAGS;\
		if [ $(DEBUG) != 0 ]; then\
			echo "Compiler=$(JAVAC); Flags=$(ALL_JFLAGS)";\
			echo "$(SNIFFJMAKE_CMD) $<";\
		fi;\
	fi;\
	if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	if [ "$(COMPILER_WRAPPER)" != "1" ]; then\
		$(JAVAC_CMD) -classpath $$CP $<;\
	else\
		$(SNIFFJMAKE_CMD) "$<";\
	fi;\
	if [ $$? -ne 0 ]; then\
		exit $$?;\
	fi;\
	if [ "$(RMI_SUPPORT)" = "1" ]; then \
		echo $(SNIFF_JAVA_RMI_FILES) | grep $*.java >$(DEVNULL);\
		if [ $$? -eq 0 ]; then\
			$(OWN_MAKE) -f $(MAKEFILE) $*.rmi;\
		fi;\
	fi;\
	if [ "$(JNI_SUPPORT)" = "1" ]; then \
		egrep "native " "$<" | egrep -v "//" >$(DEVNULL);\
		if [ $$? -eq 0 ]; then\
			$(OWN_MAKE) -f $(MAKEFILE) $*.jni;\
		fi;\
	fi
 
#     Java native code generator rule, following Java compiler rules
%.jni : $(SNIFF_JAVA_GENDIR_ROOT)/$(SNIFF_JAVA_PACKAGE_DIR)/%.class
	@ echo "Making native interface for class $(SNIFF_JAVA_PACKAGE_NAME)$*";\
	CP="$(SNIFF_CLASSPATH)$(CLASSPATH_DELIMITER)$$CLASSPATH";\
	if [ $(DEBUG) != 0 ]; then\
		echo "CLASSPATH=$$CP";\
		echo "$(JAVAH_CMD) $(SNIFF_JAVA_PACKAGE_NAME)$*";\
	fi;\
	if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	$(JAVAH_CMD) -classpath $$CP $(SNIFF_JAVA_PACKAGE_NAME)$*

#     Java RMI compiler rule, following Java compiler rules
%.rmi : $(SNIFF_JAVA_GENDIR_ROOT)/$(SNIFF_JAVA_PACKAGE_DIR)/%.class
	@ echo "Making Stubs and Skeletons for class $(SNIFF_JAVA_PACKAGE_NAME)$*";\
	CP="$(SNIFF_CLASSPATH)$(CLASSPATH_DELIMITER)$$CLASSPATH";\
	if [ $(DEBUG) != 0 ]; then\
		echo "CLASSPATH=$$CP";\
		echo "$(RMIC_CMD) $(SNIFF_JAVA_PACKAGE_NAME)$*";\
	fi;\
	if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	$(RMIC_CMD) -classpath $$CP $(SNIFF_JAVA_PACKAGE_NAME)$*

#     OrbixWeb IDL to Java compiler rule
%.idl_ : %.idl
	@ echo "Making IDL to Java from $*" ;\
	d=`dirname '$@'`;\
	relative=`echo $$d | cut -d"/" -f1`;\
	if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	if [ "$$d" != "." -a "$$relative" != "" ]; then\
		cd $$d;\
		echo make: Changing directory to \'$$d\';\
		$(OWN_MAKE) -f $(MAKEFILE) `basename '$@'`;\
	else\
		$(IDLJ_CMD) "$<";\
		ret=$$?;\
		if [ $$ret -eq 0 ]; then\
			touch '$@';\
		fi;\
		exit $$ret;\
	fi

#     Java Application target
$(JAVA_APPLICATION_TARGET) ::
	@ if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	if [ "$(SCRIPT_ONLY)" != "1" ]; then\
		$(OWN_MAKE) -f $(MAKEFILE) $(SNIFF_JAVA_GENDIR_ROOT)/$(SNIFF_JAVA_PACKAGE_DIR)/`basename '$@'.class` COMPILER_WRAPPER=1;\
		ret=$$?;\
		if [ $$ret -ne 0 ]; then\
			$(OWN_MAKE) -f $(MAKEFILE) remove_java_script_sh RUN_TARGET=`basename '$@'`;\
			exit $$ret;\
		fi;\
	fi;\
	$(OWN_MAKE) -f $(MAKEFILE) generate_java_script_sh RUN_TARGET=`basename '$@'` TOOL="$(JAVA_INTERPRETER)"

#     Java HTML target with applet class list
$(JAVA_HTML_TARGET) ::
	@ if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	if [ "$(SCRIPT_ONLY)" != "1" ]; then\
		echo "make: Making applets of '$(JAVA_HTML_TARGET)':";\
		for applet in _dummy_ $(JAVA_APPLET_CLASSES); do\
			if [ $$applet = "_dummy_" ]; then\
				continue ;\
			fi;\
			$(OWN_MAKE) -f $(MAKEFILE) $(SNIFF_JAVA_GENDIR_ROOT)/$(SNIFF_JAVA_PACKAGE_DIR)/`basename $$applet.class` COMPILER_WRAPPER=1;\
			ret=$$?;\
			if [ $$ret -ne 0 ]; then\
				$(OWN_MAKE) -f $(MAKEFILE) remove_java_script_sh RUN_TARGET=`basename '$@'`;\
				exit $$ret;\
			fi;\
		done;\
	fi;\
	if [ ! -f $(JAVA_HTML_TARGET) ];then\
		echo "make: Creating HTML file '$(JAVA_HTML_TARGET)'";\
		echo "<HTML>"	> $(JAVA_HTML_TARGET);\
		echo "<HEAD>"	>> $(JAVA_HTML_TARGET);\
		echo "<TITLE"	>> $(JAVA_HTML_TARGET);\
		echo "$(JAVA_HTML_TARGET)>"	>> $(JAVA_HTML_TARGET);\
		echo "</TITLE>"	>> $(JAVA_HTML_TARGET);\
		echo "</HEAD>"	>> $(JAVA_HTML_TARGET);\
		echo "<BODY>"	>> $(JAVA_HTML_TARGET);\
		for applet in _dummy_ $(JAVA_APPLET_CLASSES); do\
			if [ $$applet = "_dummy_" ]; then\
				continue ;\
			fi;\
			if [ $(DEBUG) != 0 ]; then\
			echo "make: Adding applet '$$applet' to HTML file";\
			fi;\
			echo "<APPLET"	>> $(JAVA_HTML_TARGET);\
			echo "CODEBASE=$(SNIFF_JAVA_GENDIR_ROOT)"	>> $(JAVA_HTML_TARGET);\
			echo "CODE=$(SNIFF_JAVA_PACKAGE_NAME)$$applet.class"	>> $(JAVA_HTML_TARGET);\
			echo "WIDTH=300"	>> $(JAVA_HTML_TARGET);\
			echo "HEIGHT=300>"	>> $(JAVA_HTML_TARGET);\
			echo "</APPLET>"	>> $(JAVA_HTML_TARGET);\
		done;\
		echo "</BODY>"	>> $(JAVA_HTML_TARGET);\
		echo "</HTML>"	>> $(JAVA_HTML_TARGET);\
	fi;\
	$(OWN_MAKE) -f $(MAKEFILE) generate_java_script_sh RUN_TARGET=`basename '$@'` TOOL="$(JAVA_APPLET_VIEWER)"
 
#     Java Jar target
$(JAVA_JAR_TARGET) ::
	@ if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	_PWD=`pwd`;\
	cd $(SNIFF_JAVA_GENDIR_ROOT);\
	echo "" > $(JAVA_JAR_TARGET).lst;\
	if [ "$(SNIFF_JAVA_JAR_FILES)" != "" ]; then\
		for file in _dummy_ $(SNIFF_JAVA_JAR_FILES); do\
			if [ "$$file" = "_dummy_" ]; then\
				continue ;\
			fi;\
			d=`dirname "$$file"`;\
			f=`basename "$$file"`;\
			if [ "$$d" = "." ]; then\
				find "$(SNIFF_JAVA_PACKAGE_DIR)" -name "$$f" -print >> $(JAVA_JAR_TARGET).lst;\
			else\
				find "$(SNIFF_JAVA_PACKAGE_DIR)/$$d" -name "$$f" -print >> $(JAVA_JAR_TARGET).lst;\
			fi;\
		done;\
	else\
		find "$(SNIFF_JAVA_PACKAGE_DIR)" -name "*.class" -print >> $(JAVA_JAR_TARGET).lst;\
	fi;\
	if [ `wc -w <$(JAVA_JAR_TARGET).lst` != 0 ]; then\
		$(JAR_CMD) "$@" `cat $(JAVA_JAR_TARGET).lst`;\
	else\
		echo "make: no files were found to archive; make sure these files exist";\
	fi;\
	cd "$$_PWD"
 
#     Java target class list
TargetClasses ::
	@ if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	if [ "$(SCRIPT_ONLY)" != "1" ]; then\
		_PWD=`pwd`;\
		echo "make: Making target classes '$(JAVA_TARGET_CLASSES)':";\
		for target in _dummy_ $(JAVA_TARGET_CLASSES); do\
			if [ $$target = "_dummy_" ]; then\
				continue ;\
			fi;\
			d=`dirname $$target`;\
			relative=`echo $$d | cut -d"/" -f1`;\
			if [ "$$d" != "." -a "$$relative" != "" ]; then\
				cd $$d;\
				echo make: Changing directory to \'$$d\';\
			fi;\
			$(OWN_MAKE) -f $(MAKEFILE) $(SNIFF_JAVA_GENDIR_ROOT)/$(SNIFF_JAVA_PACKAGE_DIR)/`basename $$target.class` COMPILER_WRAPPER=1;\
			cd "$$_PWD";\
		done;\
	fi

#	 Generate Script for running Targets
generate_java_script_sh :: remove_java_script_sh
	@ if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	echo "CLASSPATH=\"$(SNIFF_CLASSPATH)$(CLASSPATH_DELIMITER)\$$CLASSPATH\""	  >> $(RUN_TARGET).env;\
	echo "export CLASSPATH" 													  >> $(RUN_TARGET).env;\
	echo "" 																	  >> $(RUN_TARGET).env;\
	if [ $$TOOL = "$(JAVA_INTERPRETER)" ]; then\
		echo "JAVA_TARGET=$(SNIFF_JAVA_PACKAGE_NAME)$(RUN_TARGET)"				  >> $(RUN_TARGET).env;\
	else\
		echo "JAVA_TARGET=$(RUN_TARGET)"										  >> $(RUN_TARGET).env;\
	fi;\
	echo "export JAVA_TARGET" 													  >> $(RUN_TARGET).env;\
	echo "#! $(SHELL)" 															  >> $(RUN_TARGET).sh;\
	echo "" 																	  >> $(RUN_TARGET).sh;\
	echo ". ./$(RUN_TARGET).env"												  >> $(RUN_TARGET).sh;\
	echo "" 																	  >> $(RUN_TARGET).sh;\
	echo "echo Running \$$JAVA_TARGET ..."										  >> $(RUN_TARGET).sh;\
	echo "$(TOOL) \$$JAVA_TARGET \$$*"											  >> $(RUN_TARGET).sh;\
	chmod a+x $(RUN_TARGET).sh

remove_java_script_sh ::
	@ $(RM) $(RUN_TARGET).env;\
	$(RM) $(RUN_TARGET).sh

########################################################################
# Merged from general.mk that isn't used by javamake anymore
########################################################################
# rule for make help targets recursively
########################################################################
clean clean_targets targets_all rmi_all jni_all all_pre_targets ::
	@ if [ $(DEBUG) != 0 -a "$(SUBDIRS)" != "" ]; then\
		echo "make: starting recursive make for help target in project '$(SNIFF_PROJECT)'";\
		echo "make: $(OWN_MAKE) -f $(MAKEFILE) $(MFLAGS) '$@'";\
	fi;\
	_PWD=`pwd`;\
	for dir in _dummy_ $(SUBDIRS); do\
		if [ $$dir = "_dummy_" ]; then\
			continue ;\
		fi;\
		relative=`echo $$dir | cut -d"/" -f1 | grep -v ":"`;\
		if [ "$$relative" != "" ]; then\
			absdir=$$_PWD/$$dir;\
			parent=$(PARENT)$$dir/; \
		else\
			absdir=$$dir;\
			parent=$$dir/ ;\
		fi;\
		if [ -d $$absdir ]; then\
			cd $$absdir;\
			$(OWN_MAKE) -f $(MAKEFILE) PARENT=$$parent SESSION="$$session" '$@' || exit;\
		else\
			echo "make: project directory $(PARENT)$$dir does not exist. Please create it with SNiFF+ if you need it" ;\
		fi;\
	done;\
	exit 0

#     Clean Java class files, target scripts (implicitely), native header files and rmi files
clean :: _clean
_clean :
 
	@ dir=$(SNIFF_JAVA_GENDIR_ROOT)/$(SNIFF_JAVA_PACKAGE_DIR);\
	if [ $(DEBUG) != 0 ]; then\
		echo "Removing Class files" ;\
	fi;\
	if [ "$(SNIFF_JAVA_CLASS_FILES)" != "" ]; then\
		_PWD=`pwd`;\
		cd $$dir;\
		$(RM) $(SNIFF_JAVA_CLASS_FILES);\
		cd $$_PWD;\
		fi;\
	if [ "$(RMI_SUPPORT)" = "1" ]; then \
		if [ $(DEBUG) != 0 ]; then\
			echo "Removing RMI Stubs and Skeletons files" ;\
		fi;\
		for file in _dummy_ $(RMI_CLASS_FILES); do\
			if [ $$file = "_dummy_" ]; then\
				continue ;\
			fi;\
			if [ -r $$dir/$$file ]; then\
				if [ $(DEBUG) != 0 ]; then\
					echo $(RM) $$dir/$$file;\
				fi;\
				$(RM) $$dir/$$file;\
			fi;\
		done;\
	fi;\
	if [ "$(JNI_SUPPORT)" = "1" ]; then \
		if [ $(DEBUG) != 0 ]; then\
			echo "Removing Java native code generated files" ;\
		fi;\
		for file in _dummy_ `grep -l native *.java 2>$(DEVNULL)`; do\
			if [ $$file = "_dummy_" ]; then\
				continue ;\
			fi;\
			egrep "native " $$file | egrep -v "//" >$(DEVNULL);\
			if [ $$? -eq 0 ]; then\
				filetoremove=`echo $$file | sed -e 's/.java/.h/g'`;\
				if [ -r $$dir/$$filetoremove ]; then\
					if [ $(DEBUG) != 0 ]; then\
						echo $(RM) $$dir/$$filetoremove;\
					fi;\
					$(RM) $$dir/$$filetoremove;\
				fi;\
			fi;\
		done;\
	fi

#     Clean Java target scripts and targets
clean clean_targets :: _clean_targets
_clean_targets :
	@ if [ $(DEBUG) != 0 ]; then\
		echo "Removing target files" ;\
	fi;\
	if [ "$(JAVA_HTML_TARGET)" != "" -a -r $(JAVA_HTML_TARGET).sh ]; then\
		if [ $(DEBUG) != 0 ]; then\
			echo $(RM) $(JAVA_HTML_TARGET).sh;\
		fi;\
		$(RM) $(JAVA_HTML_TARGET).sh;\
	fi;\
	if [ "$(JAVA_HTML_TARGET)" != "" -a -r $(JAVA_HTML_TARGET).env ]; then\
		if [ $(DEBUG) != 0 ]; then\
			echo $(RM) $(JAVA_HTML_TARGET).env;\
		fi;\
		$(RM) $(JAVA_HTML_TARGET).env;\
	fi;\
	if [ "$(JAVA_APPLICATION_TARGET)" != "" -a -r $(JAVA_APPLICATION_TARGET).sh ]; then\
		if [ $(DEBUG) != 0 ]; then\
			echo $(RM) $(JAVA_APPLICATION_TARGET).sh;\
		fi;\
		$(RM) $(JAVA_APPLICATION_TARGET).sh;\
	fi;\
	if [ "$(JAVA_APPLICATION_TARGET)" != "" -a -r $(JAVA_APPLICATION_TARGET).env ]; then\
		if [ $(DEBUG) != 0 ]; then\
			echo $(RM) $(JAVA_APPLICATION_TARGET).env;\
		fi;\
		$(RM) $(JAVA_APPLICATION_TARGET).env;\
	fi;\
	if [ "$(JAVA_JAR_TARGET)" != "" -a -r $(SNIFF_JAVA_GENDIR_ROOT)/$(JAVA_JAR_TARGET) ]; then\
		if [ $(DEBUG) != 0 ]; then\
			echo $(RM) $(SNIFF_JAVA_GENDIR_ROOT)/$(JAVA_JAR_TARGET);\
		fi;\
		$(RM) $(SNIFF_JAVA_GENDIR_ROOT)/$(JAVA_JAR_TARGET);\
		if [ $(DEBUG) != 0 ]; then\
			echo $(RM) $(SNIFF_JAVA_GENDIR_ROOT)/$(JAVA_JAR_TARGET).lst;\
		fi;\
		$(RM) $(SNIFF_JAVA_GENDIR_ROOT)/$(JAVA_JAR_TARGET).lst;\
	fi

########################################################################
# rule for make default target recursively
########################################################################

# start a new make process to make all targets in this project
main_all : 
	@ echo "*** $(PARENT)";\
	echo "Making classes recursively";\
	if [ "$(SNIFF_JAVA_GENDIR_ROOT)" != "" -a ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
		$(MK_DIR) $(SNIFF_JAVA_GENDIR_ROOT);\
		if [ ! -d $(SNIFF_JAVA_GENDIR_ROOT) ]; then\
			exit 1;\
		fi;\
	fi;\
	JAVAC=$(JAVAC);\
	export JAVAC;\
	ALL_JFLAGS="$(ALL_JFLAGS)";\
	export ALL_JFLAGS;\
	if [ $(DEBUG) != 0 ]; then\
		echo "Compiler=$(JAVAC); Flags=$(ALL_JFLAGS)";\
		echo "$(SNIFFJMAKE_CMD) recursive";\
	fi;\
	$(SNIFFJMAKE_CMD) recursive

# make all targets in this project
targets_all :: $(PRE_TARGETS) _all $(RMI_RULE) $(JNI_RULE)
_all :
	@ for target in _dummy_ $(SNIFF_TARGETS); do\
		if [ $$target = "_dummy_" ]; then\
			continue ;\
		fi;\
		$(OWN_MAKE) -f $(MAKEFILE) $$target SCRIPT_ONLY=1;\
	done;\
	if [ $(DEBUG) != 0 ]; then\
		echo "make: all targets are done in project '$(SNIFF_PROJECT)'";\
	fi

rmi_all :: _rmi_all
_rmi_all :
	@ if [ "$(RMI_SUPPORT)" = "1" -a "$(SNIFF_JAVA_RMI_FILES)" != "" ]; then \
		for file in _dummy_ $(SNIFF_JAVA_RMI_FILES); do\
			if [ $$file = "_dummy_" ]; then\
				continue ;\
			fi;\
			$(OWN_MAKE) -f $(MAKEFILE) `echo $$file | cut -d"." -f1`.rmi;\
		done;\
	fi

jni_all :: _jni_all
_jni_all :
	@ if [ "$(JNI_SUPPORT)" = "1" ]; then \
		for file in _dummy_ `grep -l native *.java 2>$(DEVNULL)`; do\
			if [ $$file = "_dummy_" ]; then\
				continue ;\
			fi;\
			egrep "native " $$file | egrep -v "//" >$(DEVNULL);\
			if [ $$? -eq 0 ]; then\
				$(OWN_MAKE) -f $(MAKEFILE) `echo $$file | cut -d"." -f1`.jni;\
			fi;\
		done;\
	fi
 
########################################################################
# pre_targets
#	make pre-targets
# all_pre_targets
#	make pre-targets recursively
########################################################################
pre_targets :: _all_pre_targets
 
all_pre_targets :: echo_parent _all_pre_targets
_all_pre_targets :  $(PRE_TARGETS)
	@ if [ $(DEBUG) != 0 ]; then\
		echo "make: pre-targets are done in project '$(SNIFF_PROJECT)'";\
	fi
 
echo_parent :
	-@ echo "*** $(PARENT)"

check_vpath :
	-@ echo "================================";\
	echo "check_vpath not required anymore";\
	echo "================================"

symbolic_links :
	-@ echo "======================================";\
	echo "symbolic links not supported from Java";\
	echo "======================================"

#        Platform specific make macros
include $(SNIFF_DIR)/make_support/$(PLATFORM).mk
