#	file: $SNIFF_DIR/vcs/clearcase.tcl

#------ constants --------------------------------------------------------

global gPlatform;
set gPlatform [lindex [array get tcl_platform platform] 1];

global gOS;
set gOS [lindex [array get tcl_platform os] 1];

switch $gOS {
	"Windows 95" {
		set gCmd "command.com";
	}
	"Windows NT" {
		set gCmd "cmd";
	}
}

global gDebug;
set gDebug 0;

global gTmpDir;
set gTmpDir "";

global gTraceFile gTraceFileName;
set gTraceFile "";


#------ tracing ----------------------------------------------------------

switch $gPlatform {
	windows {
		set gTraceFileName "c:\\tmp\\clearcase.tcl.log";
	}
	* {
		set gTraceFileName "clearcase.tcl.log";		
	}
}

proc trace_open {} {
	set _Fct "trace_open";
	global gTraceFile gTraceFileName gDebug;

	if { $gDebug > 0 } {
		set gTraceFile [open $gTraceFileName {WRONLY CREAT APPEND}];
		fconfigure $gTraceFile -buffering none;
	}
}

proc trace_close {} {
	global gTraceFile;

	if { $gTraceFile != "" } {
		close $gTraceFile;
	}
	set gTraceFile "";
}

proc _value {arg} {
	return $arg;
}

proc trace_print {args} {
	global gTraceFile;

	if { $gTraceFile != "" } {
		puts $gTraceFile "$args";
	}
}

proc trace_var {args} {
	global gTraceFile;


	if { $gTraceFile == "" } {
		return;
	}
	set Line "";
	set VarNameList [uplevel {info locals}];
	foreach VarName $VarNameList {
		set Value [uplevel "_value \$$VarName"];
		set Line "$Line $VarName=$Value";
	}
	puts $gTraceFile "$Line";
}


#------ misc -------------------------------------------------------------

proc print_enter {Fct Text} {
	puts stdout "$Fct: \[>>>\] $Text";
}

proc print_exit {Fct Text} {
	puts stdout "$Fct: \[<<<\] $Text";
}

proc print {Fct Text} {
	puts stdout "$Fct: $Text";
}

#------ external execution ---------------------------------------------

proc unknown {args} {
	global errorCode;
	global gTraceFile;

	#puts $gTraceFile "unknown: exec >@stdout 2>@stderr $args";
	set Exception [catch "exec >@stdout 2>@stderr $args" BlockValue];
	#puts stderr "Exception=$Exception errorCode=$errorCode";

	if "$Exception" {
		switch [lindex $errorCode 0] {
		CHILDSTATUS {
			return [lindex $errorCode 2];
			}
		POSIX {
			puts stderr "unknown.exec: [lindex $errorCode 2]"; }
			return 255;
		}
	} else {
		return 0;
	}
}

#------ basic file/directory manipulation

proc Unix2WinPath {path} {
	regsub -all -- "/" $path "\\" path;
	return $path;
}


proc basename {path} {
	return [file tail $path];
}


proc dirname {path} {
	return [file dirname $path];
}


proc mkdir {Path} {
	global gCmd;
	unknown $gCmd /c mkdir $Path;
}


proc mkdir_p {Path} {
	global gCmd;
	unknown $gCmd /c mkdir $Path;
}


proc rmdir {Path} {
	global gCmd;
	unknown $gCmd /c rmdir /q $Path;;
}


proc rmdir_r {Path} {
	global gCmd;
	unknown $gCmd /c rmdir /s /q $Path;;
}


proc rm {Path} {
	global gCmd;
	unknown $gCmd /c del /f /q $Path;
	#	exit status not depending on success/failure!
}


proc rm_r {Path} {
	global gCmd;
	unknown $gCmd /c del /f /s /q $Path;
	#	exit status not depending on success/failure!
}


proc chmod_writable {Path} {
	global gCmd;
	unknown $gCmd /c attrib -r $Path;
}


proc chmod_readonly {Path} {
	global gCmd;
	unknown $gCmd /c attrib +r $Path;
}

#---- by Drasch for ClearCase-- basic file/directory manipulation

proc cp {FromPath ToPath} {
	global gCmd;
	unknown $gCmd /c copy /v $FromPath $ToPath;
	#	exit status not depending on success/failure!
}


proc check_writable {Path} {
	return [file writable $Path];
}


proc check_directory {Path} {
	if { [file exists $Path] } {
		return [file isdirectory $Path];
	} else {
		return 0;
	}
}


#------ basic ClearCase_functions

proc extract_line {
Fullstring	\
Seperator	\
Reverse		\
} {
	upvar $Fullstring String;
	if { $String == "" } {
		return "";
	}
	if { $Reverse } {
		set IndexNL [string last $Seperator $String];
	} else {
		set IndexNL [string first $Seperator $String];
	}
	if { $IndexNL == -1 } {
		set Line $String;
		set String "";
		return $Line;
	}
	if { $Reverse } {
		incr IndexNL 1;
		set Line [string range $String $IndexNL end];
		incr IndexNL -2;
		if { $IndexNL <= 0 } {
			set String "";
		} else {
			set String [string range\
				$String 0 $IndexNL];
		}
	} else {
		incr IndexNL -1;
		set Line [string range $String 0 $IndexNL];
		incr IndexNL 2;
		if { $IndexNL >= \
			[expr [string length $String] - 1] } {
			set String "";
		} else {
			set String [string range\
				$String $IndexNL end];
		}
	}
	return $Line;
}


#######################################
### ClearCase - Functions by Drasch ###
#######################################


proc ClearCase_CheckOut {	\
	P_Path		\
	F_FileName	\
	L_LockType	\
	V_Version	\
	W_Path		\
	t_Path		\
	T_Path		\
} {
	set _Fct "ClearCase_CheckOut"; trace_var;

    if { $W_Path == $t_Path } {
		if { $V_Version != "" } {
			if { [basename $V_Version] == 0 }	{
				rm [Unix2WinPath $T_Path];
			}
		}
		cp [Unix2WinPath $P_Path\\$F_FileName@@$V_Version] \
			[Unix2WinPath $T_Path];
		return 0;
    } else {
	 	if { $L_LockType == "E" } {
			unknown cleartool co \
				-nc -reserved $P_Path\\$F_FileName;
		} else {
			unknown cleartool co \
				-nc -unreserved $P_Path\\$F_FileName;
		}
	}
}


proc ClearCase_CreateRepositoryFile {	\
	P_Path		\
	F_FileName	\
	L_LockType	\
	C_Comment	\
	S_VersionName \
} {
	set _Fct "ClearCase_CreateRepositoryFile"; trace_var;

	if { [ unknown cleartool mkelem \
		-c \"$C_Comment\" -ci $P_Path\\$F_FileName; ] } {
		return 1;
	}
	if { $S_VersionName != "" }	{
		unknown cleartool mklbtype -nc \"$S_VersionName\";
		unknown cleartool mklabel -version "main\1" \
			\"$S_VersionName\" $P_Path\\$F_FileName;
	}
	if { $L_LockType == "E" } {
		unknown cleartool co -nc -reserved $P_Path\\$F_FileName;
	}
	return 0;
}


proc ClearCase_CheckIn {	\
	P_Path		\
	F_FileName	\
	L_LockType	\
	C_Comment	\
	S_VersionName \
} {
	set _Fct "ClearCase_CheckIn"; trace_var;

	if { [ unknown cleartool ci \
		-c \"$C_Comment\" -rm $P_Path\\$F_FileName; ] } {
		return 1;
	}
	if { $S_VersionName != "" }	{
		unknown cleartool mklbtype -nc $S_VersionName;
		unknown cleartool mklabel \"$S_VersionName\" $P_Path\\$F_FileName;
	}
	if { $L_LockType == "E" } {
		unknown cleartool co -nc -reserved $P_Path\\$F_FileName;
	}
	return 0;
}


proc ClearCase_Lock {	\
	P_Path		\
	F_FileName	\
} {
	set _Fct "ClearCase_Lock"; trace_var;

	unknown cleartool reserve -nc $P_Path\\$F_FileName;
}


proc ClearCase_IsDifferent {	\
	P_Path		\
	F_FileName	\
} {
	set _Fct "ClearCase_IsDifferent"; trace_var;

	if { [check_writable [Unix2WinPath $P_Path\\$F_FileName]] } {
		unknown cleartool diff -diff_format \
			-pred $P_Path\\$F_FileName >nul;
	} else {
		return 0;
	}
}

proc ClearCase_DiffText_W_V {	\
	P_Path		\
	F_FileName	\
	v_VersionNumber \
} {
	set _Fct "ClearCase_DiffText_W_V"; trace_var;

	if { $v_VersionNumber == "" } {
		set VersionRead [exec 2>@stderr \
				cleartool lsvtree -nco $P_Path\\$F_FileName];
		set IndexAt [expr [string last @@ $VersionRead] + 2];
		set VersionRead [string range $VersionRead $IndexAt end];
		unknown cleartool diff -diff_format \
			$P_Path\\$F_FileName $P_Path\\$F_FileName@@$VersionRead;
	} else {
		unknown cleartool diff -diff_format \
			$P_Path\\$F_FileName \"$P_Path\\$F_FileName@@$v_VersionNumber\";
	}
}


proc ClearCase_DiffText_V_V {	\
	P_Path		\
	F_FileName	\
	V_Version \
	v_VersionNumber \
} {
	set _Fct "ClearCase_DiffText_V_V"; trace_var;

	unknown cleartool diff -diff_format \
		$P_Path\\$F_FileName@@$V_Version $P_Path\\$F_FileName@@$v_VersionNumber;
}


proc ClearCase_UpdateFile {	\
	P_Path		\
	F_FileName	\
	V_Version \
} {
	set _Fct "ClearCase_UpdateFile"; trace_var;

	if { $V_Version == "" } {
		unknown cleartool findmerge $P_Path\\$F_FileName \
				-nc -print -flatest -whynot;
	} else {
		unknown cleartool findmerge $P_Path\\$F_FileName \
				-nc -print -fversion $V_Version -whynot;
	}
}


proc ClearCase_UnLock {	\
	P_Path		\
	F_FileName	\
} {
	set _Fct "ClearCase_UnLock"; trace_var;

	unknown cleartool unreserve -nc $P_Path\\$F_FileName;
}


proc ClearCase_DeleteVersion {	\
	P_Path		\
	F_FileName	\
	V_Version \
} {
	set _Fct "ClearCase_DeleteVersion"; trace_var;

	if { $V_Version == "" } {
		unknown cleartool rmver -force -xlabel $P_Path\\$F_FileName;
	} else {
		unknown cleartool rmver -force -xlabel $P_Path\\$F_FileName@@$V_Version;
	}
}


proc ClearCase_NoDescription {	\
} {
	set _Fct "ClearCase_NoDescription"; trace_var;

	puts "ClearCase does not support Description";
	return 0;
}


proc ClearCase_SetSymbol {	\
	P_Path		\
	F_FileName	\
	V_Version \
	s_ForceFlag	\
	S_VersionName \
} {
	set _Fct "ClearCase_SetSymbol"; trace_var;
	
	if { $V_Version != "" } {
		set Version "-version $V_Version";
	} else {
		set Version "";
	}
	if { $s_ForceFlag } {
		set ForceFlag "-replace";
	} else {
		set ForceFlag "";
	}
	unknown cleartool mklbtype -nc \"$S_VersionName\";
	unknown cleartool mklabel $ForceFlag $Version \
		 \"$S_VersionName\" $P_Path\\$F_FileName;
}


proc ClearCase_DeleteSymbol {	\
	P_Path		\
	F_FileName	\
	V_Version \
	S_VersionName \
} {
	set _Fct "ClearCase_DeleteSymbol"; trace_var;
	
	if { $V_Version != "" } {
		set Version "-version $V_Version";
	} else {
		set Version "";
	}
	unknown cleartool rmlabel $Version \
		 \"$S_VersionName\" $P_Path\\$F_FileName;
}


proc ClearCase_ChangeComment {	\
	P_Path		\
	F_FileName	\
	C_Comment	\
} {
	set _Fct "ClearCase_ChangeComment"; trace_var;
	
	unknown cleartool chevent -c \"$C_Comment\"\
		-replace $P_Path\\$F_FileName;
}


proc ClearCase_History {	\
	P_Path		\
	F_FileName	\
} {
	set _Fct "ClearCase_History"; trace_var;
	
	set List [exec 2>@stderr cleartool annotate -nco -ndata \
		-out - -long $P_Path\\$F_FileName];
	set List [string range $List\
			[string first --------------- $List] end];
	regsub -all -- "\t" $List "   " List;
	puts $List
	return 0;
}


proc ClearCase_SymbolList {	\
	A_Path		\
} {
	set _Fct "ClearCase_SymbolList"; trace_var;

	regsub -all {\\} $A_Path {\\\\} A_Path;
	foreach File $A_Path {
		ClearCase_SymbolList_OneFile $File;
	}
	return 0;
}


proc ClearCase_SymbolList_OneFile {	\
	FileName		\
} {
	set _Fct "ClearCase_SymbolList_OneFile"; trace_var;

	set CleartoolResult [exec 2>@stderr cleartool lsh\
	 	-nco -fmt \"%e %En %Vn %u %Vd %Nl\n\" $FileName];
	set lfnr 0;
	set Worktext [extract_line CleartoolResult "\n" 1];
	set VersionList "";
	puts [format "\f%s" $FileName];
	while { $Worktext != "" } {
		if { [regsub --	"^create version " \
				$Worktext "" Worktext ] } {
			set Scanned [scan $Worktext "%s %s %s %s %d/%d/%d %s %s" \
					Name Version User DayText Month Day Year Time Label]; 
			set VerNr 1.$lfnr;
			if { $lfnr == 0 } {
				set VersionList [format "%s %s 19%02d/%02d/%02d %s; %s; +1 -1;" \
					$Version $VerNr $Year $Month $Day $Time $User];
			} else {
				set VersionList [format "%s\n%s %s 19%02d/%02d/%02d %s; %s; +1 -1;" \
					$VersionList $Version $VerNr $Year $Month $Day $Time $User];
			}
			if { $Scanned > 8 } {
				set IndexLabel [string first $Label $Worktext];
				set Worktext [string range $Worktext $IndexLabel end];
				puts [format "%s: %s" $Label $VerNr];
				while { $Worktext != $Label } {
					set IndexLabel [expr [string first " " $Worktext] + 1];
					set Worktext [string range $Worktext $IndexLabel end];
					scan $Worktext "%s" Label;
					puts [format "%s: %s" $Label $VerNr];
				}
			}
			incr lfnr 1;
		}
		set Worktext [extract_line CleartoolResult "\n" 1];
	}
	puts [format "HEAD: %s" $VerNr];
	puts $VersionList;
	return 0;
}


proc ClearCase_RevisionOfSymbol {	\
	P_Path		\
	F_FileName	\
	S_VersionName \
} {
	set _Fct "ClearCase_RevisionOfSymbol"; trace_var;

	set Revision [exec 2>@stderr cleartool lsh -nco \
			-fmt \"%Vn %Nl\n\" $P_Path\\$F_FileName];
	if { [regexp -- "$S_VersionName\n" $Revision] } {
		set IndexFound [expr [string first $S_VersionName $Revision] - 2];
		set Revision [string range $Revision 0 $IndexFound];
		set IndexFound [expr [string last "\n" $Revision] + 1];
		puts [string range $Revision $IndexFound end];
	}
	return 0;
}


proc ClearCase_HistoryOfRevision {	\
	P_Path		\
	F_FileName	\
	V_Version \
} {
	set _Fct "ClearCase_HistoryOfRevision"; trace_var;
	
	unknown cleartool describe -version $V_Version \
				$P_Path\\$F_FileName;
}


proc ClearCase_Comment {	\
	P_Path		\
	F_FileName	\
	V_Version \
} {
	set _Fct "ClearCase_Comment"; trace_var;
	
	unknown cleartool describe -fmt \"%c\" \
		-version $V_Version $P_Path\\$F_FileName;
}


proc ClearCase_Lockers {	\
	A_Path	\
} {
	set _Fct "ClearCase_Lockers"; trace_var;

	set Result [exec 2>@stderr cleartool lsc $A_Path];
	set Worktext [extract_line Result "\n" 0];
	regsub -all {\\} $A_Path {\\\\} A_Path;
	foreach File $A_Path {
		set FileName [basename $File];
		set Outline $FileName;
		while { [regexp -- $FileName $Worktext] } {
			if { [regexp -- "checkout version" $Worktext] } {
				scan $Worktext "%s %s checkout version %s from %s %s"\
					Dummy User File Version Flag;
				set Outline [format "%s %s:%s:(%s)" \
					$Outline $User $Version [string index $Flag 1]];
			}
			set Worktext [extract_line Result "\n" 0];
		}
		if { $Outline != $FileName } {
			puts $Outline;
		}
	}
	return 0;
}


proc ClearCase_IsLockedBy {	\
	P_Path		\
	F_FileName	\
	U_User		\
} {
	set _Fct "ClearCase_IsLockedBy"; trace_var;

	set Return [exec 2>@stderr cleartool lsc \
		-user $U_User $P_Path\\$F_FileName];
	if { $Return != "" } {
		return 0;
	} else {
		return 1;
	}
}


proc ClearCase_IsLocked {	\
	P_Path		\
	F_FileName	\
} {
	set _Fct "ClearCase_IsLocked"; trace_var;
	
	set Return [exec 2>@stderr cleartool lsc \
		$P_Path\\$F_FileName];
	if { $Return != "" } {
		return 0;
	} else {
		return 1;
	}
}


proc ClearCase_CheckRepositoryDir {	\
} {
	set _Fct "ClearCase_CheckRepositoryDir"; trace_var;

	return 0;
}


proc ClearCase_CheckRepositoryFile {	\
	P_Path		\
	F_FileName	\
} {
	set _Fct "ClearCase_CheckRepositoryFile"; trace_var;

	set Vobs [exec 2>@stderr \
			cleartool ls -vob_only $P_Path\\$F_FileName];
	if { $Vobs == "" } {
		return 1;
	} else {
		return 0;
	}
}


proc ClearCase_DateOfRepositoryFile {	\
	P_Path		\
	F_FileName	\
} {
	set _Fct "ClearCase_DateOfRepositoryFile"; trace_var;

	set FullDate [exec 2>@stderr cleartool lsh -minor \
	 				-fmt \"%Vd\\n\" $P_Path\\$F_FileName];
	if { $FullDate != "" } {
		set IndexNL [expr [string first	"\n" $FullDate] - 1];
		set FullDate [string range $FullDate 0 $IndexNL];
		scan $FullDate "%s %d/%d/%d %s"\
						Dummy Month Day Year Time;
		puts [format "19%02d/%02d/%02d %s" \
				$Year $Month $Day $Time]; 
	}
	return 0;
}


proc ClearCase_TestTool {	\
} {
	set _Fct "ClearCase_TestTool"; trace_var;

 	set Return [catch "exec 2>@stderr cleartool help >NUL"];
	if { $Return } {
		return 1;
	} else {
		return 0;
	}
}


proc ClearCase_Constructor {	\
	t_Path	\
} {
	set _Fct "ClearCase_Constructor"; trace_var;

	if { [check_directory [Unix2WinPath $t_Path]] == 0 } {
		mkdir_p [Unix2WinPath $t_Path];
	} else {
		return 0;
	}
}


proc ClearCase_Destructor {	\
	t_Path	\
} {
	set _Fct "ClearCase_Destructor"; trace_var;

	if { [check_directory [Unix2WinPath $t_Path]] } {
		rmdir_r [Unix2WinPath $t_Path];
	} else {
		return 0;
	}
}


#------ check_and_init --------------------------------------------------

proc env_find_name {EnvVarName} {
	set _Fct "env_find_name";
	global env;
	set Env {};
	set Name {};
	set UppercaseName {};
	set RealName {};
	set NameValuePair {};

	set Env [array get env];
	set EnvVarName [string toupper $EnvVarName];
	foreach NameValuePair $Env {
		set Name [lindex $NameValuePair 0];
		set UppercaseName [string toupper $Name];
		if { [string compare $UppercaseName $EnvVarName ] == 0 } {
			set RealName $Name;
			break;
		}
	}
	return $RealName;
}

proc check_and_init {} {
	set _Fct "check_and_init"; trace_var;
	global env;
	global gTmpDir;

	#------ compute temp directory
	set TmpDirName [env_find_name "TMP"];
	if { $TmpDirName == "" } {
		set TmpDirName [env_find_Name "TEMP"];
	}
	if { $TmpDirName == "" } {
		puts stderr "ClearCase.TCL: neither env var TMP nor TEMP set";
		exit 1;
	}
	trace_print "TmpDirName=$TmpDirName";
	set gTmpDir [lindex [array get env $TmpDirName] 1];
	return 0;
}


#------ body ------------------------------------------------------------
set gDebug 0;

trace_open;
trace_print "begin: argc=$argc argv=$argv";

if { [check_and_init] != 0 } {
	trace_close;
	exit 1;
}


set ReturnCode 0;
set BlockValue 0;

if { $argc > 0 } {
	set ReturnCode [catch {eval $argv} BlockValue];
#	set ReturnCode [catch {time $argv 1} BlockValue];
#	puts stderr "[lindex $argv 0] $BlockValue";
} else {
	set ReturnCode 5;
}
trace_print "ReturnCode=$ReturnCode BlockValue=$BlockValue"
trace_print "end";
trace_close;
if { $ReturnCode == 0 } {
	exit $BlockValue;
} else {
	exit 255;
}
