##################################################################################
#
#   RCS 5.7 NT - Tcl Adaptor  -> based on the VSS TCL Adapter from Martin Klaus
# 
#	Author:     Uwe Stieber 
#
#	History: 	1.0 Initial Version - 29.10.97
#
#	file: $SNIFF_DIR/vcs/rcs.tcl
#
#	Please report problems with the adapter to: sniff-support@takefive.co.at
#						
##################################################################################

#------ constants --------------------------------------------------------
global gPathVar;
set gPathVar "";
catch {set gPathVar $env(PATH)};
catch {set gPathVar $env(Path)};
if {$gPathVar == ""} { 
	puts stderr "$gProg: Neither PATH nor Path environment variable is set"
	exit 1
};

global gPlatform;
set gPlatform [lindex [array get tcl_platform platform] 1]; 

global gOS;
set gOS [lindex [array get tcl_platform os] 1];

global gSniffDir;
catch {set gSniffDir $env(SNIFF_DIR)}
 
# Temporary path for log files
global TempPath;
set TempPath "";
switch $gPlatform {
	windows {
		catch {set TempPath $env(TMP)}
		catch {set TempPath $env(TEMP)}
		if {$TempPath == ""} {
		  puts stderr "$gProg: Neither TMP nor TEMP environment variable is set"
		  exit 1
		} 
	}
	unix {
		set TempPath "/tmp";
	}
	* {
		set TempPath ""
	}
}
 
switch $gOS {
	"Windows 95" {
		set gCmd "command.com";
	}
	"Windows NT" {
		set gCmd "cmd";
	}
}

global gProg;
set gProg "rcs_57.tcl";
 
global gDebug;
set gDebug 0;

#------ Mks toolkit on Windows ------------------------------------------
global gMksRootDir;
global gMksBinDir;
 
switch $gPlatform {
	windows {
		set gMksRootDir $env(ROOTDIR);
		set gMksBinDir $gMksRootDir/mksnt
		if { ! [file isdirectory $gMksBinDir] } {
			puts stderr "$gProg: MKS toolkit not found";
			exit 1
		}
	}
	* {
		set gMksRootDir "";
	}
}
global logname;
set logname "";
#------ tracing ----------------------------------------------------------

global gTraceFile gTraceFileName;
set gTraceFile "";
 
switch $gPlatform {
	windows {
		#set gTraceFileName "$TempPath\\rcs_57.tcl.log";
		set gTraceFileName "c:\\tmp\\rcs_57.log";
	}
	unix {
		set gTraceFileName "$TempPath/rcs_57.tcl.log";
	}
	* {
		set gTraceFileName "rcs_57.tcl.log";
	}
}
 
proc trace_open {} \
{
	set _Fct "trace_open";
	global gTraceFile gTraceFileName gDebug;

	if { $gDebug > 0 } {
		set gTraceFile [open $gTraceFileName {WRONLY CREAT APPEND}];
		fconfigure $gTraceFile -buffering none;
	}
}
proc trace_close {} \
{
	global gTraceFile;

	if { $gTraceFile != "" } {
		close $gTraceFile;
	}
	set gTraceFile "";
}
proc _value {arg} \
{
	return $arg;
}
proc trace_print {args} \
{
	global gTraceFile;

	if { $gTraceFile != "" } {
		puts $gTraceFile "$args";
		flush $gTraceFile
	}
}
proc trace_var {args} \
{
	global gTraceFile;
 
	if { $gTraceFile == "" } {
		return;
	}
	set Line "";
	set VarNameList [uplevel {info locals}];
	foreach VarName $VarNameList {
		set Value [uplevel "_value \$$VarName"];
		set Line "$Line $VarName=$Value";
	}
	puts $gTraceFile "$Line";
}

#------ path name routines -------------------------------------------------

proc get_temp_file_base_name {} {
	global gDebug;
	set Pid 0;

	set Pid [pid];
	if { $gDebug == 0 } {
		return [format %08X.tmp $Pid];
	} else {
		return "rcstcl.tmp";
	}
}

proc get_temp_file_name {} {
	global TempPath;
	set TmpFileName "";

	set TmpFileName [get_temp_file_base_name];
	return [path_concat $TempPath $TmpFileName];
}

proc path_concat {Prefix Suffix} \
{
	global gPlatform;
	switch $gPlatform {
		windows {
			set Separator {/};
		}
		unix {
			set Separator {/};
		}
		macintosh {
			set Separator {:};
		}
		* {
			puts stderr "path_concat: not supported platform=$platform";
		}
	}
	return "$Prefix$Separator$Suffix";
}

#------ external execution ---------------------------------------------
 
proc unknown {args} {
	global errorCode;
	global gTraceFile;
 
	# --- reset errorCode for better tracing --- USI 19.11.1997
	# --- also rearange the trace_print for better tracing --- USI 19.11.1997
	set errorCode "";
	trace_print "exec >@stdout 2>@stderr $args"
	set Exception [catch "exec >@stdout 2>@stderr $args" BlockValue];
	if "$Exception" {
	  trace_print "Exception=$Exception errorCode=$errorCode";
		switch [lindex $errorCode 0] {
		CHILDSTATUS {
			return [lindex $errorCode 2];
			}
		POSIX {
			puts stderr "Error during executing unknown: [lindex $errorCode 2]"; }
			return 255;
		}
	} else {
	  #trace_print "previous exec was successfully !";
		return 0;
	}
}
 
#--------- rcs helper functions ------------------------------------------------------------------

proc for_pattern_do {File StartPattern StopPattern Block} {
	for_pattern_do_at $File $StartPattern $StopPattern $Block 1;
}

proc for_pattern_do_at {File StartPattern StopPattern Block Uplevel} {
	set _Fct "for_pattern_do_level_at";

	#------ global variables referenced
	global errorCode errorInfo;

	#------ Variables inserted in caller's stack frame
	#	for use within 'Block'
	upvar $Uplevel LINE LINE;
	upvar $Uplevel PHASE PHASE;
	upvar $Uplevel LINENR LINENR;
	#	when start pattern detected:	0
	#	between start and stop pattern: 1
	#	when stop pattern detected:	2

	#------ local variables
	set CatchCode 0;
	set ReturnValue "";
	set Cmd "eval {$Block}";
	#	Note: $Block is enclosed by brackets!
	#	Otherwise, we would have the expansion:
	#		"uplevel 1 eval cmd1; cmd2"
	#	which is not intended!
	#	Note: since we executing the 'Block' in the
	#	caller's stack frame, we have to evaluate 'Block'
	#	in the local context.
	set Phase 0;
	set Line "";
	set LineNr 0;
	set NumRead 0;
	set SeenStartPattern 0;
	set SeenStopPattern 0;
	
	#------ loop over input lines, detect patterns and call 'Block'
	set NumRead [gets $File Line];
	while { ! [eof $File] && ! $SeenStopPattern } {
		if { $SeenStartPattern && ! $SeenStopPattern } {
			set Phase 1;
			set SeenStopPattern [				\
				regexp -- $StopPattern $Line Dummy	\
			];
			if { $SeenStopPattern } {
				set Phase 2;
			}
		}
		if { ! $SeenStartPattern } {
			set SeenStartPattern [				\
				regexp -- $StartPattern $Line Dummy	\
			];
			if { $SeenStartPattern } {
				set Phase 0;
			}
		}

		if { $SeenStartPattern } {
			#------ set variables for use in 'Block'
			incr LineNr;
			set LINENR $LineNr;
			set LINE $Line;
			set PHASE $Phase;
			#------ execute block
			set CatchCode [				\
				catch {uplevel $Uplevel $Cmd}	\
				ReturnValue			\
			];
			switch $CatchCode {
				0 { 
					#	ok
				}
				1 {
					#	error - prepare for reraise
					set savedErrorInfo $errorInfo;
					set savedErrorCode $errorCode;
					break;
				}
				2 {
					#	return out of block
				}
				3 {
					#	break out of block - stop
					break;
				}
				4 {
					#	continue out of block
				}
				* {
					#	unknown! XXX
				}
			}
		}

		if { ! $SeenStopPattern } {
			set NumRead [gets $File Line];
		}
	}

	#------ reraise error if one occured in 'Block'
	if { $CatchCode == 1 } {
		#	reraise error
		error $ReturnValue $errorInfo $errorCode;
	}
	return $ReturnValue;
}

proc string_normalize {String} {
	regsub -all -- "\[ \t\r\n\]+" $String " " String;
	set String [string trim $String];
	return $String;
}

proc file_text_extract {File StartPattern StopPattern} {
	set Line "";
	set NumRead 0;
	set SeenStartPattern 0;
	set SeenStopPattern 0;
	
	set NumRead [gets $File Line];
	while { ! [eof $File] && ! $SeenStopPattern } {
		if { ! $SeenStartPattern } {
			set SeenStartPattern [				\
				regexp -- $StartPattern $Line Dummy	\
			];
		}
		if { $SeenStartPattern && ! $SeenStopPattern } {
			set SeenStopPattern [				\
				regexp -- $StopPattern $Line Dummy	\
			];
		}
		if { $SeenStartPattern && ! $SeenStopPattern } {
			puts stdout $Line;
		}
		if { ! $SeenStopPattern } {
			set NumRead [gets $File Line];
		}
	}
}

#
#	file_grep: searches text file for pattern and returns
#	first matching line
#
proc file_grep {FileName Pattern} {
	set Line "";
	set File "";
	set NumRead 0;
	set Matched 0;
	set MatchingLine "";

	set File [open $FileName RDONLY];
	set NumRead [gets $File Line];
	while { ! [eof $File] && ! $Matched } {
		set Matched [regexp -- $Pattern $Line MatchingLine];
		if { $Matched } {
			continue;
		}
		set NumRead [gets $File Line];
	}
	close $File;
	return $Line;
}

#------ basic file/directory manipulation
proc dirname {path} \
{
	return [file dirname $path];
}
 
proc mkdir {Path} \
{
	global gMksBinDir;
	global gPlatform;
	if { $gPlatform == "unix"} {
		unknown mkdir $Path;
	} else {
		unknown $gMksBinDir/mkdir $Path;
	}
}
proc mkdir_p {Path} \
{
	global gMksBinDir;
	global gPlatform;
	if { $gPlatform == "unix"} {
		unknown mkdir -p $Path;
	} else {
		unknown $gMksBinDir/mkdir -p $Path;
	}
}
 
proc rm {Path} \
{
	global gMksBinDir;
	global gPlatform;
	if { $gPlatform == "unix"} {
		unknown rm -rf $Path;
	} else {
		unknown $gMksBinDir/rm -rf $Path;
	}
	#	exit status not depending on success/failure!
}
 
proc rm_r {Path} \
{
	global gMksBinDir;
	global gPlatform;
	if { $gPlatform == "unix"} {
		unknown rm -rf $Path;
	} else {
		unknown $gMksBinDir/rm -rf $Path;
	}
	#	exit status not depending on success/failure!
}
 
proc chmod_writable {Path} \
{
	global gMksBinDir;
	global gPlatform;
	if { $gPlatform == "unix"} {
		unknown chmod a+w $Path;
	} else {
		unknown $gMksBinDir/chmod a+w $Path;
	}
	return 0;
}
 
proc chmod_readonly {Path} \
{
	global gMksBinDir;
	global gPlatform;
	if { $gPlatform == "unix"} {
		unknown chmod a-w $Path;
	} else {
		unknown $gMksBinDir/chmod a-w $Path;
	}
	return 0;
} 

proc changeBackslash {aText} {
	set helpString "";
	regsub -all {\\} "$aText" {/} helpString;
	return $helpString;
}
proc basename {path} {
	return [file tail $path];
}
proc which {aCommand} {
	global gMksBinDir;
	global gPlatform;
	if { $gPlatform == "unix"} {
		unknown which $aCommand;
	} else {
		unknown $gMksBinDir/which $aCommand;
	}
}

#------ rcs helper functions 2

#	rcs_get_field extracts field values from the RCS file.
#	The extracted field (including its name) are returned.
#	If something fails, an empty string is returned.
proc rcs_get_field {FileName Field} {
	set _Fct "rcs_get_field"; trace_var;
	set TmpFileName [get_temp_file_name];
	set MatchingLine "";

	unknown rlog -V5 -h $FileName >$TmpFileName;
	set MatchingLine [file_grep $TmpFileName $Field];
	rm $TmpFileName;
	return $MatchingLine;
}


#	rcs_get_head: complete
#	rcs_get_head extracts the head revision number for
#	the file 'FileName'.
proc rcs_get_head {FileName} {
	set _Fct "rcs_get_head"; trace_var;
	set Match1 "";
	# Note: regsub does not allocate variable if no match found!
	set Head [rcs_get_field $FileName "^head:"];
	regexp -- "^head: (.*)" $Head Match Match1;
	return $Match1;
}

proc rcs_get_branch {FileName Revision} {
	set _Fct "rcs_get_branch"; trace_var;
	set TmpFile [get_temp_file_name];
	set Found 0;

	unknown rlog -V5 $FileName >$TmpFile;
	set File [open $TmpFile RDONLY];
	while { [gets $File Line] >= 0 } {
		set Matched [						\
			regexp -- "^branches:(.*)\$" $Line Match Match1	\
		];
		if { $Matched > 0 } {
			regsub -all " " $Match1 "" Branches;
			set Branches [split $Branches ";"];
			set Branches [lreplace $Branches end end];

			set First [lindex $Branches 0];
			set ParentRevision "";
			regexp -- {(.*)\.[0-9]+} $First Dummy ParentRevision;
			if {$Revision == $ParentRevision} {
				set Found 1;
				break;
			}
		}
	}
	close $File;
	rm $TmpFile;
	if { $Found } {
		return $Branches;
	} else {
		return "";
	}
}

proc rcs_log_extract {A_Path StartPattern StopPattern Block} {
	set _Fct "rcs_log_extract"; trace_var;
	regsub -all {\\} $A_Path {\\\\} A_Path;
	set File [open "|rlog -V5 $A_Path" RDONLY];
	for_pattern_do_at $File $StartPattern $StopPattern $Block 2;
	close $File;
}


#------ rcs entry points

proc char_repeat {N Char} {
	set String "";
	set I 0;
	while { $I < $N } {
		set String "$String$Char";
		incr I;
	}
	return $String;
}

set cDashedLine [char_repeat 28 "-"];
#	30 dashes
set cEqualLine [char_repeat 77 "="];

#	rcs_checkout
proc rcs_checkout {	\
	A_Path		\
	F_FileName	\
	L_LockType	\
	s_ForceFlag	\
	V_Version	\
	W_Path		\
} {
	set _Fct "rcs_checkout"; trace_var;

	if { $s_ForceFlag } {
		set ForceFlagArg "-f";
	} else {
		set ForceFlagArg "-f";
		# XXX wrong but troubles if $ForceFlagArg evaluates to {}
	}
	if { $L_LockType == "N" } {
		unknown co -V5		\
			      -q$V_Version	\
			      $ForceFlagArg	\
			      $A_Path		\
			      [path_concat $W_Path $F_FileName]	\
		;
			
	} elseif { $L_LockType == "E" } {
		unknown co -V5		\
			      -q$V_Version	\
			      -l		\
			      $ForceFlagArg	\
			      $A_Path		\
			      [path_concat $W_Path $F_FileName]	\
		;
	} else {
		set Status [unknown co -V5	\
			                  -q$V_Version		\
			                  $ForceFlagArg		\
			                  $A_Path			\
			                  [path_concat $W_Path $F_FileName]	\
		           ];
		if { $Status == 0 } {
			chmod_writable [path_concat $W_Path $F_FileName];
		} else {
			return 0;
		}
	}
}


#	rcs_create_repository_file: complete
proc rcs_create_repository_file {	\
	A_Path				\
	C_Comment			\
	F_File				\
	I_Description			\
	L_LockType			\
	S_VersionName			\
	V_Version			\
	W_Path				\
} {
	set _Fct "rcs_create_repository_file"; trace_var;

	set VersionArgument "";
	set LockArgument "";

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	set W_Path "[changeBackslash $W_Path]";
 
	if { $S_VersionName != "" } {
		set VersionArgument "-n$S_VersionName";
	} else {
		set VersionArgument "";
	}
	
	if { $L_LockType == "E" } {
		set LockArgument "-l";
	} else {
		set LockArgument "-u";
	}
 
	set Status [ unknown rcs -V5 -i -q \
				    -t-"$I_Description" \
				    $A_Path \
		];
 
	set Status [ unknown ci -V5	\
				   -q$V_Version		\
				   $LockArgument		\
				   -m"$C_Comment"		\
				   -t-"$I_Description"	\
				   $VersionArgument	\
				   $A_Path			\
				   [path_concat $W_Path $F_File]	\
		   ];
 
	# handle the readonly Flag
	if { $L_LockType != "E" } {
		chmod_readonly [path_concat $W_Path $F_File];
		trace_print "set File [path_concat $W_Path $F_File] readonly";
	}
 
	#puts stderr "Status = $Status";
	return $Status;
}


#	rcs_checkin: complete
proc rcs_checkin {	\
	A_Path		\
	b_BranchFlag	\
	C_Comment	\
	F_File		\
	L_LockType	\
	S_VersionName	\
	V_Version	\
	B_BranchName	\
	W_Path		\
} {
	set _Fct "rcs_checkin"; trace_var;

	set VersionArg $V_Version;
	set BranchArg "";

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	set W_Path "[changeBackslash $W_Path]";
 
	#------ handle branch flag
	if { $b_BranchFlag } {
		if { $V_Version == "" } {
			set VersionArg [rcs_get_head $A_Path];
		}
		set Branches [rcs_get_branch $A_Path $VersionArg];
		if { $Branches == "" } {
			set Number 1;
		} else {
			set Last [lindex $Branches end];
			regexp -- {.*\.([0-9]+)} $Last Dummy Number;
			set Number [expr $Number + 1];
		}
		set BranchArg ".$Number";
	} else {
		set BranchArg "";
	}

	#------ handle symbolic version name
	if { $S_VersionName != "" } {
		set VersionNameArg "-n$S_VersionName";
	} else {
		set VersionNameArg "";
	}
 
	#------ handle symbolic branch name
	if { $B_BranchName != "" } {
		set BranchNameArg "-n$B_BranchName";
	} else {
		set BranchNameArg "";
	}
 
	#------ handle lock type
	if { $L_LockType == "E" } {
		set LockArg "-l";
	} else {
		set LockArg "-u";
	}

	#
	set Status [unknown ci -V5				\
				  -q$VersionArg$BranchArg	\
				  -f				\
				  $LockArg			\
				  -m"$C_Comment"		\
				  $VersionNameArg		\
				  $BranchNameArg		\
				  $A_Path			\
				  [path_concat $W_Path $F_File]	\
		  ];
 
	# handle the readonly Flag
	if { $L_LockType != "E" } {
		chmod_readonly [path_concat $W_Path $F_File];
		trace_print "set File [path_concat $W_Path $F_File] readonly";
	}
 
	#puts stderr "Status = $Status";
	return $Status;
}

#	rcs_lock: complete
proc rcs_lock {		\
	A_Path		\
	F_FileName	\
	V_Version 	\
	W_Path		\
} {
	set _Fct "rcs_lock"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	set W_Path "[changeBackslash $W_Path]";
 
	set Status [unknown rcs -V5 -q -l$V_Version $A_Path];
	if { ! $Status } {
		chmod_writable [path_concat $W_Path $F_FileName];
		return 0;
	} else {
		return 1;
	}
}


#	rcs_set_work_file_readonly: complete

proc rcs_set_work_file_readonly {	\
	F_FileName			\
	W_Path				\
} {
	set _Fct "rcs_set_work_file_readonly"; trace_var;

	# checking all path variables for backslash
	set W_Path "[changeBackslash $W_Path]";
	
	chmod_readonly [path_concat $W_Path $F_FileName];
}


#	rcs_is_different: complete

proc rcs_is_different {	\
	A_Path		\
	F_FileName 	\
	V_Version	\
	W_Path 		\
} {
	set _Fct "rcs_is_different"; trace_var;
	
	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	set W_Path "[changeBackslash $W_Path]";
 
	unknown rcsdiff -V5	\
		-q		\
		-kkvl		\
		-r$V_Version	\
		-h		\
		-b		\
		$A_Path		\
		[path_concat $W_Path $F_FileName]	\
	>nul;
}


#	rcs_diff_text_w_v: complete

proc rcs_diff_text_w_v {	\
	A_Path			\
	F_File			\
	T_TempFile		\
	v_version		\
	W_Path			\
} {
	set _Fct "rcs_diff_text_w_v"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	set W_Path "[changeBackslash $W_Path]";
	
	unknown co -V5		\
		-q$v_version	\
		-f		\
		$A_Path		\
		$T_TempFile	\
	;
	unknown diff		\
		-b		\
		[path_concat $W_Path $F_File]	\
		$T_TempFile	\
	;
}


#	rcs_diff_text_v_v: complete

proc rcs_diff_text_v_v {	\
	A_Path			\
	V_Version		\
	v_version		\
} {
	set _Fct "rcs_diff_text_v_v"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	unknown rcsdiff -V5	\
		-q		\
		-r$V_Version	\
		-r$v_version	\
		-b		\
		$A_Path		\
	;
}


#	rcs_unlock:
proc rcs_unlock {		\
	A_Path			\
	V_Version		\
} {
	set _Fct "rcs_unlock"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	unknown rcs -V5		\
		-q		\
		-u$V_Version	\
		$A_Path		\
	;
}


#	rcs_break_lock: complete
proc rcs_break_lock {		\
	A_Path			\
	t_Path			\
	U_User			\
	V_Version		\
} {
	global gCmd;
	set _Fct "rcs_break_lock"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	set TmpFile [open "|$gCmd /c echo y" RDONLY];
	set ExitStatus [unknown rcs -V5		\
		-I		\
		-u$V_Version	\
		$A_Path		\
		<@$TmpFile	\
		>nul		\
		2>nul		\
	];
	close $TmpFile;
	return $ExitStatus;
}

#	rcs_delete_version: complete
proc rcs_delete_version {	\
	A_Path			\
	V_Version		\
} {
	set _Fct "rcs_delete_version"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	if { $V_Version == "" } {
		set V_Version [rcs_get_head $A_Path];
	}
	unknown rcs -V5		\
		-q		\
		-o$V_Version	\
		$A_Path		\
	;
}


#	rcs_set_description: complete
proc rcs_set_description {	\
	A_Path			\
	I_Description		\
} {
	set _Fct "rcs_set_description"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	unknown rcs -V5		\
		-q		\
		-t-"$I_Description"	\
		$A_Path		\
	;
	
}


#	rcs_set_symbol: complete
proc rcs_set_symbol {		\
	A_Path			\
	S_Symbol		\
	s_ForceFlag		\
	V_Version		\
} {
	set _Fct "rcs_set_symbol"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	if { $s_ForceFlag } {
		set SetNameArg	"-N";
	} else {
		set SetNameArg	"-n";
	}
	unknown rcs -V5		\
		-q		\
		$SetNameArg$S_Symbol:$V_Version	\
		$A_Path		\
	;
}


#	rcs_delete_symbol: complete
proc rcs_delete_symbol {	\
	A_Path			\
	S_Symbol		\
} {
	set _Fct "rcs_delete_symbol"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	unknown rcs -V5		\
		-q		\
		-n$S_Symbol	\
		$A_Path		\
	;
}


#	rcs_change_comment: complete
proc rcs_change_comment {	\
	A_Path			\
	C_Comment		\
	V_Version		\
} {
	set _Fct "rcs_change_comment"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	unknown rcs -V5		\
		-q		\
		-m$V_Version:"$C_Comment"	\
		$A_Path		\
	;
		
}

#	rcs_descriptin: complete
proc rcs_description {		\
	A_Path			\
} {
	set _Fct "rcs_description"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	global cDashedLine;
	rcs_log_extract $A_Path "^description" $cDashedLine {
		if { $PHASE == 1 } {
			puts stdout "$LINE";
		}
	}
	return 0;
}


#	rcs_history: complete
proc rcs_history {		\
	A_Path			\
} {
	set _Fct "rcs_history"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	global cDashedLine;
	global cEqualLine;
	set TmpFileName [get_temp_file_name];
	set TmpFile {};

	set Status [			\
		unknown rlog -V5	\
		$A_Path			\
		>$TmpFileName		\
	];
	set TmpFile [open $TmpFileName RDONLY];
	while { ! [eof $TmpFile] } {
		file_text_extract $TmpFile	\
			"^$cDashedLine"		\
			"^$cEqualLine"		\
		;
	}
	close $TmpFile;
	rm $TmpFileName;
	return $Status;
}


#	rcs_head: complete
proc rcs_head {	\
	A_Path	\
} {
	set _Fct "rcs_head"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	rcs_get_head $A_Path;
	return 0;
}


#	rcs_symbol_list: complete
proc rcs_symbol_list_one {	\
	A_Path			\
} {
	set _Fct "rcs_symbol_list_one"; trace_var;
	set TmpFileName [get_temp_file_name];
	set File "";

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	unknown rlog -V5	\
		$A_Path		\
		>$TmpFileName	\
	;
	set File [open $TmpFileName RDONLY];

	for_pattern_do $File "^Working file:" "" {
		regexp -- "^Working file: (.*)" $LINE Match WorkingFile;
		puts stdout "$WorkingFile";
		break;
	}
	for_pattern_do $File "^head:" "" {
		regexp -- "^head: (.*)" $LINE Match Head;
		puts stdout "HEAD: $Head";
		break;
	}
	for_pattern_do $File "^symbolic names:" "^keyword substitution:" {
		if { $PHASE == 1 } {
			set Line [string_normalize $LINE];
			puts stdout "$Line";
		}
	}
	while { ! [eof $File] } {
		for_pattern_do $File "^revision" "" {
			set Line [string_normalize $LINE];
			set Revision [lindex $Line 1];
			puts -nonewline stdout "$Revision ";
			break;
		}
		for_pattern_do $File "^date:" "" {
			set Line [string_normalize $LINE];
			puts stdout [				\
				format "%s %s %s %s %s"		\
					[lindex $Line 1]	\
					[lindex $Line 2]	\
					[lindex $Line 4]	\
					[lindex $Line 8]	\
					[lindex $Line 9]	\
			];
			break;
		}
	}
	close $File;
	rm $TmpFileName;
	return 0;
}


proc rcs_symbol_list {		\
	A_Path			\
} {
	set _Fct "rcs_symbol_list"; trace_var;

	regsub -all {\\} $A_Path {\\\\} A_Path;
	foreach File $A_Path {
		puts -nonewline "\f";
		rcs_symbol_list_one $File;
	}
	return 0;
}


#	rcs_revision_of_symbol: complete
proc rcs_revision_of_symbol {	\
	A_Path			\
	S_Symbol		\
} {
	set _Fct "rcs_revision_of_symbol"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	if { $S_Symbol == "HEAD" } {
		rcs_head $A_Absolute;
	} else {
		rcs_log_extract			\
			$A_Path			\
			"^symbolic names:"	\
			"^keyword substitution:"	\
		{
			if { $PHASE == 1 } {
				set Line [string_normalize $LINE];
				set Name [lindex $Line 0];
				if { "$S_Symbol:" == $Name } {
					puts stdout "[lindex $Line 1]";
					break;
				}
			}
		}
	}
	return 0;
}


#	rcs_history_of_revision: complete
proc rcs_history_of_revision {	\
	A_Path			\
	V_Version		\
} {
	set _Fct "rcs_history_of_revision"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	global cDashedLine cEqualLine;

	rcs_log_extract				\
		$A_Path				\
		"^revision $V_Version"		\
		"$cDashedLine|cEqualLine"	\
	{
		if { $PHASE == 1 } {
			puts stdout "$LINE";
		}
	}
	return 0;
}


#	rcs_comment: complete
proc rcs_comment {	\
	A_Path		\
	V_Version	\
} {
	set _Fct "rcs_comment"; trace_var;

	global cDashedLine cEqualLine;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	rcs_log_extract				\
		$A_Path				\
		"^revision $V_Version"		\
		"$cDashedLine|$cEqualLine"	\
	{
		#puts stdout "PHASE=$PHASE LINENR=$LINENR LINE=\"$LINE\"";
		if { $PHASE == 1 } {
			if { $LINENR == 3 && [regexp -- "^branches:" $LINE d1] } {
				continue;
			}
			if { $LINENR > 2 } {
				puts stdout "$LINE";
			}
		}
	}
	return 0;
}

proc rcs_working_file {	\
	A_Path		\
} {
	set _Fct "rcs_working_file"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	set WorkingFile "";

	rcs_log_extract $A_Path "^Working file:" "" {
		regexp -- "^Working file: (.*)" $LINE Dummy WorkingFile;
		break;
	}
	return $WorkingFile;
}


#	rcs_lockers:	complete
proc print_chars_as_dec {Channel String} {
	set Len [string length $String];
	set I 0;
	while { $I < $Len } {
		set Char [string index $String $I];
		scan $Char {%c} CharValue;
		puts -nonewline $Channel "$CharValue ";
		incr I
	}
	puts $Channel "";
}

proc rcs_lockers_of {	\
	A_Path		\
} {
	set _Fct "rcs_lockers_of"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	set WorkingFile [rcs_working_file $A_Path];	
	puts -nonewline stdout "$WorkingFile";
	rcs_log_extract $A_Path "^locks:" "^access list:" {
		if { $PHASE == 1 } {
			set Line [string trimleft $LINE];
			# sniff cannot deal with leading tab as white space
			puts -nonewline stdout " $Line";
		}
	}
	puts stdout "";
	return 0;
}


proc rcs_lockers {	\
	A_Path		\
} {
	set _Fct "rcs_lockers"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	foreach File $A_Path {
		rcs_lockers_of $File;
	}
	return 0;
}

### ??????????????????? zweimal ???????????????????
proc rcs_lockers {	\
	A_Path		\
} {
	set _Fct "rcs_lockers"; trace_var;

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	set File [open "|rlog -V5 $A_Path" RDONLY];
	while { ! [eof $File] } {
		for_pattern_do $File "^Working file: " "" {
			regexp -- "^Working file: (.*)" $LINE Match WorkingFile;
			puts -nonewline "$WorkingFile ";
			break;
		}
		for_pattern_do $File "^locks:" "^access list:" {
			if { $PHASE == 1 } {
				set Line [string trimleft $LINE];
				# sniff cannot deal with leading tab as white space
				puts -nonewline stdout " $Line";
			}
		}
		puts stdout "";
	}
	close $File;
	return 0;
}


#	rcs_is_locked_by: complete
proc rcs_is_locked_by {	\
	A_Path		\
	U_User		\
} {
	set _Fct "rcs_is_locked_by"; trace_var;
	set TmpFileName [get_temp_file_name];

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
 
	unknown rlog -V5	\
		-L		\
		-R		\
		-l$U_User	\
		$A_Path		\
		>$TmpFileName	\
	;	
	set FileSize [file size $TmpFileName];
	rm $TmpFileName;
	if { $FileSize > 0 } {
		return 0;
	} else {
		return 1;
	}
}


#	rcs_is_locked: complete
proc rcs_is_locked {	\
	A_Path
} {
	set _Fct "rcs_is_locked"; trace_var;
	set TmpFileName [get_temp_file_name];

	# checking all path variables for backslash
	set A_Path "[changeBackslash $A_Path]";
	
	unknown rlog -V5	\
		-L		\
		-R		\
		$A_Path		\
		>$TmpFileName	\
	;
	set FileSize [file size $TmpFileName];
	rm $TmpFileName;
	if { $FileSize > 0 } {
		return 0;
	} else {
		return 1;
	}
}

proc rcs_create_repository_dir {	\
	P_Path				\
} {
	set _Fct "rcs_create_repository_dir"; trace_var;
	# checking all path variables for backslash
	set P_Path "[changeBackslash $P_Path]";
	mkdir_p $P_Path;
}

##################################################################################
#  	Feature:	TestTool 
#
#	Return:		0 - OK, !0 - NOK
##################################################################################
 
proc rcs_test_tool {} \
{
	set _Fct "rcs57_test_tool "; trace_var; 
 
	global gPathVar;
	# check for 'rcs57' in Path
	set Status [regexp -nocase {rcs57} $gPathVar];
	if { $Status == 0 } { 
		# check for 'rcs' in Path
		set Status [regexp -nocase {rcs} $gPathVar];
		if { $Status == 0 } {
			return 1; 
		} else {
			return 0;
		};
	} else { 
		return 0; 
	};
}

##################################################################################
#  	Feature:	Constructor 
#
#	SNiFF+		Adaptor			Description
# 	------  	---------		--------------- 
#	%T 			T_TmpDir		Absoulte path to temporary directory 
##################################################################################
proc rcs_constructor { T_TmpDir } \
{
	mkdir_p $T_TmpDir;
	return 0;	# XXX questionable
}

##################################################################################
#  	Feature:	Destructor 
#
#	SNiFF+		Adaptor			Description
# 	------  	---------		--------------- 
#	%T 			T_TmpDir		Absoulte path to temporary directory 
##################################################################################
proc rcs_destructor { T_TmpDir } \
{
 
	rm_r $T_TmpDir;
}


#------ body ------------------------------------------------------------ 
 
set gDebug 0;

trace_open;
trace_print "begin: argc=$argc argv=$argv";

set ReturnCode 0;
set BlockValue 0;
if { $argc > 0 } {
	set ReturnCode [catch {eval $argv} BlockValue]; 
} else {
	set ReturnCode 5;
}
 
trace_print "ReturnCode=$ReturnCode BlockValue=$BlockValue";
trace_print "end";
trace_close;
if { $ReturnCode == 0 } {
	exit $BlockValue ;
} else {
	exit 255;

