################################################################
# The VSS Python-Adaptor for SNiFF+ 3.1 and higher
#
# following modules are used:
#   * VSSPrefs.py: Some Preferences
#
# Author:  Stefan Kogler
# History: 
#	created: 9.aug.1999
#	first release: with 3.2.1-CD
################################################################
import os, string, re
import vcs
import VSSPrefs
import etgui, PageLayout

from vcs import TEST, TRUE, FALSE, NL, SYSTEM, WINDOWS, UNIX
from vcs import NULLDEV, DELIMITER

VSS_RELEASE="3.2.1"
VSS_ID="$Id: VSS.py,v 1.8 2000/02/04 12:55:29 skogler Exp skogler $"

def print_version():
	id=string.split(VSS_ID)
	print "SNiFF+ Visual SourceSafe Adapter Version ",VSS_RELEASE," - VSS.py %s of %s (%s)" % (id[2],id[3],id[5])

# -- set Module name for output

module = __name__+ ': '		# the name of this module


# -- log message generated from SNiFF+

empty_log_message = "*** empty log message ***"


# -- empty description text

empty_description = "*** empty description ***"


# -- message from VSS 

no_checked_out = "No checked out files found."

# -- VSS command line exit codes

success = 0
warning = 1
error   = 100


# -- Name of the UpdateFile

Update_File = "/bin/sniffUpdateFile.VSS.sh"


# -- Name of the File to get Date and Time-Format

date_time_exe = "ldtf.exe"

# ---- VCS commands ----------------------------------


################################################################
#
# Procedure:   BreakLock
# Parameters:  None
# Description: BreakLock is not supported by VSS
# Return:      1...NOT ok
#
################################################################

def BreakLock():
	VSSPrefs.print_text(module + "BreakLock")
	etgui.ShowAlert(3,"Visual SourceSafe doesnt support lock breaking!")
	return FALSE



################################################################
#
# Procedure:   ChangeComment
# Parameters:  vcs.comment.........Comment (%C)
#              vcs.repositoryDir...VSS Repository Dir (%P)
#              vcs.revision........Revision of File (%V)
#              vcs.workingFile.....Working File (%F)
# Description: Changes the comment of a specific version
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def ChangeComment():
	VSSPrefs.print_text(module + "ChangeComment")

	Revision = re.sub(".0","",vcs.revision)	# remove tailing ".0"

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename

	vss_stat = vcs.system("ss Comment "+File+" -V"+Revision+" -C\""+vcs.escape_quotes(vcs.comment)+"\""+VSSPrefs.GlobalOpts)

	return TRUE



################################################################
#
# Procedure:   CheckIn
# Parameters:  vcs.branchFlag.....Force a branch (%b)
#              vcs.comment........Comment (%C)
#              vcs.forceFlag......Check the difference (%s)
#              vcs.lockType.......Lockers (%L)
#              vcs.RCCSPath.......Repository Path (%p)
#              vcs.repositoryDir..VSS Repository Path (%P)
#              vcs.revision.......Revision of File (%V)
#              vcs.symbolName.....Symbolic version name (%S)
#              vcs.workingFile....Working File to be checked in (%F)
#              vcs.workingDir.....Path to dir of WorkFile (%W)
# Description: Checks in the current working file to the repository
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def CheckIn():
	VSSPrefs.print_text(module + 'CheckIn')
	
	os.chdir(vcs.workingDir)

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	
	if vcs.branchFlag:		# branch flag set, ignore it
		etgui.ShowAlert(3,"A branch version cannot be created at Check In. Branch flag ignored.")
	if vcs.revision != "":		# ignore Revision
		etgui.ShowAlert(3,"A version number cannot be specified at Check In. Version number ignored.")
		
	if vcs.lockType == "E":
		LockArg = "-K"
	else:
		LockArg = ""
		
	if vcs.comment == empty_log_message:
		vss_stat = vcs.system("ss Checkin "+File+" "+LockArg+" -C- -I-"+VSSPrefs.GlobalOpts)
	else:
		vcs.output("ss Checkin "+File+" "+LockArg+" -C\""+vcs.escape_quotes(vcs.comment)+"\" -I-"+VSSPrefs.GlobalOpts)
		vss_stat = vcs.system("ss Checkin "+File+" "+LockArg+" -C\""+vcs.escape_quotes(vcs.comment)+"\" -I-"+VSSPrefs.GlobalOpts)

	if vss_stat == success:
		if vcs.symbolName != "":
			SymName = vcs.symbolName[16:]		# skip leading SNIFF_CHANGESET
			SymName = "SNiFF+CS_" + SymName
			HeadVersion = vcs.getoutput("ss Properties "+File+VSSPrefs.GlobalOpts)
			idx=string.find(HeadVersion,NL+"Latest:")
			if idx < 0: 
				print "Can't set Changeset -- Error parsing properties: @BLatest:@B not found in "+HeadVersion
				return FALSE
			HeadList = string.split(HeadVersion[idx+3:],NL)
			HeadVersion = string.split(HeadList[1])[1]
			vss_stat = vcs.system("ss Label "+File+" -V"+HeadVersion+" -L"+SymName+" -C- -I- -O\&-"+VSSPrefs.GlobalOpts)
			if vss_stat==100:
				print "VSS Checkin Error: ",File,": Cannot set Changeset Label because file was not modified (ignored)"
				return TRUE
				
	elif vss_stat == error:
			etgui.ShowAlert(3,"VSS could not Check @B"+vcs.workingFile+"@B in."+NL+"VSS reported: @B"+vcs.err+NL+"@BPlease check out first, or set a lock on the file!")

		
	
	return vcs.test(vss_stat)




################################################################
#
# Procedure:   CheckOut
# Parameters:  vcs.lockType.......Lockers (%L)
#              vcs.repositoryDir..VSS Repository Path (%P)
#              vcs.revision.......Revision of File (%V)
#              vcs.workingDir.....Path to dir of WorkFile (%W)
#              vcs.workingFile....Working File to be checked out (%F)
# Description: Checks out a version of a file from the repository
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def CheckOut():
	VSSPrefs.print_text(module + 'CheckOut')

	Revision = re.sub(".0","",vcs.revision)	# remove tailing ".0"

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename

	vss_stat = 0
	if vcs.lockType == "N":
		vss_stat = vcs.system("ss Get -V"+Revision+" "+File+" -GL"+vcs.workingDir+" -I-Y -W- -GWR"+VSSPrefs.GlobalOpts)
		vcs.chmod(vcs.workingDir+"/"+vcs.workingFile,"u-w")
		return vcs.test(vss_stat)

#### big tricks, with SS it is not possible to checkout a specific version
#### workaround: checkout without replacing file, then perform get operation

	if vcs.lockType == "E":
		if Revision != "":
			vss_stat = vcs.system("ss Checkout "+File+" -G- -I-Y -O\&-"+VSSPrefs.GlobalOpts)
			vss_stat = vcs.system("ss Get -V"+Revision+" "+File+" -GL"+vcs.workingDir+" -I-Y -W -GWR -O\&-"+VSSPrefs.GlobalOpts)
		else:
			vss_stat = vcs.system("ss Checkout "+File+" -I-Y -GWR -GWS"+VSSPrefs.GlobalOpts)
			if vss_stat == error:
				etgui.ShowAlert(3,"VSS was not able to Check Out @B"+vcs.workingFile+"@B"+NL+"VSS reported: @B"+vcs.err)
			vss_stat=success

		
	else:
		etgui.ShowAlert(3,"VSS does not support Concurrent Lock. Use Exklusive or No Lock instead!")

	VSSPrefs.print_text("Status: %s" %vss_stat)
	
	return vcs.test(vss_stat)




################################################################
#
# Procedure:   CheckRepositoryDir
# Parameters:  vcs.repositoryDir...VSS Repository Dir (%P)
# Description: checks if a RepositoryDir exists
# Returns:     TRUE if exists, FALSE otherwise
#
################################################################

def CheckRepositoryDir():
	VSSPrefs.print_text(module + "CheckRepositoryDir")

	vss_stat = vcs.system("ss Dir "+'"'+vcs.repositoryDir+'"'+" -O\&-"+VSSPrefs.GlobalOpts)
	return vcs.test(vss_stat)




################################################################
#
# Procedure:   CheckRepositoryFile
# Parameters:  vcs.repositoryDir...Path to the Repository (%P)
#              vcs.workingFile.....Working File (%F)
# Description: Checks if the File is in the Repository
# Returns:     TRUE if exists, False otherwise
#
################################################################

def CheckRepositoryFile():
	VSSPrefs.print_text(module + "CheckRepositoryFile")
#	print_all()

	vss_stat = vcs.system("ss Dir "+'"'+vcs.repositoryDir+"/"+vcs.workingFile+'"'+" -O\&-"+VSSPrefs.GlobalOpts)
	return vcs.test(vss_stat)



################################################################
#
# Procedure:   Comment
# Parameters:  vcs.repositoryDir...VSS Repository Dir (%P)
#              vcs.revision........Revision of File (%V)
#              vcs.workingFile.....Working File (%F)
# Description: Outputs the comment of a version
# Return:      TRUE
#
################################################################

def Comment():
	VSSPrefs.print_text(module + "Comment")
	
	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	
	Revision = re.sub(".0","",vcs.revision)	# remove tailing ".0"

	history = vcs.getoutput("ss History "+File+" -V"+Revision+"~"+Revision+VSSPrefs.GlobalOpts)

	index = string.find(history,"Comment: ")
	if index == -1: vcs.output("")
	else: vcs.output(history[index+9:])
	
	return TRUE



################################################################
#
# Procedure:   Constructor
# Parameters:  vcs.tmpDir...path to temp-Dir (%t)
# Description: The first action which is called in the python-
#              adaptor
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def Constructor():
	VSSPrefs.print_text(module + "Constructor")
	rc = vcs.mkdir_p(vcs.tmpDir)
	print_version()
	return vcs.test(rc)



################################################################
#
# Procedure:   CreateRepositoryDir
# Parameters:  vcs.repositoryDir...VSS Repository (%P)
# Description: creates a new subproject in VSS
#
################################################################

def CreateRepositoryDir():
	VSSPrefs.print_text(module + "CreateRepositoryDir")

	vss_stat = vcs.system("ss Create "+'"'+vcs.repositoryDir+'"'+" -C-"+VSSPrefs.GlobalOpts)

	if vss_stat == error:
		etgui.ShowAlert(3,"The VSS folder @B"+vcs.repositoryDir+"@B could not be created."+NL+"VSS reported: @B"+vcs.err+NL+"@BPlease create this folder outside SNiFF+.")
#		return FALSE

	#Seems that SourceSafe doesn't write its erroneous output anywhere.
	#print "vcs.err is :",vcs.err,":"
	#print "vcs.out is :",vcs.out,":"
	if vcs.err == "File or project not found":
		etgui.ShowAlert(3,"A top-level folder for @B"+vcs.repositoryDir+NL+"@Bdoesnt exist yet. Please create this folder with SourceSafe, or with SNiFF+ by checking in a file from that project.")
		return FALSE

	return vcs.test(vss_stat)



################################################################
#
# Procedure:   CreateRepositoryFile
# Parameters:  vcs.branchFlag.....Force a branch (%b)
#              vcs.comment........Change description (%C)
#              vcs.forceFlag......Check the difference (%s)
#              vcs.lockType.......Lockers (%L)
#              vcs.RCCSPath.......Repository Path (%p)
#              vcs.repositoryDir..VSS Repository Path (%P)
#              vcs.revision.......Revision of File (%V)
#              vcs.symbolName.....Symbolic version name (%S)
#              vcs.workingDir.....Path to dir of WorkFile (%W)
#              vcs.workingFile....Working File (%F)
# Description: creates a Repository File if it is non-existant
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def CreateRepositoryFile():
	VSSPrefs.print_text(module + 'CreateRepositoryFile')
	
	os.chdir(vcs.workingDir)

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	
	vss_stat = vcs.system("ss Cp "+'"'+vcs.repositoryDir+'"'+VSSPrefs.GlobalOpts)
	if vss_stat == error:
		etgui.ShowAlert(3,"VSS could not create the project @B"+vcs.repositoryDir+NL+"@BVSS reported: @B"+vcs.err+NL+
		"@BPlease create a higher level project first by checking in a file from that project.")
		return FALSE

	if vcs.branchFlag:		# branch flag set, ignore it
		etgui.ShowAlert(3,"A branch version cannot be created at Check In.\nBranch flag ignored.")
		return FALSE
	if vcs.revision != "":		# ignore Revision
		etgui.ShowAlert(3,"A version number cannot be specified at Check In.\nVersion number ignored.")
		return FALSE
#	if not vcs.forceFlag:			# Check Difference enabled, ignore it
#		etgui.ShowAlert(3,"Check Difference is not possible at Check In.\nCheck Difference ignored.")
		
	if vcs.lockType == "E":
		LockArg = "-K"
	else:
		LockArg = ""
	
	vcs.getoutput("pwd")
	
	if vcs.comment == empty_log_message:
		vss_stat = vcs.system("ss Add "+vcs.workingFile+" "+LockArg+" -C- -I-"+VSSPrefs.GlobalOpts)
	else:
		vss_stat = vcs.system("ss Add "+vcs.workingFile+" "+LockArg+" -C\""+vcs.escape_quotes(vcs.comment)+"\" -I-"+VSSPrefs.GlobalOpts)
		
	VSSPrefs.print_text("Status: %s" %vss_stat)

	if vss_stat == success:
		if vcs.symbolName != "":
			SymName = vcs.symbolName[16:]		# skip leading SNIFF_CHANGESET
			SymName = "SNiFF+CS_" + SymName
			HeadVersion = vcs.getoutput("ss Properties "+File+VSSPrefs.GlobalOpts)
			HeadVersion = string.split(HeadVersion)
#			print "Ver: %s" %HeadVersion[16]
			vss_stat = vcs.system("ss Label "+File+" -V"+HeadVersion[16]+" -L"+SymName+" -C- -I- -O\&-"+VSSPrefs.GlobalOpts)
	
	return vcs.test(vss_stat)




################################################################
#
# Procedure:   DateOfRepositoryFile
# Parameters:  vcs.repositoryDir..VSS Repository Path (%P)
#              vcs.workingFile....Working File (%F)
# Description: Returns the modification date of the Repository File
# Returns:     always TRUE
# Output:      Date Text ... YYYY/MM/DD HH:MM:SS
#
################################################################

def DateOfRepositoryFile():
	VSSPrefs.print_text(module + "DateOfRepositoryFile")
	
	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename

	Properties = vcs.getoutput("ss Properties "+File+VSSPrefs.GlobalOpts)
	Properties = string.split(Properties)

	Date = Properties[18]		# date is at index 18
	
	if Date[6:8] < 70:		# check on Y2k
		Century = "20"
	else:
		Century = "19"
		
	Date = Century + Date[6:8]+"/"+Date[3:5]+"/"+Date[0:2]		
	vcs.output(Date+" "+Properties[19]+":00")		# ouput

	return TRUE




################################################################
#
# Procedure:   DeleteSymbol
# Parameters:  vcs.repositoryDir   VSS Repository Path (%P)
#              vcs.symbolName......Symbolic version name (%S)
#              vcs.workingFile.....Working File (%F)
# Description: Deletes a symbolic name from the repository file
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def DeleteSymbol():
	VSSPrefs.print_text(module + "DeleteSymbol")

	SymbolIndex = string.find(vcs.symbolName, "SNIFF_CHANGESET_")
	if SymbolIndex == 0:
		vcs.symbolName = "SNiFF+CS_"+vcs.symbolName[16:]

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename

	history = vcs.getoutput("ss History "+File+" -I-"+VSSPrefs.GlobalOpts)
	split_history = string.split(history)
	
	if split_history[0] != "History": return FALSE
	
	index = 0
	version_index = -1
	for item in split_history: 
		if item == "Version": 
			VersionArg = " -V"+split_history[index+1]
			version_index = index
#			print VersionArg
		
		if item == "Label:":
			if (index == version_index + 3) and (split_history[index+1] == vcs.symbolName): 
#				LabelArg = "-L"+split_history[index+1]
#				print LabelArg
				vss_stat = vcs.system("ss Label "+File+VersionArg+" -L\"\" -C- -I-Y -O\&-"+VSSPrefs.GlobalOpts)
				return vcs.test(vss_stat)
		
		index = index + 1
	return TRUE




################################################################
#
# Procedure:   DeleteVersion
# Parameters:  vcs.revision........Revision of File (%V)
#              vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.workingDir......Path to dir of WorkFile (%W)
#              vcs.workingFile.....Working File (%F)
# Description: deletes a version in the repository file. Deletes
#              the complete history entry
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def DeleteVersion():
	VSSPrefs.print_text(module + "DeleteVersion")

	os.chdir(vcs.workingDir)

	Revision = re.sub(".0","",vcs.revision)	# remove tailing .0

	if Revision != "":
		Rev = string.split(Revision)
		RevArg = "-V"+Rev[0]
		if Rev[0]<1: etgui.ShowAlert(3,"Cannot rollback to version "+Rev[0])
	else: etgui.ShowAlert(3,"A version number must be specified!")

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	
	vss_stat = vcs.system("ss Rollback "+File+" "+RevArg+" -I-Y -O\&-"+VSSPrefs.GlobalOpts)
	
	return vcs.test(vss_stat)



################################################################
#
# Procedure:   Description
# Parameters:
# Description: Gets the description of Repository Files
# Return:      always TRUE
#
################################################################

def Description():
	VSSPrefs.print_text(module + "Description")
	return TRUE



################################################################
#
# Procedure:   Destructor
# Parameters:  vcs.tmpDir...path to temp-Dir (%t)
# Description: The last action which is called in the python-
#              adaptor
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def Destructor():
	VSSPrefs.print_text(module + "Destructor")
	if os.path.isdir(vcs.tmpDir):
		vcs.rm_fr(vcs.tmpDir)
	return TRUE




################################################################
#
# Procedure:   DiffText_V_V
# Parameters:  vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.revision........Revision of File (%V)
#              vcs.revision2.......Revision of a 2nd File (%v)
#              vcs.workingDir......Path to dir of WorkFile (%W)
#              vcs.workingFile.....Working File (%F)
# Description: Checks wheter there is a difference between two
#              versions of a file and outputs the differences
# Return:      0...OK, 1...NOT OK
#
################################################################

def DiffText_V_V():
	VSSPrefs.print_text(module + "DiffText_V_V")
	
	os.chdir(vcs.workingDir)
	
	Revision = re.sub(".0","",vcs.revision)	# remove tailing .0
	Revision2 = re.sub(".0","",vcs.revision2)	# remove tailing .0

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	
	vcs.output(vcs.getoutput("ss Diff -DU "+File+" -V"+Revision+"~"+Revision2+VSSPrefs.GlobalOpts))
	return TRUE




################################################################
#
# Procedure:   DiffText_W_V
# Parameters:  vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.revision2.......Revision of 2nd File (%V)
#              vcs.workingDir......Path to dir of WorkFile (%W)
#              vcs.workingFile.....Working File (%F)
#              vcs.tmpDir..........Path to temp dir (%t)
# Description: Checks wheter there is a difference between the
#              working file and a given version and outputs the 
#              differences
# Return:      0...OK, 1...NOT OK
#
################################################################

def DiffText_W_V():
	VSSPrefs.print_text(module + "DiffText_W_V")

	os.chdir(vcs.tmpDir)

	Revision = re.sub(".0","",vcs.revision2)	# remove tailing .0

	if Revision != "":
		RevArg = "-V"+Revision
	else:
		RevArg = ""

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'	# complete Filename = Path+Filename
	
	vss_stat = vcs.system("ss get "+File+" "+RevArg+" -O\&-"+VSSPrefs.GlobalOpts)
	if vss_stat != success:
		return vcs.test(vss_stat)
	
	vcs.output(vcs.getoutput("diff -b "+vcs.workingDir+"/"+vcs.workingFile+" "+vcs.workingFile))
	return TRUE




################################################################
#
# Procedure:   History
# Parameters:  vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.workingFile     Working File (%F)
# Description: Prints the unformatted history of the repfile
# Return:      TRUE
#
################################################################

def History():
	VSSPrefs.print_text(module + "History")

	vcs.output(vcs.getoutput("ss History "+'"'+vcs.repositoryDir+"/"+vcs.workingFile+'"'+VSSPrefs.GlobalOpts))
	return TRUE




################################################################
#
# Procedure:   HistoryOfRevision
# Parameters:  vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.revision........Revision of File (%V)
#              vcs.workingFile.....Working File (%F)
# Description: Outputs the history entry of a version
# Return:      TRUE
#
################################################################

def HistoryOfRevision():
	VSSPrefs.print_text(module + "HistoryOfRevision")
	
	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	
	Revision = re.sub(".0","",vcs.revision)	# remove tailing ".0"

	split_history=string.split(vcs.getoutput("ss History "+File+" -V"+Revision+"~"+Revision+VSSPrefs.GlobalOpts),"\n")
	# since ss breaks output at 80 chars, long Repository dirs may produce extra lines!
	while split_history[0] and split_history[0][:15] != "***************":
		del split_history[0]

	vcs.output(string.join(split_history,"\n"))
	
	return TRUE



################################################################
#
# Procedure:   IsDifferent
# Parameters:  vcs.repositoryDir..VSS Repository Path (%P)
#              vcs.revision.......Revision of File (%V)
#              vcs.workingDir.....Path to dir of WorkFile (%W)
#              vcs.workingFile....Working File (%F)
# Description: Checks wheter there is a difference between the
#              working file and a given version
# Return:      0...same files, 1...Error, 2...different files
#
################################################################

def IsDifferent():
	VSSPrefs.print_text(module + "IsDifferent")
	
	os.chdir(vcs.workingDir)
	
	Revision = re.sub(".0","",vcs.revision)	# remove tailing .0

	if Revision != "":
		RevArg = "-V"+Revision
	else:
		RevArg = ""
		
	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	DiffFile = vcs.workingDir + "/" + vcs.workingFile
	
	vss_stat = vcs.system("ss Diff -DU "+DiffFile+" "+File+" "+RevArg+" -O\&-"+VSSPrefs.GlobalOpts)
	if vss_stat == warning:
		return 2
	elif vss_stat > 1:
		return FALSE
	return TRUE



################################################################
#
# Procedure:   Lock
# Parameters:  vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.revision........Revision of File (%V)
#              vcs.workingFile     Working File (%F)
# Description: Locks the repository file and sets the state of the working
#              file to writeable
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def Lock():
	VSSPrefs.print_text(module + "Lock")

	Revision = re.sub(".0","",vcs.revision)	# remove tailing ".0"

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename

	if Revision != "":
		vss_status = vcs.system("cd "+vcs.workingDir+"; ss Checkout -V"+Revision+" "+File+" -G- -O\&-"+VSSPrefs.GlobalOpts)
		vss_status = vcs.system("ss Get -V"+Revision+" "+File+" -GL"+vcs.workingDir+" -I-Y -W -G- -O\&-"+VSSPrefs.GlobalOpts)
	else:
		vss_status = vcs.system("cd "+vcs.workingDir+"; ss Checkout "+File+" -G- -I-Y -O\&-"+VSSPrefs.GlobalOpts)
	
	return vcs.test(vss_status)




################################################################
#
# Procedure:   Lockers
# Parameters:  vcs.repositoryDir...VSS Repository Path (%p)
#              vcs.revision........Revision of File (%V)
#              vcs.workingFile   ..Working File (%F)
# Description: Outputs the list of lockers and locked versions of a
#              repository file to stdout
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def Lockers():
	VSSPrefs.print_text(module + "Lockers")
	
	out_list=[]
	
	for curFile in string.split(vcs.workingFile):
		Status = vcs.getoutput("ss Status "+'"'+vcs.repositoryDir+"/"+curFile+'"'+" -O"+VSSPrefs.GlobalOpts)
		if vcs.TEST: print "VSS Lockers: Status=",Status
	
		if Status[0:27] != no_checked_out:
			Status = string.split(Status)
			User = Status[1]
			Revision = Status[2]
		
			if Revision[0:1] == "v":
				Revision = Revision[1:]
			else:
				properties = vcs.getoutput("ss Properties "+'"'+vcs.repositoryDir+"/"+curFile+'"'+VSSPrefs.GlobalOpts)
				properties = properties[string.find(properties,"  Version: "):]
				properties = string.split(properties)
				Revision = properties[1]
		
			LockString=User+": "+Revision+".0  "
			if User and User==VSSPrefs.FakeUser:
				LockString=vcs.user+": "+Revision+".0  "+LockString
			out_list.append(curFile+" "+LockString)
	
	vcs.output(string.join(out_list, vcs.NL))

	return TRUE




################################################################
#
# Procedure:   RepositoryDir
# Parameters:  vcs.RCCSPath...Repository Path (%p)
# Description: Gets %p from SNiFF and creates the Repository
#              Folder for VSS, %P holds the path in the future
# Return:      0...always OK
#
################################################################

def RepositoryDir():
	VSSPrefs.print_text(module + 'RepositoryDir')
#	print_all()

## If both RWE and Repository Dir in Project Attributes are defined,
## SNiFF will return RCCSPath as $/RWE/local/path/$/Projec/Attrib/Path
## Searching the dollar from the right allows Proj.Attrib RWE setting to
## override the global RWE setting, which is more intuitive.
	DollarPos = string.rfind(vcs.RCCSPath,"$")		# find a $ in the path
	if DollarPos == -1:		
		# not found, so build a new folder with name of this directory
		# (will produce flat structure of projects in VSS)
		realPath=vcs.normpath(vcs.joinpath(vcs.RCCSPath,vcs.catDir))
		VSSProj=realPath[string.rfind(realPath,"/"):]
	else:				# $ found, make it as folder from there
		VSSProj=vcs.normpath(vcs.joinpath(vcs.RCCSPath[DollarPos+1:],vcs.catDir))
	vcs.output("$" + VSSProj)
	return TRUE




################################################################
#
# Procedure:   SetDescription
# Parameters:  vcs.description...the description (%I)
# Description: VSS does not support description of Repository Files
# Return:      always TRUE
#
################################################################

def SetDescription():
	VSSPrefs.print_text(module + "SetDescription")
	
	if vcs.description != empty_description:
		etgui.ShowAlert(3,"Visual SourceSafe doesnt support descriptions of repository files!")
		
	return TRUE



################################################################
#
# Procedure:   SetSymbol
# Parameters:  vcs.forceFlag.....Force Flag (%s)
#              vcs.repositoryDir.Repository Path (%p)
#              vcs.revision......Revision of File (%V)
#              vcs.symbolName....Symbolic version name (%S)
#              vcs.workingFile...Working File (%F)
# Description: Associates a version of the repository file with
#              a symbolic name
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def SetSymbol():
	VSSPrefs.print_text(module + "SetSymbol")

	Revision = re.sub(".0","",vcs.revision)	# remove tailing .0

	if Revision != "":
		RevArg = "-V"+vcs.revision
	else: RevArg = ""

	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename

	if not vcs.forceFlag:
		vss_stat = vcs.system("ss Label "+File+" "+RevArg+" -L"+vcs.symbolName+" -C- -I-Y -O\&-"+VSSPrefs.GlobalOpts)
	else:
		vss_stat = vcs.system("ss Label "+File+" "+RevArg+" -L"+vcs.symbolName+" -C- -I-N -O\&-"+VSSPrefs.GlobalOpts)
		if vss_stat != success:
			vss_stat = vcs.system("ss Label "+File+" -L"+vcs.symbolName+" -C- -I-N -O\&-"+VSSPrefs.GlobalOpts)

	return vcs.test(vss_stat)




################################################################
#
# Procedure:   SetWorkFileReadOnly
# Parameters:  vcs.workingFile...Working File (%F)
#              vcs.workingDir....Path to dir of WorkFile (%W)
# Description: performs a system command to change to readonly
#              the working file
# Return:      always TRUE
#
################################################################

def SetWorkFileReadOnly():
	VSSPrefs.print_text(module + "SetWorkFileReadOnly")

	path = vcs.joinpath(vcs.workingDir,vcs.workingFile)
	vcs.chmod(path, 'ugo-w')
	return TRUE




################################################################
#
# Procedure:   SymbolList()
# Parameters:  vcs.repositoryDir...VSS Repository Path (%p)
#              vcs.workingFile   ..Working File (%F)
# Description: Outputs a formatted complete history list of
#              repository file(s)
# Return:      always TRUE
#
################################################################

def SymbolList():
	VSSPrefs.print_text(module + "SymbolList")

	out_list=[]
	for curFile in string.split(vcs.workingFile):
		File = '"' + vcs.repositoryDir + "/" + curFile + '"'		# complete Filename = Path+Filename

		history = vcs.getoutput("ss History "+File+" -I-"+VSSPrefs.GlobalOpts)
		split_history = re.split("\n", history)
		# since ss breaks output at 80 chars, long Repository dirs may produce extra lines!
		while split_history[1] and split_history[1][:15] != "***************":
			del split_history[0]
		out_list.append('\014'+curFile)
		head_ver = split_history[2]
		version = string.split(split_history[2])[2]+".0"
		out_list.append("HEAD: " + version)
	
		split_history = split_history[3:]
	
		for item in split_history: 
			if item[19:26] == "Version":
				version = string.split(item)
				version = version[2]+".0"	# append .0
		
			if item[0:6] == "Label:":
				label = string.split(item,'"')
				tr=string.maketrans(" :,.","____")
				label_name = string.translate(label[1],tr)
				if (label_name[0:9] == "SNiFF+CS_"):
					label_name = "SNIFF_CHANGESET_"+label_name[9:]
				out_list.append(label_name+": "+version)

			if item[0:5] == "User:":
				User = re.sub("Date:.*$","",item)
				user = User[6:]

				DatePos = string.find(item, "Date:")
				date = item[DatePos+6:DatePos+14]
				#date = re.sub("\D","",date)
				## quickfix for single-lettered month -- mober
				if date[0]==" ":
					date="0"+date[1:]
				#date = re.sub(DateSep,"",date)
				date = string.join(string.split(date,DateSep))
				## end quickfix for single-lettered month -- mober
				if string.atoi(date[Y:Y+2]) < 65:
					new_date = "20" + ""
				else:
					new_date = "19" + ""
				new_date = new_date+date[Y:Y+2]+"/"+date[M:M+2]+"/"+date[D:D+2]

				TimePos = string.find(item, "Time:")
				time = item[TimePos+6:TimePos+11]
				time = time +":00"
				if time[0:1]  == " ": 
					time = re.sub(" ","0",time)	# space with 0

				VSSPrefs.print_text(version+" "+new_date+" "+time+" "+user)
				out_list.append(version+" "+new_date+" "+time+" "+user)
	
#	VSSPrefs.print_text(out_list)
	vcs.output(string.join(out_list, NL))
	
	return TRUE




################################################################
#
# Procedure:   TestTool
# Parameters:  no Parameters
# Description: when SNiFF+ is restartet and a VCS-command is 
#              launched TestTool is called for a test
# Returns:     True if found, False else
#
################################################################

def TestTool():
	global D,M,Y,DateSep
	
	VSSPrefs.print_text(module + "TestTool")

	if not vcs.is_reachable("ss"):
		etgui.ShowAlert(3,"Can not find Visual SourceSafe commandline. Please check if SourceSafe is installed and the PATH-Variable is set!")
		return FALSE

	theCmd="ss About"+VSSPrefs.GlobalOpts+" 2>&1"
	About = vcs.getoutput(theCmd)
	vss = FALSE
	if About != "":
		AboutList = string.split(About)
		if (AboutList[2] == "Visual" and AboutList[3] == "SourceSafe"):
			vss = TRUE  # SourceSafe 6.0
	
	if not vss:		# output is not satisfactory
		etgui.ShowAlert(3,"Unknown version of Visual SourceSafe found.@B"+NL+theCmd+NL+"@Breturned unknown or empty response@B"+NL+About+NL+"@BPlease check your PATH or contact TakeFive"+NL+"for an update of the Visual SourceSafe Adaptor.")
		return FALSE

	DateTimeFormat = vcs.getoutput(vcs.sniffDir+"/bin/"+date_time_exe)
	DateTimeFormat = string.split(DateTimeFormat)
	DateSep = DateTimeFormat[0]
	TimeSep = DateTimeFormat[1]
	DateFormat = DateTimeFormat[2]
	TimeFormat = DateTimeFormat[3]

	DateFormat = string.lower(DateFormat)
	DateFormat = re.sub("d+","d",DateFormat)
	DateFormat = re.sub("m+","m",DateFormat)
	DateFormat = re.sub("y+","y",DateFormat)

	D = string.find(DateFormat,"d")
	M = string.find(DateFormat,"m")
	Y = string.find(DateFormat,"y")

	if Y == 1:
		Y=4
		if D == 0: M = 2
		else: 
			M = 0
			D = 2
	if Y == 0:
		if D == 1:
			M = 2
			D = 4
		else:
			M = 2*M
			D = 2*D
			
	if Y == 2:
		Y = 4
		D = 2*D
		M = 2*M
	
	return TRUE



################################################################
#
# Procedure:   UnLock
# Parameters:  vcs.RCCSPath........Repository Path (%p)
#              vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.revision........Revision of File (%V)
#              vcs.workingDir......Path to workingFile (%W)
#..............vcs.workingFile     Working File (%F)
# Description: UnLocks the repository file which is locked by the
#              current user, version is not supported only latest!!!
# Return:      0...Ok, !0...NOT Ok
#
################################################################

def Unlock():
	VSSPrefs.print_text(module + "UnLock")
	
	Revision = re.sub(".0","",vcs.revision)	# remove tailing ".0"

	os.chdir(vcs.workingDir)

	if Revision != "":
		etgui.ShowAlert(3,"Version number ignored. Check out of locked version...")
		
	File = '"' + vcs.repositoryDir + "/" + vcs.workingFile + '"'		# complete Filename = Path+Filename
	
	vss_status = vcs.system("ss UndoCheckout "+File+" -G- -I-Y -O\&-"+VSSPrefs.GlobalOpts)
	
	return vcs.test(vss_status)




################################################################
#
# Procedure:   UpdateFile
# Parameters:  vcs.catDir..........Path to FileName (%f)
#              vcs.repositoryDir...VSS Repository Path (%P)
#              vcs.revision........Revision of File (%V)
#              vcs.sniffDir........Path to $SNIFF_DIR (%d)
#              vcs.SOWS............Path to Shared Object Workspace (%g)
#              vcs.SSWS............Path to Shared Source Workspace (%G)
#              vcs.workingDir......Path to dir of WorkFile (%W)
#              vcs.workingFile.....Working File (%F)
# Description: checks wheter the ..working file is up to date compared
#              to to the repository and, if not, updates it.
# Return:      0...Ok, !0...NOT Ok
#
################################################################


def UpdateFile():
	InStr_SSWSRoot=vcs.SSWS
	
	VSSPrefs.print_text(module + "UpdateFile")
	
	Revision = re.sub(".0","",vcs.revision)	# remove tailing .0
	catDir = re.sub("/","\\\\",vcs.catDir)
	workingDir = re.sub("/","\\\\",vcs.workingDir)
	SSWS = re.sub("/","\\\\",vcs.SSWS)
	SOWS = re.sub("/","\\\\",vcs.SOWS)

	if Revision != "":
		RevArg = "-V "+Revision		# shell script expects space!!!
	else:
		RevArg = ""

	vcs.output("sh "+vcs.sniffDir+Update_File +" \""+workingDir+"\" \
	\""+catDir+"\" \""+vcs.workingFile+"\" \""+vcs.repositoryDir+"\" \""+RevArg+"\" \"" \
	+SSWS+"\" \""+SOWS+"\" Windows \"/\"")

	Status = vcs.system("sh "+vcs.sniffDir+Update_File +" \""+workingDir+"\" \
	\""+catDir+"\" \""+vcs.workingFile+"\" \""+vcs.repositoryDir+"\" \""+RevArg+"\" \"" \
	+SSWS+"\" \""+SOWS+"\" Windows \"/\"")

	return Status

##########################################
# Administrative and Debugging Utilities
##########################################

def ToggleVCSDebug():
	try:
		vcs.TEST=1-vcs.TEST
	except:
		vcs.TEST=1
	print "VCS Debugging is now ",vcs.TEST

def print_all():
	print "RCCSPath %%p:  %s" %vcs.RCCSPath
	print "RepositoryFile %%A:  %s" %vcs.repositoryFile
	print "RepositoryDir %%P:  %s" %vcs.repositoryDir
	print "WorkingFile %%F:  %s" %vcs.workingFile
	print "WorkingDir %%W:  %s" %vcs.workingDir
	print "ProjectDir %%r:  %s" %vcs.projectDir
	print "RepositoryRoot %%R:  %s" %vcs.repositoryRoot
	print "CatDir %%f:  %s" %vcs.catDir
	
	
	print "Revision %%V:  %s" %vcs.revision
	print "lockers: %s" %vcs.lockType
	print "branchflag: %i" %vcs.branchFlag
	print "checkflag: %i" %vcs.forceFlag
	print "comment: %s" %vcs.comment
	print "symbolic: %s" %vcs.symbolName
	print "SSWS: %s" %vcs.SSWS
	print "SOWS: %s" %vcs.SOWS
	print "Date: %s" %vcs.date
	print "Temp: %s" %vcs.tmpDir
	print "tempfile: %s" %vcs.tmpFile
	print "revision: %s" %vcs.revision
	print "revision2 %s" %vcs.revision2
	
	

"""
%A		repositoryFile	abs. filename/list of filenames
%B		branchName		String
%b		branchFlag		Boolean (1/0)
%C		comment			String
%D		date			YYYY/MM/DD HH:MM:SS
%F		workingFile		working file name without path
%f		catDir			file type subdirectory
%H		SSWE			shared source WE roots (semicolon separated)
%G		SSWS			shared source workspaces (semicolon sparated)
%g		SOWS			shared object workspaces (semicolon separated)
%I		description		String
%i		pid				Integer
%L		lockType		N/E/C  (None/Excl./Conc.)
%N		projectName		String
%P		repositoryDir	path (with adapter-specific tool subdir. and file type dir.)
%p		RCCSPath		path (without ...)
%R		repositoryRoot	abs. path
%r		projectDir		abs. or rel. path
%S		symbolName		String
%s		forceFlag		Boolean
%T		tmpFile			abs. filename
%t		tmpDir			abs. path
%U		user			String
%V		revision		String
%v		revision2		String (for second file)
%W		workingDir		abs. path
%w		privateRoot		abs. path
%d		sniffDir
%e		OSTempDir


def RevisionOfSymbol():
	print module + 'command RevisionOfSymbol not implemented'
	return TRUE


def IsLockedBy():
	print module + 'command IsLockedBy not implemented'
	return 0


def IsLocked():
	print module + 'command IsLocked not implemented'
	return 0


def Head():
	print module + 'command Head not implemented'
	return TRUE


def CheckOutProject():
	print module + 'command CheckOutProject not implemented'
	return TRUE


def UpdateProject():
	print module + 'command UpdateProject not implemented'
	return TRUE


def RepositoryFile():
	VSSPrefs.print_text(module + 'RepositoryFile')
	return TRUE


def RepositoryCheckDef():
	vcs.output('I')
	return TRUE


def TempDir():
	print module + 'command TempDir not implemented'
	return TRUE

def TempFile():
	print module + 'command TempFile not implemented'
	return TRUE
def BranchDef():
	vcs.output('I')
	return TRUE

"""
