/*
 *  Copyright 2002 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *  
 */
/* "@(#) DSP/BIOS 4.61.12 05-31-02 (barracuda-j21)" */
/******************************************************************************\
*           Copyright (C) 1999 Texas Instruments Incorporated.
*                           All Rights Reserved
*------------------------------------------------------------------------------
* MODULE NAME... MCBSP
* FILENAME...... csl_mcbsphal.h
* DATE CREATED.. Sat 06/12/1999 
* PROJECT....... Chip Support Library
* COMPONENT..... HAL
* PREREQUISITS.. 
*------------------------------------------------------------------------------
* HISTORY:
*   CREATED:        06/12/1999 
*   MODIFIED:       06/19/2000 make #ifdefs consistent with new csl_ header names,
*                              cplusplus compatability
*   LAST MODIFIED:  04/03/2001 Fix MCBSP register indexing problem for MCBSP2
*   
*------------------------------------------------------------------------------
* DESCRIPTION:  (HAL interface file for the MCBSP module)
*
* Registers Covered:
*   _MCBSP_DRR0  - serial port 0 data receive register
*   _MCBSP_DXR0  - serial port 0 data transmit register
*   _MCBSP_SPCR0 - serial port 0 control register
*   _MCBSP_RCR0  - serial port 0 receive control register
*   _MCBSP_XCR0  - serial port 0 transmit control register
*   _MCBSP_SRGR0 - serial port 0 sample rate generator register
*   _MCBSP_MCR0  - serial port 0 multichannel control register
*   _MCBSP_RCER0 - serial port 0 receive channel enable register
*   _MCBSP_XCER0 - serial port 0 transmit channel enable register
*   _MCBSP_PCR0  - serial port 0 pin control register
*
*   _MCBSP_DRR1  - serial port 1 data receive register
*   _MCBSP_DXR1  - serial port 1 data transmit register
*   _MCBSP_SPCR1 - serial port 1 control register
*   _MCBSP_RCR1  - serial port 1 receive control register
*   _MCBSP_XCR1  - serial port 1 transmit control register
*   _MCBSP_SRGR1 - serial port 1 sample rate generator register
*   _MCBSP_MCR1  - serial port 1 multichannel control register
*   _MCBSP_RCER1 - serial port 1 receive channel enable register
*   _MCBSP_XCER1 - serial port 1 transmit channel enable register
*   _MCBSP_PCR1  - serial port 1 pin control register
*
*   _MCBSP_DRR2  - serial port 2 data receive register 
*   _MCBSP_DXR2  - serial port 2 data transmit register 
*   _MCBSP_SPCR2 - serial port 2 control register 
*   _MCBSP_RCR2  - serial port 2 receive control register 
*   _MCBSP_XCR2  - serial port 2 transmit control register 
*   _MCBSP_SRGR2 - serial port 2 sample rate generator register
*   _MCBSP_MCR2  - serial port 2 multichannel control register
*   _MCBSP_RCER2 - serial port 2 receive channel enable register
*   _MCBSP_XCER2 - serial port 2 transmit channel enable register
*   _MCBSP_PCR2  - serial port 2 pin control register
*
*
\******************************************************************************/
#ifndef _CSL_MCBSPHAL_H_
#define _CSL_MCBSPHAL_H_
  
#include <csl_chiphal.h>  
    
#if (_MCBSP_SUPPORT)

/****************************************\
* MCBSP scope and inline control macros
\****************************************/
#ifdef _MCBSP_cplusplus
#define CSLAPI extern "C"  
#else
#define CSLAPI extern 
#endif

#undef  USEDEFS
#undef  IDECL
#undef  IDEF

#ifdef  _CSL_MOD_
  #define IDECL CSLAPI
  #define USEDEFS
  #define IDEF
#else
  #ifdef  _INLINE
    #define IDECL static inline
    #define USEDEFS
    #define IDEF  static inline
  #else
    #define IDECL CSLAPI
  #endif
#endif

/*============================================================================*\
*  misc declarations
\*============================================================================*/
#if (((CHIP_5401) || (CHIP_5402) || (CHIP_5471))&& !(CHIP_ALL))
  #define _MCBSP_PORT_CNT              (2)
#else
  #define _MCBSP_PORT_CNT              (3)
#endif


/*============================================================================*\
* memory mapped register addresses
\*============================================================================*/

#define _MCBSP_DRR20_ADDR			(0x0020u)
#define _MCBSP_DRR10_ADDR			(0x0021u)
#define _MCBSP_DXR20_ADDR                 (0x0022u)
#define _MCBSP_DXR10_ADDR                 (0x0023u)
#define _MCBSP_SPSA0_ADDR			(0x0038u)
#define _MCBSP_SPSD0_ADDR			(0x0039u)

#define _MCBSP_DRR21_ADDR			(0x0040u)
#define _MCBSP_DRR11_ADDR			(0x0041u)
#define _MCBSP_DXR21_ADDR                 (0x0042u)
#define _MCBSP_DXR11_ADDR                 (0x0043u)
#define _MCBSP_SPSA1_ADDR			(0x0048u)
#define _MCBSP_SPSD1_ADDR			(0x0049u)

#if (_MCBSP_PORT_CNT==3)
#define _MCBSP_DRR22_ADDR			(0x0030u)
#define _MCBSP_DRR12_ADDR			(0x0031u)
#define _MCBSP_DXR22_ADDR			(0x0032u)
#define _MCBSP_DXR12_ADDR			(0x0033u)
#define _MCBSP_SPSA2_ADDR			(0x0034u)
#define _MCBSP_SPSD2_ADDR			(0x0035u)
#endif

/*============================================================================*\
* memory mapped register address macros
\*============================================================================*/
#define _MCBSP_DRR2_BASE                  (0x0020u)
#define _MCBSP_DRR1_BASE                  (0x0021u)
#define _MCBSP_DXR2_BASE                  (0x0022u)
#define _MCBSP_DXR1_BASE                  (0x0023u)
#define _MCBSP_SPSA_BASE                  (0x0038u)
#define _MCBSP_SPSD_BASE                  (0x0039u)

#define _MCBSP_DRR2_ADDR(n)               ((((n) * 0x20u) - (((n)==2)*(0x30u))) + _MCBSP_DRR2_BASE)
#define _MCBSP_DRR1_ADDR(n)               ((((n) * 0x20u) - (((n)==2)*(0x30u))) + _MCBSP_DRR1_BASE)
#define _MCBSP_DXR2_ADDR(n)               ((((n) * 0x20u) - (((n)==2)*(0x30u))) + _MCBSP_DXR2_BASE)
#define _MCBSP_DXR1_ADDR(n)               ((((n) * 0x20u) - (((n)==2)*(0x30u))) + _MCBSP_DXR1_BASE)

#define _MCBSP_SPSA_ADDR(n)               ((((n) * 0x10u) - (((n)==2)*(0x24u))) + _MCBSP_SPSA_BASE)
#define _MCBSP_SPSD_ADDR(n)               ((((n) * 0x10u) - (((n)==2)*(0x24u))) + _MCBSP_SPSD_BASE)

#define _MCBSP_SPSA_ADDRH(Port)          _MCBSP_SPSA_ADDR(Port)
#define _MCBSP_SPSD_ADDRH(Port)          _MCBSP_SPSD_ADDR(Port)

#define _MCBSP_DRR2_ADDRH(Port)          _MCBSP_DRR2_ADDR(Port)
#define _MCBSP_DRR1_ADDRH(Port)          _MCBSP_DRR1_ADDR(Port)
#define _MCBSP_DXR2_ADDRH(Port)          _MCBSP_DXR2_ADDR(Port)
#define _MCBSP_DXR1_ADDRH(Port)          _MCBSP_DXR1_ADDR(Port)

#define _MCBSP_DRR2(n)                    REG16(_MCBSP_DRR2_ADDR(n))
#define _MCBSP_DRR1(n)                    REG16(_MCBSP_DRR1_ADDR(n))
#define _MCBSP_DXR2(n)                    REG16(_MCBSP_DXR2_ADDR(n))
#define _MCBSP_DXR1(n)                    REG16(_MCBSP_DXR1_ADDR(n))
#define _MCBSP_SPSA(n)                    REG16(_MCBSP_SPSA_ADDR(n))
#define _MCBSP_SPSD(n)                    REG16(_MCBSP_SPSD_ADDR(n))

#define _MCBSP_DRR2(n)                    REG16(_MCBSP_DRR2_ADDR(n))
#define _MCBSP_DRR1(n)                    REG16(_MCBSP_DRR1_ADDR(n))
#define _MCBSP_DXR2(n)                    REG16(_MCBSP_DXR2_ADDR(n))
#define _MCBSP_DXR1(n)                    REG16(_MCBSP_DXR1_ADDR(n))
#define _MCBSP_SPSA(n)                    REG16(_MCBSP_SPSA_ADDR(n))
#define _MBCSP_SPSD(n)                    REG16(_MCBSP_SPSD_ADDR(n))



/********************************************************\
* MCBSP memory-mapped registers 
\********************************************************/
#define _MCBSP_DRR20                     REG16(_MCBSP_DRR20_ADDR)
#define _MCBSP_DRR10                     REG16(_MCBSP_DDR10_ADDR)
#define _MCBSP_DXR20                     REG16(_MCBSP_DXR20_ADDR)
#define _MCBSP_DXR10                     REG16(_MCBSP_DXR10_ADDR)
#define _MCBSP_SPSA0                     REG16(_MCBSP_SPSA0_ADDR)
#define _MCBSP_SPSD0                     REG16(_MCBSP_SPSD0_ADDR)

#define _DRR20                            REG16(_MCBSP_DRR20_ADDR)
#define _DRR10                            REG16(_MCBSP_DDR10_ADDR)
#define _DXR20                            REG16(_MCBSP_DXR20_ADDR)
#define _DXR10                            REG16(_MCBSP_DXR10_ADDR)
#define _SPSA0                            REG16(_MCBSP_SPSA0_ADDR)
#define _SPSD0                            REG16(_MCBSP_SPSD0_ADDR)

#define _MCBSP_DRR21                      REG16(_MCBSP_DRR21_ADDR)
#define _MCBSP_DRR11                      REG16(_MCBSP_DRR11_ADDR) 
#define _MCBSP_DXR21                      REG16(_MCBSP_DXR21_ADDR)
#define _MCBSP_DXR11                      REG16(_MCBSP_DXR11_ADDR)
#define _MCBSP_SPSA1                      REG16(_MCBSP_SPSA1_ADDR)
#define _MCBSP_SPSD1                      REG16(_MCBSP_SPSD1_ADDR)

#define _DRR21                            REG16(_MCBSP_DRR21_ADDR)
#define _DRR11                            REG16(_MCBSP_DRR11_ADDR) 
#define _DXR21                            REG16(_MCBSP_DXR21_ADDR)
#define _DXR11                            REG16(_MCBSP_DXR11_ADDR)
#define _SPSA1                            REG16(_MCBSP_SPSA1_ADDR)
#define _SPSD1                            REG16(_MCBSP_SPSD1_ADDR)

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_DRR22                    REG16(_MCBSP_DRR22_ADDR)
  #define _MCBSP_DRR12                    REG16(_MCBSP_DRR12_ADDR)
  #define _MCBSP_DXR22                    REG16(_MCBSP_DXR22_ADDR)
  #define _MCBSP_DXR12                    REG16(_MCBSP_DXR12_ADDR)
  #define _MCBSP_SPSA2                    REG16(_MCBSP_SPSA2_ADDR)
  #define _MCBSP_SPSD2                    REG16(_MCBSP_SPSD2_ADDR)

  #define _DRR22                          REG16(_MCBSP_DRR22_ADDR)
  #define _DRR12                          REG16(_MCBSP_DRR12_ADDR)
  #define _DXR22                          REG16(_MCBSP_DXR22_ADDR)
  #define _DXR12                          REG16(_MCBSP_DXR12_ADDR)
  #define _SPSA2                          REG16(_MCBSP_SPSA2_ADDR)
  #define _SPSD2                          REG16(_MCBSP_SPSD2_ADDR)

#endif

/********************************************************\
* MCBSP sub addresses 
\********************************************************/
#define _MCBSP_SPCR1_ADDR			(0x0000u)
#define _MCBSP_SPCR2_ADDR			(0x0001u)
#define _MCBSP_RCR1_ADDR			(0x0002u)
#define _MCBSP_RCR2_ADDR			(0x0003u)
#define _MCBSP_XCR1_ADDR			(0x0004u)
#define _MCBSP_XCR2_ADDR			(0x0005u)

#define _MCBSP_SRGR1_ADDR			(0x0006u)
#define _MCBSP_SRGR2_ADDR			(0x0007u)
#define _MCBSP_MCR1_ADDR			(0x0008u)
#define _MCBSP_MCR2_ADDR			(0x0009u)
#define _MCBSP_RCERA_ADDR			(0x000Au)
#define _MCBSP_RCERB_ADDR			(0x000Bu)
#define _MCBSP_XCERA_ADDR			(0x000Cu)
#define _MCBSP_XCERB_ADDR			(0x000Du)
#define _MCBSP_PCR_ADDR                   (0x000Eu)

#define _MCBSP_SPCR10_ADDR			(0x0000u)
#define _MCBSP_SPCR20_ADDR			(0x0001u)
#define _MCBSP_RCR10_ADDR			(0x0002u)
#define _MCBSP_RCR20_ADDR			(0x0003u)
#define _MCBSP_XCR10_ADDR			(0x0004u)
#define _MCBSP_XCR20_ADDR			(0x0005u)

#define _MCBSP_SRGR10_ADDR			(0x0006u)
#define _MCBSP_SRGR20_ADDR			(0x0007u)
#define _MCBSP_MCR10_ADDR			(0x0008u)
#define _MCBSP_MCR20_ADDR			(0x0009u)
#define _MCBSP_RCERA0_ADDR			(0x000Au)
#define _MCBSP_RCERB0_ADDR			(0x000Bu)
#define _MCBSP_XCERA0_ADDR			(0x000Cu)
#define _MCBSP_XCERB0_ADDR			(0x000Du)
#define _MCBSP_PCR0_ADDR                  (0x000Eu)

#define _MCBSP_SPCR11_ADDR			(0x0000u)
#define _MCBSP_SPCR21_ADDR			(0x0001u)
#define _MCBSP_RCR11_ADDR			(0x0002u)
#define _MCBSP_RCR21_ADDR			(0x0003u)
#define _MCBSP_XCR11_ADDR			(0x0004u)
#define _MCBSP_XCR21_ADDR			(0x0005u)

#define _MCBSP_SRGR11_ADDR			(0x0006u)
#define _MCBSP_SRGR21_ADDR			(0x0007u)
#define _MCBSP_MCR11_ADDR			(0x0008u)
#define _MCBSP_MCR21_ADDR			(0x0009u)
#define _MCBSP_RCERA1_ADDR			(0x000Au)
#define _MCBSP_RCERB1_ADDR			(0x000Bu)
#define _MCBSP_XCERA1_ADDR			(0x000Cu)
#define _MCBSP_XCERB1_ADDR			(0x000Du)
#define _MCBSP_PCR1_ADDR                  (0x000Eu)

#if (_MCBSP_PORT_CNT == 3)
  #define _MCBSP_SPCR12_ADDR			(0x0000u)
  #define _MCBSP_SPCR22_ADDR			(0x0001u)
  #define _MCBSP_RCR12_ADDR			(0x0002u)
  #define _MCBSP_RCR22_ADDR			(0x0003u)
  #define _MCBSP_XCR12_ADDR			(0x0004u)
  #define _MCBSP_XCR22_ADDR			(0x0005u)

  #define _MCBSP_SRGR12_ADDR			(0x0006u)
  #define _MCBSP_SRGR22_ADDR			(0x0007u)
  #define _MCBSP_MCR12_ADDR			(0x0008u) 
  #define _MCBSP_MCR22_ADDR			(0x0009u)
  #define _MCBSP_RCERA2_ADDR			(0x000Au)
  #define _MCBSP_RCERB2_ADDR			(0x000Bu)
  #define _MCBSP_XCERA2_ADDR			(0x000Cu)
  #define _MCBSP_XCERB2_ADDR			(0x000Du)
  #define _MCBSP_PCR2_ADDR                (0x000Eu)
#endif


#define _MCBSP_SPCR1_ADDRH(Port)         _MCBSP_SPCR1_ADDR
#define _MCBSP_SPCR2_ADDRH(Port)         _MCBSP_SPCR2_ADDR
#define _MCBSP_RCR1_ADDRH(Port)          _MCBSP_RCR1_ADDR
#define _MCBSP_RCR2_ADDRH(Port)          _MCBSP_RCR2_ADDR
#define _MCBSP_XCR1_ADDRH(Port)          _MCBSP_XCR1_ADDR
#define _MCBSP_XCR2_ADDRH(Port)          _MCBSP_XCR2_ADDR
#define _MCBSP_SRGR1_ADDRH(Port)         _MCBSP_SRGR1_ADDR
#define _MCBSP_SRGR2_ADDRH(Port)         _MCBSP_SRGR2_ADDR
#define _MCBSP_MCR1_ADDRH(Port)          _MCBSP_MCR1_ADDR
#define _MCBSP_MCR2_ADDRH(Port)          _MCBSP_MCR2_ADDR
#define _MCBSP_RCERA_ADDRH(Port)         _MCBSP_RCERA_ADDR
#define _MCBSP_RCERB_ADDRH(Port)         _MCBSP_RCERB_ADDR
#define _MCBSP_XCERA_ADDRH(Port)         _MCBSP_XCERA_ADDR
#define _MCBSP_XCERB_ADDRH(Port)         _MCBSP_XCERB_ADDR
#define _MCBSP_PCR_ADDRH(Port)           _MCBSP_PCR_ADDR

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_RCERC_ADDR               (0x0010u)
  #define _MCBSP_RCERD_ADDR               (0x0011u)
  #define _MCBSP_XCERC_ADDR               (0x0012u)
  #define _MCBSP_XCERD_ADDR               (0x0013u)
  #define _MCBSP_RCERE_ADDR               (0x0014u)
  #define _MCBSP_RCERF_ADDR               (0x0015u)
  #define _MCBSP_XCERE_ADDR               (0x0016u)
  #define _MCBSP_XCERF_ADDR               (0x0017u)
  #define _MCBSP_RCERG_ADDR               (0x0018u)
  #define _MCBSP_RCERH_ADDR               (0x0019u)
  #define _MCBSP_XCERG_ADDR               (0x001Au)
  #define _MCBSP_XCERH_ADDR               (0x001Bu)

  #define _MCBSP_RCERC0_ADDR               (0x0010u)
  #define _MCBSP_RCERD0_ADDR               (0x0011u)
  #define _MCBSP_XCERC0_ADDR               (0x0012u)
  #define _MCBSP_XCERD0_ADDR               (0x0013u)
  #define _MCBSP_RCERE0_ADDR               (0x0014u)
  #define _MCBSP_RCERF0_ADDR               (0x0015u)
  #define _MCBSP_XCERE0_ADDR               (0x0016u)
  #define _MCBSP_XCERF0_ADDR               (0x0017u)
  #define _MCBSP_RCERG0_ADDR               (0x0018u)
  #define _MCBSP_RCERH0_ADDR               (0x0019u)
  #define _MCBSP_XCERG0_ADDR               (0x001Au)
  #define _MCBSP_XCERH0_ADDR               (0x001Bu)

  #define _MCBSP_RCERC1_ADDR               (0x0010u)
  #define _MCBSP_RCERD1_ADDR               (0x0011u)
  #define _MCBSP_XCERC1_ADDR               (0x0012u)
  #define _MCBSP_XCERD1_ADDR               (0x0013u)
  #define _MCBSP_RCERE1_ADDR               (0x0014u)
  #define _MCBSP_RCERF1_ADDR               (0x0015u)
  #define _MCBSP_XCERE1_ADDR               (0x0016u)
  #define _MCBSP_XCERF1_ADDR               (0x0017u)
  #define _MCBSP_RCERG1_ADDR               (0x0018u)
  #define _MCBSP_RCERH1_ADDR               (0x0019u)
  #define _MCBSP_XCERG1_ADDR               (0x001Au)
  #define _MCBSP_XCERH1_ADDR               (0x001Bu)

  #if (_MCBSP_PORT_CNT == 3)
    #define _MCBSP_RCERC2_ADDR             (0x0010u)
    #define _MCBSP_RCERD2_ADDR             (0x0011u)
    #define _MCBSP_XCERC2_ADDR             (0x0012u)
    #define _MCBSP_XCERD2_ADDR             (0x0013u)
    #define _MCBSP_RCERE2_ADDR             (0x0014u)
    #define _MCBSP_RCERF2_ADDR             (0x0015u)
    #define _MCBSP_XCERE2_ADDR             (0x0016u)
    #define _MCBSP_XCERF2_ADDR             (0x0017u)
    #define _MCBSP_RCERG2_ADDR             (0x0018u)
    #define _MCBSP_RCERH2_ADDR             (0x0019u)
    #define _MCBSP_XCERG2_ADDR             (0x001Au)
    #define _MCBSP_XCERH2_ADDR             (0x001Bu)
  #endif

  #define _MCBSP_RCERC_ADDRH(Port)       (0x0010u)
  #define _MCBSP_RCERD_ADDRH(Port)       (0x0011u)
  #define _MCBSP_XCERC_ADDRH(Port)       (0x0012u)
  #define _MCBSP_XCERD_ADDRH(Port)       (0x0013u)
  #define _MCBSP_RCERE_ADDRH(Port)       (0x0014u)
  #define _MCBSP_RCERF_ADDRH(Port)       (0x0015u)
  #define _MCBSP_XCERE_ADDRH(Port)       (0x0016u)
  #define _MCBSP_XCERF_ADDRH(Port)       (0x0017u)
  #define _MCBSP_RCERG_ADDRH(Port)       (0x0018u)
  #define _MCBSP_RCERH_ADDRH(Port)       (0x0019u)
  #define _MCBSP_XCERG_ADDRH(Port)       (0x001Au)
  #define _MCBSP_XCERH_ADDRH(Port)       (0x001Bu)

#endif /* _MCBSP_128_CH_ENABLE_SUPPORT */

/********************************************************\
* MCBSP sub address registers
\********************************************************/
#define _MCBSP_SPCR1                       (_MCBSP_SPCR1_ADDR)
#define _MCBSP_SPCR2                       (_MCBSP_SPCR2_ADDR)
#define _MCBSP_RCR1                        (_MCBSP_RCR1_ADDR)
#define _MCBSP_RCR2                        (_MCBSP_RCR2_ADDR)
#define _MCBSP_XCR1                        (_MCBSP_XCR1_ADDR)
#define _MCBSP_XCR2                        (_MCBSP_XCR2_ADDR)
#define _MCBSP_SRGR1                       (_MCBSP_SRGR1_ADDR)
#define _MCBSP_SRGR2                       (_MCBSP_SRGR2_ADDR)
#define _MCBSP_MCR1                        (_MCBSP_MCR1_ADDR)
#define _MCBSP_MCR2                        (_MCBSP_MCR2_ADDR)
#define _MCBSP_RCERA                       (_MCBSP_RCERA_ADDR)
#define _MCBSP_RCERB                       (_MCBSP_RCERB_ADDR)
#define _MCBSP_XCERA                       (_MCBSP_XCERA_ADDR)
#define _MCBSP_XCERB                       (_MCBSP_XCERB_ADDR)
#define _MCBSP_PCR                         (_MCBSP_PCR_ADDR)
		
#define _SPCR1                             (_MCBSP_SPCR1_ADDR)
#define _SPCR2                             (_MCBSP_SPCR2_ADDR)
#define _RCR1                              (_MCBSP_RCR1_ADDR)
#define _RCR2                              (_MCBSP_RCR2_ADDR)
#define _XCR1                              (_MCBSP_XCR1_ADDR)
#define _XCR2                              (_MCBSP_XCR2_ADDR)
#define _SRGR1                             (_MCBSP_SRGR1_ADDR)
#define _SRGR2                             (_MCBSP_SRGR2_ADDR)
#define _MCR1                              (_MCBSP_MCR1_ADDR)
#define _MCR2                              (_MCBSP_MCR2_ADDR)
#define _RCERA                             (_MCBSP_RCERA_ADDR)
#define _RCERB                             (_MCBSP_RCERB_ADDR)
#define _XCERA                             (_MCBSP_XCERA_ADDR)
#define _XCERB                             (_MCBSP_XCERB_ADDR)
#define _PCR                               (_MCBSP_PCR_ADDR)
		
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_RCERC                     (_MCBSP_RCERC_ADDR)
  #define _MCBSP_RCERD                     (_MCBSP_RCERD_ADDR)
  #define _MCBSP_XCERC                     (_MCBSP_XCERC_ADDR)
  #define _MCBSP_XCERD                     (_MCBSP_XCERD_ADDR)
  #define _MCBSP_RCERE                     (_MCBSP_RCERE_ADDR)
  #define _MCBSP_RCERF                     (_MCBSP_RCERF_ADDR)
  #define _MCBSP_XCERE                     (_MCBSP_XCERE_ADDR)
  #define _MCBSP_XCERF                     (_MCBSP_XCERF_ADDR)
  #define _MCBSP_RCERG                     (_MCBSP_RCERG_ADDR)
  #define _MCBSP_RCERH                     (_MCBSP_RCERH_ADDR)
  #define _MCBSP_XCERG                     (_MCBSP_XCERG_ADDR)
  #define _MCBSP_XCERH                     (_MCBSP_XCERH_ADDR)

  #define _RCERC                           (_MCBSP_RCERC_ADDR)
  #define _RCERD                           (_MCBSP_RCERD_ADDR)
  #define _XCERC                           (_MCBSP_XCERC_ADDR)
  #define _XCERD                           (_MCBSP_XCERD_ADDR)
  #define _RCERE                           (_MCBSP_RCERE_ADDR)
  #define _RCERF                           (_MCBSP_RCERF_ADDR)
  #define _XCERE                           (_MCBSP_XCERE_ADDR)
  #define _XCERF                           (_MCBSP_XCERF_ADDR)
  #define _RCERG                           (_MCBSP_RCERG_ADDR)
  #define _RCERH                           (_MCBSP_RCERH_ADDR)
  #define _XCERG                           (_MCBSP_XCERG_ADDR)
  #define _XCERH                           (_MCBSP_XCERH_ADDR)

#endif /* _MCBSP_128_CH_ENABLE_SUPPORT */

/*----------------------------------------------------------------------------*\
* Generic Register Macros:
\*----------------------------------------------------------------------------*/
#define MCBSP_ADDR(Reg)                     _MCBSP_##Reg##_ADDR
#define MCBSP_RGET(Reg)                     _MCBSP_##Reg##_GET
#define MCBSP_RSET(Reg,Val)                 _MCBSP_##Reg##_SET(Val)
#define MCBSP_RAOI(Reg,AND,OR,INV)          _MCBSP_##Reg##_AOI(AND,OR,INV)
#define MCBSP_FGET(Reg,Field)               _MCBSP_##Reg##_FGET(##Field)
#define MCBSP_FSET(Reg,Field,Val)           _MCBSP_##Reg##_FSET(##Field,Val)
#define MCBSP_FAOI(Reg,Field,AND,OR,INV)    _MCBSP_##Reg##_FAOI(##Field,AND,OR,INV)
#define MCBSP_FMK(Reg,Field,Val)            _MCBSP_##Reg##_##Field##_MK(Val)
#define MCBSP_FMKS(Reg,Field,Sym)\
  _MCBSP_##Reg##_##Field##_MK(MCBSP_##Reg##_##Field##_##Sym)

#define MCBSP_ADDRH(Handle,Reg)             _MCBSP_##Reg##_ADDRH(((MCBSP_PrivateObj*)(Handle))->Port)
#define MCBSP_RGETH(Handle,Reg)             _MCBSP_##Reg##_GET(((MCBSP_PrivateObj*)(Handle))->Port)
#define MCBSP_RSETH(Handle,Reg,Val)         _MCBSP_##Reg##_SET((((MCBSP_PrivateObj*)(Handle))->Port),Val)
#define MCBSP_RAOIH(Handle,Reg,AND,OR,INV)\
  _MCBSP_##Reg##_AOI((((MCBSP_PrivateObj*)(Handle))->Port),AND,OR,INV)
#define MCBSP_FGETH(Handle,Reg,Field)\
  _MCBSP_##Reg##_FGET((((MCBSP_PrivateObj*)(Handle))->Port),##Field)
#define MCBSP_FSETH(Handle,Reg,Field,Val)\
  _MCBSP_##Reg##_FSET((((MCBSP_PrivateObj*)(Handle))->Port),##Field,Val)
#define MCBSP_FAOIH(Handle,Reg,Field,AND,OR,INV)\
  _MCBSP_##Reg##_FAOI((((MCBSP_PrivateObj*)(Handle))->Port),##Field,AND,OR,INV)
#define MCBSP_FMKH(Handle,Reg,Field,Val)    _MCBSP_##Reg##_##Field##_MK(Val)
#define MCBSP_FMKSH(Handle,Reg,Field,Sym)   _MCBSP_##Reg##_##Field##_MK(MCBSP_##Reg##_##Field##_##Sym)

#define MCBSP_ADDR_H(Handle,Reg)             _MCBSP_##Reg##_ADDRH(((MCBSP_PrivateObj*)(Handle))->Port)
#define MCBSP_RGET_H(Handle,Reg)             _MCBSP_##Reg##_GET(((MCBSP_PrivateObj*)(Handle))->Port)
#define MCBSP_RSET_H(Handle,Reg,Val)         _MCBSP_##Reg##_SET((((MCBSP_PrivateObj*)(Handle))->Port),Val)
#define MCBSP_RAOI_H(Handle,Reg,AND,OR,INV)\
  _MCBSP_##Reg##_AOI((((MCBSP_PrivateObj*)(Handle))->Port)AND,OR,INV)
#define MCBSP_FGET_H(Handle,Reg,Field)\
  _MCBSP_##Reg##_FGET((((MCBSP_PrivateObj*)(Handle))->Port),##Field)
#define MCBSP_FSET_H(Handle,Reg,Field,Val)\
  _MCBSP_##Reg##_FSET((((MCBSP_PrivateObj*)(Handle))->Port),##Field,Val)
#define MCBSP_FAOI_H(Handle,Reg,Field,AND,OR,INV)\
  _MCBSP_##Reg##_FAOI((((MCBSP_PrivateObj*)(Handle))->Port),##Field,AND,OR,INV)
#define MCBSP_FMK_H(Handle,Reg,Field,Val)    _MCBSP_##Reg##_##Field##_MK(Val)
#define MCBSP_FMKS_H(Handle,Reg,Field,Sym)   _MCBSP_##Reg##_##Field##_MK(MCBSP_##Reg##_##Field##_##Sym)



#define _MCBSP_DRR10_GET                     _REG_GET(_MCBSP_DRR10_ADDR)
#define _MCBSP_DRR20_GET                     _REG_GET(_MCBSP_DRR20_ADDR)
#define _MCBSP_DRR11_GET                     _REG_GET(_MCBSP_DRR11_ADDR)
#define _MCBSP_DRR21_GET                     _REG_GET(_MCBSP_DRR21_ADDR)

#if (_MCBSP_PORT_CNT == 3)
  #define _MCBSP_DRR12_GET                  _REG_GET(_MCBSP_DRR12_ADDR)
  #define _MCBSP_DRR22_GET                  _REG_GET(_MCBSP_DRR22_ADDR)
#endif

#define _MCBSP_DXR10_GET                     _REG_GET(_MCBSP_DXR10_ADDR)
#define _MCBSP_DXR20_GET                     _REG_GET(_MCBSP_DXR20_ADDR)
#define _MCBSP_DXR11_GET                     _REG_GET(_MCBSP_DXR11_ADDR)
#define _MCBSP_DXR21_GET                     _REG_GET(_MCBSP_DXR21_ADDR)

#if (_MCBSP_PORT_CNT == 3)
  #define _MCBSP_DXR12_GET                  _REG_GET(_MCBSP_DXR12_ADDR)
  #define _MCBSP_DXR22_GET                  _REG_GET(_MCBSP_DXR22_ADDR)
#endif

#define _MCBSP_DRR10_SET(Val)                     _REG_SET(_MCBSP_DRR10_ADDR,Val)
#define _MCBSP_DRR20_SET(Val)                     _REG_SET(_MCBSP_DRR20_ADDR,Val)
#define _MCBSP_DRR11_SET(Val)                     _REG_SET(_MCBSP_DRR11_ADDR,Val)
#define _MCBSP_DRR21_SET(Val)                     _REG_SET(_MCBSP_DRR21_ADDR,Val)

#if (_MCBSP_PORT_CNT == 3)
  #define _MCBSP_DRR12_SET(Val)                  _REG_SET(_MCBSP_DRR12_ADDR,Val)
  #define _MCBSP_DRR22_SET(Val)                  _REG_SET(_MCBSP_DRR22_ADDR,Val)
#endif

#define _MCBSP_DXR10_SET(Val)                     _REG_SET(_MCBSP_DXR10_ADDR,Val)
#define _MCBSP_DXR20_SET(Val)                     _REG_SET(_MCBSP_DXR20_ADDR,Val)
#define _MCBSP_DXR11_SET(Val)                     _REG_SET(_MCBSP_DXR11_ADDR,Val)
#define _MCBSP_DXR21_SET(Val)                     _REG_SET(_MCBSP_DXR21_ADDR,Val)

#if (_MCBSP_PORT_CNT == 3)
  #define _MCBSP_DXR12_SET(Val)                  _REG_SET(_MCBSP_DXR12_ADDR,Val)
  #define _MCBSP_DXR22_SET(Val)                  _REG_SET(_MCBSP_DXR22_ADDR,Val)
#endif


#define MCBSP_RCERA _MCBSP_RCERA_ADDR
#define MCBSP_RCERB _MCBSP_RCERB_ADDR
#define MCBSP_XCERA _MCBSP_XCERA_ADDR
#define MCBSP_XCERB _MCBSP_XCERB_ADDR

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define MCBSP_RCERC _MCBSP_RCERC_ADDR
  #define MCBSP_RCERD _MCBSP_RCERD_ADDR
  #define MCBSP_RCERE _MCBSP_RCERE_ADDR
  #define MCBSP_RCERF _MCBSP_RCERF_ADDR
  #define MCBSP_RCERG _MCBSP_RCERG_ADDR
  #define MCBSP_RCERH _MCBSP_RCERH_ADDR  
  #define MCBSP_XCERC _MCBSP_XCERC_ADDR
  #define MCBSP_XCERD _MCBSP_XCERD_ADDR
  #define MCBSP_XCERE _MCBSP_XCERE_ADDR
  #define MCBSP_XCERF _MCBSP_XCERF_ADDR
  #define MCBSP_XCERG _MCBSP_XCERG_ADDR 
  #define MCBSP_XCERH _MCBSP_XCERH_ADDR 
#endif      

#define MCBSP_CHAN0     0x0001
#define MCBSP_CHAN1     0x0002
#define MCBSP_CHAN2     0x0004  
#define MCBSP_CHAN3     0x0008
#define MCBSP_CHAN4     0x0010
#define MCBSP_CHAN5     0x0020  
#define MCBSP_CHAN6     0x0040
#define MCBSP_CHAN7     0x0080
#define MCBSP_CHAN8     0x0100 
#define MCBSP_CHAN9     0x0200
#define MCBSP_CHAN10    0x0400
#define MCBSP_CHAN11    0x0800  
#define MCBSP_CHAN12    0x1000
#define MCBSP_CHAN13    0x2000
#define MCBSP_CHAN14    0x4000
#define MCBSP_CHAN15    0x8000  

/*-----------------------------------------------------------------------*\
* Macros to GET/SET the value of individual registers and bit fields
\*-----------------------------------------------------------------------*/

#define _MCBSP_DXR1_GET(Port)        _REG_GET(_MCBSP_DXR1_ADDRH(Port))
#define _MCBSP_DXR1_SET(Port,Val)    _REG_SET(_MCBSP_DXR1_ADDRH(Port),Val)
#define _MCBSP_DXR1_AOI(Port,AND,OR,INV)\
   _REG_AOI(_MCBSP_DXR1_ADDRH(Port), AND, OR, INV)
#define _MCBSP_DXR1_FGET(Port,Field)\
   _FIELD_GET(_MCBSP_DXR1_ADDRH(Port),_MCBSP_DXR1_##Field)
#define _MCBSP_DXR1_FSET(Port,Field,Val)\
   _FIELD_SET(_MCBSP_DXR1_ADDRH(Port),_MCBSP_DXR1_##Field, Val)
#define _MCBSP_DXR1_FAOI(Port,Field,AND,OR,INV)\
   _FIELD_SET(_MCBSP_DXR1_ADDRH(Port),_MCBSP_DXR1_##Field,AND,OR,INV)

#define _MCBSP_DXR2_GET(Port)        _REG_GET(_MCBSP_DXR2_ADDRH(Port))
#define _MCBSP_DXR2_SET(Port,Val)    _REG_SET(_MCBSP_DXR2_ADDRH(Port),Val)
#define _MCBSP_DXR2_AOI(Port,AND,OR,INV)\
   _REG_AOI(_MCBSP_DXR2_ADDRH(Port), AND, OR, INV)
#define _MCBSP_DXR2_FGET(Port,Field)\
   _FIELD_GET(_MCBSP_DXR2_ADDRH(Port),_MCBSP_DXR2_##Field)
#define _MCBSP_DXR2_FSET(Port,Field,Val)\
   _FIELD_SET(_MCBSP_DXR2_ADDRH(Port),_MCBSP_DXR2_##Field, Val)
#define _MCBSP_DXR2_FAOI(Port,Field,AND,OR,INV)\
   _FIELD_SET(_MCBSP_DXR2_ADDRH(Port),_MCBSP_DXR2_##Field,AND,OR,INV)

#define _MCBSP_DRR1_GET(Port)        _REG_GET(_MCBSP_DRR1_ADDRH(Port))
#define _MCBSP_DRR1_SET(Port,Val)    _REG_SET(_MCBSP_DRR1_ADDRH(Port),Val)
#define _MCBSP_DRR1_AOI(Port,AND,OR,INV)\
   _REG_AOI(_MCBSP_DRR1_ADDRH(Port), AND, OR, INV)
#define _MCBSP_DRR1_FGET(Port,Field)\
   _FIELD_GET(_MCBSP_DRR1_ADDRH(Port),_MCBSP_DRR1_##Field)
#define _MCBSP_DRR1_FSET(Port,Field,Val)\
   _FIELD_SET(_MCBSP_DRR1_ADDRH(Port),_MCBSP_DRR1_##Field, Val)
#define _MCBSP_DRR1_FAOI(Port,Field,AND,OR,INV)\
   _FIELD_SET(_MCBSP_DRR1_ADDRH(Port),_MCBSP_DRR1_##Field,AND,OR,INV)

#define _MCBSP_DRR2_GET(Port)        _REG_GET(_MCBSP_DRR2_ADDRH(Port))
#define _MCBSP_DRR2_SET(Port,Val)    _REG_SET(_MCBSP_DRR2_ADDRH(Port),Val)
#define _MCBSP_DRR2_AOI(Port,AND,OR,INV)\
   _REG_AOI(_MCBSP_DRR2_ADDRH(Port), AND, OR, INV)
#define _MCBSP_DRR2_FGET(Port,Field)\
   _FIELD_GET(_MCBSP_DRR2_ADDRH(Port),_MCBSP_DRR2_##Field)
#define _MCBSP_DRR2_FSET(Port,Field,Val)\
   _FIELD_SET(_MCBSP_DRR2_ADDRH(Port),_MCBSP_DRR2_##Field, Val)
#define _MCBSP_DRR2_FAOI(Port,Field,AND,OR,INV)\
   _FIELD_SET(_MCBSP_DRR2_ADDRH(Port),_MCBSP_DRR2_##Field,AND,OR,INV)

/*============================================================================*\
* _MCBSP_DXR1 :
\*============================================================================*/

#define _MCBSP_DXR1_DXR1_SHIFT                  (0x0000u)
#define _MCBSP_DXR1_DXR1_MK(n)                  (((Uint16)(n) & 0xFFFFu)<<_MCBSP_DXR1_DXR1_SHIFT)
#define _MCBSP_DXR1_DXR1_MASK                   (_MCBSP_DXR1_DXR1_MK(0xFFFFu))
#define _MCBSP_DXR1_DXR1_CLR                    (~(_MCBSP_DXR1_DXR1_MASK))

/*============================================================================*\
* _MCBSP_DXR2 :
\*============================================================================*/

#define _MCBSP_DXR2_DXR2_SHIFT                  (0x0000u)
#define _MCBSP_DXR2_DXR2_MK(n)                  (((Uint16)(n) & 0xFFFFu)<<_MCBSP_DXR2_DXR2_SHIFT)
#define _MCBSP_DXR2_DXR2_MASK                   (_MCBSP_DXR2_DXR2_MK(0xFFFFu))
#define _MCBSP_DXR2_DXR2_CLR                    (~(_MCBSP_DXR2_DXR2_MASK))

/*============================================================================*\
* _MCBSP_DRR1 :
\*============================================================================*/

#define _MCBSP_DRR1_DRR1_SHIFT                  (0x0000u)
#define _MCBSP_DRR1_DRR1_MK(n)                  (((Uint16)(n) & 0xFFFFu)<<_MCBSP_DRR1_DRR1_SHIFT)
#define _MCBSP_DRR1_DRR1_MASK                   (_MCBSP_DRR1_DRR1_MK(0xFFFFu))
#define _MCBSP_DRR1_DRR1_CLR                    (~(_MCBSP_DRR1_DRR1_MASK))

/*============================================================================*\
* _MCBSP_DRR2 :
\*============================================================================*/

#define _MCBSP_DRR2_DRR2_SHIFT                  (0x0000u)
#define _MCBSP_DRR2_DRR2_MK(n)                  (((Uint16)(n) & 0xFFFFu)<<_MCBSP_DRR2_DRR2_SHIFT)
#define _MCBSP_DRR2_DRR2_MASK                   (_MCBSP_DRR2_DRR2_MK(0xFFFFu))
#define _MCBSP_DRR2_DRR2_CLR                    (~(_MCBSP_DRR2_DRR2_MASK))



/*============================================================================*\
* _MCBSP_SPCR1 : MCBSP Serial Port Control Register 1
*
* Fields:
* (RW) _MCBSP_SPCR1_DLB
* (RW) _MCBSP_SPCR1_RJUST
* (RW) _MCBSP_SPCR1_CLKSTP
* (RW) _MCBSP_SPCR1_DXENA
* (RW) _MCBSP_SPCR1_ABIS
* (RW) _MCBSP_SPCR1_RINTM
* (RW) _MCBSP_SPCR1_RSYNCERR
* (R)  _MCBSP_SPCR1_RFULL
* (R)  _MCBSP_SPCR1_RRDY
* (RW) _MCBSP_SPCR1_RRST
* 
\*============================================================================*/

/*---------------------------------------------------------------------------*\
* Register Macros:
\*---------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR1_ADDR)

#define _MCBSP_SPCR1_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port) , _MCBSP_SPCR1_ADDR, Val)

#define _MCBSP_SPCR1_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port) , _MCBSP_SPCR1_ADDR, AND,OR,INV)

#if (_MCBSP_ABIS_SUPPORT)
#define _MCBSP_SPCR1_CFG(Port, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR1_ADDR,\
               ( _MCBSP_SPCR1_DLB_MK(dlb)           |\
                 _MCBSP_SPCR1_RJUST_MK(rjust)       |\
                 _MCBSP_SPCR1_CLKSTP_MK(clkstp)     |\
                 _MCBSP_SPCR1_DXENA_MK(dxena)       |\
                 _MCBSP_SPCR1_RINTM_MK(rintm)       |\
                 _MCBSP_SPCR1_RSYNCERR_MK(rsyncerr) |\
                 _MCBSP_SPCR1_RRST_MK(rrst)             \
               )\
   )
#else
#define _MCBSP_SPCR1_CFG(Port, dlb, rjust, clkstp, dxena, rintm, rsyncerr, rrst)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR1_ADDR,\
               ( _MCBSP_SPCR1_DLB_MK(dlb)           |\
                 _MCBSP_SPCR1_RJUST_MK(rjust)       |\
                 _MCBSP_SPCR1_CLKSTP_MK(clkstp)     |\
                 _MCBSP_SPCR1_DXENA_MK(dxena)       |\
                 _MCBSP_SPCR1_ABIS_MK(abis)         |\
                 _MCBSP_SPCR1_RINTM_MK(rintm)       |\
                 _MCBSP_SPCR1_RSYNCERR_MK(rsyncerr) |\
                 _MCBSP_SPCR1_RRST_MK(rrst)             \
               )\
   )
#endif
#define _MCBSP_SPCR1_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR1_ADDR,_MCBSP_SPCR1_##Field)

#define _MCBSP_SPCR1_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR1_ADDR, _MCBSP_SPCR1_##Field, Val)

#define _MCBSP_SPCR1_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR1_ADDR, _MCBSP_SPCR1_##Field, AND,OR,INV)


#define _MCBSP_SPCR10_GET                     _MCBSP_SPCR1_GET(0)
#define _MCBSP_SPCR10_SET(Val)                  _MCBSP_SPCR1_SET(0,Val)
#define _MCBSP_SPCR10_AOI(AND,OR,INV)           _MCBSP_SPCR1_AOI(0,AND,OR,INV)
#define _MCBSP_SPCR10_FGET(Field)               _MCBSP_SPCR1_FGET(0,##Field)
#define _MCBSP_SPCR10_FSET(Field,Val)           _MCBSP_SPCR1_FSET(0,##Field,Val)
#define _MCBSP_SPCR10_FAOI(Field,AND,OR,INV)    _MCBSP_SPCR1_FAOI(0,##Field,AND,OR,INV)
#if (_MCBSP_ABIS_SUPPORT)
  #define _MCBSP_SPCR10_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
    _MCBSP_SPCR1_CFG(0, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)
#else
  #define _MCBSP_SPCR10_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
    _MCBSP_SPCR1_CFG(0, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)
#endif

#define _MCBSP_SPCR11_GET                       _MCBSP_SPCR1_GET(1)
#define _MCBSP_SPCR11_SET(Val)                  _MCBSP_SPCR1_SET(1,Val)
#define _MCBSP_SPCR11_AOI(AND,OR,INV)           _MCBSP_SPCR1_AOI(1,AND,OR,INV)
#define _MCBSP_SPCR11_FGET(Field)               _MCBSP_SPCR1_FGET(1,##Field)
#define _MCBSP_SPCR11_FSET(Field,Val)           _MCBSP_SPCR1_FSET(1,##Field,Val)
#define _MCBSP_SPCR11_FAOI(Field,AND,OR,INV)        _MCBSP_SPCR1_FAOI(1,##Field,AND,OR,INV)
#if (_MCBSP_ABIS_SUPPORT)
  #define _MCBSP_SPCR11_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
    _MCBSP_SPCR1_CFG(1, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)
#else
  #define _MCBSP_SPCR11_CFG(dlb, rjust, clkstp, dxena, rintm, rsyncerr, rrst)\
    _MCBSP_SPCR1_CFG(1, dlb, rjust, clkstp, dxena, rintm, rsyncerr, rrst)
#endif

#if (_MCBSP_PORT_CNT==3)
#define _MCBSP_SPCR12_GET                       _MCBSP_SPCR1_GET(2)
#define _MCBSP_SPCR12_SET(Val)                  _MCBSP_SPCR1_SET(2,Val)
#define _MCBSP_SPCR12_AOI(AND,OR,INV)           _MCBSP_SPCR1_AOI(2,AND,OR,INV)
#define _MCBSP_SPCR12_FGET(Field)               _MCBSP_SPCR1_FGET(2,##Field)
#define _MCBSP_SPCR12_FSET(Field,Val)           _MCBSP_SPCR1_FSET(2,##Field,Val)
#define _MCBSP_SPCR12_FAOI(Field,AND,OR,INV)        _MCBSP_SPCR1_FAOI(2,##Field,AND,OR,INV)
#if (_MCBSP_ABIS_SUPPORT)
  #define _MCBSP_SPCR12_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
    _MCBSP_SPCR1_CFG(2, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)
#else
  #define _MCBSP_SPCR12_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
    _MCBSP_SPCR1_CFG(2, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)
#endif
#endif

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_DLB: enable/disbale digital loopback mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_DLB_SHIFT         (0x000fu)
#define _MCBSP_SPCR1_DLB_MK(n)         (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR1_DLB_SHIFT)
#define _MCBSP_SPCR1_DLB_MASK          (_MCBSP_SPCR1_DLB_MK(1))
#define _MCBSP_SPCR1_DLB_CLR           (~(_MCBSP_SPCR1_DLB_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_RJUST: receive sign extension and justification mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_RJUST_SHIFT       (0x000du)
#define _MCBSP_SPCR1_RJUST_MK(n)       (((Uint16)(n) & 0x0003u) << _MCBSP_SPCR1_RJUST_SHIFT)
#define _MCBSP_SPCR1_RJUST_MASK        (_MCBSP_SPCR1_RJUST_MK(3))
#define _MCBSP_SPCR1_RJUST_CLR         (~(_MCBSP_SPCR1_RJUST_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_CLKSTP: clock stop mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_CLKSTP_SHIFT      (0x000bu)
#define _MCBSP_SPCR1_CLKSTP_MK(n)      (((Uint16)(n) & 0x0003u) << _MCBSP_SPCR1_CLKSTP_SHIFT)
#define _MCBSP_SPCR1_CLKSTP_MASK       (_MCBSP_SPCR1_CLKSTP_MK(3))
#define _MCBSP_SPCR1_CLKSTP_CLR        (~(_MCBSP_SPCR1_CLKSTP_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_DXENA: enable/disable extra delay for turn on time
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_DXENA_SHIFT       (0x0007u)
#define _MCBSP_SPCR1_DXENA_MK(n)       (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR1_DXENA_SHIFT)
#define _MCBSP_SPCR1_DXENA_MASK        (_MCBSP_SPCR1_DXENA_MK(1))
#define _MCBSP_SPCR1_DXENA_CLR         (~(_MCBSP_SPCR1_DXENA_MASK))

#if (_MCBSP_ABIS_SUPPORT)
/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_ABIS: enable/disable ABIS mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_ABIS_SHIFT        (0x0006u)
#define _MCBSP_SPCR1_ABIS_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR1_ABIS_SHIFT)
#define _MCBSP_SPCR1_ABIS_MASK         (_MCBSP_SPCR1_ABIS_MK(1))
#define _MCBSP_SPCR1_ABIS_CLR          (~(_MCBSP_SPCR1_ABIS_MASK))

#endif
/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_RINTM: receive interrupt mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_RINTM_SHIFT       (0x0004u)
#define _MCBSP_SPCR1_RINTM_MK(n)       (((Uint16)(n) & 0x0003u) << _MCBSP_SPCR1_RINTM_SHIFT)
#define _MCBSP_SPCR1_RINTM_MASK        (_MCBSP_SPCR1_RINTM_MK(3))
#define _MCBSP_SPCR1_RINTM_CLR         (~(_MCBSP_SPCR1_RINTM_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_RSYNCERR: detect read synchronization error
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_RSYNCERR_SHIFT      (0x0003u)
#define _MCBSP_SPCR1_RSYNCERR_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR1_RSYNCERR_SHIFT)
#define _MCBSP_SPCR1_RSYNCERR_MASK        (_MCBSP_SPCR1_RSYNCERR_MK(1))
#define _MCBSP_SPCR1_RSYNCERR_CLR        (~(_MCBSP_SPCR1_RSYNCERR_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_SPCR1_RFULL: detect receive full
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_RFULL_SHIFT         (0x0002u)
#define _MCBSP_SPCR1_RFULL_MK(n)       (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR1_RFULL_SHIFT)
#define _MCBSP_SPCR1_RFULL_MASK           (_MCBSP_SPCR1_RFULL_MK(1))
#define _MCBSP_SPCR1_RFULL_CLR           (~(_MCBSP_SPCR1_RFULL_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_SPCR1_RRDY: detect receive ready
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_RRDY_SHIFT         (0x0001u)
#define _MCBSP_SPCR1_RRDY_MK(n)       (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR1_RRDY_SHIFT)
#define _MCBSP_SPCR1_RRDY_MASK           (_MCBSP_SPCR1_RRDY_MK(1))
#define _MCBSP_SPCR1_RRDY_CLR           (~(_MCBSP_SPCR1_RRDY_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR1_RRST: reset receive side of serial port
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR1_RRST_SHIFT         (0x0000u)
#define _MCBSP_SPCR1_RRST_MK(n)       (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR1_RRST_SHIFT)
#define _MCBSP_SPCR1_RRST_MASK           (_MCBSP_SPCR1_RRST_MK(1))
#define _MCBSP_SPCR1_RRST_CLR           (~(_MCBSP_SPCR1_RRST_MASK))


/*============================================================================*\
* _MCBSP_SPCR2 : MCBSP Serial Port Control Register 2
*
* Fields:
* (RW) _MCBSP_SPCR2_FREE
* (RW) _MCBSP_SPCR2_SOFT
* (RW) _MCBSP_SPCR2_FRST
* (RW) _MCBSP_SPCR2_GRST
* (RW) _MCBSP_SPCR2_XINTM
* (RW) _MCBSP_SPCR2_XSYNCERR
* (R)  _MCBSP_SPCR2_XEMPTY
* (R)  _MCBSP_SPCR2_XRDY
* (RW) _MCBSP_SPCR2_XRST
\
* 
\*============================================================================*/

#define _MCBSP_SPCR2_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR2_ADDR)

#define _MCBSP_SPCR2_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port) , _MCBSP_SPCR2_ADDR, Val)

#define _MCBSP_SPCR2_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port) , _MCBSP_SPCR2_ADDR, AND,OR,INV)

#define _MCBSP_SPCR2_CFG(Port, free, soft, frst, grst, xintm, xsyncerr, xrst)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR2_ADDR,\
               ( _MCBSP_SPCR2_FREE_MK(free)           |\
                 _MCBSP_SPCR2_SOFT_MK(soft)           |\
                 _MCBSP_SPCR2_FRST_MK(frst)           |\
                 _MCBSP_SPCR2_GRST_MK(grst)           |\
                 _MCBSP_SPCR2_XINTM_MK(xintm)         |\
                 _MCBSP_SPCR2_XSYNCERR_MK(xsyncerr)   |\
                 _MCBSP_SPCR2_XRST_MK(xrst)            \
               )\
   )

#define _MCBSP_SPCR2_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR2_ADDR,_MCBSP_SPCR2_##Field)

#define _MCBSP_SPCR2_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR2_ADDR, _MCBSP_SPCR2_##Field, Val)

#define _MCBSP_SPCR2_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SPCR2_ADDR, _MCBSP_SPCR2_##Field, AND,OR,INV)


#define _MCBSP_SPCR20_GET                       _MCBSP_SPCR2_GET(0)
#define _MCBSP_SPCR20_SET(Val)                  _MCBSP_SPCR2_SET(0,Val)
#define _MCBSP_SPCR20_AOI(AND,OR,INV)           _MCBSP_SPCR2_AOI(0,AND,OR,INV)
#define _MCBSP_SPCR20_FGET(Field)               _MCBSP_SPCR2_FGET(0,##Field)
#define _MCBSP_SPCR20_FSET(Field,Val)           _MCBSP_SPCR2_FSET(0,##Field,Val)
#define _MCBSP_SPCR20_FAOI(Field,AND,OR,INV)    _MCBSP_SPCR2_FAOI(0,##Field,AND,OR,INV)
#define _MCBSP_SPCR20_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
  _MCBSP_SPCR2_CFG(0, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)

#define _MCBSP_SPCR21_GET                        _MCBSP_SPCR2_GET(1)
#define _MCBSP_SPCR21_SET(Val)                  _MCBSP_SPCR2_SET(1,Val)
#define _MCBSP_SPCR21_AOI(AND,OR,INV)           _MCBSP_SPCR2_AOI(1,AND,OR,INV)
#define _MCBSP_SPCR21_FGET(Field)               _MCBSP_SPCR2_FGET(1,##Field)
#define _MCBSP_SPCR21_FSET(Field,Val)           _MCBSP_SPCR2_FSET(1,##Field,Val)
#define _MCBSP_SPCR21_FAOI(Field,AND,OR,INV)    _MCBSP_SPCR2_FAOI(1,##Field,AND,OR,INV)
#define _MCBSP_SPCR21_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
  _MCBSP_SPCR2_CFG(1, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)

#if (_MCBSP_PORT_CNT==3)
#define _MCBSP_SPCR22_GET                       _MCBSP_SPCR2_GET(2)
#define _MCBSP_SPCR22_SET(Val)                  _MCBSP_SPCR2_SET(2,Val)
#define _MCBSP_SPCR22_AOI(AND,OR,INV)           _MCBSP_SPCR2_AOI(2,AND,OR,INV)
#define _MCBSP_SPCR22_FGET(Field)               _MCBSP_SPCR2_FGET(2,##Field)
#define _MCBSP_SPCR22_FSET(Field,Val)           _MCBSP_SPCR2_FSET(2,##Field,Val)
#define _MCBSP_SPCR22_FAOI(Field,AND,OR,INV)    _MCBSP_SPCR2_FAOI(2,##Field,AND,OR,INV)
#define _MCBSP_SPCR22_CFG(dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)\
  _MCBSP_SPCR2_CFG(2, dlb, rjust, clkstp, dxena, abis, rintm, rsyncerr, rrst)
#endif

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR2_FREE: enable/disable run free
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_FREE_SHIFT      (0x0009u)
#define _MCBSP_SPCR2_FREE_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_FREE_SHIFT)

#define _MCBSP_SPCR2_FREE_MASK        (_MCBSP_SPCR2_FREE_MK(1))
#define _MCBSP_SPCR2_FREE_CLR        (~(_MCBSP_SPCR2_FREE_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR2_SOFT: enable/disable soft mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_SOFT_SHIFT      (0x0008u)
#define _MCBSP_SPCR2_SOFT_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_SOFT_SHIFT)
#define _MCBSP_SPCR2_SOFT_MASK        (_MCBSP_SPCR2_SOFT_MK(1))
#define _MCBSP_SPCR2_SOFT_CLR        (~(_MCBSP_SPCR2_SOFT_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR2_FRST: frame sync generator reset
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_FRST_SHIFT      (0x0007u)
#define _MCBSP_SPCR2_FRST_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_FRST_SHIFT)
#define _MCBSP_SPCR2_FRST_MASK        (_MCBSP_SPCR2_FRST_MK(1))
#define _MCBSP_SPCR2_FRST_CLR        (~(_MCBSP_SPCR2_FRST_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR2_GRST: sample rate generator reset
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_GRST_SHIFT       (0x0006u)
#define _MCBSP_SPCR2_GRST_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_GRST_SHIFT) 
#define _MCBSP_SPCR2_GRST_MASK        (_MCBSP_SPCR2_GRST_MK(1))
#define _MCBSP_SPCR2_GRST_CLR        (~(_MCBSP_SPCR2_GRST_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR2_XINTM: transmit interrupt mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_XINTM_SHIFT     (0x0004u)
#define _MCBSP_SPCR2_XINTM_MK(n)   (((Uint16)(n) & 0x0003u) << _MCBSP_SPCR2_XINTM_SHIFT)
#define _MCBSP_SPCR2_XINTM_MASK       (_MCBSP_SPCR2_XINTM_MK(3))
#define _MCBSP_SPCR2_XINTM_CLR       (~(_MCBSP_SPCR2_XINTM_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR2_XSYNCERR: detect transmit synchronization error
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_XSYNCERR_SHIFT  (0x0003u)
#define _MCBSP_SPCR2_XSYNCERR_MK(n)  (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_XSYNCERR_SHIFT)
#define _MCBSP_SPCR2_XSYNCERR_MASK   (_MCBSP_SPCR2_XSYNCERR_MK(1))
#define _MCBSP_SPCR2_XSYNCERR_CLR    (~(_MCBSP_SPCR2_XSYNCERR_MASK))

/*----------------------------------------------------------------------------*\
* (R)  _MCBSP_SPCR2_XEMPTY: detect transmit empty
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_XEMPTY_SHIFT    (0x0002u)
#define _MCBSP_SPCR2_XEMPTY_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_XEMPTY_SHIFT)
#define _MCBSP_SPCR2_XEMPTY_MASK     (_MCBSP_SPCR2_XEMPTY_MK(1))
#define _MCBSP_SPCR2_XEMPTY_CLR      (~(_MCBSP_SPCR2_XEMPTY_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_SPCR2_XRDY: detect transmit ready
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_XRDY_SHIFT     (0x0001u)
#define _MCBSP_SPCR2_XRDY_MK(n)     (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_XRDY_SHIFT)
#define _MCBSP_SPCR2_XRDY_MASK      (_MCBSP_SPCR2_XRDY_MK(1))
#define _MCBSP_SPCR2_XRDY_CLR       (~(_MCBSP_SPCR2_XRDY_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SPCR2_XRST: reset transmit side of serial port
\*----------------------------------------------------------------------------*/
#define _MCBSP_SPCR2_XRST_SHIFT     (0x0000u)
#define _MCBSP_SPCR2_XRST_MK(n)     (((Uint16)(n) & 0x0001u) << _MCBSP_SPCR2_XRST_SHIFT)
#define _MCBSP_SPCR2_XRST_MASK      (_MCBSP_SPCR2_XRST_MK(1))
#define _MCBSP_SPCR2_XRST_CLR       (~(_MCBSP_SPCR2_XRST_MASK))

/*============================================================================*\
* _MCBSP_PCR : MCBSP Pin Control Register
*
* Fields:
* (RW) _MCBSP_PCR_XIOEN
* (RW) _MCBSP_PCR_RIOEN
* (RW) _MCBSP_PCR_FSXM
* (RW) _MCBSP_PCR_FSRM
* (RW) _MCBSP_PCR_CLKXM
* (RW) _MCBSP_PCR_CLKRM
* (RW) _MCBSP_PCR_IDLEEN
* (RW) _MCBSP_PCR_CLKSSTAT
* (RW) _MCBSP_PCR_DXSTAT
* (RW) _MCBSP_PCR_DRSTAT
* (RW) _MCBSP_PCR_FSXP
* (RW) _MCBSP_PCR_FSRP
* (RW) _MCBSP_PCR_CLKXP
* (RW) _MCBSP_PCR_CLKRP
*
* 
\*============================================================================*/

/*----------------------------------------------------------------------------*\
* Register macros
\*----------------------------------------------------------------------------*/

#define _MCBSP_PCR_GET(Port)\
   _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR)

#define _MCBSP_PCR_SET(Port, Val)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR, Val)

#define _MCBSP_PCR_AOI(Port, AND,OR,INV)\
   _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR, AND,OR,INV)

#define _MCBSP_PCR_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR, _MCBSP_PCR_##Field)

#define _MCBSP_PCR_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR, _MCBSP_PCR_##Field, Val)

#define _MCBSP_PCR_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR, _MCBSP_PCR_##Field, AND,OR,INV)

#if (_MCBSP_SCLKME_SUPORT)
   #define _MCBSP_PCR_CFG(Port,xioen,rioen,fsxm,fsrm,clkxm,clkrm,sclkme,clksstat,\
     dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
     _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR,\
            ( _MCBSP_PCR_XIOEN_MK(xioen)         |\
              _MCBSP_PCR_RIOEN_MK(rioen)         |\
              _MCBSP_PCR_FSXM_MK(fsxm)           |\
              _MCBSP_PCR_FSRM_MK(fsrm)           |\
              _MCBSP_PCR_CLKXM_MK(clkxm)         |\
              _MCBSP_PCR_CLKRM_MK(clkrm)         |\
              _MCBSP_PCR_SCLKME_MK(sclkme)       |\
              _MCBSP_PCR_CLKSSTAT_MK(clksstat)   |\
              _MCBSP_PCR_DXSTAT_MK(dxstat)       |\
              _MCBSP_PCR_DRSTAT_MK(drstat)       |\
              _MCBSP_PCR_FSXP_MK(fsxp)           |\
              _MCBSP_PCR_FSRP_MK(fsrp)           |\
              _MCBSP_PCR_CLKXP_MK(clkxp)         |\
              _MCBSP_PCR_CLKRP_MK(clkrp)         \
            )\
   )
#else 
   #define _MCBSP_PCR_CFG(Port,xioen,rioen,fsxm,fsrm,clkxm,clkrm,clksstat,\
      dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
      _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_PCR_ADDR,\
            ( _MCBSP_PCR_XIOEN_MK(xioen)         |\
              _MCBSP_PCR_RIOEN_MK(rioen)         |\
              _MCBSP_PCR_FSXM_MK(fsxm)           |\
              _MCBSP_PCR_FSRM_MK(fsrm)           |\
              _MCBSP_PCR_CLKXM_MK(clkxm)         |\
              _MCBSP_PCR_CLKRM_MK(clkrm)         |\
              _MCBSP_PCR_CLKSSTAT_MK(clksstat)   |\
              _MCBSP_PCR_DXSTAT_MK(dxstat)       |\
              _MCBSP_PCR_DRSTAT_MK(drstat)       |\
              _MCBSP_PCR_FSXP_MK(fsxp)           |\
              _MCBSP_PCR_FSRP_MK(fsrp)           |\
              _MCBSP_PCR_CLKXP_MK(clkxp)         |\
              _MCBSP_PCR_CLKRP_MK(clkrp)         \
            )\
   )
#endif /* (_MCBSP_SCLKME_SUPPORT) */

#define _MCBSP_PCR0_GET                       _MCBSP_PCR_GET(0)
#define _MCBSP_PCR0_SET(Val)                  _MCBSP_PCR_SET(0,Val)
#define _MCBSP_PCR0_AOI(AND,OR,INV)           _MCBSP_PCR_AOI(0,AND,OR,INV)
#define _MCBSP_PCR0_FGET(Field)               _MCBSP_PCR_FGET(0,##Field)
#define _MCBSP_PCR0_FSET(Field,Val)           _MCBSP_PCR_FSET(0,##Field,Val)
#define _MCBSP_PCR0_FAOI(Field,AND,OR,INV)        _MCBSP_PCR_FAOI(0,##Field,AND,OR,INV)
#if (_MCBSP_SCLKME_SUPPORT)
   #define _MCBSP_PCR0_CFG(xioen,rioen,fsxm,fsrm,clkxm,clkrm,sclkme,clksstat,\
     dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
       _MCBSP_PCR_CFG(0,xioen,rioen,fsxm,fsrm,clkxm,clkrm,sclkme,clksstat,\
       dxstat,drstat,fsxp,fsrp,clkxp,clkrp)
#else 
   #define _MCBSP_PCR0_CFG(xioen,rioen,fsxm,fsrm,clkxm,clkrm,clksstat,\
      dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
         _MCBSP_PCR_CFG(0,xioen,rioen,fsxm,fsrm,clkxm,clkrm,clksstat,\
         dxstat,drstat,fsxp,fsrp,clkxp,clkrp)
#endif /* (_MCBSP_128_CH_ENABLE_SUPPORT) */

#define _MCBSP_PCR1_GET                       _MCBSP_PCR_GET(1)
#define _MCBSP_PCR1_SET(Val)                  _MCBSP_PCR_SET(1,Val)
#define _MCBSP_PCR1_AOI(AND,OR,INV)           _MCBSP_PCR_AOI(1,AND,OR,INV)
#define _MCBSP_PCR1_FGET(Field)               _MCBSP_PCR_FGET(1,##Field)
#define _MCBSP_PCR1_FSET(Field,Val)           _MCBSP_PCR_FSET(1,##Field,Val)
#define _MCBSP_PCR1_FAOI(Field,AND,OR,INV)    _MCBSP_PCR_FAOI(1,##Field,AND,OR,INV)
#if (_MCBSP_SCLKME_SUPPORT)
   #define _MCBSP_PCR1_CFG(xioen,rioen,fsxm,fsrm,clkxm,clkrm,sclkme,clksstat,\
     dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
       _MCBSP_PCR_CFG(1,xioen,rioen,fsxm,fsrm,clkxm,clkrm,sclkme,clksstat,\
       dxstat,drstat,fsxp,fsrp,clkxp,clkrp)
#else 
   #define _MCBSP_PCR1_CFG(xioen,rioen,fsxm,fsrm,clkxm,clkrm,clksstat,\
      dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
         _MCBSP_PCR_CFG(1,xioen,rioen,fsxm,fsrm,clkxm,clkrm,clksstat,\
         dxstat,drstat,fsxp,fsrp,clkxp,clkrp)
#endif /* (_MCBSP_128_CH_ENABLE_SUPPORT) */

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_PCR2_GET                       _MCBSP_PCR_GET(2)
  #define _MCBSP_PCR2_SET(Val)                  _MCBSP_PCR_SET(2,Val)
  #define _MCBSP_PCR2_AOI(AND,OR,INV)           _MCBSP_PCR_AOI(2,AND,OR,INV)
  #define _MCBSP_PCR2_FGET(Field)               _MCBSP_PCR_FGET(2,##Field)
  #define _MCBSP_PCR2_FSET(Field,Val)           _MCBSP_PCR_FSET(2,##Field,Val)
  #define _MCBSP_PCR2_FAOI(Field,AND,OR,INV)    _MCBSP_PCR_FAOI(2,##Field,AND,OR,INV)
  #if (_MCBSP_SCLKME_SUPPORT)
     #define _MCBSP_PCR2_CFG(xioen,rioen,fsxm,fsrm,clkxm,clkrm,sclkme,clksstat,\
       dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
         _MCBSP_PCR_CFG(2,xioen,rioen,fsxm,fsrm,clkxm,clkrm,sclkme,clksstat,\
         dxstat,drstat,fsxp,fsrp,clkxp,clkrp)
  #else 
     #define _MCBSP_PCR2_CFG(xioen,rioen,fsxm,fsrm,clkxm,clkrm,clksstat,\
        dxstat,drstat,fsxp,fsrp,clkxp,clkrp)\
           _MCBSP_PCR_CFG(2,xioen,rioen,fsxm,fsrm,clkxm,clkrm,clksstat,\
           dxstat,drstat,fsxp,fsrp,clkxp,clkrp)
  #endif /* (_MCBSP_128_CH_ENABLE_SUPPORT) */
#endif

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_XIOEN: enable/disable general purpose I/O for transmit
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_XIOEN_SHIFT     (0x000du)
#define _MCBSP_PCR_XIOEN_MK(n)   (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_XIOEN_SHIFT)
#define _MCBSP_PCR_XIOEN_MASK       (_MCBSP_PCR_XIOEN_MK(1))
#define _MCBSP_PCR_XIOEN_CLR       (~(_MCBSP_PCR_XIOEN_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_RIOEN: enable/disable general purpose I/O for receive
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_RIOEN_SHIFT     (0x000cu)
#define _MCBSP_PCR_RIOEN_MK(n)   (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_RIOEN_SHIFT)
#define _MCBSP_PCR_RIOEN_MASK       (_MCBSP_PCR_RIOEN_MK(1))
#define _MCBSP_PCR_RIOEN_CLR       (~(_MCBSP_PCR_RIOEN_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_FSXM: transmit frame sync mode bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_FSXM_SHIFT      (0x000bu)
#define _MCBSP_PCR_FSXM_MK(n)      (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_FSXM_SHIFT)
#define _MCBSP_PCR_FSXM_MASK       (_MCBSP_PCR_FSXM_MK(1))
#define _MCBSP_PCR_FSXM_CLR        (~(_MCBSP_PCR_FSXM_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_FSRM: receive frame sync mode bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_FSRM_SHIFT      (0x000au)
#define _MCBSP_PCR_FSRM_MK(n)      (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_FSRM_SHIFT)
#define _MCBSP_PCR_FSRM_MASK       (_MCBSP_PCR_FSRM_MK(1))
#define _MCBSP_PCR_FSRM_CLR        (~(_MCBSP_PCR_FSRM_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_CLKXM: transmit clock mode bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_CLKXM_SHIFT     (0x0009u)
#define _MCBSP_PCR_CLKXM_MK(n)     (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_CLKXM_SHIFT)
#define _MCBSP_PCR_CLKXM_MASK      (_MCBSP_PCR_CLKXM_MK(1))
#define _MCBSP_PCR_CLKXM_CLR       (~(_MCBSP_PCR_CLKXM_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_CLKRM: receive clock mode bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_CLKRM_SHIFT     (0x0008u)
#define _MCBSP_PCR_CLKRM_MK(n)     (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_CLKRM_SHIFT)
#define _MCBSP_PCR_CLKRM_MASK      (_MCBSP_PCR_CLKRM_MK(1))
#define _MCBSP_PCR_CLKRM_CLR       (~(_MCBSP_PCR_CLKRM_MASK))

#if (_MCBSP_SCLKME_SUPPORT)

   /*----------------------------------------------------------------------------*\
   * (RW) _MCBSP_PCR_SCLKME: sample rate generator extended clock mode
   \*----------------------------------------------------------------------------*/
   #define _MCBSP_PCR_SCLKME_SHIFT    (0x0007u)
   #define _MCBSP_PCR_SCLKME_MK(n)  (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_SCLKME_SHIFT)

   #define _MCBSP_PCR_SCLKME_MASK      (_MCBSP_PCR_SCLKME_MK(1))
   #define _MCBSP_PCR_SCLKME_CLR      (~(_MCBSP_PCR_SCLKME_MASK))

#endif /* _MCBSP_SCLKME_SUPPORT */

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_PCR_CLKSSTAT: reflects value of clks pin when config as general purpose
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_CLKSSTAT_SHIFT  (0x0006u)
#define _MCBSP_PCR_CLKSSTAT_MK(n)  (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_CLKSSTAT_SHIFT)
#define _MCBSP_PCR_CLKSSTAT_MASK   (_MCBSP_PCR_CLKSSTAT_MK(1))
#define _MCBSP_PCR_CLKSSTAT_CLR    (~(_MCBSP_PCR_CLKSSTAT_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_PCR_DXSTAT: reflects val of dx pin when config as general output
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_DXSTAT_SHIFT   (0x0005u)
#define _MCBSP_PCR_DXSTAT_MK(n)   (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_DXSTAT_SHIFT)
#define _MCBSP_PCR_DXSTAT_MASK    (_MCBSP_PCR_DXSTAT_MK(1))
#define _MCBSP_PCR_DXSTAT_CLR     (~(_MCBSP_PCR_DXSTAT_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_PCR_DRSTAT: reflects val of DR pin when config as general input
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_DRSTAT_SHIFT   (0x0004u)
#define _MCBSP_PCR_DRSTAT_MK(n)   (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_DRSTAT_SHIFT)
#define _MCBSP_PCR_DRSTAT_MASK    (_MCBSP_PCR_DRSTAT_MK(1))
#define _MCBSP_PCR_DRSTAT_CLR     (~(_MCBSP_PCR_DRSTAT_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_FSXP: transmit frame sync polarity
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_FSXP_SHIFT     (0x0003u)
#define _MCBSP_PCR_FSXP_MK(n)     (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_FSXP_SHIFT)
#define _MCBSP_PCR_FSXP_MASK      (_MCBSP_PCR_FSXP_MK(1))
#define _MCBSP_PCR_FSXP_CLR       (~(_MCBSP_PCR_FSXP_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_PCR_FSRP: receive frame sync polarity
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_FSRP_SHIFT     (0x0002u)
#define _MCBSP_PCR_FSRP_MK(n)     (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_FSRP_SHIFT)
#define _MCBSP_PCR_FSRP_MASK      (_MCBSP_PCR_FSRP_MK(1))
#define _MCBSP_PCR_FSRP_CLR       (~(_MCBSP_PCR_FSRP_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_PCR_CLKXP: transmit clock polarity
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_CLKXP_SHIFT    (0x0001u)
#define _MCBSP_PCR_CLKXP_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_CLKXP_SHIFT)
#define _MCBSP_PCR_CLKXP_MASK     (_MCBSP_PCR_CLKXP_MK(1))
#define _MCBSP_PCR_CLKXP_CLR      (~(_MCBSP_PCR_CLKXP_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_PCR_CLKRP: receive clock polarity
\*----------------------------------------------------------------------------*/
#define _MCBSP_PCR_CLKRP_SHIFT    (0x0000u)
#define _MCBSP_PCR_CLKRP_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_PCR_CLKRP_SHIFT)
#define _MCBSP_PCR_CLKRP_MASK     (_MCBSP_PCR_CLKRP_MK(1))
#define _MCBSP_PCR_CLKRP_CLR      (~(_MCBSP_PCR_CLKRP_MASK))

/*============================================================================*\
* _MCBSP_RCR1 : MCBSP Recieve Control Register #1
*
* Fields:
* (RW) _MCBSP_RCR1_RFRLEN1
* (RW) _MCBSP_RCR1_RWDLEN1
* 
\*============================================================================*/

#define _MCBSP_RCR1_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR1_ADDR)

#define _MCBSP_RCR1_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR1_ADDR, Val)

#define _MCBSP_RCR1_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR1_ADDR, AND,OR,INV)

#define _MCBSP_RCR1_FGET(Port,Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR1_ADDR, _MCBSP_RCR1_##Field)

#define _MCBSP_RCR1_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR1_ADDR, _MCBSP_RCR1_##Field, Val)

#define _MCBSP_RCR1_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR1_ADDR, _MCBSP_RCR1_##Field, AND,OR,INV)

#define _MCBSP_RCR1_CFG(Port,rfrlen1,rwdlen1)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR1_ADDR,\
               ( _MCBSP_RCR1_RFRLEN1_MK(rfrlen1)  |\
                 _MCBSP_RCR1_RWDLEN1_MK(rwdlen1)   \
               )\
  )

#define _MCBSP_RCR10_GET                       _MCBSP_RCR1_GET(0)
#define _MCBSP_RCR10_SET(Val)                  _MCBSP_RCR1_SET(0,Val)
#define _MCBSP_RCR10_AOI(AND,OR,INV)           _MCBSP_RCR1_AOI(0,AND,OR,INV)
#define _MCBSP_RCR10_FGET(Field)               _MCBSP_RCR1_FGET(0,##Field)
#define _MCBSP_RCR10_FSET(Field,Val)           _MCBSP_RCR1_FSET(0,##Field,Val)
#define _MCBSP_RCR10_FAOI(Field,AND,OR,INV)    _MCBSP_RCR1_FAOI(0,##Field,AND,OR,INV)
#define _MCBSP_RCR10_CFG(rfrlen1,rwdlen1)      _MCBSP_RCR1_CFG(0,rfrlen1,rwdlen1)

#define _MCBSP_RCR11_GET                       _MCBSP_RCR1_GET(1)
#define _MCBSP_RCR11_SET(Val)                  _MCBSP_RCR1_SET(1,Val)
#define _MCBSP_RCR11_AOI(AND,OR,INV)           _MCBSP_RCR1_AOI(1,AND,OR,INV)
#define _MCBSP_RCR11_FGET(Field)               _MCBSP_RCR1_FGET(1,##Field)
#define _MCBSP_RCR11_FSET(Field,Val)           _MCBSP_RCR1_FSET(1,##Field,Val)
#define _MCBSP_RCR11_FAOI(Field,AND,OR,INV)    _MCBSP_RCR1_FAOI(1,##Field,AND,OR,INV)
#define _MCBSP_RCR11_CFG(rfrlen1,rwdlen1)      _MCBSP_RCR1_CFG(1,rfrlen1,rwdlen1)

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_RCR12_GET                     _MCBSP_RCR1_GET(2)
  #define _MCBSP_RCR12_SET(Val)                _MCBSP_RCR1_SET(2,Val)
  #define _MCBSP_RCR12_AOI(AND,OR,INV)         _MCBSP_RCR1_AOI(2,AND,OR,INV)
  #define _MCBSP_RCR12_FGET(Field)             _MCBSP_RCR1_FGET(2,##Field)
  #define _MCBSP_RCR12_FSET(Field,Val)         _MCBSP_RCR1_FSET(2,##Field,Val)
  #define _MCBSP_RCR12_FAOI(Field,AND,OR,INV)  _MCBSP_RCR1_FAOI(2,##Field,AND,OR,INV)
  #define _MCBSP_RCR12_CFG(rfrlen1,rwdlen1)    _MCBSP_RCR1_CFG(2,rfrlen1,rwdlen1)
#endif
/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCR1_RFRLEN1: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR1_RFRLEN1_SHIFT    (0x0008u)
#define _MCBSP_RCR1_RFRLEN1_MK(n)    (((Uint16)(n) & 0x007fu) << _MCBSP_RCR1_RFRLEN1_SHIFT)
#define _MCBSP_RCR1_RFRLEN1_MASK     (_MCBSP_RCR1_RFRLEN1_MK(0x7fu))
#define _MCBSP_RCR1_RFRLEN1_CLR      (~(_MCBSP_RCR1_RFRLEN1_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCR1_RWDLEN1: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR1_RWDLEN1_SHIFT    (0x0005u)
#define _MCBSP_RCR1_RWDLEN1_MK(n)    (((Uint16)(n) & 0x0007u) << _MCBSP_RCR1_RWDLEN1_SHIFT)
#define _MCBSP_RCR1_RWDLEN1_MASK     (_MCBSP_RCR1_RWDLEN1_MK(7))
#define _MCBSP_RCR1_RWDLEN1_CLR      (~(_MCBSP_RCR1_RWDLEN1_MASK))

/*============================================================================*\
* _MCBSP_RCR2 : MCBSP Recieve Control Register #2
*
* Fields:
* (RW) _MCBSP_RCR2_RPHASE
* (RW) _MCBSP_RCR2_RFRLEN2
* (RW) _MCBSP_RCR2_RWDLEN2
* (RW) _MCBSP_RCR2_RCOMPAND
* (RW) _MCBSP_RCR2_RFIG
* (RW) _MCBSP_RCR2_RDATDLY
* 
\*============================================================================*/


/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/

#define _MCBSP_RCR2_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR2_ADDR)

#define _MCBSP_RCR2_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR2_ADDR, Val)

#define _MCBSP_RCR2_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR2_ADDR, AND,OR,INV)

#define _MCBSP_RCR2_FGET(Port,Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR2_ADDR, _MCBSP_RCR2_##Field)

#define _MCBSP_RCR2_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR2_ADDR, _MCBSP_RCR2_##Field, Val)

#define _MCBSP_RCR2_FAOI(Port, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR2_ADDR, _MCBSP_RCR2_##Field, AND,OR,INV)

#define _MCBSP_RCR2_CFG(Port,rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCR2_ADDR,\
               ( _MCBSP_RCR2_RPHASE_MK(rphase)          |\
                 _MCBSP_RCR2_RFRLEN2_MK(rfrlen2)        |\
                 _MCBSP_RCR2_RWDLEN2_MK(rwdlen2)        |\
                 _MCBSP_RCR2_RCOMPAND_MK(rcompand)      |\
                 _MCBSP_RCR2_RFIG_MK(rfig)              |\
                 _MCBSP_RCR2_RDATDLY_MK(rdatdly)         \
               )\
 )

#define _MCBSP_RCR20_GET                       _MCBSP_RCR2_GET(0)
#define _MCBSP_RCR20_SET(Val)                  _MCBSP_RCR2_SET(0,Val)
#define _MCBSP_RCR20_AOI(AND,OR,INV)           _MCBSP_RCR2_AOI(0,AND,OR,INV)
#define _MCBSP_RCR20_FGET(Field)               _MCBSP_RCR2_FGET(0,##Field)
#define _MCBSP_RCR20_FSET(Field,Val)           _MCBSP_RCR2_FSET(0,##Field,Val)
#define _MCBSP_RCR20_FAOI(Field,AND,OR,INV)    _MCBSP_RCR2_FAOI(0,##Field,AND,OR,INV)
#define _MCBSP_RCR20_CFG(rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)\
  _MCBSP_RCR2_CFG(0,rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)

#define _MCBSP_RCR21_GET                       _MCBSP_RCR2_GET(1)
#define _MCBSP_RCR21_SET(Val)                  _MCBSP_RCR2_SET(1,Val)
#define _MCBSP_RCR21_AOI(AND,OR,INV)           _MCBSP_RCR2_AOI(1,AND,OR,INV)
#define _MCBSP_RCR21_FGET(Field)               _MCBSP_RCR2_FGET(1,##Field)
#define _MCBSP_RCR21_FSET(Field,Val)           _MCBSP_RCR2_FSET(1,##Field,Val)
#define _MCBSP_RCR21_FAOI(Field,AND,OR,INV)        _MCBSP_RCR2_FAOI(1,##Field,AND,OR,INV)
#define _MCBSP_RCR21_CFG(rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)\
  _MCBSP_RCR2_CFG(1,rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_RCR22_GET                       _MCBSP_RCR2_GET(2)
  #define _MCBSP_RCR22_SET(Val)                  _MCBSP_RCR2_SET(2,Val)
  #define _MCBSP_RCR22_AOI(AND,OR,INV)           _MCBSP_RCR2_AOI(2,AND,OR,INV)
  #define _MCBSP_RCR22_FGET(Field)               _MCBSP_RCR2_FGET(2,##Field)
  #define _MCBSP_RCR22_FSET(Field,Val)           _MCBSP_RCR2_FSET(2,##Field,Val)
  #define _MCBSP_RCR22_FAOI(Field,AND,OR,INV)        _MCBSP_RCR2_FAOI(2,##Field,AND,OR,INV)
  #define _MCBSP_RCR22_CFG(rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)\
    _MCBSP_RCR2_CFG(2,rphase,rfrlen2,rwdlen2,rcompand,rfig,rdatdly)
#endif

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_RCR2_RPHASE: recieve phase
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR2_RPHASE_SHIFT      (0x000Fu)
#define _MCBSP_RCR2_RPHASE_MK(n)      (((Uint16)(n) & 0x0001u) << _MCBSP_RCR2_RPHASE_SHIFT)
#define _MCBSP_RCR2_RPHASE_MASK       (_MCBSP_RCR2_RPHASE_MK(1))
#define _MCBSP_RCR2_RPHASE_CLR        (~(_MCBSP_RCR2_RPHASE_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCR2_RFRLEN2: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR2_RFRLEN2_SHIFT     (0x0008u)
#define _MCBSP_RCR2_RFRLEN2_MK(n)     (((Uint16)(n) & 0x007fu) << _MCBSP_RCR2_RFRLEN2_SHIFT)
#define _MCBSP_RCR2_RFRLEN2_MASK      (_MCBSP_RCR2_RFRLEN2_MK(0x7fu))
#define _MCBSP_RCR2_RFRLEN2_CLR       (~(_MCBSP_RCR2_RFRLEN2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCR2_RWDLEN2: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR2_RWDLEN2_SHIFT     (0x0005u)
#define _MCBSP_RCR2_RWDLEN2_MK(n)     (((Uint16)(n) & 0x0007u) << _MCBSP_RCR2_RWDLEN2_SHIFT)
#define _MCBSP_RCR2_RWDLEN2_MASK      (_MCBSP_RCR2_RWDLEN2_MK(7))
#define _MCBSP_RCR2_RWDLEN2_CLR       (~(_MCBSP_RCR2_RWDLEN2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCR2_RCOMPAND: recieve companding mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR2_RCOMPAND_SHIFT    (0x0003u)
#define _MCBSP_RCR2_RCOMPAND_MK(n)    (((Uint16)(n) & 0x0003u) << _MCBSP_RCR2_RCOMPAND_SHIFT)
#define _MCBSP_RCR2_RCOMPAND_MASK     (_MCBSP_RCR2_RCOMPAND_MK(3))
#define _MCBSP_RCR2_RCOMPAND_CLR      (~(_MCBSP_RCR2_RCOMPAND_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCR2_RFIG: recieve frame sync ignore bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR2_RFIG_SHIFT        (0x0002u)
#define _MCBSP_RCR2_RFIG_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_RCR2_RFIG_SHIFT)
#define _MCBSP_RCR2_RFIG_MASK         (_MCBSP_RCR2_RFIG_MK(1))
#define _MCBSP_RCR2_RFIG_CLR          (~(_MCBSP_RCR2_RFIG_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCR2_RDATDLY: recieve frame sync ignore bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCR2_RDATDLY_SHIFT     (0x0000u)
#define _MCBSP_RCR2_RDATDLY_MK(n)     (((Uint16)(n) & 0x0003u) << _MCBSP_RCR2_RDATDLY_SHIFT)
#define _MCBSP_RCR2_RDATDLY_MASK      (_MCBSP_RCR2_RDATDLY_MK(3))
#define _MCBSP_RCR2_RDATDLY_CLR       (~(_MCBSP_RCR2_RDATDLY_MASK))


/*============================================================================*\
* _MCBSP_XCR1 : MCBSP Recieve Control Register #1
*
* Fields:
* (RW) _MCBSP_XCR1_XFRLEN1
* (RW) _MCBSP_XCR1_XWDLEN1
* 
\*============================================================================*/

#define _MCBSP_XCR1_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR1)

#define _MCBSP_XCR1_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR1, Val)

#define _MCBSP_XCR1_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR1, AND,OR,INV)

#define _MCBSP_XCR1_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR1, _MCBSP_XCR1_##Field)

#define _MCBSP_XCR1_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR1, _MCBSP_XCR1_##Field, Val)

#define _MCBSP_XCR1_FAOI(Port, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR1, _MCBSP_XCR1_##Field, AND,OR,INV)

#define _MCBSP_XCR1_CFG(Port, xfrlen1,xwdlen1)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR1,\
     ( _MCBSP_XCR1_XFRLEN1_MK(xfrlen1)  |\
       _MCBSP_XCR1_XWDLEN1_MK(xwdlen1)  \
     )\
  )

#define _MCBSP_XCR10_GET                       _MCBSP_XCR1_GET(0)
#define _MCBSP_XCR10_SET(Val)                  _MCBSP_XCR1_SET(0,Val)
#define _MCBSP_XCR10_AOI(AND,OR,INV)           _MCBSP_XCR1_AOI(0,AND,OR,INV)
#define _MCBSP_XCR10_FGET(Field)               _MCBSP_XCR1_FGET(0,##Field)
#define _MCBSP_XCR10_FSET(Field,Val)           _MCBSP_XCR1_FSET(0,##Field,Val)
#define _MCBSP_XCR10_FAOI(Field,AND,OR,INV)    _MCBSP_XCR1_FAOI(0,##Field,AND,OR,INV)
#define _MCBSP_XCR10_CFG(xfrlen1,xwdlen1)      _MCBSP_XCR1_CFG(0, xfrlen1,xwdlen1)

#define _MCBSP_XCR11_GET                       _MCBSP_XCR1_GET(1)
#define _MCBSP_XCR11_SET(Val)                  _MCBSP_XCR1_SET(1,Val)
#define _MCBSP_XCR11_AOI(AND,OR,INV)           _MCBSP_XCR1_AOI(1,AND,OR,INV)
#define _MCBSP_XCR11_FGET(Field)               _MCBSP_XCR1_FGET(1,##Field)
#define _MCBSP_XCR11_FSET(Field,Val)           _MCBSP_XCR1_FSET(1,##Field,Val)
#define _MCBSP_XCR11_FAOI(Field,AND,OR,INV)    _MCBSP_XCR1_FAOI(1,##Field,AND,OR,INV)
#define _MCBSP_XCR11_CFG(xfrlen1,xwdlen1)      _MCBSP_XCR1_CFG(1, xfrlen1,xwdlen1)

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_XCR12_GET                     _MCBSP_XCR1_GET(2)
  #define _MCBSP_XCR12_SET(Val)                _MCBSP_XCR1_SET(2,Val)
  #define _MCBSP_XCR12_AOI(AND,OR,INV)         _MCBSP_XCR1_AOI(2,AND,OR,INV)
  #define _MCBSP_XCR12_FGET(Field)             _MCBSP_XCR1_FGET(2,##Field)
  #define _MCBSP_XCR12_FSET(Field,Val)         _MCBSP_XCR1_FSET(2,##Field,Val)
  #define _MCBSP_XCR12_FAOI(Field,AND,OR,INV)  _MCBSP_XCR1_FAOI(2,##Field,AND,OR,INV)
  #define _MCBSP_XCR12_CFG(xfrlen1,xwdlen1)    _MCBSP_XCR1_CFG(2, xfrlen1,xwdlen1)
#endif
/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCR1_XFRLEN1: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR1_XFRLEN1_SHIFT     (0x0008u)
#define _MCBSP_XCR1_XFRLEN1_MK(n)     (((Uint16)(n) & 0x007fu) << _MCBSP_XCR1_XFRLEN1_SHIFT)
#define _MCBSP_XCR1_XFRLEN1_MASK      (_MCBSP_XCR1_XFRLEN1_MK(0x7fu))
#define _MCBSP_XCR1_XFRLEN1_CLR       (~(_MCBSP_XCR1_XFRLEN1_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCR1_XWDLEN1: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR1_XWDLEN1_SHIFT     (0x0005u)
#define _MCBSP_XCR1_XWDLEN1_MK(n)     (((Uint16)(n) & 0x0007u) << _MCBSP_XCR1_XWDLEN1_SHIFT)
#define _MCBSP_XCR1_XWDLEN1_MASK      (_MCBSP_XCR1_XWDLEN1_MK(7))
#define _MCBSP_XCR1_XWDLEN1_CLR       (~(_MCBSP_XCR1_XWDLEN1_MASK))

/*============================================================================*\
* _MCBSP_XCR2 : MCBSP Recieve Control Register #2
*
* Fields:
* (RW) _MCBSP_XCR2_XPHASE
* (RW) _MCBSP_XCR2_XFRLEN2
* (RW) _MCBSP_XCR2_XWDLEN2
* (RW) _MCBSP_XCR2_XCOMPAND
* (RW) _MCBSP_XCR2_XFIG
* (RW) _MCBSP_XCR2_XDATDLY
* 
\*============================================================================*/

/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/

#define _MCBSP_XCR2_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR2)

#define _MCBSP_XCR2_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR2, Val)

#define _MCBSP_XCR2_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR2, AND,OR,INV)

#define _MCBSP_XCR2_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR2, _MCBSP_XCR2_##Field)

#define _MCBSP_XCR2_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR2, _MCBSP_XCR2_##Field, Val)

#define _MCBSP_XCR2_FAOI(Port, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR2, _MCBSP_XCR2_##Field, AND,OR,INV)

#define _MCBSP_XCR2_CFG(Port,xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _XCR2,\
               ( _MCBSP_XCR2_XPHASE_MK(xphase)          |\
                 _MCBSP_XCR2_XFRLEN2_MK(xfrlen2)        |\
                 _MCBSP_XCR2_XWDLEN2_MK(xwdlen2)        |\
                 _MCBSP_XCR2_XCOMPAND_MK(xcompand)      |\
                 _MCBSP_XCR2_XFIG_MK(xfig)              |\
                 _MCBSP_XCR2_XDATDLY_MK(xdatdly)        \
               )\
 )

#define _MCBSP_XCR20_GET                       _MCBSP_XCR2_GET(0)
#define _MCBSP_XCR20_SET(Val)                  _MCBSP_XCR2_SET(0,Val)
#define _MCBSP_XCR20_AOI(AND,OR,INV)           _MCBSP_XCR2_AOI(0,AND,OR,INV)
#define _MCBSP_XCR20_FGET(Field)               _MCBSP_XCR2_FGET(0,##Field)
#define _MCBSP_XCR20_FSET(Field,Val)           _MCBSP_XCR2_FSET(0,##Field,Val)
#define _MCBSP_XCR20_FAOI(Field,AND,OR,INV)    _MCBSP_XCR2_FAOI(0,##Field,AND,OR,INV)
#define _MCBSP_XCR20_CFG(Port,xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)\
  _MCBSP_XCR2_CFG(0,xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)

#define _MCBSP_XCR21_GET                       _MCBSP_XCR2_GET(1)
#define _MCBSP_XCR21_SET(Val)                  _MCBSP_XCR2_SET(1,Val)
#define _MCBSP_XCR21_AOI(AND,OR,INV)           _MCBSP_XCR2_AOI(1,AND,OR,INV)
#define _MCBSP_XCR21_FGET(Field)               _MCBSP_XCR2_FGET(1,##Field)
#define _MCBSP_XCR21_FSET(Field,Val)           _MCBSP_XCR2_FSET(1,##Field,Val)
#define _MCBSP_XCR21_FAOI(Field,AND,OR,INV)    _MCBSP_XCR2_FAOI(1,##Field,AND,OR,INV)
#define _MCBSP_XCR21_CFG(Port,xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)\
  _MCBSP_XCR2_CFG(1,xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_XCR22_GET                     _MCBSP_XCR2_GET(2)
  #define _MCBSP_XCR22_SET(Val)                _MCBSP_XCR2_SET(2,Val)
  #define _MCBSP_XCR22_AOI(AND,OR,INV)         _MCBSP_XCR2_AOI(2,AND,OR,INV)
  #define _MCBSP_XCR22_FGET(Field)             _MCBSP_XCR2_FGET(2,##Field)
  #define _MCBSP_XCR22_FSET(Field,Val)         _MCBSP_XCR2_FSET(2,##Field,Val)
  #define _MCBSP_XCR22_FAOI(Field,AND,OR,INV)  _MCBSP_XCR2_FAOI(2,##Field,AND,OR,INV)
  #define _MCBSP_XCR22_CFG(Port,xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)\
    _MCBSP_XCR2_CFG(2,xphase,xfrlen2,xwdlen2,xcompand,xfig,xdatdly)
#endif

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_XCR2_XPHASE: recieve phase
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR2_XPHASE_SHIFT    (0x000Fu)
#define _MCBSP_XCR2_XPHASE_MK(n)    (((Uint16)(n) & 0x0001u) << _MCBSP_XCR2_XPHASE_SHIFT)
#define _MCBSP_XCR2_XPHASE_MASK     (_MCBSP_XCR2_XPHASE_MK(1))
#define _MCBSP_XCR2_XPHASE_CLR      (~(_MCBSP_XCR2_XPHASE_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCR2_XFRLEN2: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR2_XFRLEN2_SHIFT    (0x0008u)
#define _MCBSP_XCR2_XFRLEN2_MK(n)    (((Uint16)(n) & 0x007fu) << _MCBSP_XCR2_XFRLEN2_SHIFT)
#define _MCBSP_XCR2_XFRLEN2_MASK     (_MCBSP_XCR2_XFRLEN2_MK(0x7fu))
#define _MCBSP_XCR2_XFRLEN2_CLR      (~(_MCBSP_XCR2_XFRLEN2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCR2_XWDLEN2: recieve frame length (1/2 actual size)
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR2_XWDLEN2_SHIFT    (0x0005u)
#define _MCBSP_XCR2_XWDLEN2_MK(n)    (((Uint16)(n) & 0x0007u) << _MCBSP_XCR2_XWDLEN2_SHIFT)
#define _MCBSP_XCR2_XWDLEN2_MASK     (_MCBSP_XCR2_XWDLEN2_MK(7))
#define _MCBSP_XCR2_XWDLEN2_CLR      (~(_MCBSP_XCR2_XWDLEN2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCR2_XCOMPAND: recieve companding mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR2_XCOMPAND_SHIFT    (0x0003u)
#define _MCBSP_XCR2_XCOMPAND_MK(n)    (((Uint16)(n) & 0x0003u) << _MCBSP_XCR2_XCOMPAND_SHIFT)
#define _MCBSP_XCR2_XCOMPAND_MASK     (_MCBSP_XCR2_XCOMPAND_MK(3))
#define _MCBSP_XCR2_XCOMPAND_CLR      (~(_MCBSP_XCR2_XCOMPAND_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCR2_XFIG: recieve frame sync ignore bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR2_XFIG_SHIFT        (0x0002u)
#define _MCBSP_XCR2_XFIG_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_XCR2_XFIG_SHIFT)
#define _MCBSP_XCR2_XFIG_MASK         (_MCBSP_XCR2_XFIG_MK(1))
#define _MCBSP_XCR2_XFIG_CLR          (~(_MCBSP_XCR2_XFIG_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCR2_XDATDLY: recieve frame sync ignore bit
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCR2_XDATDLY_SHIFT    (0x0000u)
#define _MCBSP_XCR2_XDATDLY_MK(n)    (((Uint16)(n) & 0x0003u) << _MCBSP_XCR2_XDATDLY_SHIFT)
#define _MCBSP_XCR2_XDATDLY_MASK     (_MCBSP_XCR2_XDATDLY_MK(3))
#define _MCBSP_XCR2_XDATDLY_CLR      (~(_MCBSP_XCR2_XDATDLY_MASK))

/*============================================================================*\
* _MCBSP_SRGR1 : MCBSP Sample Rate Generator Register #1
*
* Fields:
* (RW) _MCBSP_SRGR1_FWID
* (RW) _MCBSP_SRGR1_CLKGDV
* 
\*============================================================================*/

/*-----------------------------------------------------------------------------*\
* Register Macros:
\*-----------------------------------------------------------------------------*/

#define _MCBSP_SRGR1_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR1_ADDR)

#define _MCBSP_SRGR1_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR1_ADDR, Val)

#define _MCBSP_SRGR1_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR1_ADDR, AND,OR,INV)

#define _MCBSP_SRGR1_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR1_ADDR, _MCBSP_SRGR1_##Field)

#define _MCBSP_SRGR1_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR1_ADDR, _MCBSP_SRGR1_##Field, Val)

#define _MCBSP_SRGR1_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR1_ADDR, _MCBSP_SRGR1_##Field, AND,OR,INV)

#define _MCBSP_SRGR1_CFG(Port,fwid,clkgdv)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR1_ADDR,\
     ( _MCBSP_SRGR1_FWID_MK(fwid)     |\
       _MCBSP_SRGR1_CLKGDV_MK(clkgdv) \
     )\
)

#define _MCBSP_SRGR10_GET                       _MCBSP_SRGR1_GET(0)
#define _MCBSP_SRGR10_SET(Val)                  _MCBSP_SRGR1_SET(0,Val)
#define _MCBSP_SRGR10_AOI(AND,OR,INV)           _MCBSP_SRGR1_AOI(0,AND,OR,INV)
#define _MCBSP_SRGR10_FGET(Field)               _MCBSP_SRGR1_FGET(0,##Field)
#define _MCBSP_SRGR10_FSET(Field,Val)           _MCBSP_SRGR1_FSET(0,##Field,Val)
#define _MCBSP_SRGR10_FAOI(Field,AND,OR,INV)    _MCBSP_SRGR1_FAOI(0,##Field,AND,OR,INV)
#define _MCBSP_SRGR10_CFG(fwid,clkgdv)          _MCBSP_SRGR1_CFG(0,fwid,clkgdv)

#define _MCBSP_SRGR11_GET                       _MCBSP_SRGR1_GET(1)
#define _MCBSP_SRGR11_SET(Val)                  _MCBSP_SRGR1_SET(1,Val)
#define _MCBSP_SRGR11_AOI(AND,OR,INV)           _MCBSP_SRGR1_AOI(1,AND,OR,INV)
#define _MCBSP_SRGR11_FGET(Field)               _MCBSP_SRGR1_FGET(1,##Field)
#define _MCBSP_SRGR11_FSET(Field,Val)           _MCBSP_SRGR1_FSET(1,##Field,Val)
#define _MCBSP_SRGR11_FAOI(Field,AND,OR,INV)    _MCBSP_SRGR1_FAOI(1,##Field,AND,OR,INV)
#define _MCBSP_SRGR11_CFG(fwid,clkgdv)          _MCBSP_SRGR1_CFG(1,fwid,clkgdv)

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_SRGR12_GET                       _MCBSP_SRGR1_GET(2)
  #define _MCBSP_SRGR12_SET(Val)                  _MCBSP_SRGR1_SET(2,Val)
  #define _MCBSP_SRGR12_AOI(AND,OR,INV)           _MCBSP_SRGR1_AOI(2,AND,OR,INV)
  #define _MCBSP_SRGR12_FGET(Field)               _MCBSP_SRGR1_FGET(2,##Field)
  #define _MCBSP_SRGR12_FSET(Field,Val)           _MCBSP_SRGR1_FSET(2,##Field,Val)
  #define _MCBSP_SRGR12_FAOI(Field,AND,OR,INV)    _MCBSP_SRGR1_FAOI(2,##Field,AND,OR,INV)
  #define _MCBSP_SRGR12_CFG(fwid,clkgdv)          _MCBSP_SRGR1_CFG(2,fwid,clkgdv)
#endif

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_SRGR1_FWID: frame width
\*----------------------------------------------------------------------------*/
#define _MCBSP_SRGR1_FWID_SHIFT       (0x0008u)
#define _MCBSP_SRGR1_FWID_MK(n)       (((Uint16)(n) & 0x00ffu) << _MCBSP_SRGR1_FWID_SHIFT)
#define _MCBSP_SRGR1_FWID_MASK        (_MCBSP_SRGR1_FWID_MK(0xffu))
#define _MCBSP_SRGR1_FWID_CLR         (~(_MCBSP_SRGR1_FWID_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_SRGR1_CLKGDV: sample rate generator clock divider
\*----------------------------------------------------------------------------*/
#define _MCBSP_SRGR1_CLKGDV_SHIFT     (0x0000u)
#define _MCBSP_SRGR1_CLKGDV_MK(n)     (((Uint16)(n) & 0x00ffu) << _MCBSP_SRGR1_CLKGDV_SHIFT)
#define _MCBSP_SRGR1_CLKGDV_MASK      (_MCBSP_SRGR1_CLKGDV_MK(0xffu))
#define _MCBSP_SRGR1_CLKGDV_CLR       (~(_MCBSP_SRGR1_CLKGDV_MASK))

/*============================================================================*\
* _MCBSP_SRGR2 : MCBSP Sample Rate Generator Register #2
*
* Fields:
* (RW) _MCBSP_SRGR2_GSYNC
* (RW) _MCBSP_SRGR2_CLKSP
* (RW) _MCBSP_SRGR2_CLKSM
* (RW) _MCBSP_SRGR2_FSGM
* (RW) _MCBSP_SRGR2_FPER
* 
\*============================================================================*/

/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/

#define _MCBSP_SRGR2_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR2_ADDR)

#define _MCBSP_SRGR2_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR2_ADDR, Val)

#define _MCBSP_SRGR2_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR2_ADDR, AND,OR,INV)

#define _MCBSP_SRGR2_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR2_ADDR, _MCBSP_SRGR2_##Field)

#define _MCBSP_SRGR2_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR2_ADDR, _MCBSP_SRGR2_##Field, Val)

#define _MCBSP_SRGR2_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR2_ADDR, _MCBSP_SRGR2_##Field, AND,OR,INV)

#define _MCBSP_SRGR2_CFG(Port,gsync,clksp,clksm,fsgm,fper)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_SRGR2_ADDR,\
               ( _MCBSP_SRGR2_GSYNC_MK(gsync)          |\
                 _MCBSP_SRGR2_CLKSP_MK(clksp)          |\
                 _MCBSP_SRGR2_CLKSM_MK(clksm)          |\
                 _MCBSP_SRGR2_FSGM_MK(fsgm)            |\
                 _MCBSP_SRGR2_FPER_MK(fper)            \
                )\
   )

#define _MCBSP_SRGR20_GET                       _MCBSP_SRGR2_GET(0)
#define _MCBSP_SRGR20_SET(Val)                  _MCBSP_SRGR2_SET(0,Val)
#define _MCBSP_SRGR20_AOI(AND,OR,INV)           _MCBSP_SRGR2_AOI(0,AND,OR,INV)
#define _MCBSP_SRGR20_FGET(Field)               _MCBSP_SRGR2_FGET(0,##Field)
#define _MCBSP_SRGR20_FSET(Field,Val)           _MCBSP_SRGR2_FSET(0,##Field,Val)
#define _MCBSP_SRGR20_FAOI(Field,AND,OR,INV)    _MCBSP_SRGR2_FAOI(0,##Field,AND,OR,INV)
#define _MCBSP_SRGR20_CFG(gsync,clksp,clksm,fsgm,fper)\
  _MCBSP_SRGR2_CFG(0,gsync,clksp,clksm,fsgm,fper)

#define _MCBSP_SRGR21_GET                       _MCBSP_SRGR2_GET(1)
#define _MCBSP_SRGR21_SET(Val)                  _MCBSP_SRGR2_SET(1,Val)
#define _MCBSP_SRGR21_AOI(AND,OR,INV)           _MCBSP_SRGR2_AOI(1,AND,OR,INV)
#define _MCBSP_SRGR21_FGET(Field)               _MCBSP_SRGR2_FGET(1,##Field)
#define _MCBSP_SRGR21_FSET(Field,Val)           _MCBSP_SRGR2_FSET(1,##Field,Val)
#define _MCBSP_SRGR21_FAOI(Field,AND,OR,INV)    _MCBSP_SRGR2_FAOI(1,##Field,AND,OR,INV)
#define _MCBSP_SRGR21_CFG(gsync,clksp,clksm,fsgm,fper)\
  _MCBSP_SRGR2_CFG(1,gsync,clksp,clksm,fsgm,fper)

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_SRGR22_GET                       _MCBSP_SRGR2_GET(2)
  #define _MCBSP_SRGR22_SET(Val)                  _MCBSP_SRGR2_SET(2,Val)
  #define _MCBSP_SRGR22_AOI(AND,OR,INV)           _MCBSP_SRGR2_AOI(2,AND,OR,INV)
  #define _MCBSP_SRGR22_FGET(Field)               _MCBSP_SRGR2_FGET(2,##Field)
  #define _MCBSP_SRGR22_FSET(Field,Val)           _MCBSP_SRGR2_FSET(2,##Field,Val)
  #define _MCBSP_SRGR22_FAOI(Field,AND,OR,INV)    _MCBSP_SRGR2_FAOI(2,##Field,AND,OR,INV)
  #define _MCBSP_SRGR22_CFG(gsync,clksp,clksm,fsgm,fper)\
    _MCBSP_SRGR2_CFG(2,gsync,clksp,clksm,fsgm,fper)
#endif
/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SRGR2_GSYNC: clock synchronization
\*----------------------------------------------------------------------------*/
#define _MCBSP_SRGR2_GSYNC_SHIFT        (0x000fu)
#define _MCBSP_SRGR2_GSYNC_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_SRGR2_GSYNC_SHIFT)
#define _MCBSP_SRGR2_GSYNC_MASK         (_MCBSP_SRGR2_GSYNC_MK(1))
#define _MCBSP_SRGR2_GSYNC_CLR          (~(_MCBSP_SRGR2_GSYNC_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SRGR2_CLKSP: clock polarity select
\*----------------------------------------------------------------------------*/
#define _MCBSP_SRGR2_CLKSP_SHIFT        (0x000eu)
#define _MCBSP_SRGR2_CLKSP_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_SRGR2_CLKSP_SHIFT)
#define _MCBSP_SRGR2_CLKSP_MASK         (_MCBSP_SRGR2_CLKSP_MK(1))
#define _MCBSP_SRGR2_CLKSP_CLR          (~(_MCBSP_SRGR2_CLKSP_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SRGR2_CLKSM: clock mode select
\*----------------------------------------------------------------------------*/
#define _MCBSP_SRGR2_CLKSM_SHIFT        (0x000du)
#define _MCBSP_SRGR2_CLKSM_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_SRGR2_CLKSM_SHIFT)
#define _MCBSP_SRGR2_CLKSM_MASK         (_MCBSP_SRGR2_CLKSM_MK(1))
#define _MCBSP_SRGR2_CLKSM_CLR          (~(_MCBSP_SRGR2_CLKSM_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_SRGR2_FSGM: transmit frame sync mode
\*----------------------------------------------------------------------------*/
#define _MCBSP_SRGR2_FSGM_SHIFT        (0x000cu)
#define _MCBSP_SRGR2_FSGM_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_SRGR2_FSGM_SHIFT)
#define _MCBSP_SRGR2_FSGM_MASK         (_MCBSP_SRGR2_FSGM_MK(1))
#define _MCBSP_SRGR2_FSGM_CLR          (~(_MCBSP_SRGR2_FSGM_MASK))

/*----------------------------------------------------------------------------*\
* (R) _MCBSP_SRGR2_FPER: sample rate generator clock divider
\*----------------------------------------------------------------------------*/
#define _MCBSP_SRGR2_FPER_SHIFT        (0x0000u)
#define _MCBSP_SRGR2_FPER_MK(n)        (((Uint16)(n) & 0x0fffu) << _MCBSP_SRGR2_FPER_SHIFT)
#define _MCBSP_SRGR2_FPER_MASK         (_MCBSP_SRGR2_FPER_MK(0xfffu))
#define _MCBSP_SRGR2_FPER_CLR          (~(_MCBSP_SRGR2_FPER_MASK))

/*============================================================================*\
* _MCBSP_MCR1 : MCBSP Multi-Channel Control Register #1
*
* Fields:
* (RW) _MCBSP_MCR1_RMCME     (only present on 5416,5411/5412,5421,5440,5441,5409A,5410A)
* (RW) _MCBSP_MCR1_RPBBLK
* (RW) _MCBSP_MCR1_RPABLK
* (RW) _MCBSP_MCR1_RPCBLK
* (RW) _MCBSP_MCR1_RMCM
* 
\*============================================================================*/

/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/

#define _MCBSP_MCR1_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR)

#define _MCBSP_MCR1_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR, Val)

#define _MCBSP_MCR1_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR, AND,OR,INV)

#define _MCBSP_MCR1_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR, _MCBSP_MCR1_##Field)

#define _MCBSP_MCR1_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR, _MCBSP_MCR1_##Field, Val)

#define _MCBSP_MCR1_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR, _MCBSP_MCR1_##Field, AND,OR,INV)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_MCR1_CFG(Port,rmcme, rpbblk, rpablk, rpcblk, rmcm)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR,\
               ( _MCBSP_MCR1_RMCME_MK(rmcme)       |\
                 _MCBSP_MCR1_RPBBLK_MK(rpbblk)     |\
                 _MCBSP_MCR1_RPABLK_MK(rpablk)     |\
                 _MCBSP_MCR1_RPCBLK_MK(rpcblk)     |\
                 _MCBSP_MCR1_RMCM_MK(rmcm)         \
                )\
    )

#else
  #define _MCBSP_MCR1_CFG(Port,rpbblk, rpablk, rpcblk, rmcm)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR1_ADDR,\
               ( _MCBSP_MCR1_RPBBLK_MK(rpbblk)     |\
                 _MCBSP_MCR1_RPABLK_MK(rpablk)     |\
                 _MCBSP_MCR1_RPCBLK_MK(rpcblk)     |\
                 _MCBSP_MCR1_RMCM_MK(rmcm)         \
                )\
    )
#endif

#define _MCBSP_MCR10_GET                       _MCBSP_MCR1_GET(0)
#define _MCBSP_MCR10_SET(Val)                  _MCBSP_MCR1_SET(0,Val)
#define _MCBSP_MCR10_AOI(AND,OR,INV)           _MCBSP_MCR1_AOI(0,AND,OR,INV)
#define _MCBSP_MCR10_FGET(Field)               _MCBSP_MCR1_FGET(0,##Field)
#define _MCBSP_MCR10_FSET(Field,Val)           _MCBSP_MCR1_FSET(0,##Field,Val)
#define _MCBSP_MCR10_FAOI(Field,AND,OR,INV)    _MCBSP_MCR1_FAOI(0,##Field,AND,OR,INV)
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_MCR10_CFG(rmcme, rpbblk, rpablk, rpcblk, rmcm)\
    _MCBSP_MCR1_CFG(0,rmcme, rpbblk, rpablk, rpcblk, rmcm)
#else
  #define _MCBSP_MCR10_CFG(rpbblk, rpablk, rpcblk, rmcm)\
    _MCBSP_MCR1_CFG(0,rpbblk, rpablk, rpcblk, rmcm)
#endif

#define _MCBSP_MCR11_GET                      _MCBSP_MCR1_GET(1)
#define _MCBSP_MCR11_SET(Val)                  _MCBSP_MCR1_SET(1,Val)
#define _MCBSP_MCR11_AOI(AND,OR,INV)           _MCBSP_MCR1_AOI(1,AND,OR,INV)
#define _MCBSP_MCR11_FGET(Field)               _MCBSP_MCR1_FGET(1,##Field)
#define _MCBSP_MCR11_FSET(Field,Val)           _MCBSP_MCR1_FSET(1,##Field,Val)
#define _MCBSP_MCR11_FAOI(Field,AND,OR,INV)    _MCBSP_MCR1_FAOI(1,##Field,AND,OR,INV)
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_MCR11_CFG(rmcme, rpbblk, rpablk, rpcblk, rmcm)\
    _MCBSP_MCR1_CFG(1,rmcme, rpbblk, rpablk, rpcblk, rmcm)
#else
  #define _MCBSP_MCR11_CFG(rpbblk, rpablk, rpcblk, rmcm)\
    _MCBSP_MCR1_CFG(1,rpbblk, rpablk, rpcblk, rmcm)
#endif

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_MCR12_GET                       _MCBSP_MCR1_GET(2)
  #define _MCBSP_MCR12_SET(Val)                  _MCBSP_MCR1_SET(2,Val)
  #define _MCBSP_MCR12_AOI(AND,OR,INV)           _MCBSP_MCR1_AOI(2,AND,OR,INV)
  #define _MCBSP_MCR12_FGET(Field)               _MCBSP_MCR1_FGET(2,##Field)
  #define _MCBSP_MCR12_FSET(Field,Val)           _MCBSP_MCR1_FSET(2,##Field,Val)
  #define _MCBSP_MCR12_FAOI(Field,AND,OR,INV)    _MCBSP_MCR1_FAOI(2,##Field,AND,OR,INV)
  #if (_MCBSP_128_CH_ENABLE_SUPPORT)
    #define _MCBSP_MCR12_CFG(rmcme, rpbblk, rpablk, rpcblk, rmcm)\
      _MCBSP_MCR1_CFG(2,rmcme, rpbblk, rpablk, rpcblk, rmcm)
  #else
    #define _MCBSP_MCR12_CFG(rpbblk, rpablk, rpcblk, rmcm)\
      _MCBSP_MCR1_CFG(2,rpbblk, rpablk, rpcblk, rmcm)
  #endif
#endif

//----------------------------------------------------------------------------
// End Register Macros
//----------------------------------------------------------------------------
#if (_MCBSP_128_CH_ENABLE_SUPPORT)

   /*----------------------------------------------------------------------------*\
   * (RW) _MCBSP_MCR1_RMCME: enable channel select for all 128 channels
   \*----------------------------------------------------------------------------*/
   #define _MCBSP_MCR1_RMCME_SHIFT        (0x0009u)
   #define _MCBSP_MCR1_RMCME_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_MCR1_RMCME_SHIFT)
   #define _MCBSP_MCR1_RMCME_MASK         (_MCBSP_MCR1_RMCME_MK(1))
   #define _MCBSP_MCR1_RMCME_CLR          (~(_MCBSP_MCR1_RMCME_MASK))

#endif

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR1_RPBBLK: receive partition B block
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR1_RPBBLK_SHIFT         (0x0007u)
#define _MCBSP_MCR1_RPBBLK_MK(n)         (((Uint16)(n) & 0x0003u) << _MCBSP_MCR1_RPBBLK_SHIFT)
#define _MCBSP_MCR1_RPBBLK_MASK          (_MCBSP_MCR1_RPBBLK_MK(3))
#define _MCBSP_MCR1_RPBBLK_CLR           (~(_MCBSP_MCR1_RPBBLK_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR1_RPABLK: receive partition A block
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR1_RPABLK_SHIFT         (0x0005u)
#define _MCBSP_MCR1_RPABLK_MK(n)         (((Uint16)(n) & 0x0003u) << _MCBSP_MCR1_RPABLK_SHIFT)
#define _MCBSP_MCR1_RPABLK_MASK          (_MCBSP_MCR1_RPABLK_MK(3))
#define _MCBSP_MCR1_RPABLK_CLR           (~(_MCBSP_MCR1_RPABLK_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR1_RPCBLK: receive current block
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR1_RPCBLK_SHIFT         (0x0002u)
#define _MCBSP_MCR1_RPCBLK_MK(n)         (((Uint16)(n) & 0x0007u) << _MCBSP_MCR1_RPCBLK_SHIFT)
#define _MCBSP_MCR1_RPCBLK_MASK          (_MCBSP_MCR1_RPCBLK_MK(7))
#define _MCBSP_MCR1_RPCBLK_CLR           (~(_MCBSP_MCR1_RPCBLK_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR1_RMCM: multi-channel selection enable
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR1_RMCM_SHIFT          (0x0000u)
#define _MCBSP_MCR1_RMCM_MK(n)          (((Uint16)(n) & 0x0001u) << _MCBSP_MCR1_RMCM_SHIFT)
#define _MCBSP_MCR1_RMCM_MASK           (_MCBSP_MCR1_RMCM_MK(1))
#define _MCBSP_MCR1_RMCM_CLR            (~(_MCBSP_MCR1_RMCM_MASK))

/*============================================================================*\
* _MCBSP_MCR2 : MCBSP Multi-Channel Control Register #2
*
* Fields:
* (RW) _MCBSP_MCR2_XMCME    available only on 5411,5412,5416,5421,5440,5441,5409A,5410A
* (RW) _MCBSP_MCR2_XPBBLK
* (RW) _MCBSP_MCR2_XPABLK
* (RW) _MCBSP_MCR2_XCBLK
* (RW) _MCBSP_MCR2_XMCM
* 
\*============================================================================*/

/*-----------------------------------------------------------------------------*\
* Register Macros:
\*-----------------------------------------------------------------------------*/

#define _MCBSP_MCR2_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR)

#define _MCBSP_MCR2_SET(Port, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR, Val)

#define _MCBSP_MCR2_AOI(Port, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR, AND,OR,INV)

#define _MCBSP_MCR2_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR, _MCBSP_MCR2_##Field)

#define _MCBSP_MCR2_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR, _MCBSP_MCR2_##Field, Val)

#define _MCBSP_MCR2_FAOI(Port, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR,MCR2, _MCBSP_MCR2_##Field, AND,OR,INV)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_MCR2_CFG(Port, xmcme, xpbblk, xpablk, xpcblk, xmcm)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR,\
               ( _MCBSP_MCR2_XMCME_MK(xmcme)       |\
                 _MCBSP_MCR2_XPBBLK_MK(xpbblk)     |\
                 _MCBSP_MCR2_XPABLK_MK(xpablk)     |\
                 _MCBSP_MCR2_XPCBLK_MK(xpcblk)     |\
                 _MCBSP_MCR2_XMCM_MK(xmcm)         \
               )\
    )

#else
  #define _MCBSP_MCR2_CFG(Port,xpbblk, xpablk, xpcblk, xmcm)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_MCR2_ADDR,\
               ( _MCBSP_MCR2_XPBBLK_MK(xpbblk)     |\
                 _MCBSP_MCR2_XPABLK_MK(xpablk)     |\
                 _MCBSP_MCR2_XPCBLK_MK(xpcblk)     |\
                 _MCBSP_MCR2_XMCM_MK(xmcm)         \
                )\
    )
#endif

#define _MCBSP_MCR20_GET                       _MCBSP_MCR2_GET(0)
#define _MCBSP_MCR20_SET(Val)                  _MCBSP_MCR2_SET(0,Val)
#define _MCBSP_MCR20_AOI(AND,OR,INV)           _MCBSP_MCR2_AOI(0,AND,OR,INV)
#define _MCBSP_MCR20_FGET(Field)               _MCBSP_MCR2_FGET(0,##Field)
#define _MCBSP_MCR20_FSET(Field,Val)           _MCBSP_MCR2_FSET(0,##Field,Val)
#define _MCBSP_MCR20_FAOI(Field,AND,OR,INV)    _MCBSP_MCR2_FAOI(0,##Field,AND,OR,INV)
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_MCR20_CFG(xmcme, xpbblk, xpablk, xpcblk, xmcm)\
     _MCBSP_MCR2_CFG(0, xmcme, xpbblk, xpablk, xpcblk, xmcm)
#else
  #define _MCBSP_MCR20_CFG(xpbblk, xpablk, xpcblk, xmcm)\
    _MCBSP_MCR2_CFG(0,xpbblk, xpablk, xpcblk, xmcm)
#endif

#define _MCBSP_MCR21_GET                       _MCBSP_MCR2_GET(1)
#define _MCBSP_MCR21_SET(Val)                  _MCBSP_MCR2_SET(1,Val)
#define _MCBSP_MCR21_AOI(AND,OR,INV)           _MCBSP_MCR2_AOI(1,AND,OR,INV)
#define _MCBSP_MCR21_FGET(Field)               _MCBSP_MCR2_FGET(1,##Field)
#define _MCBSP_MCR21_FSET(Field,Val)           _MCBSP_MCR2_FSET(1,##Field,Val)
#define _MCBSP_MCR21_FAOI(Field,AND,OR,INV)    _MCBSP_MCR2_FAOI(1,##Field,AND,OR,INV)
#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_MCR21_CFG(xmcme, xpbblk, xpablk, xpcblk, xmcm)\
     _MCBSP_MCR2_CFG(1, xmcme, xpbblk, xpablk, xpcblk, xmcm)
#else
  #define _MCBSP_MCR21_CFG(xpbblk, xpablk, xpcblk, xmcm)\
    _MCBSP_MCR2_CFG(1,xpbblk, xpablk, xpcblk, xmcm)
#endif

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_MCR22_GET                       _MCBSP_MCR2_GET(2)
  #define _MCBSP_MCR22_SET(Val)                  _MCBSP_MCR2_SET(2,Val)
  #define _MCBSP_MCR22_AOI(AND,OR,INV)           _MCBSP_MCR2_AOI(2,AND,OR,INV)
  #define _MCBSP_MCR22_FGET(Field)               _MCBSP_MCR2_FGET(2,##Field)
  #define _MCBSP_MCR22_FSET(Field,Val)           _MCBSP_MCR2_FSET(2,##Field,Val)
  #define _MCBSP_MCR22_FAOI(Field,AND,OR,INV)    _MCBSP_MCR2_FAOI(2,##Field,AND,OR,INV)
  #if (_MCBSP_128_CH_ENABLE_SUPPORT)
    #define _MCBSP_MCR22_CFG(xmcme, xpbblk, xpablk, xpcblk, xmcm)\
       _MCBSP_MCR2_CFG(2, xmcme, xpbblk, xpablk, xpcblk, xmcm)
  #else
    #define _MCBSP_MCR22_CFG(xpbblk, xpablk, xpcblk, xmcm)\
      _MCBSP_MCR2_CFG(2,xpbblk, xpablk, xpcblk, xmcm)
  #endif
#endif

//--------------------------------------------------------------------------
// End Register Macros
//--------------------------------------------------------------------------
#if (_MCBSP_128_CH_ENABLE_SUPPORT)

   /*----------------------------------------------------------------------------*\
   * (RW) _MCBSP_MCR2_XMCME: enable channel select for all 128 channels
   \*----------------------------------------------------------------------------*/
   #define _MCBSP_MCR2_XMCME_SHIFT        (0x0009u)
   #define _MCBSP_MCR2_XMCME_MK(n)        (((Uint16)(n) & 0x0001u) << _MCBSP_MCR2_XMCME_SHIFT)
   #define _MCBSP_MCR2_XMCME_MASK         (_MCBSP_MCR2_XMCME_MK(1))
   #define _MCBSP_MCR2_XMCME_CLR          (~(_MCBSP_MCR2_XMCME_MASK))

#endif

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR2_XPBBLK: transmit partition B block
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR2_XPBBLK_SHIFT          (0x0007u)
#define _MCBSP_MCR2_XPBBLK_MK(n)          (((Uint16)(n) & 0x0003u) << _MCBSP_MCR2_XPBBLK_SHIFT)
#define _MCBSP_MCR2_XPBBLK_MASK           (_MCBSP_MCR2_XPBBLK_MK(3))
#define _MCBSP_MCR2_XPBBLK_CLR            (~(_MCBSP_MCR2_XPBBLK_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR2_XPABLK: transmit partition A block
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR2_XPABLK_SHIFT          (0x0005u)
#define _MCBSP_MCR2_XPABLK_MK(n)          (((Uint16)(n) & 0x0003u) << _MCBSP_MCR2_XPABLK_SHIFT)
#define _MCBSP_MCR2_XPABLK_MASK           (_MCBSP_MCR2_XPABLK_MK(3))
#define _MCBSP_MCR2_XPABLK_CLR            (~(_MCBSP_MCR2_XPABLK_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR2_XPCBLK: transmit current block
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR2_XPCBLK_SHIFT         (0x0002u)
#define _MCBSP_MCR2_XPCBLK_MK(n)         (((Uint16)(n) & 0x0007u) << _MCBSP_MCR2_XPCBLK_SHIFT)
#define _MCBSP_MCR2_XPCBLK_MASK          (_MCBSP_MCR2_XPCBLK_MK(7))
#define _MCBSP_MCR2_XPCBLK_CLR           (~(_MCBSP_MCR2_XPCBLK_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_MCR2_XMCM: multi-channel selection enable
\*----------------------------------------------------------------------------*/
#define _MCBSP_MCR2_XMCM_SHIFT           (0x0000u)
#define _MCBSP_MCR2_XMCM_MK(n)           (((Uint16)(n) & 0x0003u) << _MCBSP_MCR2_XMCM_SHIFT)
#define _MCBSP_MCR2_XMCM_MASK            (_MCBSP_MCR2_XMCM_MK(3))
#define _MCBSP_MCR2_XMCM_CLR             (~(_MCBSP_MCR2_XMCM_MASK))

/*============================================================================*\
* _MCBSP_RCER: MCBSP Receive Channel Enable Register
*
* Fields:
* (RW) _MCBSP_RCER_RCE15
* (RW) _MCBSP_RCER_RCE14
* (RW) _MCBSP_RCER_RCE13
* (RW) _MCBSP_RCER_RCE12
* (RW) _MCBSP_RCER_RCE11
* (RW) _MCBSP_RCER_RCE10
* (RW) _MCBSP_RCER_RCE9
* (RW) _MCBSP_RCER_RCE8
* (RW) _MCBSP_RCER_RCE7
* (RW) _MCBSP_RCER_RCE6
* (RW) _MCBSP_RCER_RCE5
* (RW) _MCBSP_RCER_RCE4
* (RW) _MCBSP_RCER_RCE3
* (RW) _MCBSP_RCER_RCE2
* (RW) _MCBSP_RCER_RCE1
* (RW) _MCBSP_RCER_RCE0
* 
\*============================================================================*/
/*----------------------------------------------------------------------------*\
* RCER whole register masks/shift macros
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCERA_SHIFT         (0x0000u)
#define _MCBSP_RCER_RCERA_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCERA_SHIFT)
#define _MCBSP_RCER_RCERA_MASK          (_MCBSP_RCER_RCERA_MK(0xFFFFu))
#define _MCBSP_RCER_RCERA_CLR           (~(_MCBSP_RCER_RCERA_MASK))

#define _MCBSP_RCER_RCERB_SHIFT         (0x0000u)
#define _MCBSP_RCER_RCERB_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCERB_SHIFT)
#define _MCBSP_RCER_RCERB_MASK          (_MCBSP_RCER_RCERB_MK(0xFFFFu))
#define _MCBSP_RCER_RCERB_CLR           (~(_MCBSP_RCER_RCERB_MASK))

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_RCER_RCERC_SHIFT         (0x0000u)
  #define _MCBSP_RCER_RCERC_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCERC_SHIFT)
  #define _MCBSP_RCER_RCERC_MASK          (_MCBSP_RCER_RCERC_MK(0xFFFFu))
  #define _MCBSP_RCER_RCERC_CLR           (~(_MCBSP_RCER_RCERC_MASK))

  #define _MCBSP_RCER_RCERD_SHIFT         (0x0000u)
  #define _MCBSP_RCER_RCERD_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCERD_SHIFT)
  #define _MCBSP_RCER_RCERD_MASK          (_MCBSP_RCER_RCERD_MK(0xFFFFu))
  #define _MCBSP_RCER_RCERD_CLR           (~(_MCBSP_RCER_RCERD_MASK))

  #define _MCBSP_RCER_RCERE_SHIFT         (0x0000u)
  #define _MCBSP_RCER_RCERE_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCERE_SHIFT)
  #define _MCBSP_RCER_RCERE_MASK          (_MCBSP_RCER_RCERE_MK(0xFFFFu))
  #define _MCBSP_RCER_RCERE_CLR           (~(_MCBSP_RCER_RCERE_MASK))

  #define _MCBSP_RCER_RCERF_SHIFT         (0x0000u)
  #define _MCBSP_RCER_RCERF_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCERF_SHIFT)
  #define _MCBSP_RCER_RCERF_MASK          (_MCBSP_RCER_RCERF_MK(0xFFFFu))
  #define _MCBSP_RCER_RCERF_CLR           (~(_MCBSP_RCER_RCERF_MASK))

  #define _MCBSP_RCER_RCERG_SHIFT         (0x0000u) 
  #define _MCBSP_RCER_RCERG_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCERG_SHIFT)
  #define _MCBSP_RCER_RCERG_MASK          (_MCBSP_RCER_RCERG_MK(0xFFFFu))
  #define _MCBSP_RCER_RCERG_CLR           (~(_MCBSP_RCER_RCERG_MASK))
#endif  /* _MCBSP_128_CH_ENABLE_SUPPORT */

#define _MCBSP_RCERA_FIELD(Field)         _MCBSP_RCER_##Field
#define _MCBSP_RCERB_FIELD(Field)         _MCBSP_RCER_##Field

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_RCERC_FIELD(Field)        _MCBSP_RCER_##Field
  #define _MCBSP_RCERD_FIELD(Field)        _MCBSP_RCER_##Field
  #define _MCBSP_RCERE_FIELD(Field)        _MCBSP_RCER_##Field
  #define _MCBSP_RCERF_FIELD(Field)        _MCBSP_RCER_##Field
  #define _MCBSP_RCERG_FIELD(Field)        _MCBSP_RCER_##Field
#endif

/*----------------------------------------------------------------------------*\
* Register Macros:
\*----------------------------------------------------------------------------*/

#define _MCBSP_RCER_GET(Port, Reg)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_##Reg##_ADDR)

#define _MCBSP_RCER_SET(Port, Reg, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_##Reg##_ADDR, Val)

#define _MCBSP_RCER_AOI(Port, Reg, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_##Reg##_ADDR, AND,OR,INV)

#define _MCBSP_RCER_FGET(Port, Reg, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_##Reg##_ADDR, _MCBSP_RCER_##Field)

#define _MCBSP_RCER_FSET(Port, Reg, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_##Reg##_ADDR, _MCBSP_RCER_##Field , Val)

#define _MCBSP_RCER_FAOI(Port, Reg, Field, AND,OR,INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_##Reg##_ADDR, _MCBSP_RCER_##Field , AND,OR,INV)

#define _MCBSP_RCER_CFG(Port, Reg,\
                        rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,\
                        rc11,rc12,rc13,rc14,rc15)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_##Reg##_ADDR,\
            ( _MCBSP_RCER_RCE15_MK(rc15)          |\
              _MCBSP_RCER_RCE14_MK(rc14)          |\
              _MCBSP_RCER_RCE13_MK(rc13)          |\
              _MCBSP_RCER_RCE12_MK(rc12)          |\
              _MCBSP_RCER_RCE11_MK(rc11)          |\
              _MCBSP_RCER_RCE10_MK(rc10)          |\
              _MCBSP_RCER_RCE9_MK(rc9)            |\
              _MCBSP_RCER_RCE8_MK(rc8)            |\
              _MCBSP_RCER_RCE7_MK(rc7)            |\
              _MCBSP_RCER_RCE6_MK(rc6)            |\
              _MCBSP_RCER_RCE5_MK(rc5)            |\
              _MCBSP_RCER_RCE4_MK(rc4)            |\
              _MCBSP_RCER_RCE3_MK(rc3)            |\
              _MCBSP_RCER_RCE2_MK(rc2)            |\
              _MCBSP_RCER_RCE1_MK(rc1)            |\
              _MCBSP_RCER_RCE0_MK(rc0)            \
            )\
 )

// RCERA //
#define _MCBSP_RCERA_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERA_ADDR)

#define _MCBSP_RCERA_SET(Port,Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERA_ADDR, Val)

#define _MCBSP_RCERA_AOI(Port,AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERA_ADDR, AND,OR,INV)

#define _MCBSP_RCERA_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERA_ADDR, _MCBSP_RCER_##Field)

#define _MCBSP_RCERA_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERA_ADDR, _MCBSP_RCER_##Field, Val)

#define _MCBSP_RCERA_FAOI(Port, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERA_ADDR, _MCBSP_RCER_##Field , AND,OR,INV)

// RCERB //
#define _MCBSP_RCERB_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERB_ADDR)

#define _MCBSP_RCERB_SET(Port,Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERB_ADDR, Val)

#define _MCBSP_RCERB_AOI(Port,AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERB_ADDR, AND,OR,INV)

#define _MCBSP_RCERB_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERB_ADDR, _MCBSP_RCER_##Field)

#define _MCBSP_RCERB_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERB_ADDR, _MCBSP_RCER_##Field, Val)

#define _MCBSP_RCERB_FAOI(Port, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERB_ADDR, _MCBSP_RCER_##Field, AND,OR,INV)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  // RCERC //
  #define _MCBSP_RCERC_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERC_ADDR)

  #define _MCBSP_RCERC_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERC_ADDR, Val)

  #define _MCBSP_RCERC_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERC_ADDR, AND,OR,INV)

  #define _MCBSP_RCERC_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERC_ADDR, _MCBSP_RCER_##Field)

  #define _MCBSP_RCERC_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERC_ADDR, _MCBSP_RCER_##Field, Val)

  #define _MCBSP_RCERC_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERC_ADDR, _MCBSP_RCERC_##Field, AND,OR,INV)

  // RCERD //
  #define _MCBSP_RCERD_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERD_ADDR)

  #define _MCBSP_RCERD_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERD_ADDR, Val)

  #define _MCBSP_RCERD_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERD_ADDR, AND,OR,INV)

  #define _MCBSP_RCERD_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERD_ADDR, _MCBSP_RCER_##Field)

  #define _MCBSP_RCERD_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERD_ADDR, _MCBSP_RCER_##Field,  Val)

  #define _MCBSP_RCERD_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERD_ADDR, _MCBSP_RCER_##Field, AND,OR,INV)

  // RCERE //
  #define _MCBSP_RCERE_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERE_ADDR)

  #define _MCBSP_RCERE_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERE_ADDR, Val)

  #define _MCBSP_RCERE_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERE_ADDR, AND,OR,INV)

  #define _MCBSP_RCERE_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERE_ADDR, _MCBSP_RCER_##Field)

  #define _MCBSP_RCERE_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERE_ADDR, _MCBSP_RCER_##Field,  Val)

  #define _MCBSP_RCERE_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERE_ADDR, _MCBSP_RCER_##Field, AND,OR,INV)

  // RCERF //
  #define _MCBSP_RCERF_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERF_ADDR)

  #define _MCBSP_RCERF_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERF_ADDR, Val)

  #define _MCBSP_RCERF_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERF_ADDR, AND,OR,INV)

  #define _MCBSP_RCERF_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERF_ADDR, _MCBSP_RCER_##Field)

  #define _MCBSP_RCERF_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERF_ADDR, _MCBSP_RCER_##Field, Val)

  #define _MCBSP_RCERF_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERF_ADDR, _MCBSP_RCER_##Field, AND,OR,INV)

  // RCERG //
  #define _MCBSP_RCERG_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERG_ADDR)

  #define _MCBSP_RCERG_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERG_ADDR, Val)

  #define _MCBSP_RCERG_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERG_ADDR, AND,OR,INV)

  #define _MCBSP_RCERG_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERG_ADDR, _MCBSP_RCER_##Field)

  #define _MCBSP_RCERG_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERG_ADDR, _MCBSP_RCER_##Field,  Val)

  #define _MCBSP_RCERG_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERG_ADDR, _MCBSP_RCER_##Field, AND,OR,INV)

  // RCERH //
  #define _MCBSP_RCERH_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERH_ADDR)

  #define _MCBSP_RCERH_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERH_ADDR, Val)

  #define _MCBSP_RCERH_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERH_ADDR, AND,OR,INV)

  #define _MCBSP_RCERH_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERH_ADDR, _MCBSP_RCER_##Field)

  #define _MCBSP_RCERH_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERH_ADDR, _MCBSP_RCER_##Field, Val)

  #define _MCBSP_RCERH_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_RCERH_ADDR, _MCBSP_RCER_##Field, AND,OR,INV)
#endif

#define _MCBSP_RCERA0_GET                       _MCBSP_RCER_GET(0,RCERA)
#define _MCBSP_RCERA0_SET(Val)                  _MCBSP_RCER_SET(0,RCERA,Val)
#define _MCBSP_RCERA0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERA,AND,OR,INV)
#define _MCBSP_RCERA0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERA,##Field)
#define _MCBSP_RCERA0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERA,##Field,Val)
#define _MCBSP_RCERA0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERA,##Field,AND,OR,INV)
#define _MCBSP_RCERA0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_RCER_CFG(0, RCERA,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#define _MCBSP_RCERB0_GET                       _MCBSP_RCER_GET(0,RCERB)
#define _MCBSP_RCERB0_SET(Val)                  _MCBSP_RCER_SET(0,RCERB,Val)
#define _MCBSP_RCERB0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERB,AND,OR,INV)
#define _MCBSP_RCERB0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERB,##Field)
#define _MCBSP_RCERB0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERB,##Field,Val)
#define _MCBSP_RCERB0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERB,##Field,AND,OR,INV)
#define _MCBSP_RCERB0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_RCER_CFG(0, RCERB,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_RCERC0_GET                       _MCBSP_RCER_GET(0,RCERC)
  #define _MCBSP_RCERC0_SET(Val)                  _MCBSP_RCER_SET(0,RCERC,Val)
  #define _MCBSP_RCERC0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERC,AND,OR,INV)
  #define _MCBSP_RCERC0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERC,##Field)
  #define _MCBSP_RCERC0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERC,##Field,Val)
  #define _MCBSP_RCERC0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERC,##Field,AND,OR,INV)
  #define _MCBSP_RCERC0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(0, RCERC,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERD0_GET                       _MCBSP_RCER_GET(0,RCERD)
  #define _MCBSP_RCERD0_SET(Val)                  _MCBSP_RCER_SET(0,RCERD,Val)
  #define _MCBSP_RCERD0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERD,AND,OR,INV)
  #define _MCBSP_RCERD0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERD,##Field)
  #define _MCBSP_RCERD0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERD,##Field,Val)
  #define _MCBSP_RCERD0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERD,##Field,AND,OR,INV)
  #define _MCBSP_RCERD0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(0, RCERD,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERE0_GET                       _MCBSP_RCER_GET(0,RCERE) 
  #define _MCBSP_RCERE0_SET(Val)                  _MCBSP_RCER_SET(0,RCERE,Val)
  #define _MCBSP_RCERE0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERE,AND,OR,INV)
  #define _MCBSP_RCERE0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERE,##Field)
  #define _MCBSP_RCERE0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERE,##Field,Val)
  #define _MCBSP_RCERE0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERE,##Field,AND,OR,INV)
  #define _MCBSP_RCERE0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(0, RCERE,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERF0_GET                       _MCBSP_RCER_GET(0,RCERF)
  #define _MCBSP_RCERF0_SET(Val)                  _MCBSP_RCER_SET(0,RCERF,Val)
  #define _MCBSP_RCERF0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERF,AND,OR,INV)
  #define _MCBSP_RCERF0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERF,##Field)
  #define _MCBSP_RCERF0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERF,##Field,Val)
  #define _MCBSP_RCERF0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERF,##Field,AND,OR,INV)
  #define _MCBSP_RCERF0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(0, RCERF,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERG0_GET                       _MCBSP_RCER_GET(0,RCERG)
  #define _MCBSP_RCERG0_SET(Val)                  _MCBSP_RCER_SET(0,RCERG,Val)
  #define _MCBSP_RCERG0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERG,AND,OR,INV)
  #define _MCBSP_RCERG0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERG,##Field)
  #define _MCBSP_RCERG0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERG,##Field,Val)
  #define _MCBSP_RCERG0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERG,##Field,AND,OR,INV)
  #define _MCBSP_RCERG0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(0, RCERG,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERH0_GET                       _MCBSP_RCER_GET(0,RCERH)
  #define _MCBSP_RCERH0_SET(Val)                  _MCBSP_RCER_SET(0,RCERH,Val)
  #define _MCBSP_RCERH0_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(0,RCERH,AND,OR,INV)
  #define _MCBSP_RCERH0_FGET(Field)               _MCBSP_RCER_FGET(0,RCERH,##Field)
  #define _MCBSP_RCERH0_FSET(Field,Val)           _MCBSP_RCER_FSET(0,RCERH,##Field,Val)
  #define _MCBSP_RCERH0_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(0,RCERH,##Field,AND,OR,INV)
  #define _MCBSP_RCERH0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(0, RCERH,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)
#endif

#define _MCBSP_RCERA1_GET                       _MCBSP_RCER_GET(1,RCERA)
#define _MCBSP_RCERA1_SET(Val)                  _MCBSP_RCER_SET(1,RCERA,Val)
#define _MCBSP_RCERA1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERA,AND,OR,INV)
#define _MCBSP_RCERA1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERA,##Field)
#define _MCBSP_RCERA1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERA,##Field,Val)
#define _MCBSP_RCERA1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERA,##Field,AND,OR,INV)
#define _MCBSP_RCERA1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_RCER_CFG(1, RCERA,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#define _MCBSP_RCERB1_GET                       _MCBSP_RCER_GET(1,RCERB)
#define _MCBSP_RCERB1_SET(Val)                  _MCBSP_RCER_SET(1,RCERB,Val)
#define _MCBSP_RCERB1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERB,AND,OR,INV)
#define _MCBSP_RCERB1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERB,##Field)
#define _MCBSP_RCERB1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERB,##Field,Val)
#define _MCBSP_RCERB1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERB,##Field,AND,OR,INV)
#define _MCBSP_RCERB1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_RCER_CFG(1, RCERB,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_RCERC1_GET                       _MCBSP_RCER_GET(1,RCERC)
  #define _MCBSP_RCERC1_SET(Val)                  _MCBSP_RCER_SET(1,RCERC,Val)
  #define _MCBSP_RCERC1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERC,AND,OR,INV)
  #define _MCBSP_RCERC1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERC,##Field)
  #define _MCBSP_RCERC1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERC,##Field,Val)
  #define _MCBSP_RCERC1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERC,##Field,AND,OR,INV)
  #define _MCBSP_RCERC1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_RCER_CFG(1, RCERC,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERD1_GET                       _MCBSP_RCER_GET(1,RCERD)
  #define _MCBSP_RCERD1_SET(Val)                  _MCBSP_RCER_SET(1,RCERD,Val)
  #define _MCBSP_RCERD1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERD,AND,OR,INV)
  #define _MCBSP_RCERD1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERD,##Field)
  #define _MCBSP_RCERD1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERD,##Field,Val)
  #define _MCBSP_RCERD1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERD,##Field,AND,OR,INV)
  #define _MCBSP_RCERD1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(1, RCERD,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERE1_GET                       _MCBSP_RCER_GET(1,RCERE) 
  #define _MCBSP_RCERE1_SET(Val)                  _MCBSP_RCER_SET(1,RCERE,Val)
  #define _MCBSP_RCERE1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERE,AND,OR,INV)
  #define _MCBSP_RCERE1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERE,##Field)
  #define _MCBSP_RCERE1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERE,##Field,Val)
  #define _MCBSP_RCERE1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERE,##Field,AND,OR,INV)
  #define _MCBSP_RCERE1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(1, RCERE,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERF1_GET                       _MCBSP_RCER_GET(1,RCERF)
  #define _MCBSP_RCERF1_SET(Val)                  _MCBSP_RCER_SET(1,RCERF,Val)
  #define _MCBSP_RCERF1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERF,AND,OR,INV)
  #define _MCBSP_RCERF1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERF,##Field)
  #define _MCBSP_RCERF1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERF,##Field,Val)
  #define _MCBSP_RCERF1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERF,##Field,AND,OR,INV)
  #define _MCBSP_RCERF1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(1, RCERF,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERG1_GET                       _MCBSP_RCER_GET(1,RCERG)
  #define _MCBSP_RCERG1_SET(Val)                  _MCBSP_RCER_SET(1,RCERG,Val)
  #define _MCBSP_RCERG1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERG,AND,OR,INV)
  #define _MCBSP_RCERG1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERG,##Field)
  #define _MCBSP_RCERG1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERG,##Field,Val)
  #define _MCBSP_RCERG1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERG,##Field,AND,OR,INV)
  #define _MCBSP_RCERG1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(1, RCERG,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERH1_GET                       _MCBSP_RCER_GET(1,RCERH)
  #define _MCBSP_RCERH1_SET(Val)                  _MCBSP_RCER_SET(1,RCERH,Val)
  #define _MCBSP_RCERH1_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(1,RCERH,AND,OR,INV)
  #define _MCBSP_RCERH1_FGET(Field)               _MCBSP_RCER_FGET(1,RCERH,##Field)
  #define _MCBSP_RCERH1_FSET(Field,Val)           _MCBSP_RCER_FSET(1,RCERH,##Field,Val)
  #define _MCBSP_RCERH1_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(1,RCERH,###Field,AND,OR,INV)
  #define _MCBSP_RCERH1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(1, RCERH,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)
#endif

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_RCERA2_GET                       _MCBSP_RCER_GET(2,RCERA)
  #define _MCBSP_RCERA2_SET(Val)                  _MCBSP_RCER_SET(2,RCERA,Val)
  #define _MCBSP_RCERA2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERA,AND,OR,INV)
  #define _MCBSP_RCERA2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERA,##Field)
  #define _MCBSP_RCERA2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERA,##Field,Val)
  #define _MCBSP_RCERA2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERA,##Field,AND,OR,INV)
  #define _MCBSP_RCERA2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(2, RCERA,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_RCERB2_GET                       _MCBSP_RCER_GET(2,RCERB)
  #define _MCBSP_RCERB2_SET(Val)                  _MCBSP_RCER_SET(2,RCERB,Val)
  #define _MCBSP_RCERB2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERB,AND,OR,INV)
  #define _MCBSP_RCERB2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERB,##Field)
  #define _MCBSP_RCERB2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERB,##Field,Val)
  #define _MCBSP_RCERB2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERB,##Field,AND,OR,INV)
  #define _MCBSP_RCERB2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_RCER_CFG(2, RCERB,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #if (_MCBSP_128_CH_ENABLE_SUPPORT)
    #define _MCBSP_RCERC2_GET                       _MCBSP_RCER_GET(2,RCERC)
    #define _MCBSP_RCERC2_SET(Val)                  _MCBSP_RCER_SET(2,RCERC,Val)
    #define _MCBSP_RCERC2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERC,AND,OR,INV)
    #define _MCBSP_RCERC2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERC,##Field)
    #define _MCBSP_RCERC2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERC,##Field,Val)
    #define _MCBSP_RCERC2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERC,##Field,AND,OR,INV)
    #define _MCBSP_RCERC2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
      _MCBSP_RCER_CFG(2, RCERC,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_RCERD2_GET                       _MCBSP_RCER_GET(2,RCERD)
    #define _MCBSP_RCERD2_SET(Val)                  _MCBSP_RCER_SET(2,RCERD,Val)
    #define _MCBSP_RCERD2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERD,AND,OR,INV)
    #define _MCBSP_RCERD2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERD,##Field)
    #define _MCBSP_RCERD2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERD,##Field,Val)
    #define _MCBSP_RCERD2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERD,##Field,AND,OR,INV)
    #define _MCBSP_RCERD2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_RCER_CFG(2, RCERD,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_RCERE2_GET                       _MCBSP_RCER_GET(2,RCERE) 
    #define _MCBSP_RCERE2_SET(Val)                  _MCBSP_RCER_SET(2,RCERE,Val)
    #define _MCBSP_RCERE2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERE,AND,OR,INV)
    #define _MCBSP_RCERE2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERE,##Field)
    #define _MCBSP_RCERE2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERE,##Field,Val)
    #define _MCBSP_RCERE2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERE,##Field,AND,OR,INV)
    #define _MCBSP_RCERE2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_RCER_CFG(2, RCERE,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_RCERF2_GET                       _MCBSP_RCER_GET(2,RCERF)
    #define _MCBSP_RCERF2_SET(Val)                  _MCBSP_RCER_SET(2,RCERF,Val)
    #define _MCBSP_RCERF2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERF,AND,OR,INV)
    #define _MCBSP_RCERF2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERF,##Field)
    #define _MCBSP_RCERF2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERF,##Field,Val)
    #define _MCBSP_RCERF2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERF,##Field,AND,OR,INV)
    #define _MCBSP_RCERF2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_RCER_CFG(2, RCERF,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_RCERG2_GET                       _MCBSP_RCER_GET(2,RCERG)
    #define _MCBSP_RCERG2_SET(Val)                  _MCBSP_RCER_SET(2,RCERG,Val)
    #define _MCBSP_RCERG2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERG,AND,OR,INV)
    #define _MCBSP_RCERG2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERG,##Field)
    #define _MCBSP_RCERG2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERG,##Field,Val)
    #define _MCBSP_RCERG2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERG,##Field,AND,OR,INV)
    #define _MCBSP_RCERG2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_RCER_CFG(2, RCERG,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_RCERH2_GET                       _MCBSP_RCER_GET(2,RCERH)
    #define _MCBSP_RCERH2_SET(Val)                  _MCBSP_RCER_SET(2,RCERH,Val)
    #define _MCBSP_RCERH2_AOI(AND,OR,INV)           _MCBSP_RCER_AOI(2,RCERH,AND,OR,INV)
    #define _MCBSP_RCERH2_FGET(Field)               _MCBSP_RCER_FGET(2,RCERH,##Field)
    #define _MCBSP_RCERH2_FSET(Field,Val)           _MCBSP_RCER_FSET(2,RCERH,##Field,Val)
    #define _MCBSP_RCERH2_FAOI(Field,AND,OR,INV)    _MCBSP_RCER_FAOI(2,RCERH,##Field,AND,OR,INV)
    #define _MCBSP_RCERH2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_RCER_CFG(2, RCERH,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)
  #endif
#endif

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE15: receive enable for channel 15
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE15_SHIFT           (0x000fu)
#define _MCBSP_RCER_RCE15_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE15_SHIFT)
#define _MCBSP_RCER_RCE15_MASK            (_MCBSP_RCER_RCE15_MK(1))
#define _MCBSP_RCER_RCE15_CLR             (~(_MCBSP_RCER_RCE15_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE14: receive enable for channel 14
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE14_SHIFT           (0x000eu)
#define _MCBSP_RCER_RCE14_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE14_SHIFT)
#define _MCBSP_RCER_RCE14_MASK            (_MCBSP_RCER_RCE14_MK(1))
#define _MCBSP_RCER_RCE14_CLR             (~(_MCBSP_RCER_RCE14_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE13: receive enable for channel 13
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE13_SHIFT           (0x000du)
#define _MCBSP_RCER_RCE13_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE13_SHIFT)
#define _MCBSP_RCER_RCE13_MASK            (_MCBSP_RCER_RCE13_MK(1))
#define _MCBSP_RCER_RCE13_CLR             (~(_MCBSP_RCER_RCE13_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE12: receive enable for channel 12
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE12_SHIFT           (0x000cu)
#define _MCBSP_RCER_RCE12_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE12_SHIFT)
#define _MCBSP_RCER_RCE12_MASK            (_MCBSP_RCER_RCE12_MK(1))
#define _MCBSP_RCER_RCE12_CLR             (~(_MCBSP_RCER_RCE12_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE11: receive enable for channel 11
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE11_SHIFT           (0x000bu)
#define _MCBSP_RCER_RCE11_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE11_SHIFT)
#define _MCBSP_RCER_RCE11_MASK            (_MCBSP_RCER_RCE11_MK(1))
#define _MCBSP_RCER_RCE11_CLR             (~(_MCBSP_RCER_RCE11_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE10: receive enable for channel 10
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE10_SHIFT           (0x000au)
#define _MCBSP_RCER_RCE10_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE10_SHIFT)
#define _MCBSP_RCER_RCE10_MASK            (_MCBSP_RCER_RCE10_MK(1))
#define _MCBSP_RCER_RCE10_CLR             (~(_MCBSP_RCER_RCE10_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE9: receive enable for channel 9
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE9_SHIFT            (0x0009u)
#define _MCBSP_RCER_RCE9_MK(n)            (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE9_SHIFT)
#define _MCBSP_RCER_RCE9_MASK             (_MCBSP_RCER_RCE9_MK(1))
#define _MCBSP_RCER_RCE9_CLR              (~(_MCBSP_RCER_RCE9_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE8: receive enable for channel 8
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE8_SHIFT            (0x0008u)
#define _MCBSP_RCER_RCE8_MK(n)            (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE8_SHIFT)
#define _MCBSP_RCER_RCE8_MASK             (_MCBSP_RCER_RCE8_MK(1))
#define _MCBSP_RCER_RCE8_CLR              (~(_MCBSP_RCER_RCE8_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE7: receive enable for channel 7
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE7_SHIFT            (0x0007u)
#define _MCBSP_RCER_RCE7_MK(n)            (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE7_SHIFT)
#define _MCBSP_RCER_RCE7_MASK             (_MCBSP_RCER_RCE7_MK(1))
#define _MCBSP_RCER_RCE7_CLR              (~(_MCBSP_RCER_RCE7_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE6: receive enable for channel 6
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE6_SHIFT            (0x0006u)
#define _MCBSP_RCER_RCE6_MK(n)            (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE6_SHIFT)
#define _MCBSP_RCER_RCE6_MASK             (_MCBSP_RCER_RCE6_MK(1))
#define _MCBSP_RCER_RCE6_CLR              (~(_MCBSP_RCER_RCE6_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE5: receive enable for channel 5
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE5_SHIFT            (0x0005u)
#define _MCBSP_RCER_RCE5_MK(n)            (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE5_SHIFT)
#define _MCBSP_RCER_RCE5_MASK             (_MCBSP_RCER_RCE5_MK(1))
#define _MCBSP_RCER_RCE5_CLR              (~(_MCBSP_RCER_RCE5_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE4: receive enable for channel 4
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE4_SHIFT           (0x000fu)
#define _MCBSP_RCER_RCE4_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE4_SHIFT)
#define _MCBSP_RCER_RCE4_MASK            (_MCBSP_RCER_RCE4_MK(1))
#define _MCBSP_RCER_RCE4_CLR             (~(_MCBSP_RCER_RCE4_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE3: receive enable for channel 3
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE3_SHIFT           (0x000fu)
#define _MCBSP_RCER_RCE3_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE3_SHIFT)
#define _MCBSP_RCER_RCE3_MASK            (_MCBSP_RCER_RCE3_MK(1))
#define _MCBSP_RCER_RCE3_CLR             (~(_MCBSP_RCER_RCE3_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE2: receive enable for channel 2
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE2_SHIFT           (0x000fu)
#define _MCBSP_RCER_RCE2_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE2_SHIFT)
#define _MCBSP_RCER_RCE2_MASK            (_MCBSP_RCER_RCE2_MK(1))
#define _MCBSP_RCER_RCE2_CLR             (~(_MCBSP_RCER_RCE2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE1: receive enable for channel 1
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE1_SHIFT           (0x0001u)
#define _MCBSP_RCER_RCE1_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE1_SHIFT)
#define _MCBSP_RCER_RCE1_MASK            (_MCBSP_RCER_RCE1_MK(1))
#define _MCBSP_RCER_RCE1_CLR             (~(_MCBSP_RCER_RCE1_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCE0: receive enable for channel 0
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCE0_SHIFT           (0x0000u)
#define _MCBSP_RCER_RCE0_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_RCER_RCE0_SHIFT)
#define _MCBSP_RCER_RCE0_MASK            (_MCBSP_RCER_RCE0_MK(1))
#define _MCBSP_RCER_RCE0_CLR             (~(_MCBSP_RCER_RCE0_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_RCER_RCER: receive enable for channel 0
\*----------------------------------------------------------------------------*/
#define _MCBSP_RCER_RCER_SHIFT           (0x0000u)
#define _MCBSP_RCER_RCER_MK(n)           (((Uint16)(n) & 0xFFFFu) << _MCBSP_RCER_RCER_SHIFT)
#define _MCBSP_RCER_RCER_MASK            (_MCBSP_RCER_RCER_MK(1))
#define _MCBSP_RCER_RCER_CLR             (~(_MCBSP_RCER_RCER_MASK))

/*============================================================================*\
* _MCBSP_XCER : MCBSP Receive Channel Enable Register
*
* Fields:
* (RW) _MCBSP_XCER_XCE15
* (RW) _MCBSP_XCER_XCE14
* (RW) _MCBSP_XCER_XCE13
* (RW) _MCBSP_XCER_XCE12
* (RW) _MCBSP_XCER_XCE11
* (RW) _MCBSP_XCER_XCE10
* (RW) _MCBSP_XCER_XCE9
* (RW) _MCBSP_XCER_XCE8
* (RW) _MCBSP_XCER_XCE7
* (RW) _MCBSP_XCER_XCE6
* (RW) _MCBSP_XCER_XCE5
* (RW) _MCBSP_XCER_XCE4
* (RW) _MCBSP_XCER_XCE3
* (RW) _MCBSP_XCER_XCE2
* (RW) _MCBSP_XCER_XCE1
* (RW) _MCBSP_XCER_XCE0
* 
\*============================================================================*/

#define _MCBSP_XCER_GET(Port, Reg)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _##Reg)

#define _MCBSP_XCER_SET(Port, Reg, Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _##Reg, Val)

#define _MCBSP_XCER_AOI(Port, Reg, AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _##Reg, AND,OR,INV)

#define _MCBSP_XCER_FGET(Port, Reg, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _##Reg, _MCBSP_XCER_##Field)

#define _MCBSP_XCER_FSET(Port, Reg, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _##Reg, _MCBSP_XCER_##Field, Val)

#define _MCBSP_XCER_FAOI(Port, Reg, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _##Reg, _MCBSP_XCER_##Field, AND,OR,INV)

#define _MCBSP_XCER_CFG(Port, Reg,\
                        rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,\
                        rc11,rc12,rc13,rc14,rc15)\
   _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD(Port), Reg,\
            ( _MCBSP_XCER_XCE15_MK(rc15)          |\
              _MCBSP_XCER_XCE14_MK(rc14)          |\
              _MCBSP_XCER_XCE13_MK(rc13)          |\
              _MCBSP_XCER_XCE12_MK(rc12)          |\
              _MCBSP_XCER_XCE11_MK(rc11)          |\
              _MCBSP_XCER_XCE10_MK(rc10)          |\
              _MCBSP_XCER_XCE9_MK(rc9)            |\
              _MCBSP_XCER_XCE8_MK(rc8)            |\
              _MCBSP_XCER_XCE7_MK(rc7)            |\
              _MCBSP_XCER_XCE6_MK(rc6)            |\
              _MCBSP_XCER_XCE5_MK(rc5)            |\
              _MCBSP_XCER_XCE4_MK(rc4)            |\
              _MCBSP_XCER_XCE3_MK(rc3)            |\
              _MCBSP_XCER_XCE2_MK(rc2)            |\
              _MCBSP_XCER_XCE1_MK(rc1)            |\
              _MCBSP_XCER_XCE0_MK(rc0)            \
            )\
 )

// XCERA //
#define _MCBSP_XCERA_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERA_ADDR)

#define _MCBSP_XCERA_SET(Port,Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERA_ADDR, Val)

#define _MCBSP_XCERA_AOI(Port,AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERA_ADDR, AND,OR,INV)

#define _MCBSP_XCERA_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERA_ADDR, _MCBSP_XCER_##Field)

#define _MCBSP_XCERA_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERA_ADDR, _MCBSP_XCER_##Field, Val)

#define _MCBSP_XCERA_FAOI(Port, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERA_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)

// XCERB //
#define _MCBSP_XCERB_GET(Port)\
  _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERB_ADDR)

#define _MCBSP_XCERB_SET(Port,Val)\
  _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERB_ADDR, Val)

#define _MCBSP_XCERB_AOI(Port,AND,OR,INV)\
  _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERB_ADDR, AND,OR,INV)

#define _MCBSP_XCERB_FGET(Port, Field)\
  _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERB_ADDR, _MCBSP_XCER_##Field)

#define _MCBSP_XCERB_FSET(Port, Field, Val)\
  _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERB_ADDR, _MCBSP_XCER_##Field, Val)

#define _MCBSP_XCERB_FAOI(Port, Field, AND, OR, INV)\
  _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERB_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  // XCERC //
  #define _MCBSP_XCERC_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERC_ADDR)

  #define _MCBSP_XCERC_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERC_ADDR, Val)

  #define _MCBSP_XCERC_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERC_ADDR, AND,OR,INV)

  #define _MCBSP_XCERC_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERC_ADDR, _MCBSP_XCER_##Field)

  #define _MCBSP_XCERC_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERC_ADDR, _MCBSP_XCER_##Field,  Val)

  #define _MCBSP_XCERC_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERC_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)

  // XCERD //
  #define _MCBSP_XCERD_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERD_ADDR)

  #define _MCBSP_XCERD_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERD_ADDR, Val)

  #define _MCBSP_XCERD_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERD_ADDR, AND,OR,INV)

  #define _MCBSP_XCERD_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERD_ADDR, _MCBSP_XCER_##Field)

  #define _MCBSP_XCERD_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERD_ADDR, _MCBSP_XCER_##Field,  Val)

  #define _MCBSP_XCERD_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERD_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)

  // XCERE //
  #define _MCBSP_XCERE_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERE_ADDR)

  #define _MCBSP_XCERE_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERE_ADDR, Val)

  #define _MCBSP_XCERE_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERE_ADDR, AND,OR,INV)

  #define _MCBSP_XCERE_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERE_ADDR, _MCBSP_XCER_##Field)

  #define _MCBSP_XCERE_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERE_ADDR, _MCBSP_XCER_##Field,Val)

  #define _MCBSP_XCERE_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERE_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)

  // XCERF //
  #define _MCBSP_XCERF_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERF_ADDR)

  #define _MCBSP_XCERF_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERF_ADDR, Val)

  #define _MCBSP_XCERF_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERF_ADDR, AND,OR,INV)

  #define _MCBSP_XCERF_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERF_ADDR, _MCBSP_XCER_##Field)

  #define _MCBSP_XCERF_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERF_ADDR, _MCBSP_XCER_##Field, Val)

  #define _MCBSP_XCERF_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERF_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)

  // XCERG //
  #define _MCBSP_XCERG_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERG_ADDR)

  #define _MCBSP_XCERG_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERG_ADDR, Val)

  #define _MCBSP_XCERG_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERG_ADDR, AND,OR,INV)

  #define _MCBSP_XCERG_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERG_ADDR, _MCBSP_XCER_##Field)

  #define _MCBSP_XCERG_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERG_ADDR, _MCBSP_XCER_##Field, Val)

  #define _MCBSP_XCERG_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERG_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)

  // XCERH //
  #define _MCBSP_XCERH_GET(Port)\
    _SUBREG_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERH_ADDR)

  #define _MCBSP_XCERH_SET(Port,Val)\
    _SUBREG_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERH_ADDR, Val)

  #define _MCBSP_XCERH_AOI(Port,AND,OR,INV)\
    _SUBREG_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERH_ADDR, AND,OR,INV)

  #define _MCBSP_XCERH_FGET(Port, Field)\
    _SUBFIELD_GET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERH_ADDR, _MCBSP_XCER_##Field)

  #define _MCBSP_XCERH_FSET(Port, Field, Val)\
    _SUBFIELD_SET(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERH_ADDR, _MCBSP_XCER_##Field, Val)

  #define _MCBSP_XCERH_FAOI(Port, Field, AND, OR, INV)\
    _SUBFIELD_AOI(_MCBSP_SPSA_ADDR(Port), _MCBSP_SPSD_ADDR(Port), _MCBSP_XCERH_ADDR, _MCBSP_XCER_##Field, AND,OR,INV)
#endif

#define _MCBSP_XCERA0_GET                       _MCBSP_XCER_GET(0,XCERA)
#define _MCBSP_XCERA0_SET(Val)                  _MCBSP_XCER_SET(0,XCERA,Val)
#define _MCBSP_XCERA0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERA,AND,OR,INV)
#define _MCBSP_XCERA0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERA,##Field)
#define _MCBSP_XCERA0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERA,##Field,Val)
#define _MCBSP_XCERA0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERA,##Field,AND,OR,INV)
#define _MCBSP_XCERA0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_XCER_CFG(0, XCERA,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#define _MCBSP_XCERB0_GET                       _MCBSP_XCER_GET(0,XCERB)
#define _MCBSP_XCERB0_SET(Val)                  _MCBSP_XCER_SET(0,XCERB,Val)
#define _MCBSP_XCERB0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERB,AND,OR,INV)
#define _MCBSP_XCERB0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERB,##Field)
#define _MCBSP_XCERB0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERB,##Field,Val)
#define _MCBSP_XCERB0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERB,##Field,AND,OR,INV)
#define _MCBSP_XCERB0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_XCER_CFG(0, XCERB,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_XCERC0_GET                       _MCBSP_XCER_GET(0,XCERC)
  #define _MCBSP_XCERC0_SET(Val)                  _MCBSP_XCER_SET(0,XCERC,Val)
  #define _MCBSP_XCERC0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERC,AND,OR,INV)
  #define _MCBSP_XCERC0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERC,##Field)
  #define _MCBSP_XCERC0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERC,##Field,Val)
  #define _MCBSP_XCERC0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERC,##Field,AND,OR,INV)
  #define _MCBSP_XCERC0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
    _MCBSP_XCER_CFG(0, XCERC,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERD0_GET                       _MCBSP_XCER_GET(0,XCERD)
  #define _MCBSP_XCERD0_SET(Val)                  _MCBSP_XCER_SET(0,XCERD,Val)
  #define _MCBSP_XCERD0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERD,AND,OR,INV)
  #define _MCBSP_XCERD0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERD,##Field)
  #define _MCBSP_XCERD0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERD,##Field,Val)
  #define _MCBSP_XCERD0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERD,##Field,AND,OR,INV)
  #define _MCBSP_XCERD0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(0, XCERD,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERE0_GET                       _MCBSP_XCER_GET(0,XCERE) 
  #define _MCBSP_XCERE0_SET(Val)                  _MCBSP_XCER_SET(0,XCERE,Val)
  #define _MCBSP_XCERE0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERE,AND,OR,INV)
  #define _MCBSP_XCERE0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERE,##Field)
  #define _MCBSP_XCERE0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERE,##Field,Val)
  #define _MCBSP_XCERE0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERE,##Field,AND,OR,INV)
  #define _MCBSP_XCERE0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(0, XCERE,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERF0_GET                       _MCBSP_XCER_GET(0,XCERF)
  #define _MCBSP_XCERF0_SET(Val)                  _MCBSP_XCER_SET(0,XCERF,Val)
  #define _MCBSP_XCERF0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERF,AND,OR,INV)
  #define _MCBSP_XCERF0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERF,##Field)
  #define _MCBSP_XCERF0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERF,##Field,Val)
  #define _MCBSP_XCERF0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERF,##Field,AND,OR,INV)
  #define _MCBSP_XCERF0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(0, XCERF,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERG0_GET                       _MCBSP_XCER_GET(0,XCERG)
  #define _MCBSP_XCERG0_SET(Val)                  _MCBSP_XCER_SET(0,XCERG,Val)
  #define _MCBSP_XCERG0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERG,AND,OR,INV)
  #define _MCBSP_XCERG0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERG,##Field)
  #define _MCBSP_XCERG0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERG,##Field,Val)
  #define _MCBSP_XCERG0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERG,##Field,AND,OR,INV)
  #define _MCBSP_XCERG0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(0, XCERG,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERH0_GET                       _MCBSP_XCER_GET(0,XCERH)
  #define _MCBSP_XCERH0_SET(Val)                  _MCBSP_XCER_SET(0,XCERH,Val)
  #define _MCBSP_XCERH0_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(0,XCERH,AND,OR,INV)
  #define _MCBSP_XCERH0_FGET(Field)               _MCBSP_XCER_FGET(0,XCERH,##Field)
  #define _MCBSP_XCERH0_FSET(Field,Val)           _MCBSP_XCER_FSET(0,XCERH,##Field,Val)
  #define _MCBSP_XCERH0_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(0,XCERH,##Field,AND,OR,INV)
  #define _MCBSP_XCERH0_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(0, XCERH,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)
#endif

#define _MCBSP_XCERA1_GET                       _MCBSP_XCER_GET(1,XCERA)
#define _MCBSP_XCERA1_SET(Val)                  _MCBSP_XCER_SET(1,XCERA,Val)
#define _MCBSP_XCERA1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERA,AND,OR,INV)
#define _MCBSP_XCERA1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERA,##Field)
#define _MCBSP_XCERA1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERA,##Field,Val)
#define _MCBSP_XCERA1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERA,##Field,AND,OR,INV)
#define _MCBSP_XCERA1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_XCER_CFG(1, XCERA,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#define _MCBSP_XCERB1_GET                       _MCBSP_XCER_GET(1,XCERB)
#define _MCBSP_XCERB1_SET(Val)                  _MCBSP_XCER_SET(1,XCERB,Val)
#define _MCBSP_XCERB1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERB,AND,OR,INV)
#define _MCBSP_XCERB1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERB,##Field)
#define _MCBSP_XCERB1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERB,##Field,Val)
#define _MCBSP_XCERB1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERB,##Field,AND,OR,INV)
#define _MCBSP_XCERB1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
 _MCBSP_XCER_CFG(1, XCERB,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_XCERC1_GET                       _MCBSP_XCER_GET(1,XCERC)
  #define _MCBSP_XCERC1_SET(Val)                  _MCBSP_XCER_SET(1,XCERC,Val)
  #define _MCBSP_XCERC1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERC,AND,OR,INV)
  #define _MCBSP_XCERC1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERC,##Field)
  #define _MCBSP_XCERC1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERC,##Field,Val)
  #define _MCBSP_XCERC1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERC,##Field,AND,OR,INV)
  #define _MCBSP_XCERC1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
    _MCBSP_XCER_CFG(1, XCERC,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERD1_GET                       _MCBSP_XCER_GET(1,XCERD)
  #define _MCBSP_XCERD1_SET(Val)                  _MCBSP_XCER_SET(1,XCERD,Val)
  #define _MCBSP_XCERD1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERD,AND,OR,INV)
  #define _MCBSP_XCERD1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERD,##Field)
  #define _MCBSP_XCERD1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERD,##Field,Val)
  #define _MCBSP_XCERD1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERD,##Field,AND,OR,INV)
  #define _MCBSP_XCERD1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(1, XCERD,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERE1_GET                       _MCBSP_XCER_GET(1,XCERE) 
  #define _MCBSP_XCERE1_SET(Val)                  _MCBSP_XCER_SET(1,XCERE,Val)
  #define _MCBSP_XCERE1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERE,AND,OR,INV)
  #define _MCBSP_XCERE1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERE,##Field)
  #define _MCBSP_XCERE1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERE,##Field,Val)
  #define _MCBSP_XCERE1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERE,##Field,AND,OR,INV)
  #define _MCBSP_XCERE1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(1, XCERE,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERF1_GET                       _MCBSP_XCER_GET(1,XCERF)
  #define _MCBSP_XCERF1_SET(Val)                  _MCBSP_XCER_SET(1,XCERF,Val)
  #define _MCBSP_XCERF1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERF,AND,OR,INV)
  #define _MCBSP_XCERF1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERF,##Field)
  #define _MCBSP_XCERF1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERF,##Field,Val)
  #define _MCBSP_XCERF1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERF,##Field,AND,OR,INV)
  #define _MCBSP_XCERF1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(1, XCERF,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERG1_GET                       _MCBSP_XCER_GET(1,XCERG)
  #define _MCBSP_XCERG1_SET(Val)                  _MCBSP_XCER_SET(1,XCERG,Val)
  #define _MCBSP_XCERG1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERG,AND,OR,INV)
  #define _MCBSP_XCERG1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERG,##Field)
  #define _MCBSP_XCERG1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERG,##Field,Val)
  #define _MCBSP_XCERG1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERG,##Field,AND,OR,INV)
  #define _MCBSP_XCERG1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(1, XCERG,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERH1_GET                       _MCBSP_XCER_GET(1,XCERH)
  #define _MCBSP_XCERH1_SET(Val)                  _MCBSP_XCER_SET(1,XCERH,Val)
  #define _MCBSP_XCERH1_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(1,XCERH,AND,OR,INV)
  #define _MCBSP_XCERH1_FGET(Field)               _MCBSP_XCER_FGET(1,XCERH,##Field)
  #define _MCBSP_XCERH1_FSET(Field,Val)           _MCBSP_XCER_FSET(1,XCERH,##Field,Val)
  #define _MCBSP_XCERH1_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(1,XCERH,##Field,AND,OR,INV)
  #define _MCBSP_XCERH1_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(1, XCERH,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)
#endif

#if (_MCBSP_PORT_CNT==3)
  #define _MCBSP_XCERA2_GET                       _MCBSP_XCER_GET(2,XCERA)
  #define _MCBSP_XCERA2_SET(Val)                  _MCBSP_XCER_SET(2,XCERA,Val)
  #define _MCBSP_XCERA2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERA,AND,OR,INV)
  #define _MCBSP_XCERA2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERA,##Field)
  #define _MCBSP_XCERA2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERA,##Field,Val)
  #define _MCBSP_XCERA2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERA,##Field,AND,OR,INV)
  #define _MCBSP_XCERA2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(2, XCERA,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #define _MCBSP_XCERB2_GET                       _MCBSP_XCER_GET(2,XCERB)
  #define _MCBSP_XCERB2_SET(Val)                  _MCBSP_XCER_SET(2,XCERB,Val)
  #define _MCBSP_XCERB2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERB,AND,OR,INV)
  #define _MCBSP_XCERB2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERB,##Field)
  #define _MCBSP_XCERB2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERB,##Field,Val)
  #define _MCBSP_XCERB2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERB,##Field,AND,OR,INV)
  #define _MCBSP_XCERB2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
   _MCBSP_XCER_CFG(2, XCERB,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

  #if (_MCBSP_128_CH_ENABLE_SUPPORT)
    #define _MCBSP_XCERC2_GET                       _MCBSP_XCER_GET(2,XCERC)
    #define _MCBSP_XCERC2_SET(Val)                  _MCBSP_XCER_SET(2,XCERC,Val)
    #define _MCBSP_XCERC2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERC,AND,OR,INV)
    #define _MCBSP_XCERC2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERC,##Field)
    #define _MCBSP_XCERC2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERC,##Field,Val)
    #define _MCBSP_XCERC2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERC,##Field,AND,OR,INV)
    #define _MCBSP_XCERC2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
      _MCBSP_XCER_CFG(2, XCERC,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_XCERD2_GET                       _MCBSP_XCER_GET(2,XCERD)
    #define _MCBSP_XCERD2_SET(Val)                  _MCBSP_XCER_SET(2,XCERD,Val)
    #define _MCBSP_XCERD2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERD,AND,OR,INV)
    #define _MCBSP_XCERD2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERD,##Field)
    #define _MCBSP_XCERD2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERD,##Field,Val)
    #define _MCBSP_XCERD2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERD,##Field,AND,OR,INV)
    #define _MCBSP_XCERD2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_XCER_CFG(2, XCERD,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_XCERE2_GET                       _MCBSP_XCER_GET(2,XCERE) 
    #define _MCBSP_XCERE2_SET(Val)                  _MCBSP_XCER_SET(2,XCERE,Val)
    #define _MCBSP_XCERE2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERE,AND,OR,INV)
    #define _MCBSP_XCERE2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERE,##Field)
    #define _MCBSP_XCERE2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERE,##Field,Val)
    #define _MCBSP_XCERE2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERE,##Field,AND,OR,INV)
    #define _MCBSP_XCERE2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_XCER_CFG(2, XCERE,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_XCERF2_GET                       _MCBSP_XCER_GET(2,XCERF)
    #define _MCBSP_XCERF2_SET(Val)                  _MCBSP_XCER_SET(2,XCERF,Val)
    #define _MCBSP_XCERF2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERF,AND,OR,INV)
    #define _MCBSP_XCERF2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERF,##Field)
    #define _MCBSP_XCERF2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERF,##Field,Val)
    #define _MCBSP_XCERF2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERF,##Field,AND,OR,INV)
    #define _MCBSP_XCERF2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_XCER_CFG(2, XCERF,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_XCERG2_GET                       _MCBSP_XCER_GET(2,XCERG)
    #define _MCBSP_XCERG2_SET(Val)                  _MCBSP_XCER_SET(2,XCERG,Val)
    #define _MCBSP_XCERG2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERG,AND,OR,INV)
    #define _MCBSP_XCERG2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERG,##Field)
    #define _MCBSP_XCERG2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERG,##Field,Val)
    #define _MCBSP_XCERG2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERG,##Field,AND,OR,INV)
    #define _MCBSP_XCERG2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_XCER_CFG(2, XCERG,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)

    #define _MCBSP_XCERH2_GET                       _MCBSP_XCER_GET(2,XCERH)
    #define _MCBSP_XCERH2_SET(Val)                  _MCBSP_XCER_SET(2,XCERH,Val)
    #define _MCBSP_XCERH2_AOI(AND,OR,INV)           _MCBSP_XCER_AOI(2,XCERH,AND,OR,INV)
    #define _MCBSP_XCERH2_FGET(Field)               _MCBSP_XCER_FGET(2,XCERH,##Field)
    #define _MCBSP_XCERH2_FSET(Field,Val)           _MCBSP_XCER_FSET(2,XCERH,##Field,Val)
    #define _MCBSP_XCERH2_FAOI(Field,AND,OR,INV)    _MCBSP_XCER_FAOI(2,XCERH,##Field,AND,OR,INV)
    #define _MCBSP_XCERH2_CFG(rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)\
     _MCBSP_XCER_CFG(2, XCERH,rc0,rc1,rc2,rc3,rc4,rc5,rc6,rc7,rc8,rc9,rc10,rc11,rc12,rc13,rc14,rc15)
  #endif
#endif

/*----------------------------------------------------------------------------*\
* XCER whole register masks/shift macros
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCERA_SHIFT         (0x0000u)
#define _MCBSP_XCER_XCERA_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERA_SHIFT)
#define _MCBSP_XCER_XCERA_MASK          (_MCBSP_XCER_XCERA_MK(0xFFFFu))
#define _MCBSP_XCER_XCERA_CLR           (~(_MCBSP_XCER_XCERA_MASK))

#define _MCBSP_XCER_XCERB_SHIFT         (0x0000u)
#define _MCBSP_XCER_XCERB_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERB_SHIFT)
#define _MCBSP_XCER_XCERB_MASK          (_MCBSP_XCER_XCERB_MK(0xFFFFu))
#define _MCBSP_XCER_XCERB_CLR           (~(_MCBSP_XCER_XCERB_MASK))

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_XCER_XCERC_SHIFT         (0x0000u)
  #define _MCBSP_XCER_XCERC_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERC_SHIFT)
  #define _MCBSP_XCER_XCERC_MASK          (_MCBSP_XCER_XCERC_MK(0xFFFFu))
  #define _MCBSP_XCER_XCERC_CLR           (~(_MCBSP_XCER_XCERC_MASK))

  #define _MCBSP_XCER_XCERD_SHIFT         (0x0000u)
  #define _MCBSP_XCER_XCERD_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERD_SHIFT)
  #define _MCBSP_XCER_XCERD_MASK          (_MCBSP_XCER_XCERD_MK(0xFFFFu))
  #define _MCBSP_XCER_XCERD_CLR           (~(_MCBSP_XCER_XCERD_MASK))

  #define _MCBSP_XCER_XCERE_SHIFT         (0x0000u)
  #define _MCBSP_XCER_XCERE_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERE_SHIFT)
  #define _MCBSP_XCER_XCERE_MASK          (_MCBSP_XCER_XCERE_MK(0xFFFFu))
  #define _MCBSP_XCER_XCERE_CLR           (~(_MCBSP_XCER_XCERE_MASK))
 
  #define _MCBSP_XCER_XCERF_SHIFT         (0x0000u)
  #define _MCBSP_XCER_XCERF_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERF_SHIFT)
  #define _MCBSP_XCER_XCERF_MASK          (_MCBSP_XCER_XCERF_MK(0xFFFFu))
  #define _MCBSP_XCER_XCERF_CLR           (~(_MCBSP_XCER_XCERF_MASK))

  #define _MCBSP_XCER_XCERG_SHIFT         (0x0000u)
  #define _MCBSP_XCER_XCERG_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERG_SHIFT)
  #define _MCBSP_XCER_XCERG_MASK          (_MCBSP_XCER_XCERG_MK(0xFFFFu))
  #define _MCBSP_XCER_XCERG_CLR           (~(_MCBSP_XCER_XCERG_MASK))

  #define _MCBSP_XCER_XCERH_SHIFT         (0x0000u)
  #define _MCBSP_XCER_XCERH_MK(n)         (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCERH_SHIFT)
  #define _MCBSP_XCER_XCERH_MASK          (_MCBSP_XCER_XCERH_MK(0xFFFFu))
  #define _MCBSP_XCER_XCERH_CLR           (~(_MCBSP_XCER_XCERH_MASK))

#endif

#define _MCBSP_XCERA_FIELD(Field)        _MCBSP_XCER_##Field
#define _MCBSP_XCERB_FIELD(Field)        _MCBSP_XCER_##Field

#if (_MCBSP_128_CH_ENABLE_SUPPORT)
  #define _MCBSP_XCERC_FIELD(Field)        _MCBSP_XCER_##Field
  #define _MCBSP_XCERD_FIELD(Field)        _MCBSP_XCER_##Field
  #define _MCBSP_XCERE_FIELD(Field)        _MCBSP_XCER_##Field
  #define _MCBSP_XCERF_FIELD(Field)        _MCBSP_XCER_##Field
  #define _MCBSP_XCERG_FIELD(Field)        _MCBSP_XCER_##Field
#endif

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE15: receive enable for channel 15
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE15_SHIFT          (0x000fu)
#define _MCBSP_XCER_XCE15_MK(n)          (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE15_SHIFT)
#define _MCBSP_XCER_XCE15_MASK           (_MCBSP_XCER_XCE15_MK(1))
#define _MCBSP_XCER_XCE15_CLR            (~(_MCBSP_XCER_XCE15_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE14: receive enable for channel 14
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE14_SHIFT          (0x000eu)
#define _MCBSP_XCER_XCE14_MK(n)          (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE14_SHIFT)
#define _MCBSP_XCER_XCE14_MASK           (_MCBSP_XCER_XCE14_MK(1))
#define _MCBSP_XCER_XCE14_CLR            (~(_MCBSP_XCER_XCE14_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE13: receive enable for channel 13
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE13_SHIFT          (0x000du)
#define _MCBSP_XCER_XCE13_MK(n)          (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE13_SHIFT)
#define _MCBSP_XCER_XCE13_MASK           (_MCBSP_XCER_XCE13_MK(1))
#define _MCBSP_XCER_XCE13_CLR            (~(_MCBSP_XCER_XCE13_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE12: receive enable for channel 12
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE12_SHIFT          (0x000cu)
#define _MCBSP_XCER_XCE12_MK(n)          (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE12_SHIFT)
#define _MCBSP_XCER_XCE12_MASK           (_MCBSP_XCER_XCE12_MK(1))
#define _MCBSP_XCER_XCE12_CLR            (~(_MCBSP_XCER_XCE12_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE11: receive enable for channel 11
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE11_SHIFT          (0x000bu)
#define _MCBSP_XCER_XCE11_MK(n)          (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE11_SHIFT)
#define _MCBSP_XCER_XCE11_MASK           (_MCBSP_XCER_XCE11_MK(1))
#define _MCBSP_XCER_XCE11_CLR            (~(_MCBSP_XCER_XCE11_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE10: receive enable for channel 10
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE10_SHIFT          (0x000au)
#define _MCBSP_XCER_XCE10_MK(n)          (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE10_SHIFT)
#define _MCBSP_XCER_XCE10_MASK           (_MCBSP_XCER_XCE10_MK(1))
#define _MCBSP_XCER_XCE10_CLR            (~(_MCBSP_XCER_XCE10_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE9: receive enable for channel 9
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE9_SHIFT           (0x0009u)
#define _MCBSP_XCER_XCE9_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE9_SHIFT)
#define _MCBSP_XCER_XCE9_MASK            (_MCBSP_XCER_XCE9_MK(1))
#define _MCBSP_XCER_XCE9_CLR             (~(_MCBSP_XCER_XCE9_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE8: receive enable for channel 8
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE8_SHIFT           (0x0008u)
#define _MCBSP_XCER_XCE8_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE8_SHIFT)
#define _MCBSP_XCER_XCE8_MASK            (_MCBSP_XCER_XCE8_MK(1))
#define _MCBSP_XCER_XCE8_CLR             (~(_MCBSP_XCER_XCE8_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE7: receive enable for channel 7
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE7_SHIFT           (0x0007u)
#define _MCBSP_XCER_XCE7_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE7_SHIFT)
#define _MCBSP_XCER_XCE7_MASK            (_MCBSP_XCER_XCE7_MK(1))
#define _MCBSP_XCER_XCE7_CLR             (~(_MCBSP_XCER_XCE7_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE6: receive enable for channel 6
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE6_SHIFT           (0x0006u)
#define _MCBSP_XCER_XCE6_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE6_SHIFT)
#define _MCBSP_XCER_XCE6_MASK            (_MCBSP_XCER_XCE6_MK(1))
#define _MCBSP_XCER_XCE6_CLR             (~(_MCBSP_XCER_XCE6_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE5: receive enable for channel 5
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE5_SHIFT           (0x0005u)
#define _MCBSP_XCER_XCE5_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE5_SHIFT)
#define _MCBSP_XCER_XCE5_MASK            (_MCBSP_XCER_XCE5_MK(1))
#define _MCBSP_XCER_XCE5_CLR             (~(_MCBSP_XCER_XCE5_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE4: receive enable for channel 4
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE4_SHIFT           (0x000fu)
#define _MCBSP_XCER_XCE4_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE4_SHIFT)
#define _MCBSP_XCER_XCE4_MASK            (_MCBSP_XCER_XCE4_MK(1))
#define _MCBSP_XCER_XCE4_CLR             (~(_MCBSP_XCER_XCE4_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE3: receive enable for channel 3
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE3_SHIFT           (0x000fu)
#define _MCBSP_XCER_XCE3_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE3_SHIFT)
#define _MCBSP_XCER_XCE3_MASK            (_MCBSP_XCER_XCE3_MK(1))
#define _MCBSP_XCER_XCE3_CLR             (~(_MCBSP_XCER_XCE3_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE2: receive enable for channel 2
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE2_SHIFT           (0x000fu)
#define _MCBSP_XCER_XCE2_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE2_SHIFT)
#define _MCBSP_XCER_XCE2_MASK            (_MCBSP_XCER_XCE2_MK(1))
#define _MCBSP_XCER_XCE2_CLR             (~(_MCBSP_XCER_XCE2_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE1: receive enable for channel 1
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE1_SHIFT           (0x0001u)
#define _MCBSP_XCER_XCE1_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE1_SHIFT)
#define _MCBSP_XCER_XCE1_MASK            (_MCBSP_XCER_XCE1_MK(1))
#define _MCBSP_XCER_XCE1_CLR             (~(_MCBSP_XCER_XCE1_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCE0: receive enable for channel 0
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCE0_SHIFT           (0x0000u)
#define _MCBSP_XCER_XCE0_MK(n)           (((Uint16)(n) & 0x0001u) << _MCBSP_XCER_XCE0_SHIFT)
#define _MCBSP_XCER_XCE0_MASK            (_MCBSP_XCER_XCE0_MK(1))
#define _MCBSP_XCER_XCE0_CLR             (~(_MCBSP_XCER_XCE0_MASK))

/*----------------------------------------------------------------------------*\
* (RW) _MCBSP_XCER_XCER: receive enable for channel 0
\*----------------------------------------------------------------------------*/
#define _MCBSP_XCER_XCER_SHIFT           (0x0000u)
#define _MCBSP_XCER_XCER_MK(n)           (((Uint16)(n) & 0xFFFFu) << _MCBSP_XCER_XCER_SHIFT)
#define _MCBSP_XCER_XCER_MASK            (_MCBSP_XCER_XCER_MK(1))
#define _MCBSP_XCER_XCER_CLR             (~(_MCBSP_XCER_XCER_MASK))


#else
   #ifndef _MCBSP_MOD_ /* _MCBSP_SUPPORT */
     #error MCBSP HAL Not Supported on Specified Target
   #endif
#endif  /* _MCBSP_SUPPORT */

#endif /* _CSL_MCBSPHAL_H_ */
/******************************************************************************\
* end  csl_mcbsphal.h
\******************************************************************************/
